/**
 *    _____ _________    __    ___    ____
 *   / ___// ____/   |  / /   /   |  / __ \
 *   \__ \/ /   / /| | / /   / /| | / /_/ /
 *  ___/ / /___/ ___ |/ /___/ ___ |/ _, _/
 * /____/\____/_/  |_/_____/_/  |_/_/ |_|
 *
 * @scalar/api-reference 1.43.15
 *
 * Website: https://scalar.com
 * GitHub:  https://github.com/scalar/scalar
 * License: https://github.com/scalar/scalar/blob/main/LICENSE
**/

!function(){"use strict";try{if("undefined"!=typeof document){var a=document.createElement("style");a.appendChild(document.createTextNode('.references-classic-header[data-v-9198d025]{display:flex;align-items:center;gap:12px;max-width:var(--refs-content-max-width);margin:auto;padding:12px 0}.references-classic-header-content[data-v-9198d025]{display:flex;gap:12px;flex-grow:1}.references-classic-header-container[data-v-9198d025]{padding:0 60px}@container narrow-references-container (max-width: 900px){.references-classic-header[data-v-9198d025]{padding:12px 24px}.references-classic-header-container[data-v-9198d025]{padding:0}}.references-classic-header-icon[data-v-9198d025]{height:24px;color:var(--scalar-color-1)}.client-libraries-content[data-v-6a49c111]{container:client-libraries-content / inline-size;display:flex;justify-content:center;overflow:hidden;padding:0 12px;background-color:var(--scalar-background-1);border-left:var(--scalar-border-width) solid var(--scalar-border-color);border-right:var(--scalar-border-width) solid var(--scalar-border-color)}.client-libraries[data-v-6a49c111]{display:flex;align-items:center;justify-content:center;width:100%;position:relative;cursor:pointer;white-space:nowrap;padding:8px 2px;gap:6px;color:var(--scalar-color-3);border-bottom:1px solid transparent;-webkit-user-select:none;user-select:none}.client-libraries[data-v-6a49c111]:not(.client-libraries__active):hover:before{content:"";position:absolute;width:calc(100% - 4px);height:calc(100% - 4px);background:var(--scalar-background-2);left:2px;top:2px;z-index:0;border-radius:var(--scalar-radius)}.client-libraries[data-v-6a49c111]:active{color:var(--scalar-color-1)}.client-libraries[data-v-6a49c111]:focus-visible{outline:none;box-shadow:inset 0 0 0 1px var(--scalar-color-accent)}@media screen and (max-width:450px){.client-libraries[data-v-6a49c111]:nth-of-type(4),.client-libraries[data-v-6a49c111]:nth-of-type(5){display:none}}.client-libraries-icon[data-v-6a49c111]{max-width:14px;max-height:14px;min-width:14px;width:100%;aspect-ratio:1;display:flex;align-items:center;justify-content:center;position:relative;box-sizing:border-box;color:currentColor}.client-libraries-icon__more svg[data-v-6a49c111]{height:initial}@container client-libraries-content (width < 400px){.client-libraries__select[data-v-6a49c111]{width:fit-content}.client-libraries__select .client-libraries-icon__more+span[data-v-6a49c111]{display:none}}@container client-libraries-content (width < 380px){.client-libraries[data-v-6a49c111]{width:100%}.client-libraries span[data-v-6a49c111]{display:none}}.client-libraries__active[data-v-6a49c111]{color:var(--scalar-color-1);border-bottom:1px solid var(--scalar-color-1)}@keyframes codeloader-6a49c111{0%{transform:rotate(0)}to{transform:rotate(1turn)}}.client-libraries .client-libraries-text[data-v-6a49c111]{font-size:var(--scalar-small);position:relative;display:flex;align-items:center}.client-libraries__active .client-libraries-text[data-v-6a49c111]{color:var(--scalar-color-1);font-weight:var(--scalar-semibold)}@media screen and (max-width:600px){.references-classic .client-libraries[data-v-6a49c111]{flex-direction:column}}.selected-client[data-v-e59e2ca0]{color:var(--scalar-color-1);font-size:var(--scalar-small);font-family:var(--scalar-font-code);padding:9px 12px;border-top:none;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;background:var(--scalar-background-1);border:var(--scalar-border-width) solid var(--scalar-border-color);border-bottom-left-radius:var(--scalar-radius-lg);border-bottom-right-radius:var(--scalar-radius-lg);min-height:fit-content}.client-libraries-heading[data-v-e59e2ca0]{font-size:var(--scalar-small);font-weight:var(--scalar-font-medium);color:var(--scalar-color-1);padding:9px 12px;background-color:var(--scalar-background-2);display:flex;align-items:center;max-height:32px;border:var(--scalar-border-width) solid var(--scalar-border-color);border-top-left-radius:var(--scalar-radius-lg);border-top-right-radius:var(--scalar-radius-lg)}[data-v-e59e2ca0] .scalar-codeblock-pre .hljs{margin-top:8px}.badge[data-v-3dedb7e4]{color:var(--badge-text-color, var(--scalar-color-2));font-size:var(--scalar-mini);background:var(--badge-background-color, var(--scalar-background-2));border:var(--scalar-border-width) solid var(--badge-border-color, var(--scalar-border-color));padding:2px 6px;border-radius:12px;display:inline-block}.badge.text-orange[data-v-3dedb7e4]{background:color-mix(in srgb,var(--scalar-color-orange),transparent 90%);border:transparent}.badge.text-yellow[data-v-3dedb7e4]{background:color-mix(in srgb,var(--scalar-color-yellow),transparent 90%);border:transparent}.badge.text-red[data-v-3dedb7e4]{background:color-mix(in srgb,var(--scalar-color-red),transparent 90%);border:transparent}.badge.text-purple[data-v-3dedb7e4]{background:color-mix(in srgb,var(--scalar-color-purple),transparent 90%);border:transparent}.badge.text-green[data-v-3dedb7e4]{background:color-mix(in srgb,var(--scalar-color-green),transparent 90%);border:transparent}@layer properties{@supports (((-webkit-hyphens:none)) and (not (margin-trim:inline))) or ((-moz-orient:inline) and (not (color:rgb(from red r g b)))){[data-v-59b5011b],[data-v-59b5011b]:before,[data-v-59b5011b]:after,[data-v-59b5011b]::backdrop{--tw-outline-style:solid}}}.download-container[data-v-59b5011b]{z-index:1;flex-direction:column;gap:16px;width:fit-content;margin:0 .5px 8px;display:flex;position:relative}.download-container[data-v-59b5011b]:has(:focus-visible):before,.download-container.download-both[data-v-59b5011b]:hover:before{content:"";border-radius:var(--scalar-radius-lg);width:calc(100% + 24px);height:90px;box-shadow:var(--scalar-shadow-2);pointer-events:none;background:var(--scalar-background-1);position:absolute;top:-11px;left:-12px}.download-button[data-v-59b5011b]{color:var(--scalar-link-color);cursor:pointer;outline:none;justify-content:center;align-items:center;gap:4px;height:fit-content;padding:0;display:flex;position:relative;white-space:nowrap!important}.download-button[data-v-59b5011b]:before{border-radius:var(--scalar-radius);content:"";width:calc(100% + 18px);height:calc(100% + 16px);position:absolute;top:-8px;left:-9px}.download-button[data-v-59b5011b]:last-of-type:before{width:calc(100% + 15px)}.download-button[data-v-59b5011b]:hover:before{background:var(--scalar-background-2);border:var(--scalar-border-width)solid var(--scalar-border-color)}.download-button[data-v-59b5011b]:focus-visible:before{background:var(--scalar-background-2);border:var(--scalar-border-width)solid var(--scalar-border-color);outline-style:var(--tw-outline-style);outline-width:1px}.download-button span[data-v-59b5011b]{--font-color:var(--scalar-link-color,var(--scalar-color-accent));--font-visited:var(--scalar-link-color-visited,var(--scalar-color-2));-webkit-text-decoration:var(--scalar-text-decoration);text-decoration:var(--scalar-text-decoration);color:var(--font-color);font-weight:var(--scalar-link-font-weight,var(--scalar-semibold));text-underline-offset:.25rem;text-decoration-thickness:1px;-webkit-text-decoration-color:var(--font-color);text-decoration-color:var(--font-color)}@supports (color:color-mix(in lab,red,red)){.download-button span[data-v-59b5011b]{-webkit-text-decoration-color:color-mix(in srgb,var(--font-color)30%,transparent);text-decoration-color:color-mix(in srgb,var(--font-color)30%,transparent)}}.download-button span[data-v-59b5011b]{z-index:1;align-items:center;gap:6px;line-height:1.625;display:flex}.download-button:hover span[data-v-59b5011b]{-webkit-text-decoration-color:var(--scalar-color-1,currentColor);text-decoration-color:var(--scalar-color-1,currentColor);color:var(--scalar-link-color-hover,var(--scalar-color-accent));-webkit-text-decoration:var(--scalar-text-decoration-hover);text-decoration:var(--scalar-text-decoration-hover)}.download-button[data-v-59b5011b]:nth-of-type(2){clip-path:inset(50%);white-space:nowrap;border-width:0;width:1px;height:1px;margin:-1px;padding:0;position:absolute;overflow:hidden}.download-container:has(:focus-visible) .download-button[data-v-59b5011b]:nth-of-type(2),.download-container:hover .download-button[data-v-59b5011b]:nth-of-type(2){clip-path:none;white-space:normal;width:auto;height:auto;margin:0;padding:0;position:absolute;top:42px;overflow:visible}.extension[data-v-59b5011b]{z-index:1;background:var(--scalar-link-color,var(--scalar-color-accent));color:var(--scalar-background-1)}.download-container:has(:focus-visible) .extension[data-v-59b5011b],.download-container:hover .extension[data-v-59b5011b]{opacity:1}.download-link[data-v-59b5011b]{--font-color:var(--scalar-link-color,var(--scalar-color-accent));--font-visited:var(--scalar-link-color-visited,var(--scalar-color-2));-webkit-text-decoration:var(--scalar-text-decoration);text-decoration:var(--scalar-text-decoration);color:var(--font-color);font-weight:var(--scalar-link-font-weight,var(--scalar-semibold));text-underline-offset:.25rem;text-decoration-thickness:1px;-webkit-text-decoration-color:var(--font-color);text-decoration-color:var(--font-color)}@supports (color:color-mix(in lab,red,red)){.download-link[data-v-59b5011b]{-webkit-text-decoration-color:color-mix(in srgb,var(--font-color)30%,transparent);text-decoration-color:color-mix(in srgb,var(--font-color)30%,transparent)}}.download-link[data-v-59b5011b]:hover{--font-color:var(--scalar-link-color,var(--scalar-color-accent));-webkit-text-decoration-color:var(--font-color);text-decoration-color:var(--font-color)}.introduction-card[data-v-a8605b85]{display:flex;flex-direction:column}.introduction-card-row[data-v-a8605b85]{gap:24px}@media(min-width:600px){.introduction-card-row[data-v-a8605b85]{flex-flow:row wrap}}.introduction-card-row[data-v-a8605b85]>*{flex:1}@media(min-width:600px){.introduction-card-row[data-v-a8605b85]>*{min-width:min-content}}@media(max-width:600px){.introduction-card-row[data-v-a8605b85]>*{max-width:100%}}@container (max-width: 900px){.introduction-card-row[data-v-a8605b85]{flex-direction:column;align-items:stretch;gap:0px}}.introduction-card[data-v-a8605b85] .security-scheme-label{text-transform:uppercase;font-weight:var(--scalar-semibold)}.introduction-card-row[data-v-a8605b85] .scalar-card:nth-of-type(2) .scalar-card-header{display:none}.introduction-card-row[data-v-a8605b85] .scalar-card:nth-of-type(2) .scalar-card-header.scalar-card--borderless+.scalar-card-content{margin-top:0}.section[data-v-be4443e9]{position:relative;display:flex;flex-direction:column;max-width:var(--refs-content-max-width);margin:auto;padding:90px 0;scroll-margin-top:var(--refs-viewport-offset)}.section[data-v-be4443e9]:has(~div.contents){border-bottom:var(--scalar-border-width) solid var(--scalar-border-color)}.references-classic .section[data-v-be4443e9]{padding:48px 0;gap:24px}@container narrow-references-container (max-width: 900px){.references-classic .section[data-v-be4443e9],.section[data-v-be4443e9]{padding:48px 24px}}.section[data-v-be4443e9]:not(:last-of-type){border-bottom:var(--scalar-border-width) solid var(--scalar-border-color)}.section-wrapper[data-v-ff689b94]{color:var(--scalar-color-1);padding-top:12px;margin-top:-12px}.section-accordion[data-v-ff689b94]{display:flex;flex-direction:column;border-radius:var(--scalar-radius-lg);background:var(--scalar-background-2);scroll-margin-top:var(--refs-viewport-offset)}.section-accordion-transparent[data-v-ff689b94]{background:transparent;border:var(--scalar-border-width) solid var(--scalar-border-color)}.section-accordion-button[data-v-ff689b94]{padding:6px}.section-accordion-button[data-v-ff689b94]{display:flex;align-items:center;gap:6px;cursor:pointer}.section-accordion-button-content[data-v-ff689b94]{flex:1;min-width:0}.section-accordion-button-actions[data-v-ff689b94]{display:flex;align-items:center;gap:6px;color:var(--scalar-color-3)}.section-accordion-chevron[data-v-ff689b94]{margin-right:4px;cursor:pointer;opacity:1;color:var(--scalar-color-3)}.section-accordion-button:hover .section-accordion-chevron[data-v-ff689b94]{color:var(--scalar-color-1)}.section-accordion-content[data-v-ff689b94]{border-top:var(--scalar-border-width) solid var(--scalar-border-color);display:flex;flex-direction:column}.section-accordion-description[data-v-ff689b94]{font-weight:var(--scalar-semibold);font-size:var(--scalar-mini);color:var(--scalar-color--1);padding:10px 12px 0}.section-accordion-content-card[data-v-ff689b94] .property:last-of-type{padding-bottom:9px}.section-column[data-v-699c28e3]{flex:1;min-width:0}@container narrow-references-container (max-width: 900px){.section-column[data-v-699c28e3]:nth-of-type(2){padding-top:0}}.section-columns[data-v-8b9602bf]{display:flex;gap:48px}@container narrow-references-container (max-width: 900px){.section-columns[data-v-8b9602bf]{flex-direction:column;gap:24px}}.section-container[data-v-20a1472a]{position:relative;padding:0 60px;width:100%;border-top:var(--scalar-border-width) solid var(--scalar-border-color)}.section-container[data-v-20a1472a]:has(.introduction-section){border-top:none}@container narrow-references-container (max-width: 900px){.section-container[data-v-20a1472a]{padding:0}}.section-accordion-wrapper[data-v-9419dd23]{padding:0 60px}.section-accordion[data-v-9419dd23]{position:relative;width:100%;max-width:var(--refs-content-max-width);margin:auto}.section-accordion-content[data-v-9419dd23]{display:flex;flex-direction:column;gap:12px;padding-top:12px}.section-accordion-button[data-v-9419dd23]{width:100%;display:flex;cursor:pointer;padding:6px 0;margin:-6px 0;border-radius:var(--scalar-radius)}.section-accordion-chevron[data-v-9419dd23]{position:absolute;left:-22px;top:12px;color:var(--scalar-color-3)}.section-accordion-button:hover .section-accordion-chevron[data-v-9419dd23]{color:var(--scalar-color-1)}.section-accordion-title[data-v-9419dd23]{display:flex;flex-direction:column;align-items:flex-start;flex:1;padding:0 6px}.section-accordion-title[data-v-9419dd23] .section-header-wrapper{grid-template-columns:1fr}.section-accordion-title[data-v-9419dd23] .section-header{margin-bottom:0}@container narrow-references-container (max-width: 900px){.section-accordion-chevron[data-v-9419dd23]{width:16px;left:-16px;top:14px}.section-accordion-wrapper[data-v-9419dd23]{padding:calc(var(--refs-viewport-offset)) 24px 0 24px}}.loading[data-v-8e0226d7]{background:var(--scalar-background-3);animation:loading-skeleton-8e0226d7 1.5s infinite alternate;border-radius:var(--scalar-radius-lg);min-height:1.6em;margin:.6em 0;max-width:100%}.loading[data-v-8e0226d7]:first-of-type{min-height:3em;margin-bottom:24px;margin-top:0}.loading[data-v-8e0226d7]:last-of-type{width:60%}.loading.single-line[data-v-8e0226d7]{min-height:3em;margin:.6em 0;max-width:80%}@keyframes loading-skeleton-8e0226d7{0%{opacity:1}to{opacity:.33}}@container narrow-references-container (max-width: 900px){.section-content--with-columns[data-v-9735459e]{flex-direction:column;gap:24px}}.section-header-wrapper[data-v-465a7a78]{grid-template-columns:1fr;display:grid}@media(min-width:1200px){.section-header-wrapper[data-v-465a7a78]{grid-template-columns:repeat(2,1fr)}}.section-header[data-v-465a7a78]{font-size:var(--font-size,var(--scalar-heading-1));font-weight:var(--font-weight,var(--scalar-bold));color:var(--scalar-color-1);word-wrap:break-word;margin-top:0;margin-bottom:12px;line-height:1.45}.section-header.tight[data-v-465a7a78]{margin-bottom:6px}.section-header.loading[data-v-465a7a78]{width:80%}.section-header-label[data-v-f1ac6c38]{display:inline}.screenreader-only[data-v-df2e1026]{position:absolute;width:1px;height:1px;padding:0;margin:-1px;overflow:hidden;clip:rect(0,0,0,0);border:0}.collapsible-section[data-v-999a158a]{border-top:var(--scalar-border-width) solid var(--scalar-border-color);position:relative}.collapsible-section-header[data-v-999a158a]{color:var(--scalar-color-1)}.collapsible-section .collapsible-section-trigger[data-v-999a158a]{display:flex;align-items:center;cursor:pointer;padding:10px 0;font-size:var(--scalar-font-size-3);z-index:1;position:relative}.collapsible-section-trigger svg[data-v-999a158a]{color:var(--scalar-color-3);position:absolute;left:-19px}.collapsible-section:hover .collapsible-section-trigger svg[data-v-999a158a]{color:var(--scalar-color-1)}.collapsible-section .collapsible-section-trigger[data-v-999a158a] .anchor-copy{line-height:18.5px}.collapsible-section-content[data-v-999a158a]{padding:0;margin:0 0 10px;scroll-margin-top:140px}.references-classic .introduction-description[data-v-fe80002d] img{max-width:720px}.icons-only[data-v-0939d4d9] span{display:none}.sticky-cards[data-v-0b1e2255]{display:flex;flex-direction:column;position:sticky;top:calc(var(--refs-viewport-offset) + 24px)}.introduction-card-item[data-v-708aae59]{display:flex;margin-bottom:12px;flex-direction:column;justify-content:start}.introduction-card-item[data-v-708aae59]:has(.description) .server-form-container{border-bottom-left-radius:0;border-bottom-right-radius:0}.introduction-card-item[data-v-708aae59] .request-item{border-bottom:0}.schema-type-icon[data-v-70cb5c13]{color:var(--scalar-color-1);display:none}.schema-type[data-v-70cb5c13]{font-family:var(--scalar-font-code);color:var(--scalar-color-1)}.property-enum-value[data-v-88bc950e]{color:var(--scalar-color-3);line-height:1.5;overflow-wrap:break-word;display:flex;align-items:stretch;position:relative;--decorator-width: 1px;--decorator-color: color-mix( in srgb, var(--scalar-background-1), var(--scalar-color-1) 25% )}.property-enum-value-content[data-v-88bc950e]{display:flex;flex-direction:column;padding:3px 0}.property-enum-value-label[data-v-88bc950e]{display:flex;font-family:var(--scalar-font-code);color:var(--scalar-color-1);position:relative}.property-enum-value:last-of-type .property-enum-value-label[data-v-88bc950e]{padding-bottom:0}.property-enum-value[data-v-88bc950e]:before{content:"";margin-right:12px;width:var(--decorator-width);display:block;background-color:var(--decorator-color)}.property-enum-value[data-v-88bc950e]:last-of-type:before,.property-enum-values:has(.enum-toggle-button) .property-enum-value[data-v-88bc950e]:nth-last-child(2):before{height:calc(.5lh + 4px)}.property-enum-value-label[data-v-88bc950e]:after{content:"";position:absolute;top:.5lh;left:-12px;width:8px;height:var(--decorator-width);background-color:var(--decorator-color)}.property-enum-value[data-v-88bc950e]:last-of-type:after{bottom:0;height:50%;background:var(--scalar-background-1);border-top:var(--scalar-border-width) solid var(--decorator-color)}.property-enum-value-description[data-v-88bc950e]{color:var(--scalar-color-3)}.property-heading:empty+.property-description[data-v-d4946030]:last-of-type,.property-description[data-v-d4946030]:first-of-type:last-of-type{margin-top:0}.property-list[data-v-d4946030]{border:var(--scalar-border-width) solid var(--scalar-border-color);border-radius:var(--scalar-radius);margin-top:10px}.property-list .property[data-v-d4946030]:last-of-type{padding-bottom:10px}.property-enum-values[data-v-d4946030]{font-size:var(--scalar-font-size-3);list-style:none;margin-top:8px;padding-left:2px}.enum-toggle-button[data-v-d4946030]:hover{color:var(--scalar-color-1)}.property-detail[data-v-827ea49d]{display:inline-flex}.property-detail+.property-detail[data-v-827ea49d]:before{display:block;content:"·";margin:0 .5ch}.property-detail-truncate[data-v-827ea49d]{overflow:hidden}.property-detail-truncate>.property-detail-value[data-v-827ea49d]{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.property-detail-prefix[data-v-827ea49d]{color:var(--scalar-color-2)}code.property-detail-value[data-v-827ea49d]{font-family:var(--scalar-font-code);font-size:var(--scalar-font-size-3);color:var(--scalar-color-2);background:var(--scalar-background-3);padding:0 4px;border:.5px solid var(--scalar-border-color);border-radius:var(--scalar-radius)}.property-example[data-v-72def0ea]{display:flex;flex-direction:column;font-size:var(--scalar-mini);position:relative}.property-example[data-v-72def0ea]:hover:before{content:"";position:absolute;top:0;left:0;width:100%;height:20px;border-radius:var(--scalar-radius)}.property-example:hover .property-example-label span[data-v-72def0ea]{color:var(--scalar-color-1)}.property-example-label span[data-v-72def0ea]{color:var(--scalar-color-3);position:relative;border-bottom:var(--scalar-border-width) dotted currentColor}.property-example-value[data-v-72def0ea]{font-family:var(--scalar-font-code);display:flex;gap:8px;align-items:center;width:100%;padding:6px}.property-example-value span[data-v-72def0ea]{display:block;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.property-example-value[data-v-72def0ea] svg{color:var(--scalar-color-3)}.property-example-value[data-v-72def0ea]:hover svg{color:var(--scalar-color-1)}.property-example-value[data-v-72def0ea]{background:var(--scalar-background-2);border:var(--scalar-border-width) solid var(--scalar-border-color);border-radius:var(--scalar-radius)}.property-example-value-list[data-v-72def0ea]{position:absolute;top:18px;left:50%;transform:translate3d(-50%,0,0);overflow:auto;background-color:var(--scalar-background-1);box-shadow:var(--scalar-shadow-1);border-radius:var(--scalar-radius-lg);border:var(--scalar-border-width) solid var(--scalar-border-color);padding:9px;min-width:200px;max-width:300px;flex-direction:column;gap:3px;display:none;z-index:2}.property-example:hover .property-example-value-list[data-v-72def0ea],.property-example:focus-within .property-example-value-list[data-v-72def0ea]{display:flex}.property-heading[data-v-5d03e993]{display:flex;flex-wrap:wrap;align-items:baseline;row-gap:9px;white-space:nowrap}.property-heading[data-v-5d03e993]:has(+.children),.property-heading[data-v-5d03e993]:has(+.property-rule){margin-bottom:9px}.property-heading[data-v-5d03e993]>*{margin-right:9px}.property-heading[data-v-5d03e993]:last-child{margin-right:0}.property-heading>.property-detail[data-v-5d03e993]:not(:last-of-type){margin-right:0}.property-name[data-v-5d03e993]{max-width:100%;font-family:var(--scalar-font-code);font-weight:var(--scalar-semibold);font-size:var(--scalar-font-size-3);white-space:normal;overflow-wrap:break-word}.property-additional[data-v-5d03e993]{font-family:var(--scalar-font-code)}.property-required[data-v-5d03e993],.property-optional[data-v-5d03e993]{color:var(--scalar-color-2)}.property-required[data-v-5d03e993]{font-size:var(--scalar-mini);color:var(--scalar-color-orange)}.property-read-only[data-v-5d03e993]{font-size:var(--scalar-mini);color:var(--scalar-color-blue)}.property-write-only[data-v-5d03e993]{font-size:var(--scalar-mini);color:var(--scalar-color-green)}.property-discriminator[data-v-5d03e993]{font-size:var(--scalar-mini);color:var(--scalar-color-purple)}.property-detail[data-v-5d03e993]{font-size:var(--scalar-mini);color:var(--scalar-color-2);display:flex;align-items:center;min-width:0}.property-const[data-v-5d03e993]{color:var(--scalar-color-1)}.deprecated[data-v-5d03e993]{text-decoration:line-through}.property[data-v-7ddcdaa6]{color:var(--scalar-color-1);display:flex;flex-direction:column;padding:8px;font-size:var(--scalar-small);position:relative}.property.property--level-0[data-v-7ddcdaa6]:has(>.property-rule>.schema-card>.schema-properties.schema-properties-open>ul>li.property){padding-top:0}.property--compact.property--level-0[data-v-7ddcdaa6],.property--compact.property--level-1[data-v-7ddcdaa6]{padding:8px 0}.composition-panel .property.property.property.property--level-0[data-v-7ddcdaa6]{padding:0}.property--compact.property--level-0 .composition-panel .property--compact.property--level-1[data-v-7ddcdaa6]{padding:8px}.property[data-v-7ddcdaa6]:has(>.property-rule:nth-of-type(1)):not(.property--compact){padding-top:8px;padding-bottom:8px}.property--deprecated[data-v-7ddcdaa6]{background:repeating-linear-gradient(-45deg,var(--scalar-background-2) 0,var(--scalar-background-2) 2px,transparent 2px,transparent 5px);background-size:100%}.property--deprecated[data-v-7ddcdaa6]>*{opacity:.75}.property-description[data-v-7ddcdaa6]{margin-top:6px;line-height:1.4;font-size:var(--scalar-small)}.property-description[data-v-7ddcdaa6]:has(+.property-rule){margin-bottom:9px}[data-v-7ddcdaa6] .property-description *{color:var(--scalar-color-2)!important}.property[data-v-7ddcdaa6]:not(:last-of-type){border-bottom:var(--scalar-border-width) solid var(--scalar-border-color)}.property-description+.children[data-v-7ddcdaa6],.children+.property-rule[data-v-7ddcdaa6]{margin-top:9px}.children[data-v-7ddcdaa6]{display:flex;flex-direction:column}.children .property--compact.property--level-1[data-v-7ddcdaa6]{padding:12px}.property-example-value[data-v-7ddcdaa6]{all:unset;font-family:var(--scalar-font-code);padding:6px;border-top:var(--scalar-border-width) solid var(--scalar-border-color)}.property-rule[data-v-7ddcdaa6]{border-radius:var(--scalar-radius-lg);display:flex;flex-direction:column}.property-rule[data-v-7ddcdaa6] .composition-panel .schema-card .schema-properties.schema-properties-open{border-top-left-radius:0;border-top-right-radius:0}.property-rule[data-v-7ddcdaa6] .composition-panel>.schema-card>.schema-card-description{padding-left:8px;padding-right:8px;border-left:1px solid var(--scalar-border-color);border-right:1px solid var(--scalar-border-color)}.property-rule[data-v-7ddcdaa6] .composition-panel>.schema-card>.schema-card-description+.schema-properties{margin-top:0}.property-example[data-v-7ddcdaa6]{background:transparent;border:none;display:flex;flex-direction:row;gap:8px}.property-example-label[data-v-7ddcdaa6],.property-example-value[data-v-7ddcdaa6]{padding:3px 0 0}.property-example-value[data-v-7ddcdaa6]{background:var(--scalar-background-2);border-top:0;border-radius:var(--scalar-radius);padding:3px 4px}.property-name[data-v-7ddcdaa6]{font-family:var(--scalar-font-code);font-weight:var(--scalar-semibold)}.property-name-additional-properties[data-v-7ddcdaa6]:before,.property-name-pattern-properties[data-v-7ddcdaa6]:before{text-transform:uppercase;font-size:var(--scalar-micro);display:inline-block;padding:2px 4px;border-radius:var(--scalar-radius);color:var(--scalar-color-1);border:1px solid var(--scalar-border-color);background-color:var(--scalar-background-2);margin-right:4px}.property-name-pattern-properties[data-v-7ddcdaa6]:before{content:"regex"}.property-name-additional-properties[data-v-7ddcdaa6]:before{content:"unknown property name"}.error[data-v-4d81600f]{background-color:var(--scalar-color-red)}.schema-card[data-v-4d81600f]{font-size:var(--scalar-font-size-4);color:var(--scalar-color-1)}.schema-card-title[data-v-4d81600f]{height:var(--schema-title-height);padding:6px 8px;display:flex;align-items:center;gap:4px;color:var(--scalar-color-2);font-weight:var(--scalar-semibold);font-size:var(--scalar-mini);border-bottom:var(--scalar-border-width) solid transparent}button.schema-card-title[data-v-4d81600f]{cursor:pointer}button.schema-card-title[data-v-4d81600f]:hover{color:var(--scalar-color-1)}.schema-card-title-icon--open[data-v-4d81600f]{transform:rotate(45deg)}.schema-properties-open>.schema-card-title[data-v-4d81600f]{border-bottom-left-radius:0;border-bottom-right-radius:0;border-bottom:var(--scalar-border-width) solid var(--scalar-border-color)}.schema-properties-open>.schema-properties[data-v-4d81600f]{width:fit-content}.schema-card-description[data-v-4d81600f]{color:var(--scalar-color-2)}.schema-card-description+.schema-properties[data-v-4d81600f]{width:fit-content}.schema-card-description+.schema-properties[data-v-4d81600f]{margin-top:8px}.schema-properties-open.schema-properties[data-v-4d81600f],.schema-properties-open>.schema-card--open[data-v-4d81600f]{width:100%}.schema-properties[data-v-4d81600f]{display:flex;flex-direction:column;border:var(--scalar-border-width) solid var(--scalar-border-color);border-radius:var(--scalar-radius-lg);width:fit-content}.schema-properties-name[data-v-4d81600f]{width:100%}.schema-properties .schema-properties[data-v-4d81600f]{border-radius:13.5px}.schema-properties .schema-properties.schema-properties-open[data-v-4d81600f]{border-radius:var(--scalar-radius-lg)}.schema-properties-open[data-v-4d81600f]{width:100%}.schema-card--compact[data-v-4d81600f]{align-self:flex-start}.schema-card--compact.schema-card--open[data-v-4d81600f]{align-self:initial}.schema-card-title--compact[data-v-4d81600f]{color:var(--scalar-color-2);padding:6px 10px 6px 8px;height:auto;border-bottom:none}.schema-card-title--compact>.schema-card-title-icon[data-v-4d81600f]{margin:0}.schema-card-title--compact>.schema-card-title-icon--open[data-v-4d81600f]{transform:rotate(45deg)}.schema-properties-open>.schema-card-title--compact[data-v-4d81600f]{position:static}.property--level-0>.schema-properties>.schema-card--level-0>.schema-properties[data-v-4d81600f]{border:none}.property--level-0 .schema-card--level-0:not(.schema-card--compact) .property--level-1[data-v-4d81600f]{padding:0 0 8px}:not(.composition-panel)>.schema-card--compact.schema-card--level-0>.schema-properties[data-v-4d81600f]{border:none}[data-v-4d81600f] .schema-card-description p{font-size:var(--scalar-small, var(--scalar-paragraph));color:var(--scalar-color-2);line-height:1.5;display:block;margin-bottom:6px}.children .schema-card-description[data-v-4d81600f]:first-of-type{padding-top:0}.reference-models-anchor[data-v-161968a4]{display:flex;align-items:center;font-size:20px;padding-left:6px;color:var(--scalar-color-1)}.reference-models-label[data-v-161968a4]{display:block;font-size:var(--scalar-mini)}.reference-models-label[data-v-161968a4] em{font-weight:var(--scalar-bold)}.show-more[data-v-d1c2b649]{appearance:none;border:none;border:var(--scalar-border-width) solid var(--scalar-border-color);margin:auto;padding:8px 12px 8px 16px;border-radius:30px;color:var(--scalar-color-1);font-weight:var(--scalar-semibold);font-size:var(--scalar-small);display:flex;align-items:center;justify-content:center;position:relative;gap:6px;top:-48px}.show-more[data-v-d1c2b649]:hover{background:var(--scalar-background-2);cursor:pointer}.show-more[data-v-d1c2b649]:active{box-shadow:0 0 0 1px var(--scalar-border-color)}@container narrow-references-container (max-width: 900px){.show-more[data-v-d1c2b649]{top:-24px}}.tag-section[data-v-1124be5d]{margin-bottom:48px}.tag-name[data-v-1124be5d]{text-transform:capitalize}.tag-description[data-v-1124be5d]{padding-bottom:4px;text-align:left}.endpoint[data-v-ad8530a6]{display:flex;white-space:nowrap;cursor:pointer;text-decoration:none}.endpoint:hover .endpoint-path[data-v-ad8530a6],.endpoint:focus-visible .endpoint-path[data-v-ad8530a6]{text-decoration:underline}.endpoint .post[data-v-ad8530a6],.endpoint .get[data-v-ad8530a6],.endpoint .delete[data-v-ad8530a6],.endpoint .put[data-v-ad8530a6]{white-space:nowrap}.endpoint-method[data-v-ad8530a6],.endpoint-path[data-v-ad8530a6]{color:var(--scalar-color-1);min-width:62px;display:inline-flex;line-height:1.55;font-family:var(--scalar-font-code);font-size:var(--scalar-small);cursor:pointer}.endpoint-method[data-v-ad8530a6]{text-align:right}.endpoint-path[data-v-ad8530a6]{margin-left:12px;text-transform:initial}.deprecated[data-v-ad8530a6]{text-decoration:line-through}.endpoints-card[data-v-f726f753]{position:sticky;top:calc(var(--refs-viewport-offset) + 24px);font-size:var(--scalar-font-size-3)}.endpoints[data-v-f726f753]{overflow:auto;background:var(--scalar-background-2);padding:10px 12px;width:100%}.section-container[data-v-d207e09e]{border-top:var(--scalar-border-width) solid var(--scalar-border-color)}.section-container[data-v-d207e09e]:has(.show-more){background-color:color-mix(in srgb,var(--scalar-background-2),transparent)}.operation-path[data-v-ec6c8861]{overflow:hidden;word-wrap:break-word;font-weight:var(--scalar-semibold);line-break:anywhere}.deprecated[data-v-ec6c8861]{text-decoration:line-through}.empty-state[data-v-ab9ce344]{margin:10px 0 10px 12px;text-align:center;font-size:var(--scalar-mini);min-height:56px;display:flex;align-items:center;justify-content:center;border-radius:var(--scalar-radius-lg);color:var(--scalar-color-2)}.rule-title[data-v-ab9ce344]{font-family:var(--scalar-font-code);color:var(--scalar-color-1);display:inline-block;margin:12px 0 6px;border-radius:var(--scalar-radius)}.rule[data-v-ab9ce344]{margin:0 12px;border-radius:var(--scalar-radius-lg)}.rule-items[data-v-ab9ce344]{counter-reset:list-number;display:flex;flex-direction:column;gap:12px;border-left:1px solid var(--scalar-border-color);padding:12px 0}.rule-item[data-v-ab9ce344]{counter-increment:list-number;border:1px solid var(--scalar-border-color);border-radius:var(--scalar-radius-lg);overflow:hidden;margin-left:24px}.rule-item[data-v-ab9ce344]:before{border:1px solid var(--scalar-border-color);border-top:0;border-right:0;content:" ";display:block;width:24px;height:6px;border-radius:0 0 0 var(--scalar-radius-lg);margin-top:6px;color:var(--scalar-color-2);transform:translate(-25px);color:var(--scalar-color-1);position:absolute}.tab[data-v-c8207e48]{background:none;border:none;font-size:var(--scalar-small);font-family:var(--scalar-font);font-weight:var(--scalar-font-normal);color:var(--scalar-color-2);line-height:calc(var(--scalar-small) + 2px);white-space:nowrap;cursor:pointer;padding:0;margin-right:3px;text-transform:uppercase;position:relative;line-height:22px}.tab[data-v-c8207e48]:before{content:"";position:absolute;z-index:0;left:-6px;top:-6px;width:calc(100% + 12px);height:calc(100% + 12px);border-radius:var(--scalar-radius);background:var(--scalar-background-3);opacity:0}.tab[data-v-c8207e48]:hover:before,.tab[data-v-c8207e48]:focus-visible:before{opacity:1}.tab[data-v-c8207e48]:focus-visible:before{outline:1px solid var(--scalar-color-accent)}.tab span[data-v-c8207e48]{z-index:1;position:relative}.tab-selected[data-v-c8207e48]{color:var(--scalar-color-1);font-weight:var(--scalar-semibold)}.tab-selected[data-v-c8207e48]:after{content:"";position:absolute;background:currentColor;width:100%;left:0;height:1px;bottom:calc(var(--tab-list-padding-y) * -1)}.tab-list[data-v-fec8fbbb]{display:flex;gap:6px;position:relative;flex:1;--tab-list-padding-y: 7px;--tab-list-padding-x: 12px;padding:var(--tab-list-padding-y) var(--tab-list-padding-x);overflow:auto}.scalar-card-header.scalar-card-header-tabs[data-v-fec8fbbb]{padding:0}.response-card[data-v-97958459]{font-size:var(--scalar-font-size-3)}.markdown[data-v-97958459] *{margin:0}.code-copy[data-v-97958459]{display:flex;align-items:center;justify-content:center;appearance:none;-webkit-appearance:none;outline:none;background:transparent;cursor:pointer;color:var(--scalar-color-3);border:none;padding:0;margin-right:12px}.code-copy[data-v-97958459]:hover{color:var(--scalar-color-1)}.code-copy svg[data-v-97958459]{width:13px;height:13px}.response-card-footer[data-v-97958459]{display:flex;flex-direction:row;justify-content:space-between;flex-shrink:0;padding:7px 12px;gap:8px}.response-example-selector[data-v-97958459]{align-self:flex-start;margin:-4px}.response-description[data-v-97958459]{font-weight:var(--scalar-semibold);font-size:var(--scalar-small);color:var(--scalar-color--1);display:flex;align-items:center;box-sizing:border-box}.schema-type[data-v-97958459]{font-size:var(--scalar-micro);color:var(--scalar-color-2);font-weight:var(--scalar-semibold);background:var(--scalar-background-3);padding:2px 4px;border-radius:4px;margin-right:4px}.schema-example[data-v-97958459]{font-size:var(--scalar-micro);color:var(--scalar-color-2);font-weight:var(--scalar-semibold)}.example-response-tab[data-v-97958459]{display:block;margin:6px}.scalar-card-checkbox[data-v-97958459]{display:flex;align-items:center;justify-content:center;position:relative;min-height:17px;cursor:pointer;-webkit-user-select:none;user-select:none;font-size:var(--scalar-small);font-weight:var(--scalar-font-normal);color:var(--scalar-color-2);width:fit-content;white-space:nowrap;gap:6px;padding:7px 6px}.scalar-card-checkbox:has(.scalar-card-checkbox-input:focus-visible) .scalar-card-checkbox-checkmark[data-v-97958459]{outline:1px solid var(--scalar-color-accent)}.scalar-card-checkbox[data-v-97958459]:hover{color:var(--scalar-color--1)}.scalar-card-checkbox .scalar-card-checkbox-input[data-v-97958459]{position:absolute;opacity:0;cursor:pointer;height:0;width:0}.scalar-card-checkbox-checkmark[data-v-97958459]{height:16px;width:16px;border-radius:var(--scalar-radius);background-color:transparent;background-color:var(--scalar-background-3);box-shadow:inset 0 0 0 var(--scalar-border-width) var(--scalar-border-color)}.scalar-card-checkbox[data-v-97958459]:has(.scalar-card-checkbox-input:checked){color:var(--scalar-color-1);font-weight:var(--scalar-semibold)}.scalar-card-checkbox .scalar-card-checkbox-input:checked~.scalar-card-checkbox-checkmark[data-v-97958459]{background-color:var(--scalar-button-1);box-shadow:none}.scalar-card-checkbox-checkmark[data-v-97958459]:after{content:"";position:absolute;display:none}.scalar-card-checkbox .scalar-card-checkbox-input:checked~.scalar-card-checkbox-checkmark[data-v-97958459]:after{display:block}.scalar-card-checkbox .scalar-card-checkbox-checkmark[data-v-97958459]:after{right:11.5px;top:12.5px;width:5px;height:9px;border:solid 1px var(--scalar-button-1-color);border-width:0 1.5px 1.5px 0;transform:rotate(45deg)}.headers-card[data-v-6fb09984]{z-index:0;margin-top:12px;margin-bottom:6px;position:relative;font-size:var(--scalar-font-size-4);color:var(--scalar-color-1);align-self:flex-start}.headers-card.headers-card--open[data-v-6fb09984]{align-self:initial}.headers-card-title[data-v-6fb09984]{padding:6px 10px;display:flex;align-items:center;gap:4px;color:var(--scalar-color-3);font-weight:var(--scalar-semibold);font-size:var(--scalar-micro);border-radius:13.5px}button.headers-card-title[data-v-6fb09984]{cursor:pointer}button.headers-card-title[data-v-6fb09984]:hover{color:var(--scalar-color-1)}.headers-card-title-icon--open[data-v-6fb09984]{transform:rotate(45deg)}.headers-properties[data-v-6fb09984]{display:flex;flex-direction:column;border:var(--scalar-border-width) solid var(--scalar-border-color);border-radius:13.5px;width:fit-content}.headers-properties-open>.headers-card-title[data-v-6fb09984]{border-bottom-left-radius:0;border-bottom-right-radius:0;border-bottom:var(--scalar-border-width) solid var(--scalar-border-color)}.headers-properties-open[data-v-6fb09984]{border-radius:var(--scalar-radius-lg);width:100%}.headers-card .property[data-v-6fb09984]:last-of-type{padding-bottom:10px}.headers-card-title>.headers-card-title-icon[data-v-6fb09984]{width:10px;height:10px;margin:0}.headers-card-title>.headers-card-title-icon--open[data-v-6fb09984]{transform:rotate(45deg)}.parameter-item[data-v-2b6dfab9]{display:flex;flex-direction:column;border-top:var(--scalar-border-width) solid var(--scalar-border-color)}.parameter-item:last-of-type .parameter-schema[data-v-2b6dfab9]{padding-bottom:0}.parameter-item-container[data-v-2b6dfab9]{padding:0}.parameter-item-headers[data-v-2b6dfab9]{border:var(--scalar-border-width) solid var(--scalar-border-color)}.parameter-item-name[data-v-2b6dfab9]{position:relative;font-weight:var(--scalar-semibold);font-size:var(--scalar-font-size-3);font-family:var(--scalar-font-code);color:var(--scalar-color-1);overflow-wrap:break-word}.parameter-item-description[data-v-2b6dfab9],.parameter-item-description-summary[data-v-2b6dfab9]{font-size:var(--scalar-mini);color:var(--scalar-color-2)}.parameter-item-description-summary.parameter-item-description-summary[data-v-2b6dfab9]>*{--markdown-line-height: 1}.parameter-item-trigger+.parameter-item-container[data-v-2b6dfab9] .property--level-0>.property-heading .property-detail-value{font-size:var(--scalar-micro)}.parameter-item-required-optional[data-v-2b6dfab9]{color:var(--scalar-color-2);font-weight:var(--scalar-semibold);margin-right:6px;position:relative}.parameter-item--required[data-v-2b6dfab9]{text-transform:uppercase;font-size:var(--scalar-micro);font-weight:var(--scalar-semibold);color:var(--scalar-color-orange)}.parameter-item-description[data-v-2b6dfab9],.parameter-item-description[data-v-2b6dfab9] p{margin-top:4px;font-size:var(--scalar-small);color:var(--scalar-color-2);line-height:1.4}.parameter-schema[data-v-2b6dfab9]{padding-bottom:9px;margin-top:3px}.parameter-item-trigger[data-v-2b6dfab9]{display:flex;align-items:baseline;gap:6px;flex-wrap:wrap;padding:12px 0;outline:none}.parameter-item-trigger-open[data-v-2b6dfab9]{padding-bottom:0}.parameter-item-trigger[data-v-2b6dfab9]:after{content:"";position:absolute;height:10px;width:100%;bottom:0}.parameter-item-icon[data-v-2b6dfab9]{color:var(--scalar-color-3);left:-19px;top:.5lh;translate:0 -50%;position:absolute}.parameter-item-trigger:hover .parameter-item-icon[data-v-2b6dfab9],.parameter-item-trigger:focus-visible .parameter-item-icon[data-v-2b6dfab9]{color:var(--scalar-color-1)}.parameter-item-trigger:focus-visible .parameter-item-icon[data-v-2b6dfab9]{outline:1px solid var(--scalar-color-accent);outline-offset:2px;border-radius:var(--scalar-radius)}.request-body[data-v-e9972a68]{margin-top:24px}.request-body-header[data-v-e9972a68]{display:flex;align-items:center;justify-content:space-between;padding-bottom:12px;border-bottom:var(--scalar-border-width) solid var(--scalar-border-color);flex-flow:wrap}.request-body-title[data-v-e9972a68]{display:flex;align-items:center;gap:8px;font-size:var(--scalar-font-size-2);font-weight:var(--scalar-semibold);color:var(--scalar-color-1)}.request-body-required[data-v-e9972a68]{font-size:var(--scalar-micro);color:var(--scalar-color-orange);font-weight:400}.request-body-description[data-v-e9972a68]{margin-top:6px;font-size:var(--scalar-small);width:100%}.request-body-header+.request-body-schema[data-v-e9972a68]:has(>.schema-card>.schema-card-description),.request-body-header+.request-body-schema[data-v-e9972a68]:has(>.schema-card>.schema-properties>*>.property--level-0){padding-top:8px}.request-body-description[data-v-e9972a68] .markdown *{color:var(--scalar-color-2)!important}.callback-sticky-offset[data-v-102d2096]{top:var(--refs-viewport-offset, 0px);z-index:1}.callback-operation-container[data-v-102d2096] .request-body,.callback-operation-container[data-v-102d2096] .request-body-description,.callback-operation-container[data-v-102d2096] .request-body-header{margin-top:0}.callback-operation-container[data-v-102d2096] .request-body-header{--scalar-font-size-2: var(--scalar-font-size-4);padding:8px;border-bottom:none;border:.5px solid var(--scalar-border-color);border-radius:var(--scalar-radius-lg) var(--scalar-radius-lg) 0 0;background:color-mix(in srgb,var(--scalar-background-2) 50%,transparent)}.callback-operation-container[data-v-102d2096] .request-body-schema>.schema-card>.schema-card-description{padding-inline:8px}.callback-operation-container[data-v-102d2096] ul li.property.property--level-1{padding:8px}.callback-operation-container[data-v-102d2096] .request-body-schema{background-color:var(--scalar-background-1);border:var(--scalar-border-width) solid var(--scalar-border-color);border-top:none;overflow:hidden;border-radius:0 0 var(--scalar-radius-lg) var(--scalar-radius-lg)}.callback-operation-container[data-v-102d2096] .parameter-list{margin-top:0}.callback-operation-container[data-v-102d2096] .parameter-list-title{background:color-mix(in srgb,var(--scalar-background-2) 50%,transparent);border-radius:var(--scalar-radius-lg) var(--scalar-radius-lg) 0 0;padding:8px;margin-bottom:0;border:var(--scalar-border-width) solid var(--scalar-border-color);border-bottom:none;--scalar-font-size-2: var(--scalar-font-size-4)}.callback-operation-container[data-v-102d2096] .parameter-list-items{border:var(--scalar-border-width) solid var(--scalar-border-color);border-radius:0 0 var(--scalar-radius-lg) var(--scalar-radius-lg)}.callback-operation-container[data-v-102d2096] .parameter-list-items>li:first-of-type{border-top:none}.callback-operation-container[data-v-102d2096] .parameter-list-items>li{padding:0 8px}.show-api-client-button[data-v-e851edeb]{appearance:none;border:none;padding:1px 6px;white-space:nowrap;border-radius:var(--scalar-radius);display:flex;justify-content:center;align-items:center;font-weight:var(--scalar-semibold);font-size:var(--scalar-small);line-height:22px;color:var(--scalar-background-2);font-family:var(--scalar-font);background:var(--scalar-button-1);position:relative;cursor:pointer;box-sizing:border-box;box-shadow:inset 0 0 0 1px #0000001a;outline-offset:2px}.show-api-client-button span[data-v-e851edeb],.show-api-client-button svg[data-v-e851edeb]{fill:currentColor;color:var(--scalar-button-1-color);z-index:1}.show-api-client-button[data-v-e851edeb]:hover{background:var(--scalar-button-1-hover)}.show-api-client-button svg[data-v-e851edeb]{margin-right:4px}.operation-title[data-v-8a5966f4]{justify-content:space-between;display:flex}.operation-details[data-v-8a5966f4]{flex-shrink:1;align-items:center;gap:9px;min-width:0;margin-top:0;display:flex}.operation-details[data-v-8a5966f4] .endpoint-anchor .scalar-button svg{width:16px;height:16px}.endpoint-type[data-v-8a5966f4]{z-index:0;width:60px;font-size:var(--scalar-small);text-transform:uppercase;font-weight:var(--scalar-bold);font-family:var(--scalar-font);flex-shrink:0;justify-content:center;align-items:center;gap:6px;padding:6px;display:flex;position:relative}.endpoint-type[data-v-8a5966f4]:after{content:"";z-index:-1;opacity:.15;border-radius:var(--scalar-radius);background:currentColor;position:absolute;inset:0}.endpoint-anchor[data-v-8a5966f4]{flex-shrink:1;align-items:center;min-width:0;display:flex}.endpoint-anchor.label[data-v-8a5966f4]{display:flex}.endpoint-label[data-v-8a5966f4]{min-width:0;color:var(--scalar-color-1);flex-shrink:1;align-items:baseline;gap:9px;display:flex}.endpoint-label-path[data-v-8a5966f4]{font-family:var(--scalar-font-code);font-size:var(--scalar-mini);text-overflow:ellipsis;white-space:nowrap;overflow:hidden}.endpoint-label-path[data-v-8a5966f4] em{color:var(--scalar-color-2)}.endpoint-label-name[data-v-8a5966f4]{color:var(--scalar-color-2);font-size:var(--scalar-small);text-overflow:ellipsis;white-space:nowrap;flex-shrink:1000000000;overflow:hidden}.endpoint-try-hint[data-v-8a5966f4]{flex-shrink:0;padding:2px}.endpoint-copy[data-v-8a5966f4]{color:currentColor}.endpoint-copy[data-v-8a5966f4] svg{stroke-width:2px}.endpoint-content[data-v-8a5966f4]{grid-auto-columns:1fr;grid-auto-flow:row;gap:9px;padding:9px;display:grid}@media(min-width:1000px){.endpoint-content[data-v-8a5966f4]{grid-auto-flow:column}}@container (max-width:900px){.endpoint-content[data-v-8a5966f4]{grid-template-columns:1fr}}.endpoint-content[data-v-8a5966f4]>*{min-width:0}.operation-details-card[data-v-8a5966f4]{flex-direction:column;gap:12px;min-width:0;display:flex}:is(.operation-details-card-item[data-v-8a5966f4] .parameter-list,.operation-details-card-item[data-v-8a5966f4] .callbacks-list){border:var(--scalar-border-width)solid var(--scalar-border-color);border-radius:var(--scalar-radius-lg);margin-top:0}.operation-details-card-item[data-v-8a5966f4]{flex-direction:column;gap:12px;display:flex}.operation-details-card-item[data-v-8a5966f4] .parameter-list-items{margin-bottom:0}.operation-details-card[data-v-8a5966f4] .parameter-item:last-of-type .parameter-schema{padding-bottom:12px}.operation-details-card[data-v-8a5966f4] .parameter-list .parameter-list{margin-bottom:12px}.operation-details-card[data-v-8a5966f4] .parameter-item{margin:0;padding:0}.operation-details-card[data-v-8a5966f4] .property{margin:0;padding:9px}:is(.operation-details-card[data-v-8a5966f4] .parameter-list-title,.operation-details-card[data-v-8a5966f4] .request-body-title,.operation-details-card[data-v-8a5966f4] .callbacks-title){text-transform:uppercase;font-weight:var(--scalar-bold);font-size:var(--scalar-mini);color:var(--scalar-color-2);margin:0;padding:9px;line-height:1.33}.operation-details-card[data-v-8a5966f4] .callback-list-item-title{padding-left:28px;padding-right:12px}.operation-details-card[data-v-8a5966f4] .callback-list-item-icon{left:6px}.operation-details-card[data-v-8a5966f4] .callback-operation-container{padding-inline:9px;padding-bottom:9px}:is(.operation-details-card[data-v-8a5966f4] .callback-operation-container>.request-body,.operation-details-card[data-v-8a5966f4] .callback-operation-container>.parameter-list){border:none}.operation-details-card[data-v-8a5966f4] .callback-operation-container>.request-body>.request-body-header{border-bottom:var(--scalar-border-width)solid var(--scalar-border-color);padding:0 0 9px}.operation-details-card[data-v-8a5966f4] .request-body-description{border-top:var(--scalar-border-width)solid var(--scalar-border-color);margin-top:0;padding:9px 9px 0}.operation-details-card[data-v-8a5966f4] .request-body{border-radius:var(--scalar-radius-lg);border:var(--scalar-border-width)solid var(--scalar-border-color);margin-top:0}.operation-details-card[data-v-8a5966f4] .request-body .schema-card--level-0>.schema-card-description{padding-inline:9px}.operation-details-card[data-v-8a5966f4] .request-body-header{border-bottom:0;padding-bottom:0}.operation-details-card[data-v-8a5966f4] .contents button{margin-right:9px}.operation-details-card[data-v-8a5966f4] .schema-card--open+.schema-card:not(.schema-card--open){margin-inline:9px;margin-bottom:9px}.operation-details-card[data-v-8a5966f4] .request-body-schema .property--level-0{padding:0}.operation-details-card[data-v-8a5966f4] .selected-content-type{margin-right:9px}.operation-example-card[data-v-8a5966f4]{top:calc(var(--refs-viewport-offset) + 24px);max-height:calc(var(--refs-viewport-height) - 48px);position:sticky}@media(max-width:600px){.operation-example-card[data-v-8a5966f4]{max-height:unset;position:static}}.examples[data-v-a158242e]{position:sticky;top:calc(var(--refs-viewport-offset) + 24px)}.examples[data-v-a158242e]>*{max-height:calc((var(--refs-viewport-height) - 60px) / 2);position:relative}@media(max-width:600px){.examples[data-v-a158242e]>*{max-height:unset}}.deprecated[data-v-a158242e] *{text-decoration:line-through}.section-flare[data-v-2a9c8c02]{top:0;right:0;pointer-events:none}.narrow-references-container{container-name:narrow-references-container;container-type:inline-size}.ref-search-meta[data-v-c1c368f9]{background:var(--scalar-background-1);border-bottom-left-radius:var(--scalar-radius-lg);border-bottom-right-radius:var(--scalar-radius-lg);padding:6px 12px;font-size:var(--scalar-font-size-4);color:var(--scalar-color-3);font-weight:var(--scalar-semibold);display:flex;gap:12px;border-top:var(--scalar-border-width) solid var(--scalar-border-color)}@layer properties{@supports (((-webkit-hyphens:none)) and (not (margin-trim:inline))) or ((-moz-orient:inline) and (not (color:rgb(from red r g b)))){*,:before,:after,::backdrop{--tw-translate-x:0;--tw-translate-y:0;--tw-translate-z:0;--tw-rotate-x:initial;--tw-rotate-y:initial;--tw-rotate-z:initial;--tw-skew-x:initial;--tw-skew-y:initial;--tw-divide-x-reverse:0;--tw-border-style:solid;--tw-divide-y-reverse:0;--tw-gradient-position:initial;--tw-gradient-from:#0000;--tw-gradient-via:#0000;--tw-gradient-to:#0000;--tw-gradient-stops:initial;--tw-gradient-via-stops:initial;--tw-gradient-from-position:0%;--tw-gradient-via-position:50%;--tw-gradient-to-position:100%;--tw-leading:initial;--tw-font-weight:initial;--tw-shadow:0 0 #0000;--tw-shadow-color:initial;--tw-shadow-alpha:100%;--tw-inset-shadow:0 0 #0000;--tw-inset-shadow-color:initial;--tw-inset-shadow-alpha:100%;--tw-ring-color:initial;--tw-ring-shadow:0 0 #0000;--tw-inset-ring-color:initial;--tw-inset-ring-shadow:0 0 #0000;--tw-ring-inset:initial;--tw-ring-offset-width:0px;--tw-ring-offset-color:#fff;--tw-ring-offset-shadow:0 0 #0000;--tw-outline-style:solid;--tw-blur:initial;--tw-brightness:initial;--tw-contrast:initial;--tw-grayscale:initial;--tw-hue-rotate:initial;--tw-invert:initial;--tw-opacity:initial;--tw-saturate:initial;--tw-sepia:initial;--tw-drop-shadow:initial;--tw-drop-shadow-color:initial;--tw-drop-shadow-alpha:100%;--tw-drop-shadow-size:initial;--tw-backdrop-blur:initial;--tw-backdrop-brightness:initial;--tw-backdrop-contrast:initial;--tw-backdrop-grayscale:initial;--tw-backdrop-hue-rotate:initial;--tw-backdrop-invert:initial;--tw-backdrop-opacity:initial;--tw-backdrop-saturate:initial;--tw-backdrop-sepia:initial;--tw-duration:initial;--tw-ease:initial;--tw-content:"";--tw-scale-x:1;--tw-scale-y:1;--tw-scale-z:1;--tw-space-x-reverse:0}}}@layer scalar-base{@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-alert:color-mix(in srgb,var(--scalar-color-orange),var(--scalar-color-1)20%)}}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-color-1)20%)}}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-alert:color-mix(in srgb,var(--scalar-color-orange),var(--scalar-background-1)95%)}}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-background-1)95%)}}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-tooltip-background:color-mix(in srgb,var(--scalar-background-1),#fff 10%)}}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-color-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-background-1)20%)}}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-alert:color-mix(in srgb,var(--scalar-color-orange),var(--scalar-background-1)95%)}}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-background-1)95%)}}:root,:host{--leading-snug:1.375;--leading-normal:1.5;--leading-relaxed:1.625;--ease-in-out:cubic-bezier(.4,0,.2,1);--default-transition-duration:.15s;--default-transition-timing-function:cubic-bezier(.4,0,.2,1)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-alert:color-mix(in srgb,var(--scalar-color-orange),var(--scalar-color-1)20%)}}.light-mode{--scalar-color-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-color-1)20%)}}.light-mode{--scalar-background-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-alert:color-mix(in srgb,var(--scalar-color-orange),var(--scalar-background-1)95%)}}.light-mode{--scalar-background-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-background-1)95%)}}.dark-mode{--scalar-tooltip-background:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-tooltip-background:color-mix(in srgb,var(--scalar-background-1),#fff 10%)}}.dark-mode{--scalar-color-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-color-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-background-1)20%)}}.dark-mode{--scalar-background-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-alert:color-mix(in srgb,var(--scalar-color-orange),var(--scalar-background-1)95%)}}.dark-mode{--scalar-background-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-background-1)95%)}}}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-alert:color-mix(in srgb,var(--scalar-color-orange),var(--scalar-color-1)20%)}}}.light-mode{--scalar-color-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-color-1)20%)}}}.light-mode{--scalar-background-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-alert:color-mix(in srgb,var(--scalar-color-orange),var(--scalar-background-1)95%)}}}.light-mode{--scalar-background-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-background-1)95%)}}}.dark-mode{--scalar-tooltip-background:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-tooltip-background:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-tooltip-background:color-mix(in srgb,var(--scalar-background-1),#fff 10%)}}}.dark-mode{--scalar-color-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-color-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-color-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-background-1)20%)}}}.dark-mode{--scalar-background-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-alert:color-mix(in srgb,var(--scalar-color-orange),var(--scalar-background-1)95%)}}}.dark-mode{--scalar-background-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-background-1)95%)}}}}:root,:host{--leading-snug:1.375;--ease-in-out:cubic-bezier(.4,0,.2,1);--default-transition-duration:.15s;--default-transition-timing-function:cubic-bezier(.4,0,.2,1)}@supports (color:color-mix(in lab,red,red)){@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-alert:color-mix(in srgb,var(--scalar-color-orange),var(--scalar-color-1)20%)}}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-color-1)20%)}}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-alert:color-mix(in srgb,var(--scalar-color-orange),var(--scalar-background-1)95%)}}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-background-1)95%)}}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-tooltip-background:color-mix(in srgb,var(--scalar-background-1),#fff 10%)}}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-color-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-background-1)20%)}}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-alert:color-mix(in srgb,var(--scalar-color-orange),var(--scalar-background-1)95%)}}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-background-1)95%)}}.light-mode{--scalar-color-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-alert:color-mix(in srgb,var(--scalar-color-orange),var(--scalar-color-1)20%)}}}.light-mode{--scalar-color-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-color-1)20%)}}}.light-mode{--scalar-background-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-alert:color-mix(in srgb,var(--scalar-color-orange),var(--scalar-background-1)95%)}}}.light-mode{--scalar-background-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-background-1)95%)}}}.dark-mode{--scalar-tooltip-background:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-tooltip-background:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-tooltip-background:color-mix(in srgb,var(--scalar-background-1),#fff 10%)}}}.dark-mode{--scalar-color-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-color-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-color-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-background-1)20%)}}}.dark-mode{--scalar-background-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-alert:color-mix(in srgb,var(--scalar-color-orange),var(--scalar-background-1)95%)}}}.dark-mode{--scalar-background-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-background-1)95%)}}}}body{line-height:inherit;margin:0}:root{--scalar-border-width:.5px;--scalar-radius:3px;--scalar-radius-lg:6px;--scalar-radius-xl:8px;--scalar-font:"Inter",-apple-system,BlinkMacSystemFont,"Segoe UI",Roboto,Oxygen,Ubuntu,Cantarell,"Open Sans","Helvetica Neue",sans-serif;--scalar-font-code:"JetBrains Mono",ui-monospace,Menlo,Monaco,"Cascadia Mono","Segoe UI Mono","Roboto Mono","Oxygen Mono","Ubuntu Monospace","Source Code Pro","Fira Mono","Droid Sans Mono","Courier New",monospace;--scalar-heading-1:24px;--scalar-page-description:16px;--scalar-heading-2:20px;--scalar-heading-3:16px;--scalar-heading-4:16px;--scalar-heading-5:16px;--scalar-heading-6:16px;--scalar-paragraph:16px;--scalar-small:14px;--scalar-mini:13px;--scalar-micro:12px;--scalar-bold:600;--scalar-semibold:500;--scalar-regular:400;--scalar-font-size-1:21px;--scalar-font-size-2:16px;--scalar-font-size-3:14px;--scalar-font-size-4:13px;--scalar-font-size-5:12px;--scalar-font-size-6:12px;--scalar-font-size-7:10px;--scalar-line-height-1:32px;--scalar-line-height-2:24px;--scalar-line-height-3:20px;--scalar-line-height-4:18px;--scalar-line-height-5:16px;--scalar-font-normal:400;--scalar-font-medium:500;--scalar-font-bold:700;--scalar-text-decoration:none;--scalar-text-decoration-hover:underline;--scalar-link-font-weight:inherit;--scalar-sidebar-indent:20px}.dark-mode{color-scheme:dark;--scalar-scrollbar-color:#ffffff2e;--scalar-scrollbar-color-active:#ffffff5c;--scalar-button-1:#fff;--scalar-button-1-hover:#ffffffe6;--scalar-button-1-color:black;--scalar-shadow-1:0 1px 3px 0 #0000001a;--scalar-shadow-2:0 0 0 .5px var(--scalar-border-color),#0f0f0f33 0px 3px 6px,#0f0f0f66 0px 9px 24px;--scalar-lifted-brightness:1.45;--scalar-backdrop-brightness:.5;--scalar-text-decoration-color:currentColor;--scalar-text-decoration-color-hover:currentColor}.light-mode{color-scheme:light;--scalar-scrollbar-color-active:#0000005c;--scalar-scrollbar-color:#0000002e;--scalar-button-1:#000;--scalar-button-1-hover:#000c;--scalar-button-1-color:#ffffffe6;--scalar-shadow-1:0 1px 3px 0 #0000001c;--scalar-shadow-2:#00000014 0px 13px 20px 0px,#00000014 0px 3px 8px 0px,#eeeeed 0px 0 0 .5px;--scalar-lifted-brightness:1;--scalar-backdrop-brightness:1;--scalar-text-decoration-color:currentColor;--scalar-text-decoration-color-hover:currentColor}.light-mode .dark-mode{color-scheme:dark!important}@media(max-width:460px){:root{--scalar-font-size-1:22px;--scalar-font-size-2:14px;--scalar-font-size-3:12px}}@media(max-width:720px){:root{--scalar-heading-1:24px;--scalar-page-description:20px}}:root{--scalar-text-decoration:underline;--scalar-text-decoration-hover:underline}.light-mode{--scalar-background-1:#fff;--scalar-background-2:#f6f6f6;--scalar-background-3:#e7e7e7;--scalar-background-accent:#8ab4f81f;--scalar-color-1:#1b1b1b;--scalar-color-2:#757575;--scalar-color-3:#8e8e8e;--scalar-color-accent:#09f;--scalar-border-color:#dfdfdf}.dark-mode{--scalar-background-1:#0f0f0f;--scalar-background-2:#1a1a1a;--scalar-background-3:#272727;--scalar-color-1:#e7e7e7;--scalar-color-2:#a4a4a4;--scalar-color-3:#797979;--scalar-color-accent:#00aeff;--scalar-background-accent:#3ea6ff1f;--scalar-border-color:#2d2d2d}.light-mode,.dark-mode{--scalar-sidebar-background-1:var(--scalar-background-1);--scalar-sidebar-color-1:var(--scalar-color-1);--scalar-sidebar-color-2:var(--scalar-color-2);--scalar-sidebar-border-color:var(--scalar-border-color);--scalar-sidebar-item-hover-background:var(--scalar-background-2);--scalar-sidebar-item-hover-color:var(--scalar-sidebar-color-2);--scalar-sidebar-item-active-background:var(--scalar-background-2);--scalar-sidebar-color-active:var(--scalar-sidebar-color-1);--scalar-sidebar-indent-border:var(--scalar-sidebar-border-color);--scalar-sidebar-indent-border-hover:var(--scalar-sidebar-border-color);--scalar-sidebar-indent-border-active:var(--scalar-sidebar-border-color);--scalar-sidebar-search-background:transparent;--scalar-sidebar-search-color:var(--scalar-color-3);--scalar-sidebar-search-border-color:var(--scalar-border-color)}.light-mode{--scalar-color-green:#069061;--scalar-color-red:#ef0006;--scalar-color-yellow:#edbe20;--scalar-color-blue:#0082d0;--scalar-color-orange:#ff5800;--scalar-color-purple:#5203d1;--scalar-link-color:var(--scalar-color-1);--scalar-link-color-hover:var(--scalar-link-color);--scalar-button-1:#000;--scalar-button-1-hover:#000c;--scalar-button-1-color:#ffffffe6;--scalar-tooltip-background:#1a1a1ae6;--scalar-tooltip-color:#ffffffd9;--scalar-color-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-alert:color-mix(in srgb,var(--scalar-color-orange),var(--scalar-color-1)20%)}}}}}.light-mode{--scalar-color-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-color-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-color-1)20%)}}}}}.light-mode{--scalar-background-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-alert:color-mix(in srgb,var(--scalar-color-orange),var(--scalar-background-1)95%)}}}}}.light-mode{--scalar-background-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.light-mode{--scalar-background-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-background-1)95%)}}}}}.dark-mode{--scalar-color-green:#00b648;--scalar-color-red:#dc1b19;--scalar-color-yellow:#ffc90d;--scalar-color-blue:#4eb3ec;--scalar-color-orange:#ff8d4d;--scalar-color-purple:#b191f9;--scalar-link-color:var(--scalar-color-1);--scalar-link-color-hover:var(--scalar-link-color);--scalar-button-1:#fff;--scalar-button-1-hover:#ffffffe6;--scalar-button-1-color:black;--scalar-tooltip-background:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-tooltip-background:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-tooltip-background:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-tooltip-background:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-tooltip-background:color-mix(in srgb,var(--scalar-background-1),#fff 10%)}}}}}.dark-mode{--scalar-tooltip-color:#fffffff2;--scalar-color-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-color-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-color-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-color-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-color-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-background-1)20%)}}}}}.dark-mode{--scalar-background-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-alert:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-alert:color-mix(in srgb,var(--scalar-color-orange),var(--scalar-background-1)95%)}}}}}.dark-mode{--scalar-background-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-danger:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.dark-mode{--scalar-background-danger:color-mix(in srgb,var(--scalar-color-red),var(--scalar-background-1)95%)}}}}}@supports (color:color(display-p3 1 1 1)){.light-mode{--scalar-color-accent:color(display-p3 0 .6 1);--scalar-color-green:color(display-p3 .023529 .564706 .380392);--scalar-color-red:color(display-p3 .937255 0 .023529);--scalar-color-yellow:color(display-p3 .929412 .745098 .12549);--scalar-color-blue:color(display-p3 0 .509804 .815686);--scalar-color-orange:color(display-p3 1 .4 .02);--scalar-color-purple:color(display-p3 .321569 .011765 .819608)}.dark-mode{--scalar-color-accent:color(display-p3 .07 .67 1);--scalar-color-green:color(display-p3 0 .713725 .282353);--scalar-color-red:color(display-p3 .862745 .105882 .098039);--scalar-color-yellow:color(display-p3 1 .788235 .05098);--scalar-color-blue:color(display-p3 .305882 .701961 .92549);--scalar-color-orange:color(display-p3 1 .552941 .301961);--scalar-color-purple:color(display-p3 .694118 .568627 .976471)}}:root,:host{--leading-snug:1.375;--ease-in-out:cubic-bezier(.4,0,.2,1);--default-transition-duration:.15s;--default-transition-timing-function:cubic-bezier(.4,0,.2,1);--leading-normal:1.5}body{background-color:var(--scalar-background-1);margin:0}}@layer scalar-theme;.scalar-app .\\@container{container-type:inline-size}.scalar-app .-top-2{top:-8px}.scalar-app .top-3\\.5{top:14px}.scalar-app .-left-4\\.5{left:-18px}.scalar-app .-left-5{left:-20px}.scalar-app .z-1000{z-index:1000}.scalar-app .order-789{order:789}.scalar-app .-m-1{margin:-4px}.scalar-app .-m-2{margin:-8px}.scalar-app .-mx-2{margin-inline:-8px}.scalar-app .my-2{margin-block:8px}.scalar-app .my-3{margin-block:12px}.scalar-app .-mt-1{margin-top:-4px}.scalar-app .mt-6{margin-top:24px}.scalar-app .mb-3{margin-bottom:12px}.scalar-app .size-4\\.5{width:18px;height:18px}.scalar-app .h-\\[calc\\(100\\%\\+16px\\)\\]{height:calc(100% + 16px)}.scalar-app .h-\\[var\\(--scalar-header-height\\)\\]{height:var(--scalar-header-height)}.scalar-app .max-h-\\[60vh\\]{max-height:60vh}.scalar-app .min-h-3{min-height:12px}.scalar-app .min-h-7{min-height:28px}.scalar-app .min-h-dvh{min-height:100dvh}.scalar-app .w-0{width:0}.scalar-app .w-4\\.5{width:18px}.scalar-app .w-96{width:384px}.scalar-app .w-110{width:440px}.scalar-app .w-120{width:480px}.scalar-app .max-w-\\(--refs-content-max-width\\){max-width:var(--refs-content-max-width)}.scalar-app .max-w-64{max-width:256px}.scalar-app .min-w-3{min-width:12px}.scalar-app .min-w-7{min-width:28px}.scalar-app .rotate-45{rotate:45deg}.scalar-app .scroll-mt-16{scroll-margin-top:64px}.scalar-app .scroll-mt-24{scroll-margin-top:96px}.scalar-app .list-none{list-style-type:none}.scalar-app .content-end{align-content:flex-end}.scalar-app .gap-7{gap:28px}.scalar-app .overflow-x-scroll{overflow-x:scroll}.scalar-app .rounded-b-none{border-bottom-right-radius:0;border-bottom-left-radius:0}@supports (color:color-mix(in lab,red,red)){.scalar-app .bg-b-1\\.5{background-color:color-mix(in srgb,var(--scalar-background-1),var(--scalar-background-2))}}.scalar-app .p-7{padding:28px}.scalar-app .px-15{padding-inline:60px}.scalar-app .py-2\\.25{padding-block:9px}.scalar-app .pt-1\\.5{padding-top:6px}.scalar-app .pb-12{padding-bottom:48px}.scalar-app .leading-\\[1\\.45\\]{--tw-leading:1.45;line-height:1.45}.scalar-app .leading-relaxed{--tw-leading:var(--leading-relaxed);line-height:var(--leading-relaxed)}.scalar-app .text-current{color:currentColor}.scalar-app .italic{font-style:italic}.scalar-app .\\[--scalar-address-bar-height\\:0px\\]{--scalar-address-bar-height:0px}.scalar-app .\\[grid-area\\:header\\]{grid-area:header}.scalar-app .\\[grid-area\\:navigation\\]{grid-area:navigation}:is(.scalar-app .\\*\\:\\!p-0>*){padding:0!important}.scalar-app .group-last\\:mr-0:is(:where(.group):last-child *){margin-right:0}.scalar-app .group-open\\:rotate-90:is(:where(.group):is([open],:popover-open,:open) *){rotate:90deg}.scalar-app .group-open\\:flex-wrap:is(:where(.group):is([open],:popover-open,:open) *){flex-wrap:wrap}.scalar-app .group-open\\:whitespace-normal:is(:where(.group):is([open],:popover-open,:open) *){white-space:normal}.scalar-app .group-focus-within\\/parameter-item\\:w-auto:is(:where(.group\\/parameter-item):focus-within *){width:auto}@media(hover:hover){.scalar-app .group-hover\\:flex:is(:where(.group):hover *){display:flex}.scalar-app .group-hover\\:text-c-1:is(:where(.group):hover *){color:var(--scalar-color-1)}.scalar-app .group-hover\\:opacity-100:is(:where(.group):hover *),.scalar-app .group-hover\\/heading\\:opacity-100:is(:where(.group\\/heading):hover *){opacity:1}.scalar-app .group-hover\\/parameter-item\\:w-auto:is(:where(.group\\/parameter-item):hover *){width:auto}}.scalar-app .group-has-focus-visible\\/heading\\:opacity-100:is(:where(.group\\/heading):has(:focus-visible) *){opacity:1}.scalar-app .empty\\:hidden:empty{display:none}@media(hover:hover){.scalar-app .hover\\:bg-b-2:hover{background-color:var(--scalar-background-2)}.scalar-app .hover\\:text-c-1:hover{color:var(--scalar-color-1)}}.scalar-app .has-focus\\:outline:has(:focus){outline-style:var(--tw-outline-style);outline-width:1px}@media(min-width:1200px){.scalar-app .xl\\:mb-1\\.5{margin-bottom:6px}.scalar-app .xl\\:gap-12{gap:48px}.scalar-app .xl\\:border-r{border-right-style:var(--tw-border-style);border-right-width:var(--scalar-border-width)}.scalar-app .xl\\:border-none{--tw-border-style:none;border-style:none}.scalar-app .xl\\:first\\:ml-auto:first-child{margin-left:auto}}.scalar-app .\\[\\&_a\\]\\:underline a{text-decoration-line:underline}.scalar-app .\\[\\&_a\\:hover\\]\\:text-c-1 a:hover{color:var(--scalar-color-1)}.scalar-app .\\[\\&_code\\]\\:font-code code{font-family:var(--scalar-font-code)}.scalar-app .\\[\\&_em\\]\\:text-c-1 em{color:var(--scalar-color-1)}.scalar-app .\\[\\&_em\\]\\:not-italic em{font-style:normal}@supports (color:color-mix(in lab,red,red)){.scalar-app .bg-b-1\\.5{background-color:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.scalar-app .bg-b-1\\.5{background-color:color-mix(in srgb,var(--scalar-background-1),var(--scalar-background-2))}}}@supports (color:color-mix(in lab,red,red)){.scalar-app .to-b-1\\.5{--tw-gradient-to:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.scalar-app .to-b-1\\.5{--tw-gradient-to:color-mix(in srgb,var(--scalar-background-1),var(--scalar-background-2))}}:is(.scalar-app .\\*\\:border-border-tooltip>*){border-color:var(--scalar-tooltip-color)}@supports (color:color-mix(in lab,red,red)){:is(.scalar-app .\\*\\:border-border-tooltip>*){border-color:color-mix(in srgb,var(--scalar-tooltip-color),var(--scalar-tooltip-background))}}}@property --tw-divide-x-reverse{syntax:"*";inherits:false;initial-value:0}@property --tw-divide-y-reverse{syntax:"*";inherits:false;initial-value:0}@property --tw-gradient-position{syntax:"*";inherits:false}@property --tw-gradient-from{syntax:"<color>";inherits:false;initial-value:#0000}@property --tw-gradient-via{syntax:"<color>";inherits:false;initial-value:#0000}@property --tw-gradient-to{syntax:"<color>";inherits:false;initial-value:#0000}@property --tw-gradient-stops{syntax:"*";inherits:false}@property --tw-gradient-via-stops{syntax:"*";inherits:false}@property --tw-gradient-from-position{syntax:"<length-percentage>";inherits:false;initial-value:0%}@property --tw-gradient-via-position{syntax:"<length-percentage>";inherits:false;initial-value:50%}@property --tw-gradient-to-position{syntax:"<length-percentage>";inherits:false;initial-value:100%}@property --tw-ease{syntax:"*";inherits:false}@keyframes fade-in-27df5cd8{0%{opacity:0}70%{opacity:0}to{opacity:1}}@keyframes rotate-27df5cd8{0%{transform:scale(3.5)rotate(0)}to{transform:scale(3.5)rotate(360deg)}}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown a{-webkit-text-decoration-color:color-mix(in srgb,var(--font-color)30%,transparent);text-decoration-color:color-mix(in srgb,var(--font-color)30%,transparent)}}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert{background-color:color-mix(in srgb,var(--scalar-background-2),transparent)}}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-note{background-color:color-mix(in srgb,var(--scalar-color-blue),transparent 97%)}}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-note{border:var(--scalar-border-width)solid color-mix(in srgb,var(--scalar-color-blue),transparent 50%)}}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-tip{background-color:color-mix(in srgb,var(--scalar-color-2),transparent 97%)}}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-tip{border:var(--scalar-border-width)solid color-mix(in srgb,var(--scalar-color-2),transparent 50%)}}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-important,.scalar-app .markdown .markdown-alert.markdown-alert-warning{background-color:color-mix(in srgb,var(--scalar-color-orange),transparent 97%)}}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-important,.scalar-app .markdown .markdown-alert.markdown-alert-warning{border:var(--scalar-border-width)solid color-mix(in srgb,var(--scalar-color-orange),transparent 50%)}}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-caution{background-color:color-mix(in srgb,var(--scalar-color-red),transparent 97%)}}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-caution{border:var(--scalar-border-width)solid color-mix(in srgb,var(--scalar-color-red),transparent 50%)}}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-success{background-color:color-mix(in srgb,var(--scalar-color-green),transparent 97%)}}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-success{border:var(--scalar-border-width)solid color-mix(in srgb,var(--scalar-color-green),transparent 50%)}}@property --tw-backdrop-blur{syntax:"*";inherits:false}@property --tw-backdrop-brightness{syntax:"*";inherits:false}@property --tw-backdrop-contrast{syntax:"*";inherits:false}@property --tw-backdrop-grayscale{syntax:"*";inherits:false}@property --tw-backdrop-hue-rotate{syntax:"*";inherits:false}@property --tw-backdrop-invert{syntax:"*";inherits:false}@property --tw-backdrop-opacity{syntax:"*";inherits:false}@property --tw-backdrop-saturate{syntax:"*";inherits:false}@property --tw-backdrop-sepia{syntax:"*";inherits:false}@keyframes fadein-layout-c36b47da{0%{opacity:0}to{opacity:1}}@keyframes fadein-modal-c36b47da{0%{opacity:0;transform:translateY(10px)}to{opacity:1;transform:translate(0)}}@media(hover:hover){.scalar-app .group-hover\\/button\\:opacity-0:is(:where(.group\\/button):hover *){opacity:0}.scalar-app .group-hover\\/group-button\\:flex:is(:where(.group\\/group-button):hover *){display:flex}.scalar-app .group-hover\\/group-button\\:hidden:is(:where(.group\\/group-button):hover *){display:none}.scalar-app .peer-hover\\/button\\:opacity-100:is(:where(.peer\\/button):hover~*),.scalar-app .hover\\:opacity-100:hover{opacity:1}}@supports (color:color-mix(in lab,red,red)){.scalar-app .bg-b-1\\.5{background-color:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.scalar-app .bg-b-1\\.5{background-color:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.scalar-app .bg-b-1\\.5{background-color:color-mix(in srgb,var(--scalar-background-1),var(--scalar-background-2))}}}}@supports (color:color-mix(in lab,red,red)){.scalar-app .to-b-1\\.5{--tw-gradient-to:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.scalar-app .to-b-1\\.5{--tw-gradient-to:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.scalar-app .to-b-1\\.5{--tw-gradient-to:color-mix(in srgb,var(--scalar-background-1),var(--scalar-background-2))}}}:is(.scalar-app .\\*\\:border-border-tooltip>*){border-color:var(--scalar-tooltip-color)}@supports (color:color-mix(in lab,red,red)){:is(.scalar-app .\\*\\:border-border-tooltip>*){border-color:var(--scalar-tooltip-color)}@supports (color:color-mix(in lab,red,red)){:is(.scalar-app .\\*\\:border-border-tooltip>*){border-color:color-mix(in srgb,var(--scalar-tooltip-color),var(--scalar-tooltip-background))}}}}@property --tw-content{syntax:"*";inherits:false;initial-value:""}@supports (color:color-mix(in lab,red,red)){.scalar-app .bg-b-1\\.5{background-color:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.scalar-app .bg-b-1\\.5{background-color:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.scalar-app .bg-b-1\\.5{background-color:color-mix(in srgb,var(--scalar-background-1),var(--scalar-background-2))}}}.scalar-app .to-b-1\\.5{--tw-gradient-to:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.scalar-app .to-b-1\\.5{--tw-gradient-to:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.scalar-app .to-b-1\\.5{--tw-gradient-to:color-mix(in srgb,var(--scalar-background-1),var(--scalar-background-2))}}}:is(.scalar-app .\\*\\:border-border-tooltip>*){border-color:var(--scalar-tooltip-color)}@supports (color:color-mix(in lab,red,red)){:is(.scalar-app .\\*\\:border-border-tooltip>*){border-color:var(--scalar-tooltip-color)}@supports (color:color-mix(in lab,red,red)){:is(.scalar-app .\\*\\:border-border-tooltip>*){border-color:color-mix(in srgb,var(--scalar-tooltip-color),var(--scalar-tooltip-background))}}}}@media(hover:hover){.scalar-app .group-hover\\:text-c-1:is(:where(.group):hover *){color:var(--scalar-color-1)}.scalar-app .group-hover\\/button\\:bg-sidebar-indent-border-hover:is(:where(.group\\/button):hover *){background-color:var(--scalar-sidebar-indent-border-hover,var(--scalar-border-color))}.scalar-app .group-hover\\/button\\:text-c-1:is(:where(.group\\/button):hover *){color:var(--scalar-color-1)}.scalar-app .group-hover\\/code-block\\:opacity-100:is(:where(.group\\/code-block):hover *){opacity:1}.scalar-app .hover\\:bg-b-2:hover{background-color:var(--scalar-background-2)}.scalar-app .hover\\:bg-b-3:hover{background-color:var(--scalar-background-3)}.scalar-app .hover\\:bg-h-btn:hover{background-color:var(--scalar-button-1-hover)}.scalar-app .hover\\:bg-sidebar-b-1:hover{background-color:var(--scalar-sidebar-background-1,var(--scalar-background-1))}.scalar-app .hover\\:bg-sidebar-b-hover:hover{background-color:var(--scalar-sidebar-item-hover-background,var(--scalar-background-2))}.scalar-app .hover\\:bg-linear-to-b:hover{--tw-gradient-position:to bottom}@supports (background-image:linear-gradient(in lab,red,red)){.scalar-app .hover\\:bg-linear-to-b:hover{--tw-gradient-position:to bottom in oklab}}.scalar-app .hover\\:bg-linear-to-b:hover{background-image:linear-gradient(var(--tw-gradient-stops))}.scalar-app .hover\\:bg-linear-to-t:hover{--tw-gradient-position:to top}@supports (background-image:linear-gradient(in lab,red,red)){.scalar-app .hover\\:bg-linear-to-t:hover{--tw-gradient-position:to top in oklab}}.scalar-app .hover\\:bg-linear-to-t:hover{background-image:linear-gradient(var(--tw-gradient-stops))}.scalar-app .hover\\:text-c-1:hover{color:var(--scalar-color-1)}.scalar-app .hover\\:text-sidebar-c-1:hover{color:var(--scalar-sidebar-color-1,var(--scalar-color-1))}.scalar-app .hover\\:text-sidebar-c-hover:hover{color:var(--scalar-sidebar-item-hover-color,var(--scalar-sidebar-color-2))}.scalar-app .hover\\:underline:hover{text-decoration-line:underline}.scalar-app .hover\\:brightness-90:hover{--tw-brightness:brightness(90%);filter:var(--tw-blur,)var(--tw-brightness,)var(--tw-contrast,)var(--tw-grayscale,)var(--tw-hue-rotate,)var(--tw-invert,)var(--tw-saturate,)var(--tw-sepia,)var(--tw-drop-shadow,)}}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown a{-webkit-text-decoration-color:var(--font-color)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown a{-webkit-text-decoration-color:color-mix(in srgb,var(--font-color)30%,transparent)}}.scalar-app .markdown a{-webkit-text-decoration-color:var(--font-color);text-decoration-color:var(--font-color)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown a{-webkit-text-decoration-color:color-mix(in srgb,var(--font-color)30%,transparent);text-decoration-color:color-mix(in srgb,var(--font-color)30%,transparent)}}.scalar-app .markdown .markdown-alert{background-color:var(--scalar-background-2)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert{background-color:color-mix(in srgb,var(--scalar-background-2),transparent)}}.scalar-app .markdown .markdown-alert.markdown-alert-note{background-color:var(--scalar-color-blue)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-note{background-color:color-mix(in srgb,var(--scalar-color-blue),transparent 97%)}}.scalar-app .markdown .markdown-alert.markdown-alert-note{border:var(--scalar-border-width)solid var(--scalar-color-blue)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-note{border:var(--scalar-border-width)solid color-mix(in srgb,var(--scalar-color-blue),transparent 50%)}}.scalar-app .markdown .markdown-alert.markdown-alert-tip{background-color:var(--scalar-color-2)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-tip{background-color:color-mix(in srgb,var(--scalar-color-2),transparent 97%)}}.scalar-app .markdown .markdown-alert.markdown-alert-tip{border:var(--scalar-border-width)solid var(--scalar-color-2)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-tip{border:var(--scalar-border-width)solid color-mix(in srgb,var(--scalar-color-2),transparent 50%)}}.scalar-app .markdown .markdown-alert.markdown-alert-important,.scalar-app .markdown .markdown-alert.markdown-alert-warning{background-color:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-important,.scalar-app .markdown .markdown-alert.markdown-alert-warning{background-color:color-mix(in srgb,var(--scalar-color-orange),transparent 97%)}}.scalar-app .markdown .markdown-alert.markdown-alert-important,.scalar-app .markdown .markdown-alert.markdown-alert-warning{border:var(--scalar-border-width)solid var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-important,.scalar-app .markdown .markdown-alert.markdown-alert-warning{border:var(--scalar-border-width)solid color-mix(in srgb,var(--scalar-color-orange),transparent 50%)}}.scalar-app .markdown .markdown-alert.markdown-alert-caution{background-color:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-caution{background-color:color-mix(in srgb,var(--scalar-color-red),transparent 97%)}}.scalar-app .markdown .markdown-alert.markdown-alert-caution{border:var(--scalar-border-width)solid var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-caution{border:var(--scalar-border-width)solid color-mix(in srgb,var(--scalar-color-red),transparent 50%)}}.scalar-app .markdown .markdown-alert.markdown-alert-success{background-color:var(--scalar-color-green)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-success{background-color:color-mix(in srgb,var(--scalar-color-green),transparent 97%)}}.scalar-app .markdown .markdown-alert.markdown-alert-success{border:var(--scalar-border-width)solid var(--scalar-color-green)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-success{border:var(--scalar-border-width)solid color-mix(in srgb,var(--scalar-color-green),transparent 50%)}}}.scalar-app .right-0\\.75{right:3px}.scalar-app .ml-2{margin-left:8px}.scalar-app .self-start{align-self:flex-start}@media(hover:hover){.scalar-app .group-hover\\/button\\:opacity-0:is(:where(.group\\/button):hover *){opacity:0}.scalar-app .group-hover\\/group-button\\:flex:is(:where(.group\\/group-button):hover *){display:flex}.scalar-app .group-hover\\/group-button\\:hidden:is(:where(.group\\/group-button):hover *){display:none}}.scalar-app .group-focus-visible\\/button\\:opacity-0:is(:where(.group\\/button):focus-visible *),.scalar-app .group-has-\\[\\~\\*_\\[aria-expanded\\=true\\]\\]\\/button\\:opacity-0:is(:where(.group\\/button):has(~* [aria-expanded=true]) *),.scalar-app .group-has-\\[\\~\\*\\:focus-within\\]\\/button\\:opacity-0:is(:where(.group\\/button):has(~:focus-within) *),.scalar-app .group-has-\\[\\~\\*\\:hover\\]\\/button\\:opacity-0:is(:where(.group\\/button):has(~:hover) *){opacity:0}@media(hover:hover){.scalar-app .peer-hover\\/button\\:opacity-100:is(:where(.peer\\/button):hover~*){opacity:1}}.scalar-app .peer-focus-visible\\/button\\:opacity-100:is(:where(.peer\\/button):focus-visible~*){opacity:1}.scalar-app .after\\:pointer-events-none:after{content:var(--tw-content);pointer-events:none}.scalar-app .after\\:absolute:after{content:var(--tw-content);position:absolute}.scalar-app .after\\:inset-0:after{content:var(--tw-content);inset:0}.scalar-app .after\\:inset-x-0:after{content:var(--tw-content);inset-inline:0}.scalar-app .after\\:-top-0\\.5:after{content:var(--tw-content);top:-2px}.scalar-app .after\\:-bottom-0\\.5:after{content:var(--tw-content);bottom:-2px}.scalar-app .after\\:block:after{content:var(--tw-content);display:block}.scalar-app .after\\:h-0\\.75:after{content:var(--tw-content);height:3px}.scalar-app .after\\:rounded:after{content:var(--tw-content);border-radius:var(--scalar-radius)}.scalar-app .after\\:bg-blue:after{content:var(--tw-content);background-color:var(--scalar-color-blue)}.scalar-app .after\\:opacity-15:after{content:var(--tw-content);opacity:.15}.scalar-app .focus-within\\:opacity-100:focus-within{opacity:1}@media(hover:hover){.scalar-app .hover\\:opacity-100:hover{opacity:1}}.scalar-app .has-\\[\\&\\[aria-expanded\\=true\\]\\]\\:opacity-100:has([aria-expanded=true]){opacity:1}:where(.scalar-app){font-family:var(--scalar-font);color:var(--scalar-color-1);-webkit-text-size-adjust:100%;tab-size:4;line-height:1.15}:where(.scalar-app) *,:where(.scalar-app) :before,:where(.scalar-app) :after{box-sizing:border-box;border-style:solid;border-width:0;border-color:var(--scalar-border-color);outline-width:1px;outline-style:none;outline-color:var(--scalar-color-accent);font-feature-settings:inherit;font-variation-settings:inherit;font-family:inherit;font-size:inherit;font-weight:inherit;font-style:inherit;-webkit-text-decoration:inherit;text-decoration:inherit;text-align:inherit;line-height:inherit;color:inherit;margin:unset;padding:unset;text-rendering:optimizeLegibility;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}:where(.scalar-app) :before,:where(.scalar-app) :after{--tw-content:""}:where(.scalar-app) button,:where(.scalar-app) input,:where(.scalar-app) optgroup,:where(.scalar-app) select,:where(.scalar-app) textarea{background:0 0}:where(.scalar-app) ::file-selector-button{background:0 0}:where(.scalar-app) ol,:where(.scalar-app) ul,:where(.scalar-app) menu{list-style:none}:where(.scalar-app) input:where(:not([type=button],[type=reset],[type=submit])),:where(.scalar-app) select,:where(.scalar-app) textarea{border-radius:var(--scalar-radius);border-width:1px}:where(.scalar-app) input::placeholder{color:var(--scalar-color-3);font-family:var(--scalar-font)}:where(.scalar-app) input[type=search]::-webkit-search-cancel-button{appearance:none}:where(.scalar-app) input[type=search]::-webkit-search-decoration{appearance:none}:where(.scalar-app) summary::-webkit-details-marker{display:none}:where(.scalar-app) input:-webkit-autofill{-webkit-background-clip:text!important;background-clip:text!important}:where(.scalar-app) :focus-visible{border-radius:var(--scalar-radius);outline-style:solid}:where(.scalar-app) button:focus-visible,:where(.scalar-app) [role=button]:focus-visible{outline-offset:-1px}:where(.scalar-app) button,:where(.scalar-app) [role=button]{cursor:pointer}:where(.scalar-app) :disabled{cursor:default}:where(.scalar-app) img,:where(.scalar-app) svg,:where(.scalar-app) video,:where(.scalar-app) canvas,:where(.scalar-app) audio,:where(.scalar-app) iframe,:where(.scalar-app) embed,:where(.scalar-app) object{vertical-align:middle;display:block}:where(.scalar-app) [hidden]{display:none}.scalar-app .cm-scroller,.scalar-app .custom-scroll{scrollbar-color:transparent transparent;scrollbar-width:thin;-webkit-overflow-scrolling:touch;overflow-y:auto}.scalar-app .custom-scroll-self-contain-overflow{overscroll-behavior:contain}.scalar-app .cm-scroller:hover,.scalar-app .custom-scroll:hover,.scalar-app.scalar-scrollbars-obtrusive .cm-scroller,.scalar-app.scalar-scrollbars-obtrusive .custom-scroll{scrollbar-color:var(--scalar-scrollbar-color,transparent)transparent}.scalar-app .cm-scroller:hover::-webkit-scrollbar-thumb{background:var(--scalar-scrollbar-color);background-clip:content-box;border:3px solid #0000}.scalar-app .custom-scroll:hover::-webkit-scrollbar-thumb{background:var(--scalar-scrollbar-color);background-clip:content-box;border:3px solid #0000}.scalar-app .cm-scroller::-webkit-scrollbar-thumb:active{background:var(--scalar-scrollbar-color-active);background-clip:content-box;border:3px solid #0000}.scalar-app .custom-scroll::-webkit-scrollbar-thumb:active{background:var(--scalar-scrollbar-color-active);background-clip:content-box;border:3px solid #0000}.scalar-app .cm-scroller::-webkit-scrollbar-corner{background:0 0}.scalar-app .custom-scroll::-webkit-scrollbar-corner{background:0 0}.scalar-app .cm-scroller::-webkit-scrollbar{width:12px;height:12px}.scalar-app .custom-scroll::-webkit-scrollbar{width:12px;height:12px}.scalar-app .cm-scroller::-webkit-scrollbar-track{background:0 0}.scalar-app .custom-scroll::-webkit-scrollbar-track{background:0 0}.scalar-app .cm-scroller::-webkit-scrollbar-thumb{background:padding-box content-box;border:3px solid #0000;border-radius:20px}.scalar-app .custom-scroll::-webkit-scrollbar-thumb{background:padding-box content-box;border:3px solid #0000;border-radius:20px}@media(pointer:coarse){.scalar-app .cm-scroller,.scalar-app .custom-scroll{padding-right:12px}}.scalar-app .invisible{visibility:hidden}.scalar-app .inset-y-0{inset-block:0}.scalar-app .top-\\(--nested-items-offset\\){top:var(--nested-items-offset)}.scalar-app .top-0\\.5{top:2px}.scalar-app .top-1\\/2{top:50%}.scalar-app .top-22{top:88px}.scalar-app .top-\\[1lh\\]{top:1lh}.scalar-app .top-px{top:1px}.scalar-app .left-2{left:8px}.scalar-app .left-2\\.5{left:10px}.scalar-app .left-4{left:16px}.scalar-app .left-10{left:40px}.scalar-app .left-\\[calc\\(4px\\+var\\(--scalar-sidebar-indent\\)\\*var\\(--scalar-sidebar-level\\)\\)\\]{left:calc(4px + var(--scalar-sidebar-indent)*var(--scalar-sidebar-level))}.scalar-app .left-border{left:var(--scalar-border-width)}.scalar-app .left-px{left:1px}.scalar-app .z-tooltip{z-index:99999}.scalar-app .-m-1\\.5{margin:-6px}.scalar-app .-m-px{margin:-1px}.scalar-app .m-1{margin:4px}.scalar-app .-mx-0\\.75{margin-inline:-3px}.scalar-app .-mx-px{margin-inline:-1px}.scalar-app .mx-px{margin-inline:1px}.scalar-app .-my-1\\.5{margin-block:-6px}.scalar-app .-my-2{margin-block:-8px}.scalar-app .my-0\\.75{margin-block:3px}.scalar-app .-mt-1\\.5{margin-top:-6px}.scalar-app .mt-0{margin-top:0}.scalar-app .mt-\\[15svh\\]{margin-top:15svh}.scalar-app .mt-\\[20svh\\]{margin-top:20svh}.scalar-app .-mr-0\\.25{margin-right:-1px}.scalar-app .mr-0{margin-right:0}.scalar-app .mr-\\[calc\\(20px-var\\(--scalar-sidebar-indent\\)\\)\\]{margin-right:calc(20px - var(--scalar-sidebar-indent))}.scalar-app .-mb-1{margin-bottom:-4px}.scalar-app .-ml-0\\.75{margin-left:-3px}.scalar-app .line-clamp-\\(--markdown-clamp\\){-webkit-line-clamp:var(--markdown-clamp);-webkit-box-orient:vertical;display:-webkit-box;overflow:hidden}.scalar-app .\\!hidden{display:none!important}.scalar-app .size-2{width:8px;height:8px}.scalar-app .size-2\\.75{width:11px;height:11px}.scalar-app .size-3\\.25{width:13px;height:13px}.scalar-app .size-60{width:240px;height:240px}.scalar-app .size-\\[23px\\]{width:23px;height:23px}.scalar-app .h-0{height:0}.scalar-app .h-1{height:4px}.scalar-app .h-24{height:96px}.scalar-app .h-32{height:128px}.scalar-app .h-\\[1lh\\]{height:1lh}.scalar-app .h-border{height:var(--scalar-border-width)}.scalar-app .h-dvh{height:100dvh}.scalar-app .max-h-20{max-height:80px}.scalar-app .max-h-\\[80svh\\]{max-height:80svh}.scalar-app .max-h-\\[90svh\\]{max-height:90svh}.scalar-app .max-h-dvh{max-height:100dvh}.scalar-app .max-h-radix-popper{max-height:calc(var(--radix-popper-available-height) - 8px)}.scalar-app .min-h-96{min-height:384px}.scalar-app .min-h-header{min-height:48px}.scalar-app .w-12{width:48px}.scalar-app .w-24{width:96px}.scalar-app .w-32{width:128px}.scalar-app .w-40{width:160px}.scalar-app .w-48{width:192px}.scalar-app .w-\\[38px\\]{width:38px}.scalar-app .w-\\[calc\\(100vw-12px\\)\\]{width:calc(100vw - 12px)}.scalar-app .w-\\[var\\(--scalar-sidebar-indent\\)\\]{width:var(--scalar-sidebar-indent)}.scalar-app .w-border{width:var(--scalar-border-width)}.scalar-app .w-min{width:min-content}.scalar-app .w-screen{width:100vw}.scalar-app .max-w-\\[360px\\]{max-width:360px}.scalar-app .max-w-\\[480px\\]{max-width:480px}.scalar-app .max-w-\\[540px\\]{max-width:540px}.scalar-app .max-w-\\[640px\\]{max-width:640px}.scalar-app .max-w-\\[800px\\]{max-width:800px}.scalar-app .max-w-\\[1000px\\]{max-width:1000px}.scalar-app .max-w-\\[inherit\\]{max-width:inherit}.scalar-app .max-w-xs{max-width:320px}.scalar-app .min-w-6{min-width:24px}.scalar-app .min-w-40{min-width:160px}.scalar-app .min-w-min{min-width:min-content}.scalar-app .flex-shrink,.scalar-app .shrink{flex-shrink:1}.scalar-app .-translate-x-full{--tw-translate-x:-100%;translate:var(--tw-translate-x)var(--tw-translate-y)}.scalar-app .translate-x-2\\.5{--tw-translate-x:10px;translate:var(--tw-translate-x)var(--tw-translate-y)}.scalar-app .translate-x-\\[14px\\]{--tw-translate-x:14px;translate:var(--tw-translate-x)var(--tw-translate-y)}.scalar-app .translate-x-full{--tw-translate-x:100%;translate:var(--tw-translate-x)var(--tw-translate-y)}.scalar-app .-translate-y-1\\/2{--tw-translate-y:-50%;translate:var(--tw-translate-x)var(--tw-translate-y)}.scalar-app .appearance-none{appearance:none}.scalar-app .grid-flow-col{grid-auto-flow:column}.scalar-app .\\!items-end{align-items:flex-end!important}.scalar-app .\\!items-start{align-items:flex-start!important}.scalar-app .items-baseline{align-items:baseline}.scalar-app .\\!justify-end{justify-content:flex-end!important}.scalar-app .\\!justify-start{justify-content:flex-start!important}.scalar-app .gap-2\\.25{gap:9px}.scalar-app .gap-x-4{column-gap:16px}.scalar-app .gap-y-8{row-gap:32px}:where(.scalar-app .divide-x>:not(:last-child)){--tw-divide-x-reverse:0;border-inline-style:var(--tw-border-style);border-inline-start-width:calc(var(--scalar-border-width)*var(--tw-divide-x-reverse));border-inline-end-width:calc(var(--scalar-border-width)*calc(1 - var(--tw-divide-x-reverse)))}.scalar-app .self-end{align-self:flex-end}.scalar-app .overflow-x-clip{overflow-x:clip}.scalar-app .overflow-y-scroll{overflow-y:scroll}.scalar-app .overscroll-contain{overscroll-behavior:contain}.scalar-app .rounded-none{border-radius:0}.scalar-app .rounded-l-none{border-top-left-radius:0;border-bottom-left-radius:0}.scalar-app .border-1{border-style:var(--tw-border-style);border-width:1px}.scalar-app .border-solid{--tw-border-style:solid;border-style:solid}.scalar-app .border-\\(--scalar-background-3\\){border-color:var(--scalar-background-3)}.scalar-app .border-border{border-color:var(--scalar-border-color)}.scalar-app .border-c-alert{border-color:var(--scalar-color-alert)}.scalar-app .border-red{border-color:var(--scalar-color-red)}.scalar-app .border-sidebar-border{border-color:var(--scalar-sidebar-border-color,var(--scalar-border-color))}.scalar-app .border-sidebar-border-search{border-color:var(--scalar-sidebar-search-border-color,var(--scalar-border-color))}.scalar-app .bg-\\(--bg-light\\){background-color:var(--bg-light)}.scalar-app .bg-b-1,.scalar-app .bg-b-1\\.5{background-color:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.scalar-app .bg-b-1\\.5{background-color:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.scalar-app .bg-b-1\\.5{background-color:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.scalar-app .bg-b-1\\.5{background-color:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.scalar-app .bg-b-1\\.5{background-color:color-mix(in srgb,var(--scalar-background-1),var(--scalar-background-2))}}}}}.scalar-app .bg-b-alert{background-color:var(--scalar-background-alert)}.scalar-app .bg-b-btn{background-color:var(--scalar-button-1)}.scalar-app .bg-b-tooltip{background-color:var(--scalar-tooltip-background)}.scalar-app .bg-backdrop{background-color:#00000038}.scalar-app .bg-border{background-color:var(--scalar-border-color)}.scalar-app .bg-c-danger{background-color:var(--scalar-color-danger)}.scalar-app .bg-inherit{background-color:inherit}.scalar-app .bg-red{background-color:var(--scalar-color-red)}.scalar-app .bg-sidebar-b-search{background-color:var(--scalar-sidebar-search-background,var(--scalar-background-2))}.scalar-app .bg-sidebar-indent-border{background-color:var(--scalar-sidebar-indent-border,var(--scalar-border-color))}.scalar-app .bg-sidebar-indent-border-active{background-color:var(--scalar-sidebar-indent-border-active,var(--scalar-color-accent))}.scalar-app .bg-transparent{background-color:#0000}.scalar-app .bg-linear-to-b{--tw-gradient-position:to bottom}@supports (background-image:linear-gradient(in lab,red,red)){.scalar-app .bg-linear-to-b{--tw-gradient-position:to bottom in oklab}}.scalar-app .bg-linear-to-b{background-image:linear-gradient(var(--tw-gradient-stops))}.scalar-app .from-b-1{--tw-gradient-from:var(--scalar-background-1);--tw-gradient-stops:var(--tw-gradient-via-stops,var(--tw-gradient-position),var(--tw-gradient-from)var(--tw-gradient-from-position),var(--tw-gradient-to)var(--tw-gradient-to-position))}.scalar-app .to-b-1\\.5{--tw-gradient-to:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.scalar-app .to-b-1\\.5{--tw-gradient-to:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.scalar-app .to-b-1\\.5{--tw-gradient-to:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.scalar-app .to-b-1\\.5{--tw-gradient-to:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.scalar-app .to-b-1\\.5{--tw-gradient-to:color-mix(in srgb,var(--scalar-background-1),var(--scalar-background-2))}}}}}.scalar-app .to-b-1\\.5{--tw-gradient-stops:var(--tw-gradient-via-stops,var(--tw-gradient-position),var(--tw-gradient-from)var(--tw-gradient-from-position),var(--tw-gradient-to)var(--tw-gradient-to-position))}.scalar-app .to-b-2{--tw-gradient-to:var(--scalar-background-2);--tw-gradient-stops:var(--tw-gradient-via-stops,var(--tw-gradient-position),var(--tw-gradient-from)var(--tw-gradient-from-position),var(--tw-gradient-to)var(--tw-gradient-to-position))}.scalar-app .mask-repeat{-webkit-mask-repeat:repeat;mask-repeat:repeat}.scalar-app .p-0\\.25{padding:1px}.scalar-app .p-2\\.5{padding:10px}.scalar-app .p-6{padding:24px}.scalar-app .px-3\\.5{padding-inline:14px}.scalar-app .px-9{padding-inline:36px}.scalar-app .py-4{padding-block:16px}.scalar-app .py-\\[6\\.75px\\]{padding-block:6.75px}.scalar-app .pl-8{padding-left:32px}.scalar-app .text-base\\/5{font-size:var(--scalar-font-size-3);line-height:var(--scalar-line-height-5)}.scalar-app .text-sm\\/5{font-size:var(--scalar-font-size-4);line-height:var(--scalar-line-height-5)}.scalar-app .text-lg{font-size:var(--scalar-font-size-2)}.scalar-app .leading-5{--tw-leading:var(--scalar-line-height-5);line-height:var(--scalar-line-height-5)}.scalar-app .font-sidebar{--tw-font-weight:var(--scalar-sidebar-font-weight,var(--scalar-regular));font-weight:var(--scalar-sidebar-font-weight,var(--scalar-regular))}.scalar-app .font-sidebar-active{--tw-font-weight:var(--scalar-sidebar-font-weight-active,var(--scalar-semibold));font-weight:var(--scalar-sidebar-font-weight-active,var(--scalar-semibold))}.scalar-app .text-nowrap{text-wrap:nowrap}.scalar-app .text-wrap{text-wrap:wrap}.scalar-app .break-words,.scalar-app .wrap-break-word{overflow-wrap:break-word}.scalar-app .text-c-accent{color:var(--scalar-color-accent)}.scalar-app .text-c-alert{color:var(--scalar-color-alert)}.scalar-app .text-c-tooltip{color:var(--scalar-tooltip-color)}.scalar-app .text-sidebar-c-1{color:var(--scalar-sidebar-color-1,var(--scalar-color-1))}.scalar-app .text-sidebar-c-search{color:var(--scalar-sidebar-search-color,var(--scalar-color-3))}.scalar-app .text-white{color:#fff}.scalar-app .opacity-40{opacity:.4}.scalar-app .outline-offset-1{outline-offset:1px}.scalar-app .outline-offset-\\[-1px\\]{outline-offset:-1px}.scalar-app .backdrop-blur{--tw-backdrop-blur:blur(8px);-webkit-backdrop-filter:var(--tw-backdrop-blur,)var(--tw-backdrop-brightness,)var(--tw-backdrop-contrast,)var(--tw-backdrop-grayscale,)var(--tw-backdrop-hue-rotate,)var(--tw-backdrop-invert,)var(--tw-backdrop-opacity,)var(--tw-backdrop-saturate,)var(--tw-backdrop-sepia,);backdrop-filter:var(--tw-backdrop-blur,)var(--tw-backdrop-brightness,)var(--tw-backdrop-contrast,)var(--tw-backdrop-grayscale,)var(--tw-backdrop-hue-rotate,)var(--tw-backdrop-invert,)var(--tw-backdrop-opacity,)var(--tw-backdrop-saturate,)var(--tw-backdrop-sepia,)}:is(.scalar-app .\\*\\:size-3>*){width:12px;height:12px}:is(.scalar-app .\\*\\:size-4>*){width:16px;height:16px}:is(.scalar-app .\\*\\:h-5>*){height:20px}:is(.scalar-app .\\*\\:min-w-5>*){min-width:20px}:is(.scalar-app .\\*\\:flex-1>*){flex:1}:is(.scalar-app .\\*\\:justify-center>*){justify-content:center}:is(.scalar-app .\\*\\:gap-px>*){gap:1px}:is(.scalar-app .\\*\\:rounded>*){border-radius:var(--scalar-radius)}:is(.scalar-app .\\*\\:border>*){border-style:var(--tw-border-style);border-width:var(--scalar-border-width)}:is(.scalar-app .\\*\\:border-border-tooltip>*){border-color:var(--scalar-tooltip-color)}@supports (color:color-mix(in lab,red,red)){:is(.scalar-app .\\*\\:border-border-tooltip>*){border-color:var(--scalar-tooltip-color)}@supports (color:color-mix(in lab,red,red)){:is(.scalar-app .\\*\\:border-border-tooltip>*){border-color:var(--scalar-tooltip-color)}@supports (color:color-mix(in lab,red,red)){:is(.scalar-app .\\*\\:border-border-tooltip>*){border-color:var(--scalar-tooltip-color)}@supports (color:color-mix(in lab,red,red)){:is(.scalar-app .\\*\\:border-border-tooltip>*){border-color:color-mix(in srgb,var(--scalar-tooltip-color),var(--scalar-tooltip-background))}}}}}:is(.scalar-app .\\*\\:px-1>*){padding-inline:4px}:is(.scalar-app .\\*\\:text-xs>*){font-size:var(--scalar-font-size-5)}@media(hover:hover){.scalar-app .group-hover\\:text-c-1:is(:where(.group):hover *){color:var(--scalar-color-1)}.scalar-app .group-hover\\/button\\:bg-sidebar-indent-border-hover:is(:where(.group\\/button):hover *){background-color:var(--scalar-sidebar-indent-border-hover,var(--scalar-border-color))}.scalar-app .group-hover\\/button\\:text-c-1:is(:where(.group\\/button):hover *){color:var(--scalar-color-1)}.scalar-app .group-hover\\/code-block\\:opacity-100:is(:where(.group\\/code-block):hover *){opacity:1}}.scalar-app .group-focus-visible\\/toggle\\:outline:is(:where(.group\\/toggle):focus-visible *){outline-style:var(--tw-outline-style);outline-width:1px}.scalar-app .placeholder\\:font-\\[inherit\\]::placeholder{font-family:inherit}.scalar-app .first\\:rounded-t-\\[inherit\\]:first-child,:is(.scalar-app .\\*\\:first\\:rounded-t-\\[inherit\\]>*):first-child{border-top-left-radius:inherit;border-top-right-radius:inherit}.scalar-app .last\\:rounded-b-\\[inherit\\]:last-child,:is(.scalar-app .\\*\\:last\\:rounded-b-\\[inherit\\]>*):last-child{border-bottom-right-radius:inherit;border-bottom-left-radius:inherit}.scalar-app .focus-within\\:outline-none:focus-within{--tw-outline-style:none;outline-style:none}@media(hover:hover){.scalar-app .hover\\:bg-b-2:hover{background-color:var(--scalar-background-2)}.scalar-app .hover\\:bg-b-3:hover{background-color:var(--scalar-background-3)}.scalar-app .hover\\:bg-h-btn:hover{background-color:var(--scalar-button-1-hover)}.scalar-app .hover\\:bg-sidebar-b-1:hover{background-color:var(--scalar-sidebar-background-1,var(--scalar-background-1))}.scalar-app .hover\\:bg-sidebar-b-hover:hover{background-color:var(--scalar-sidebar-item-hover-background,var(--scalar-background-2))}.scalar-app .hover\\:bg-linear-to-b:hover{--tw-gradient-position:to bottom}@supports (background-image:linear-gradient(in lab,red,red)){.scalar-app .hover\\:bg-linear-to-b:hover{--tw-gradient-position:to bottom in oklab}}.scalar-app .hover\\:bg-linear-to-b:hover{background-image:linear-gradient(var(--tw-gradient-stops))}.scalar-app .hover\\:bg-linear-to-t:hover{--tw-gradient-position:to top}@supports (background-image:linear-gradient(in lab,red,red)){.scalar-app .hover\\:bg-linear-to-t:hover{--tw-gradient-position:to top in oklab}}.scalar-app .hover\\:bg-linear-to-t:hover{background-image:linear-gradient(var(--tw-gradient-stops))}.scalar-app .hover\\:text-c-1:hover{color:var(--scalar-color-1)}.scalar-app .hover\\:text-sidebar-c-1:hover{color:var(--scalar-sidebar-color-1,var(--scalar-color-1))}.scalar-app .hover\\:text-sidebar-c-hover:hover{color:var(--scalar-sidebar-item-hover-color,var(--scalar-sidebar-color-2))}.scalar-app .hover\\:underline:hover{text-decoration-line:underline}.scalar-app .hover\\:brightness-90:hover{--tw-brightness:brightness(90%);filter:var(--tw-blur,)var(--tw-brightness,)var(--tw-contrast,)var(--tw-grayscale,)var(--tw-hue-rotate,)var(--tw-invert,)var(--tw-saturate,)var(--tw-sepia,)var(--tw-drop-shadow,)}}.scalar-app .focus-visible\\:border-c-btn:focus-visible{border-color:var(--scalar-button-1-color)}.scalar-app .focus-visible\\:opacity-100:focus-visible{opacity:1}.scalar-app .focus-visible\\:outline:focus-visible{outline-style:var(--tw-outline-style);outline-width:1px}.scalar-app .active\\:bg-b-btn:active{background-color:var(--scalar-button-1)}.scalar-app .active\\:brightness-90:active{--tw-brightness:brightness(90%);filter:var(--tw-blur,)var(--tw-brightness,)var(--tw-contrast,)var(--tw-grayscale,)var(--tw-hue-rotate,)var(--tw-invert,)var(--tw-saturate,)var(--tw-sepia,)var(--tw-drop-shadow,)}.scalar-app .has-\\[\\:focus-visible\\]\\:bg-sidebar-b-1:has(:focus-visible){background-color:var(--scalar-sidebar-background-1,var(--scalar-background-1))}.scalar-app .has-\\[\\:focus-visible\\]\\:outline:has(:focus-visible),.scalar-app .has-\\[input\\:focus-visible\\]\\:outline:has(:is(input:focus-visible)){outline-style:var(--tw-outline-style);outline-width:1px}@media(min-width:800px){.scalar-app .md\\:w-\\[calc\\(100vw-16px\\)\\]{width:calc(100vw - 16px)}}@media(min-width:1000px){.scalar-app .lg\\:w-\\[calc\\(100vw-32px\\)\\]{width:calc(100vw - 32px)}.scalar-app .lg\\:w-full{width:100%}}.scalar-app .dark\\:bg-\\(--bg-dark\\):where(.dark-mode,.dark-mode *){background-color:var(--bg-dark)}.scalar-app .dark\\:bg-b-3:where(.dark-mode,.dark-mode *){background-color:var(--scalar-background-3)}.scalar-app .dark\\:bg-backdrop-dark:where(.dark-mode,.dark-mode *){background-color:#00000073}.scalar-app .dark\\:bg-linear-to-t:where(.dark-mode,.dark-mode *){--tw-gradient-position:to top}@supports (background-image:linear-gradient(in lab,red,red)){.scalar-app .dark\\:bg-linear-to-t:where(.dark-mode,.dark-mode *){--tw-gradient-position:to top in oklab}}.scalar-app .dark\\:bg-linear-to-t:where(.dark-mode,.dark-mode *){background-image:linear-gradient(var(--tw-gradient-stops))}@media(hover:hover){.scalar-app .dark\\:hover\\:bg-b-3:where(.dark-mode,.dark-mode *):hover{background-color:var(--scalar-background-3)}.scalar-app .dark\\:hover\\:bg-linear-to-b:where(.dark-mode,.dark-mode *):hover{--tw-gradient-position:to bottom}@supports (background-image:linear-gradient(in lab,red,red)){.scalar-app .dark\\:hover\\:bg-linear-to-b:where(.dark-mode,.dark-mode *):hover{--tw-gradient-position:to bottom in oklab}}.scalar-app .dark\\:hover\\:bg-linear-to-b:where(.dark-mode,.dark-mode *):hover{background-image:linear-gradient(var(--tw-gradient-stops))}.scalar-app .dark\\:hover\\:bg-linear-to-t:where(.dark-mode,.dark-mode *):hover{--tw-gradient-position:to top}@supports (background-image:linear-gradient(in lab,red,red)){.scalar-app .dark\\:hover\\:bg-linear-to-t:where(.dark-mode,.dark-mode *):hover{--tw-gradient-position:to top in oklab}}.scalar-app .dark\\:hover\\:bg-linear-to-t:where(.dark-mode,.dark-mode *):hover{background-image:linear-gradient(var(--tw-gradient-stops))}}@media(max-width:720px)and (max-height:480px){.scalar-app .zoomed\\:\\!whitespace-normal{white-space:normal!important}}.loader-wrapper[data-v-27df5cd8]{--loader-size:50%;justify-content:center;align-items:center;display:flex;position:relative}.svg-loader[data-v-27df5cd8]{width:var(--loader-size);height:var(--loader-size);fill:none;stroke:currentColor;background-color:#0000;top:1rem;right:.9rem;overflow:visible}.svg-path[data-v-27df5cd8]{stroke-width:12px;fill:none;transition:all .3s}.svg-x-mark[data-v-27df5cd8]{stroke-dasharray:57;stroke-dashoffset:57px;transition-delay:0s}.svg-check-mark[data-v-27df5cd8]{stroke-dasharray:149;stroke-dashoffset:149px;transition-delay:0s}.icon-is-invalid .svg-x-mark[data-v-27df5cd8],.icon-is-valid .svg-check-mark[data-v-27df5cd8]{stroke-dashoffset:0;transition-delay:.3s}.circular-loader[data-v-27df5cd8]{transform-origin:50%;background:0 0;animation:.7s linear infinite rotate-27df5cd8,.4s fade-in-27df5cd8;transform:scale(3.5)}.loader-path[data-v-27df5cd8]{stroke-dasharray:50 200;stroke-dashoffset:-100px;stroke-linecap:round}.loader-path-off[data-v-27df5cd8]{stroke-dasharray:50 200;stroke-dashoffset:-100px;opacity:0;transition:opacity .3s}.scalar-code-block:hover .scalar-code-copy[data-v-e1870266]{opacity:100}.copy-icon[data-v-e1870266],.check-icon[data-v-e1870266]{transition:transform .15s ease-in-out;position:absolute;top:50%;left:50%;transform:translate(-50%,-50%)scale(1)}.copy-icon.copied[data-v-e1870266],.check-icon[data-v-e1870266]{transform:translate(-50%,-50%)scale(0)}.check-icon.visible[data-v-e1870266]{transform:translate(-50%,-50%)scale(1)}.scalar-code-block{background:inherit;padding:10px 8px 12px 12px;position:relative;overflow:auto}.scalar-codeblock-pre{all:unset;text-wrap:nowrap;white-space-collapse:preserve;background:0 0;border-radius:0;width:fit-content;margin:0}.toggle-icon-ellipse[data-v-60be8692]{background:var(--scalar-background-1);border-radius:50%;width:7px;height:7px;transition:width .3s ease-in-out,height .3s ease-in-out;display:inline-block;position:relative;overflow:hidden;box-shadow:inset 0 0 0 1px}.toggle-icon-moon-mask[data-v-60be8692]{background:var(--scalar-background-1);border:1px solid;border-radius:50%;width:100%;height:100%;transition:transform .3s ease-in-out;display:block;position:absolute;bottom:2.5px;left:2.5px;transform:translate(4px,-4px)}.toggle-icon-sun-ray[data-v-60be8692]{background:currentColor;border-radius:8px;width:12px;height:1px;transition:transform .3s ease-in-out;position:absolute}.toggle-icon-sun-ray[data-v-60be8692]:nth-of-type(2){transform:rotate(90deg)}.toggle-icon-sun-ray[data-v-60be8692]:nth-of-type(3){transform:rotate(45deg)}.toggle-icon-sun-ray[data-v-60be8692]:nth-of-type(4){transform:rotate(-45deg)}.toggle-icon-dark .toggle-icon-ellipse[data-v-60be8692]{width:10px;height:10px;-webkit-mask-image:radial-gradient(circle at 0 100%,pink 10px,#0000 12px);mask-image:radial-gradient(circle at 0 100%,pink 10px,#0000 12px)}.toggle-icon-dark .toggle-icon-sun-ray[data-v-60be8692]{transform:scale(0)}.toggle-icon-dark .toggle-icon-moon-mask[data-v-60be8692]{transform:translateZ(0)}.scalar-icon[data-v-b651bb23],.scalar-icon[data-v-b651bb23] *{stroke-width:var(--c07589c2)}.scalar-app :where(code.hljs) *{font-size:inherit;font-family:var(--scalar-font-code);text-align:left;white-space:pre;word-spacing:normal;word-break:normal;word-wrap:normal;tab-size:4;line-height:1.4}.scalar-app code.hljs{all:unset;font-size:inherit;color:var(--scalar-color-2);font-family:var(--scalar-font-code);counter-reset:linenumber}.scalar-app .hljs{color:var(--scalar-color-2);background:0 0}.scalar-app .hljs .line:before{color:var(--scalar-color-3);counter-increment:linenumber;content:counter(linenumber);min-width:calc(var(--line-digits)*1ch);text-align:right;margin-right:.875rem;display:inline-block}.scalar-app .hljs-comment,.scalar-app .hljs-quote{color:var(--scalar-color-3);font-style:italic}.scalar-app .hljs-number{color:var(--scalar-color-orange)}.scalar-app .hljs-regexp,.scalar-app .hljs-string,.scalar-app .hljs-built_in{color:var(--scalar-color-blue)}.scalar-app .hljs-title.class_{color:var(--scalar-color-1)}.scalar-app .hljs-keyword{color:var(--scalar-color-purple)}.scalar-app .hljs-title.function_{color:var(--scalar-color-orange)}.scalar-app .hljs-subst,.scalar-app .hljs-name{color:var(--scalar-color-blue)}.scalar-app .hljs-attr,.scalar-app .hljs-attribute{color:var(--scalar-color-1)}.scalar-app .hljs-addition,.scalar-app .hljs-literal,.scalar-app .hljs-selector-tag,.scalar-app .hljs-type{color:var(--scalar-color-green)}.scalar-app .hljs-selector-attr,.scalar-app .hljs-selector-pseudo{color:var(--scalar-color-orange)}.scalar-app .hljs-doctag,.scalar-app .hljs-section,.scalar-app .hljs-title{color:var(--scalar-color-blue)}.scalar-app .hljs-selector-id,.scalar-app .hljs-template-variable,.scalar-app .hljs-variable{color:var(--scalar-color-1)}.scalar-app .hljs-name,.scalar-app .hljs-section,.scalar-app .hljs-strong{font-weight:var(--scalar-semibold)}.scalar-app .hljs-bullet,.scalar-app .hljs-link,.scalar-app .hljs-meta,.scalar-app .hljs-symbol{color:var(--scalar-color-blue)}.scalar-app .hljs-deletion{color:var(--scalar-color-red)}.scalar-app .hljs-formula{background:var(--scalar-color-1)}.scalar-app .hljs-emphasis{font-style:italic}.scalar-app .credential .credential-value{color:#0000;font-size:0}.scalar-app .credential:after{content:"·····";color:var(--scalar-color-3);-webkit-user-select:none;user-select:none}.hljs.language-html{color:var(--scalar-color-1)}.hljs.language-html .hljs-attr{color:var(--scalar-color-2)}.hljs.language-curl .hljs-string{color:var(--scalar-color-blue)}.hljs.language-curl .hljs-literal{color:var(--scalar-color-1)}.hljs.language-php .hljs-variable{color:var(--scalar-color-blue)}.hljs.language-objectivec .hljs-meta{color:var(--scalar-color-1)}.hljs.language-objectivec .hljs-built_in,.hljs-built_in{color:var(--scalar-color-orange)}.scalar-app .markdown{--scalar-refs-heading-spacing:24px;--markdown-border:var(--scalar-border-width)solid var(--scalar-border-color);--markdown-spacing-sm:12px;--markdown-spacing-md:16px;--markdown-line-height:1.625;--markdown-heading-line-height:1.15;font-family:var(--scalar-font);word-break:break-word;line-height:var(--markdown-line-height)}.scalar-app .markdown>*{margin-bottom:var(--markdown-spacing-md)}.scalar-app .markdown>:not(h1):not(h2):not(h3):not(h4):not(h5):not(h6):last-child{margin-bottom:0}.scalar-app .markdown h1,.scalar-app .markdown h2,.scalar-app .markdown h3,.scalar-app .markdown h4,.scalar-app .markdown h5,.scalar-app .markdown h6{font-weight:var(--scalar-bold);margin-top:var(--scalar-refs-heading-spacing);margin-bottom:var(--markdown-spacing-sm);line-height:var(--markdown-heading-line-height,1.15);scroll-margin-top:1rem;display:block}.scalar-app .markdown h1{font-size:1.5rem}.scalar-app .markdown h2,.scalar-app .markdown h3{font-size:1.25rem}.scalar-app .markdown h4,.scalar-app .markdown h5,.scalar-app .markdown h6{font-size:1rem}.scalar-app .markdown b,.scalar-app .markdown strong{font-weight:var(--scalar-bold)}.scalar-app .markdown p{color:inherit;line-height:var(--markdown-line-height);display:block}.scalar-app .markdown img{border-radius:var(--scalar-radius);max-width:100%;display:inline-block;overflow:hidden}.scalar-app .markdown ul,.scalar-app .markdown ol{line-height:var(--markdown-line-height);flex-direction:column;gap:2px;padding-left:1.6em;display:flex}.scalar-app .markdown li{margin-top:2px;padding-left:7px}.scalar-app ol>li::marker{font:var(--scalar-font);font-variant-numeric:tabular-nums;font-weight:var(--scalar-semibold);white-space:nowrap}.scalar-app ol>*>li::marker{font:var(--scalar-font);font-variant-numeric:tabular-nums;font-weight:var(--scalar-semibold);white-space:nowrap}.scalar-app .markdown ol{list-style-type:decimal}.scalar-app .markdown ol ol{list-style-type:lower-alpha}.scalar-app .markdown ol ol ol ol,.scalar-app .markdown ol ol ol ol ol ol ol{list-style-type:decimal}.scalar-app .markdown ol ol ol ol ol,.scalar-app .markdown ol ol ol ol ol ol ol ol{list-style-type:lower-alpha}.scalar-app .markdown ol ol ol,.scalar-app .markdown ol ol ol ol ol ol,.scalar-app .markdown ol ol ol ol ol ol ol ol ol{list-style-type:lower-roman}.scalar-app .markdown ul>li,.scalar-app .markdown ul>*>li{list-style-type:disc}.scalar-app .markdown table{table-layout:fixed;border:var(--scalar-border-width)solid var(--scalar-border-color);border-radius:var(--scalar-radius);border-spacing:0;width:100%;margin:1em 0;display:table;position:relative;overflow-x:auto}.scalar-app .markdown tbody,.scalar-app .markdown thead{vertical-align:middle}.scalar-app .markdown tbody{display:table-row-group}.scalar-app .markdown thead{display:table-header-group}.scalar-app .markdown tr{border-color:inherit;vertical-align:inherit;display:table-row}.scalar-app .markdown td,.scalar-app .markdown th{vertical-align:top;min-width:1em;line-height:var(--markdown-line-height);word-break:break-word;font-size:var(--scalar-small);color:var(--scalar-color-1);border-right:var(--markdown-border);border-bottom:var(--markdown-border);padding:8.5px 16px;display:table-cell;position:relative}.scalar-app .markdown td>*,.scalar-app .markdown th>*{margin-bottom:0}.scalar-app .markdown th:empty{display:none}.scalar-app .markdown td:first-of-type,.scalar-app .markdown th:first-of-type{border-left:none}.scalar-app .markdown td:last-of-type,.scalar-app .markdown th:last-of-type{border-right:none}.scalar-app .markdown tr:last-of-type td{border-bottom:none}.scalar-app .markdown th{font-weight:var(--scalar-bold);text-align:left;background:var(--scalar-background-2);border-left-color:#0000}.scalar-app .markdown th:first-of-type{border-top-left-radius:var(--scalar-radius)}.scalar-app .markdown th:last-of-type{border-top-right-radius:var(--scalar-radius)}.scalar-app .markdown tr>[align=left]{text-align:left}.scalar-app .markdown tr>[align=right]{text-align:right}.scalar-app .markdown tr>[align=center]{text-align:center}.scalar-app .markdown details{border:var(--markdown-border);border-radius:var(--scalar-radius);color:var(--scalar-color-1)}.scalar-app .markdown details>:not(summary){margin:var(--markdown-spacing-md);margin-bottom:0}.scalar-app .markdown details>p:has(>strong):not(:has(:not(strong))){margin-bottom:8px}.scalar-app .markdown details>p:has(>strong):not(:has(:not(strong)))+*{margin-top:0}.scalar-app .markdown details>table{width:calc(100% - calc(var(--markdown-spacing-md)*2))}.scalar-app .markdown summary{min-height:40px;font-weight:var(--scalar-semibold);line-height:var(--markdown-line-height);cursor:pointer;-webkit-user-select:none;user-select:none;border-radius:2.5px;align-items:flex-start;gap:8px;padding:7px 14px;display:flex;position:relative}.scalar-app .markdown summary:hover{background-color:var(--scalar-background-2)}.scalar-app .markdown details[open]{padding-bottom:var(--markdown-spacing-md)}.scalar-app .markdown details[open]>summary{border-bottom:var(--markdown-border);border-bottom-right-radius:0;border-bottom-left-radius:0}.scalar-app .markdown summary:before{content:"";width:var(--markdown-spacing-md);height:var(--markdown-spacing-md);background-color:var(--scalar-color-3);flex-shrink:0;margin-top:5px;display:block;-webkit-mask-image:url(\'data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 256 256" fill="currentColor" width="1em" height="1em"><path d="M181.66,133.66l-80,80a8,8,0,0,1-11.32-11.32L164.69,128,90.34,53.66a8,8,0,0,1,11.32-11.32l80,80A8,8,0,0,1,181.66,133.66Z"></path></svg>\');mask-image:url(\'data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 256 256" fill="currentColor" width="1em" height="1em"><path d="M181.66,133.66l-80,80a8,8,0,0,1-11.32-11.32L164.69,128,90.34,53.66a8,8,0,0,1,11.32-11.32l80,80A8,8,0,0,1,181.66,133.66Z"></path></svg>\')}.scalar-app .markdown summary:hover:before{background-color:var(--scalar-color-1)}.scalar-app .markdown details[open]>summary:before{transition:transform .1s ease-in-out;transform:rotate(90deg)}.scalar-app .markdown details:has(+details){border-bottom:0;border-bottom-right-radius:0;border-bottom-left-radius:0;margin-bottom:0}.scalar-app .markdown details:has(+details)+details,.scalar-app .markdown details:has(+details)+details>summary{border-top-left-radius:0;border-top-right-radius:0}.scalar-app .markdown a{--font-color:var(--scalar-link-color,var(--scalar-color-accent));--font-visited:var(--scalar-link-color-visited,var(--scalar-color-2));-webkit-text-decoration:var(--scalar-text-decoration);text-decoration:var(--scalar-text-decoration);color:var(--font-color);font-weight:var(--scalar-link-font-weight,var(--scalar-semibold));text-underline-offset:.25rem;text-decoration-thickness:1px;-webkit-text-decoration-color:var(--font-color);text-decoration-color:var(--font-color)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown a{-webkit-text-decoration-color:var(--font-color)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown a{-webkit-text-decoration-color:var(--font-color)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown a{-webkit-text-decoration-color:color-mix(in srgb,var(--font-color)30%,transparent)}}}.scalar-app .markdown a{-webkit-text-decoration-color:var(--font-color);text-decoration-color:var(--font-color)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown a{-webkit-text-decoration-color:var(--font-color)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown a{-webkit-text-decoration-color:color-mix(in srgb,var(--font-color)30%,transparent)}}.scalar-app .markdown a{-webkit-text-decoration-color:var(--font-color);text-decoration-color:var(--font-color)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown a{-webkit-text-decoration-color:color-mix(in srgb,var(--font-color)30%,transparent);text-decoration-color:color-mix(in srgb,var(--font-color)30%,transparent)}}}}.scalar-app .markdown a:hover{-webkit-text-decoration-color:var(--scalar-color-1,currentColor);text-decoration-color:var(--scalar-color-1,currentColor);color:var(--scalar-link-color-hover,var(--scalar-color-accent));-webkit-text-decoration:var(--scalar-text-decoration-hover);text-decoration:var(--scalar-text-decoration-hover)}.scalar-app .markdown a:visited{color:var(--font-visited)}.scalar-app .markdown em{font-style:italic}.scalar-app .markdown sup,.scalar-app .markdown sub{font-size:var(--scalar-micro);font-weight:450}.scalar-app .markdown sup{vertical-align:super}.scalar-app .markdown sub{vertical-align:sub}.scalar-app .markdown del{text-decoration:line-through}.scalar-app .markdown code{font-family:var(--scalar-font-code);background-color:var(--scalar-background-2);box-shadow:0 0 0 var(--scalar-border-width) var(--scalar-border-color);font-size:var(--scalar-micro);border-radius:2px;padding:0 3px}.scalar-app .markdown .hljs{font-size:var(--scalar-small)}.scalar-app .markdown pre code{white-space:pre;padding:var(--markdown-spacing-sm);margin:var(--markdown-spacing-sm)0;-webkit-overflow-scrolling:touch;min-width:100px;max-width:100%;line-height:1.5;display:block;overflow-x:auto}.scalar-app .markdown hr{border:none;border-bottom:var(--markdown-border)}.scalar-app .markdown blockquote{border-left:1px solid var(--scalar-color-1);padding-left:var(--markdown-spacing-md);font-weight:var(--scalar-bold);font-size:var(--scalar-font-size-2);margin:0;display:block}.scalar-app .markdown li.task-list-item{list-style:none;position:relative}.scalar-app .markdown li.task-list-item>input{appearance:none;width:var(--markdown-spacing-md);height:var(--markdown-spacing-md);border:1px solid var(--scalar-color-3);border-radius:var(--scalar-radius);display:inline;position:absolute;top:.225em;left:-1.4em}.scalar-app .markdown li.task-list-item>input[type=checkbox]:checked{background-color:var(--scalar-color-1);border-color:var(--scalar-color-1)}.scalar-app .markdown li.task-list-item>input[type=checkbox]:before{content:"";border:solid var(--scalar-background-1);opacity:0;border-width:0 1.5px 1.5px 0;width:5px;height:10px;position:absolute;top:1px;left:5px;transform:rotate(45deg)}.scalar-app .markdown li.task-list-item>input[type=checkbox]:checked:before{opacity:1}.scalar-app .markdown .markdown-alert{border-radius:var(--scalar-radius);background-color:var(--scalar-background-2);align-items:stretch}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert{background-color:var(--scalar-background-2)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert{background-color:var(--scalar-background-2)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert{background-color:color-mix(in srgb,var(--scalar-background-2),transparent)}}}}.scalar-app .markdown .markdown-alert{border:var(--markdown-border);gap:var(--markdown-spacing-sm);padding:10px 14px;display:flex;position:relative}.scalar-app .markdown .markdown-alert .markdown-alert-icon:before{content:"";background-color:currentColor;flex-shrink:0;width:18px;height:18px;margin-top:3px;display:block;-webkit-mask-position:50%;mask-position:50%;-webkit-mask-size:contain;mask-size:contain;-webkit-mask-repeat:no-repeat;mask-repeat:no-repeat}.scalar-app .markdown .markdown-alert.markdown-alert-note{background-color:var(--scalar-color-blue)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-note{background-color:var(--scalar-color-blue)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-note{background-color:var(--scalar-color-blue)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-note{background-color:color-mix(in srgb,var(--scalar-color-blue),transparent 97%)}}}}.scalar-app .markdown .markdown-alert.markdown-alert-note{border:var(--scalar-border-width)solid var(--scalar-color-blue)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-note{border:var(--scalar-border-width)solid var(--scalar-color-blue)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-note{border:var(--scalar-border-width)solid var(--scalar-color-blue)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-note{border:var(--scalar-border-width)solid color-mix(in srgb,var(--scalar-color-blue),transparent 50%)}}}}.scalar-app .markdown .markdown-alert.markdown-alert-tip{background-color:var(--scalar-color-2)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-tip{background-color:var(--scalar-color-2)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-tip{background-color:var(--scalar-color-2)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-tip{background-color:color-mix(in srgb,var(--scalar-color-2),transparent 97%)}}}}.scalar-app .markdown .markdown-alert.markdown-alert-tip{border:var(--scalar-border-width)solid var(--scalar-color-2)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-tip{border:var(--scalar-border-width)solid var(--scalar-color-2)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-tip{border:var(--scalar-border-width)solid var(--scalar-color-2)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-tip{border:var(--scalar-border-width)solid color-mix(in srgb,var(--scalar-color-2),transparent 50%)}}}}.scalar-app .markdown .markdown-alert.markdown-alert-note .markdown-alert-icon:before,.scalar-app .markdown .markdown-alert.markdown-alert-tip .markdown-alert-icon:before{color:var(--scalar-color-blue);-webkit-mask-image:url(\'data:image/svg+xml,<svg data-v-852d534d="" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 256 256" fill="currentColor" class="icon-placeholder"><path d="M128,24A104,104,0,1,0,232,128,104.11,104.11,0,0,0,128,24Zm0,192a88,88,0,1,1,88-88A88.1,88.1,0,0,1,128,216Zm16-40a8,8,0,0,1-8,8,16,16,0,0,1-16-16V128a8,8,0,0,1,0-16,16,16,0,0,1,16,16v40A8,8,0,0,1,144,176ZM112,84a12,12,0,1,1,12,12A12,12,0,0,1,112,84Z"></path></svg>\');mask-image:url(\'data:image/svg+xml,<svg data-v-852d534d="" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 256 256" fill="currentColor" class="icon-placeholder"><path d="M128,24A104,104,0,1,0,232,128,104.11,104.11,0,0,0,128,24Zm0,192a88,88,0,1,1,88-88A88.1,88.1,0,0,1,128,216Zm16-40a8,8,0,0,1-8,8,16,16,0,0,1-16-16V128a8,8,0,0,1,0-16,16,16,0,0,1,16,16v40A8,8,0,0,1,144,176ZM112,84a12,12,0,1,1,12,12A12,12,0,0,1,112,84Z"></path></svg>\')}.scalar-app .markdown .markdown-alert.markdown-alert-important,.scalar-app .markdown .markdown-alert.markdown-alert-warning{background-color:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-important,.scalar-app .markdown .markdown-alert.markdown-alert-warning{background-color:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-important,.scalar-app .markdown .markdown-alert.markdown-alert-warning{background-color:var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-important,.scalar-app .markdown .markdown-alert.markdown-alert-warning{background-color:color-mix(in srgb,var(--scalar-color-orange),transparent 97%)}}}}.scalar-app .markdown .markdown-alert.markdown-alert-important,.scalar-app .markdown .markdown-alert.markdown-alert-warning{border:var(--scalar-border-width)solid var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-important,.scalar-app .markdown .markdown-alert.markdown-alert-warning{border:var(--scalar-border-width)solid var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-important,.scalar-app .markdown .markdown-alert.markdown-alert-warning{border:var(--scalar-border-width)solid var(--scalar-color-orange)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-important,.scalar-app .markdown .markdown-alert.markdown-alert-warning{border:var(--scalar-border-width)solid color-mix(in srgb,var(--scalar-color-orange),transparent 50%)}}}}.scalar-app .markdown .markdown-alert.markdown-alert-important .markdown-alert-icon:before,.scalar-app .markdown .markdown-alert.markdown-alert-warning .markdown-alert-icon:before{-webkit-mask-image:url(\'data:image/svg+xml,<svg data-v-852d534d="" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 256 256" fill="currentColor" class="icon-placeholder"><path d="M236.8,188.09,149.35,36.22h0a24.76,24.76,0,0,0-42.7,0L19.2,188.09a23.51,23.51,0,0,0,0,23.72A24.35,24.35,0,0,0,40.55,224h174.9a24.35,24.35,0,0,0,21.33-12.19A23.51,23.51,0,0,0,236.8,188.09ZM222.93,203.8a8.5,8.5,0,0,1-7.48,4.2H40.55a8.5,8.5,0,0,1-7.48-4.2,7.59,7.59,0,0,1,0-7.72L120.52,44.21a8.75,8.75,0,0,1,15,0l87.45,151.87A7.59,7.59,0,0,1,222.93,203.8ZM120,144V104a8,8,0,0,1,16,0v40a8,8,0,0,1-16,0Zm20,36a12,12,0,1,1-12-12A12,12,0,0,1,140,180Z"></path></svg>\');mask-image:url(\'data:image/svg+xml,<svg data-v-852d534d="" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 256 256" fill="currentColor" class="icon-placeholder"><path d="M236.8,188.09,149.35,36.22h0a24.76,24.76,0,0,0-42.7,0L19.2,188.09a23.51,23.51,0,0,0,0,23.72A24.35,24.35,0,0,0,40.55,224h174.9a24.35,24.35,0,0,0,21.33-12.19A23.51,23.51,0,0,0,236.8,188.09ZM222.93,203.8a8.5,8.5,0,0,1-7.48,4.2H40.55a8.5,8.5,0,0,1-7.48-4.2,7.59,7.59,0,0,1,0-7.72L120.52,44.21a8.75,8.75,0,0,1,15,0l87.45,151.87A7.59,7.59,0,0,1,222.93,203.8ZM120,144V104a8,8,0,0,1,16,0v40a8,8,0,0,1-16,0Zm20,36a12,12,0,1,1-12-12A12,12,0,0,1,140,180Z"></path></svg>\')}.scalar-app .markdown .markdown-alert.markdown-alert-caution{background-color:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-caution{background-color:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-caution{background-color:var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-caution{background-color:color-mix(in srgb,var(--scalar-color-red),transparent 97%)}}}}.scalar-app .markdown .markdown-alert.markdown-alert-caution{border:var(--scalar-border-width)solid var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-caution{border:var(--scalar-border-width)solid var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-caution{border:var(--scalar-border-width)solid var(--scalar-color-red)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-caution{border:var(--scalar-border-width)solid color-mix(in srgb,var(--scalar-color-red),transparent 50%)}}}}.scalar-app .markdown .markdown-alert.markdown-alert-caution .markdown-alert-icon:before{color:var(--scalar-color-red);-webkit-mask-image:url(\'data:image/svg+xml,<svg data-v-852d534d="" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 256 256" fill="currentColor" class="icon-placeholder"><path d="M128,24A104,104,0,1,0,232,128,104.11,104.11,0,0,0,128,24Zm0,192a88,88,0,1,1,88-88A88.1,88.1,0,0,1,128,216Zm-8-80V80a8,8,0,0,1,16,0v56a8,8,0,0,1-16,0Zm20,36a12,12,0,1,1-12-12A12,12,0,0,1,140,172Z"></path></svg>\');mask-image:url(\'data:image/svg+xml,<svg data-v-852d534d="" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 256 256" fill="currentColor" class="icon-placeholder"><path d="M128,24A104,104,0,1,0,232,128,104.11,104.11,0,0,0,128,24Zm0,192a88,88,0,1,1,88-88A88.1,88.1,0,0,1,128,216Zm-8-80V80a8,8,0,0,1,16,0v56a8,8,0,0,1-16,0Zm20,36a12,12,0,1,1-12-12A12,12,0,0,1,140,172Z"></path></svg>\')}.scalar-app .markdown .markdown-alert.markdown-alert-success{background-color:var(--scalar-color-green)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-success{background-color:var(--scalar-color-green)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-success{background-color:var(--scalar-color-green)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-success{background-color:color-mix(in srgb,var(--scalar-color-green),transparent 97%)}}}}.scalar-app .markdown .markdown-alert.markdown-alert-success{border:var(--scalar-border-width)solid var(--scalar-color-green)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-success{border:var(--scalar-border-width)solid var(--scalar-color-green)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-success{border:var(--scalar-border-width)solid var(--scalar-color-green)}@supports (color:color-mix(in lab,red,red)){.scalar-app .markdown .markdown-alert.markdown-alert-success{border:var(--scalar-border-width)solid color-mix(in srgb,var(--scalar-color-green),transparent 50%)}}}}.scalar-app .markdown .markdown-alert.markdown-alert-success .markdown-alert-icon:before{color:var(--scalar-color-green);-webkit-mask-image:url(\'data:image/svg+xml,<svg data-v-852d534d="" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 256 256" fill="currentColor" class="icon-placeholder"><path d="M173.66,98.34a8,8,0,0,1,0,11.32l-56,56a8,8,0,0,1-11.32,0l-24-24a8,8,0,0,1,11.32-11.32L112,148.69l50.34-50.35A8,8,0,0,1,173.66,98.34ZM232,128A104,104,0,1,1,128,24,104.11,104.11,0,0,1,232,128Zm-16,0a88,88,0,1,0-88,88A88.1,88.1,0,0,0,216,128Z"></path></svg>\');mask-image:url(\'data:image/svg+xml,<svg data-v-852d534d="" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 256 256" fill="currentColor" class="icon-placeholder"><path d="M173.66,98.34a8,8,0,0,1,0,11.32l-56,56a8,8,0,0,1-11.32,0l-24-24a8,8,0,0,1,11.32-11.32L112,148.69l50.34-50.35A8,8,0,0,1,173.66,98.34ZM232,128A104,104,0,1,1,128,24,104.11,104.11,0,0,1,232,128Zm-16,0a88,88,0,1,0-88,88A88.1,88.1,0,0,0,216,128Z"></path></svg>\')}.scalar-app .markdown .markdown-alert.markdown-alert-note .markdown-alert-icon:before{color:var(--scalar-color-blue)}.scalar-app .markdown .markdown-alert.markdown-alert-tip .markdown-alert-icon:before{color:var(--scalar-color-2)}.scalar-app .markdown .markdown-alert.markdown-alert-important .markdown-alert-icon:before{color:var(--scalar-color-purple)}.scalar-app .markdown .markdown-alert.markdown-alert-warning .markdown-alert-icon:before{color:var(--scalar-color-orange)}.scalar-app .markdown .markdown-alert .markdown-alert-content{line-height:var(--markdown-line-height);margin:0}.scalar-app .markdown.markdown-summary.markdown-summary :before,.scalar-app .markdown.markdown-summary.markdown-summary :after{content:none}.scalar-app .markdown.markdown-summary.markdown-summary :not(strong,em,a){font-size:inherit;font-weight:inherit;line-height:var(--markdown-line-height);display:contents}.scalar-app .markdown.markdown-summary.markdown-summary img,.scalar-app .markdown.markdown-summary.markdown-summary svg,.scalar-app .markdown.markdown-summary.markdown-summary hr,.scalar-app .markdown.markdown-summary.markdown-summary pre{display:none}.dark-mode .scalar-dropdown-item[data-v-6660bbc5]:hover{filter:brightness(1.1)}.group\\/item>*>.scalar-sidebar-indent .scalar-sidebar-indent-border[data-v-3e080c68]{inset-block:-1px}.group\\/item:first-child>*>.scalar-sidebar-indent .scalar-sidebar-indent-border[data-v-3e080c68]{top:0}.group\\/item:last-child>*>.scalar-sidebar-indent .scalar-sidebar-indent-border[data-v-3e080c68]{bottom:0}.group\\/items.-translate-x-full .group\\/button{transition-behavior:allow-discrete;max-height:0;transition-property:display,max-height;transition-duration:0s;transition-delay:.3s;display:none}.group\\/item.group\\/nested-items-open>*>.group\\/items.translate-x-0 .group\\/button{max-height:3.40282e38px;display:flex}.group\\/sidebar-section:first-of-type>.group\\/spacer-before,.group\\/sidebar-section:last-of-type>.group\\/spacer-after{height:0}.group\\/sidebar-section:has(+.group\\/sidebar-section)>.group\\/spacer-after{height:0;margin-bottom:-1px}:where(body)>.scalar-tooltip{--scalar-tooltip-padding:8px;padding:calc(var(--scalar-tooltip-padding) + var(--scalar-tooltip-offset));z-index:99999;max-width:320px;font-size:var(--scalar-font-size-5);--tw-leading:var(--scalar-line-height-5);line-height:var(--scalar-line-height-5);--tw-font-weight:var(--scalar-semibold);font-weight:var(--scalar-semibold);overflow-wrap:break-word;color:var(--scalar-tooltip-color)}:where(body)>.scalar-tooltip:before{content:"";inset:var(--scalar-tooltip-offset);z-index:-1;border-radius:var(--scalar-radius);background-color:var(--scalar-tooltip-background);--tw-backdrop-blur:blur(8px);-webkit-backdrop-filter:var(--tw-backdrop-blur,)var(--tw-backdrop-brightness,)var(--tw-backdrop-contrast,)var(--tw-backdrop-grayscale,)var(--tw-backdrop-hue-rotate,)var(--tw-backdrop-invert,)var(--tw-backdrop-opacity,)var(--tw-backdrop-saturate,)var(--tw-backdrop-sepia,);backdrop-filter:var(--tw-backdrop-blur,)var(--tw-backdrop-brightness,)var(--tw-backdrop-contrast,)var(--tw-backdrop-grayscale,)var(--tw-backdrop-hue-rotate,)var(--tw-backdrop-invert,)var(--tw-backdrop-opacity,)var(--tw-backdrop-saturate,)var(--tw-backdrop-sepia,);position:absolute}:where(body.dark-mode)>.scalar-tooltip:before{--tw-shadow:inset 0 0 0 var(--tw-shadow-color,calc(var(--scalar-border-width)*2))var(--scalar-border-color);box-shadow:var(--tw-inset-shadow),var(--tw-inset-ring-shadow),var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow)}.dark-mode .scalar-dropdown-item[data-v-3402682d]:hover{filter:brightness(1.1)}.scalar-modal-layout[data-v-c36b47da]{animation:.3s ease-in-out forwards fadein-layout-c36b47da}.scalar-modal[data-v-c36b47da]{box-shadow:var(--scalar-shadow-2);animation:.3s ease-in-out .1s forwards fadein-modal-c36b47da;transform:translateY(10px)}.scalar-modal-layout-full[data-v-c36b47da]{opacity:1!important;background:0 0!important}.modal-content-search .modal-body[data-v-c36b47da]{flex-direction:column;max-height:440px;padding:0;display:flex;overflow:hidden}@media(max-width:720px)and (max-height:480px){.scalar-modal-layout .scalar-modal[data-v-c36b47da]{max-height:90svh;margin-top:5svh}}.full-size-styles[data-v-c36b47da]{margin:initial;border-right:var(--scalar-border-width)solid var(--scalar-border-color);animation:.3s ease-in-out forwards fadein-layout-c36b47da;left:0;transform:translate(0);background-color:var(--scalar-background-1)!important;max-height:100%!important;box-shadow:none!important;border-radius:0!important;position:absolute!important;top:0!important}@media(min-width:800px){.full-size-styles[data-v-c36b47da]{width:50dvw!important}}.full-size-styles[data-v-c36b47da]:after{content:"";width:50dvw;height:100dvh;position:absolute;top:0;right:-50dvw}.sidebar-heading-type[data-v-1857170e]{text-transform:uppercase;color:var(--method-color,var(--scalar-color-1));font-size:10px;line-height:14px;font-weight:var(--scalar-bold);font-family:var(--scalar-font-code);white-space:nowrap;flex-shrink:0;align-items:center;gap:4px;display:inline-flex;overflow:hidden}.scalar-app .pointer-events-auto{pointer-events:auto}.scalar-app .pointer-events-none{pointer-events:none}.scalar-app .collapse{visibility:collapse}.scalar-app .visible{visibility:visible}.scalar-app .floating-bg:before{background-color:var(--scalar-background-2);border-radius:var(--scalar-radius);content:"";opacity:0;z-index:1;width:calc(100% + 8px);height:calc(100% - 4px);transition:opacity .2s ease-in-out;position:absolute;top:2.5px;left:-4px}.scalar-app .floating-bg:hover:before{opacity:1}.scalar-app .centered{--tw-translate-y:-50%;--tw-translate-x:-50%;translate:var(--tw-translate-x)var(--tw-translate-y);position:absolute;top:50%;left:50%}.scalar-app .centered-y{--tw-translate-y:-50%;translate:var(--tw-translate-x)var(--tw-translate-y);position:absolute;top:50%}.scalar-app .centered-x{--tw-translate-x:-50%;translate:var(--tw-translate-x)var(--tw-translate-y);position:absolute;left:50%}.scalar-app .sr-only{clip-path:inset(50%);white-space:nowrap;border-width:0;width:1px;height:1px;margin:-1px;padding:0;position:absolute;overflow:hidden}.scalar-app .absolute{position:absolute}.scalar-app .fixed{position:fixed}.scalar-app .relative{position:relative}.scalar-app .static{position:static}.scalar-app .sticky{position:sticky}.scalar-app .inset-0{inset:0}.scalar-app .inset-x-0{inset-inline:0}.scalar-app .inset-x-1{inset-inline:4px}.scalar-app .-top-\\(--scalar-address-bar-height\\){top:calc(var(--scalar-address-bar-height)*-1)}.scalar-app .-top-\\[104px\\]{top:-104px}.scalar-app .top-0{top:0}.scalar-app .top-2{top:8px}.scalar-app .top-12{top:48px}.scalar-app .top-\\[calc\\(100\\%\\+4px\\)\\]{top:calc(100% + 4px)}.scalar-app .-right-\\[30px\\]{right:-30px}.scalar-app .right-0{right:0}.scalar-app .right-1{right:4px}.scalar-app .right-1\\.5{right:6px}.scalar-app .right-1\\/2{right:50%}.scalar-app .right-2{right:8px}.scalar-app .right-4{right:16px}.scalar-app .right-7{right:28px}.scalar-app .right-14{right:56px}.scalar-app .right-16{right:64px}.scalar-app .bottom-0{bottom:0}.scalar-app .bottom-1{bottom:4px}.scalar-app .bottom-1\\/2{bottom:50%}.scalar-app .bottom-\\[var\\(--scalar-border-width\\)\\]{bottom:var(--scalar-border-width)}.scalar-app .left-0{left:0}.scalar-app .left-1\\/2{left:50%}.scalar-app .left-3{left:12px}.scalar-app .-z-1{z-index:-1}.scalar-app .z-0{z-index:0}.scalar-app .z-1{z-index:1}.scalar-app .z-10{z-index:10}.scalar-app .z-20{z-index:20}.scalar-app .z-50{z-index:50}.scalar-app .z-\\[1\\]{z-index:1}.scalar-app .z-\\[1002\\]{z-index:1002}.scalar-app .z-\\[10000\\]{z-index:10000}.scalar-app .z-\\[10001\\]{z-index:10001}.scalar-app .z-context{z-index:1000}.scalar-app .z-context-plus{z-index:1001}.scalar-app .z-overlay{z-index:10000}.scalar-app .order-last{order:9999}.scalar-app .col-span-full{grid-column:1/-1}.scalar-app .container{width:100%}@media(min-width:400px){.scalar-app .container{max-width:400px}}@media(min-width:600px){.scalar-app .container{max-width:600px}}@media(min-width:800px){.scalar-app .container{max-width:800px}}@media(min-width:1000px){.scalar-app .container{max-width:1000px}}@media(min-width:1200px){.scalar-app .container{max-width:1200px}}@media(min-width:96rem){.scalar-app .container{max-width:96rem}}.scalar-app .\\!m-0{margin:0!important}.scalar-app .-m-0\\.5{margin:-2px}.scalar-app .m-0{margin:0}.scalar-app .m-4{margin:16px}.scalar-app .m-auto{margin:auto}.scalar-app .m-header{margin:48px}.scalar-app .-mx-0\\.25{margin-inline:-1px}.scalar-app .mx-1{margin-inline:4px}.scalar-app .mx-auto{margin-inline:auto}.scalar-app .-my-1{margin-block:-4px}.scalar-app .my-12{margin-block:48px}.scalar-app .-mt-\\[\\.5px\\]{margin-top:-.5px}.scalar-app .mt-0\\.25{margin-top:1px}.scalar-app .mt-1{margin-top:4px}.scalar-app .mt-1\\.5{margin-top:6px}.scalar-app .mt-2{margin-top:8px}.scalar-app .mt-3{margin-top:12px}.scalar-app .mt-5{margin-top:20px}.scalar-app .mt-10{margin-top:40px}.scalar-app .mt-\\[0\\.5px\\]{margin-top:.5px}.scalar-app .mt-auto{margin-top:auto}.scalar-app .\\!mr-0{margin-right:0!important}.scalar-app .-mr-0\\.5{margin-right:-2px}.scalar-app .-mr-1{margin-right:-4px}.scalar-app .-mr-1\\.5{margin-right:-6px}.scalar-app .-mr-3{margin-right:-12px}.scalar-app .mr-0\\.5{margin-right:2px}.scalar-app .mr-0\\.75{margin-right:3px}.scalar-app .mr-1{margin-right:4px}.scalar-app .mr-1\\.5{margin-right:6px}.scalar-app .mr-1\\.25{margin-right:5px}.scalar-app .mr-2{margin-right:8px}.scalar-app .mr-2\\.5{margin-right:10px}.scalar-app .mr-3{margin-right:12px}.scalar-app .mr-\\[6\\.25px\\]{margin-right:6.25px}.scalar-app .mr-auto{margin-right:auto}.scalar-app .\\!mb-0{margin-bottom:0!important}.scalar-app .-mb-\\[var\\(--scalar-border-width\\)\\]{margin-bottom:calc(var(--scalar-border-width)*-1)}.scalar-app .mb-0{margin-bottom:0}.scalar-app .mb-1{margin-bottom:4px}.scalar-app .mb-1\\.5{margin-bottom:6px}.scalar-app .mb-2{margin-bottom:8px}.scalar-app .mb-4{margin-bottom:16px}.scalar-app .mb-\\[\\.5px\\]{margin-bottom:.5px}.scalar-app .-ml-0\\.5{margin-left:-2px}.scalar-app .-ml-0\\.25{margin-left:-1px}.scalar-app .-ml-1{margin-left:-4px}.scalar-app .-ml-2{margin-left:-8px}.scalar-app .-ml-12{margin-left:-48px}.scalar-app .ml-0\\.5{margin-left:2px}.scalar-app .ml-0\\.75{margin-left:3px}.scalar-app .ml-1{margin-left:4px}.scalar-app .ml-1\\.25{margin-left:5px}.scalar-app .ml-3{margin-left:12px}.scalar-app .ml-auto{margin-left:auto}.scalar-app .box-border{box-sizing:border-box}.scalar-app .box-content{box-sizing:content-box}.scalar-app .flex-center{justify-content:center;align-items:center;display:flex}.scalar-app .line-clamp-1{-webkit-line-clamp:1;-webkit-box-orient:vertical;display:-webkit-box;overflow:hidden}.scalar-app .\\!block{display:block!important}.scalar-app .\\!flex{display:flex!important}.scalar-app .block{display:block}.scalar-app .contents{display:contents}.scalar-app .flex{display:flex}.scalar-app .grid{display:grid}.scalar-app .hidden{display:none}.scalar-app .inline{display:inline}.scalar-app .inline-block{display:inline-block}.scalar-app .inline-flex{display:inline-flex}.scalar-app .table{display:table}.scalar-app .aspect-\\[4\\/3\\]{aspect-ratio:4/3}.scalar-app .aspect-square{aspect-ratio:1}.scalar-app .size-2\\.5{width:10px;height:10px}.scalar-app .size-3{width:12px;height:12px}.scalar-app .size-3\\.5{width:14px;height:14px}.scalar-app .size-3\\/4{width:75%;height:75%}.scalar-app .size-4{width:16px;height:16px}.scalar-app .size-5{width:20px;height:20px}.scalar-app .size-6{width:24px;height:24px}.scalar-app .size-7{width:28px;height:28px}.scalar-app .size-8{width:32px;height:32px}.scalar-app .size-10{width:40px;height:40px}.scalar-app .size-full{width:100%;height:100%}.scalar-app .h-\\(--scalar-address-bar-height\\){height:var(--scalar-address-bar-height)}.scalar-app .h-1\\.5{height:6px}.scalar-app .h-2{height:8px}.scalar-app .h-2\\.5{height:10px}.scalar-app .h-2\\.25{height:9px}.scalar-app .h-3{height:12px}.scalar-app .h-3\\.5{height:14px}.scalar-app .h-4{height:16px}.scalar-app .h-5{height:20px}.scalar-app .h-6{height:24px}.scalar-app .h-7{height:28px}.scalar-app .h-8{height:32px}.scalar-app .h-9{height:36px}.scalar-app .h-10{height:40px}.scalar-app .h-12{height:48px}.scalar-app .h-16{height:64px}.scalar-app .h-64{height:256px}.scalar-app .h-\\[68px\\]{height:68px}.scalar-app .h-\\[calc\\(100\\%-273\\.5px\\)\\]{height:calc(100% - 273.5px)}.scalar-app .h-\\[calc\\(100\\%_-_50px\\)\\]{height:calc(100% - 50px)}.scalar-app .h-auto{height:auto}.scalar-app .h-fit{height:fit-content}.scalar-app .h-full{height:100%}.scalar-app .h-header{height:48px}.scalar-app .h-min{height:min-content}.scalar-app .h-px{height:1px}.scalar-app .h-screen{height:100vh}.scalar-app .\\!max-h-\\[initial\\]{max-height:initial!important}.scalar-app .max-h-8{max-height:32px}.scalar-app .max-h-40{max-height:160px}.scalar-app .max-h-80{max-height:320px}.scalar-app .max-h-\\[40dvh\\]{max-height:40dvh}.scalar-app .max-h-\\[50dvh\\]{max-height:50dvh}.scalar-app .max-h-\\[60svh\\]{max-height:60svh}.scalar-app .max-h-\\[auto\\]{max-height:auto}.scalar-app .max-h-\\[calc\\(100\\%-32px\\)\\]{max-height:calc(100% - 32px)}.scalar-app .max-h-\\[inherit\\]{max-height:inherit}.scalar-app .max-h-fit{max-height:fit-content}.scalar-app .max-h-screen{max-height:100vh}.scalar-app .\\!min-h-full{min-height:100%!important}.scalar-app .min-h-0{min-height:0}.scalar-app .min-h-8{min-height:32px}.scalar-app .min-h-10{min-height:40px}.scalar-app .min-h-11{min-height:44px}.scalar-app .min-h-12{min-height:48px}.scalar-app .min-h-16{min-height:64px}.scalar-app .min-h-20{min-height:80px}.scalar-app .min-h-\\[64px\\]{min-height:64px}.scalar-app .min-h-\\[65px\\]{min-height:65px}.scalar-app .min-h-\\[calc\\(1rem\\*4\\)\\]{min-height:4rem}.scalar-app .min-h-\\[calc\\(4rem\\+0\\.5px\\)\\]{min-height:calc(4rem + .5px)}.scalar-app .min-h-\\[calc\\(4rem\\+1px\\)\\]{min-height:calc(4rem + 1px)}.scalar-app .min-h-fit{min-height:fit-content}.scalar-app .\\!w-fit{width:fit-content!important}.scalar-app .w-0\\.5{width:2px}.scalar-app .w-1\\.5{width:6px}.scalar-app .w-1\\/2{width:50%}.scalar-app .w-2{width:8px}.scalar-app .w-2\\.5{width:10px}.scalar-app .w-2\\.25{width:9px}.scalar-app .w-3{width:12px}.scalar-app .w-3\\.5{width:14px}.scalar-app .w-4{width:16px}.scalar-app .w-5{width:20px}.scalar-app .w-6{width:24px}.scalar-app .w-7{width:28px}.scalar-app .w-8{width:32px}.scalar-app .w-10{width:40px}.scalar-app .w-16{width:64px}.scalar-app .w-20{width:80px}.scalar-app .w-56{width:224px}.scalar-app .w-64{width:256px}.scalar-app .w-72{width:288px}.scalar-app .w-\\[60px\\]{width:60px}.scalar-app .w-\\[100px\\]{width:100px}.scalar-app .w-\\[150px\\]{width:150px}.scalar-app .w-\\[calc\\(100\\%-10px\\)\\]{width:calc(100% - 10px)}.scalar-app .w-\\[calc\\(100\\%_-_8px\\)\\]{width:calc(100% - 8px)}.scalar-app .w-\\[inherit\\]{width:inherit}.scalar-app .w-auto{width:auto}.scalar-app .w-dvw{width:100dvw}.scalar-app .w-fit{width:fit-content}.scalar-app .w-full{width:100%}.scalar-app .w-max{width:max-content}.scalar-app .max-w-8{max-width:32px}.scalar-app .max-w-40{max-width:160px}.scalar-app .max-w-\\[14px\\]{max-width:14px}.scalar-app .max-w-\\[16rem\\]{max-width:16rem}.scalar-app .max-w-\\[37px\\]{max-width:37px}.scalar-app .max-w-\\[100\\%\\]{max-width:100%}.scalar-app .max-w-\\[150px\\]{max-width:150px}.scalar-app .max-w-\\[380px\\]{max-width:380px}.scalar-app .max-w-\\[420px\\]{max-width:420px}.scalar-app .max-w-\\[720px\\]{max-width:720px}.scalar-app .max-w-\\[calc\\(100dvw-24px\\)\\]{max-width:calc(100dvw - 24px)}.scalar-app .max-w-full{max-width:100%}.scalar-app .min-w-0{min-width:0}.scalar-app .min-w-2\\.25{min-width:9px}.scalar-app .min-w-3\\.5{min-width:14px}.scalar-app .min-w-4{min-width:16px}.scalar-app .min-w-8{min-width:32px}.scalar-app .min-w-32{min-width:128px}.scalar-app .min-w-48{min-width:192px}.scalar-app .min-w-\\[37px\\]{min-width:37px}.scalar-app .min-w-\\[100px\\]{min-width:100px}.scalar-app .min-w-\\[150px\\]{min-width:150px}.scalar-app .min-w-\\[296px\\]{min-width:296px}.scalar-app .min-w-fit{min-width:fit-content}.scalar-app .min-w-full{min-width:100%}.scalar-app .flex-1{flex:1}.scalar-app .flex-shrink{flex-shrink:1}.scalar-app .shrink-0{flex-shrink:0}.scalar-app .flex-grow{flex-grow:1}.scalar-app .-translate-x-1\\/2{--tw-translate-x:-50%;translate:var(--tw-translate-x)var(--tw-translate-y)}.scalar-app .translate-x-0{--tw-translate-x:0px;translate:var(--tw-translate-x)var(--tw-translate-y)}.scalar-app .translate-x-1\\/2{--tw-translate-x:50%;translate:var(--tw-translate-x)var(--tw-translate-y)}.scalar-app .translate-y-1\\/2{--tw-translate-y:50%;translate:var(--tw-translate-x)var(--tw-translate-y)}.scalar-app .scale-75{--tw-scale-x:75%;--tw-scale-y:75%;--tw-scale-z:75%;scale:var(--tw-scale-x)var(--tw-scale-y)}.scalar-app .rotate-90{rotate:90deg}.scalar-app .rotate-180{rotate:180deg}.scalar-app .transform{transform:var(--tw-rotate-x,)var(--tw-rotate-y,)var(--tw-rotate-z,)var(--tw-skew-x,)var(--tw-skew-y,)}.scalar-app .cursor-auto{cursor:auto}.scalar-app .cursor-default{cursor:default}.scalar-app .cursor-grab{cursor:grab}.scalar-app .cursor-help{cursor:help}.scalar-app .cursor-not-allowed{cursor:not-allowed}.scalar-app .cursor-pointer{cursor:pointer}.scalar-app .cursor-text{cursor:text}.scalar-app .resize{resize:both}.scalar-app .resize-none{resize:none}.scalar-app .auto-rows-\\[32px\\]{grid-auto-rows:32px}.scalar-app .auto-rows-auto{grid-auto-rows:auto}.scalar-app .grid-cols-2{grid-template-columns:repeat(2,minmax(0,1fr))}.scalar-app .grid-cols-\\[44px_1fr_repeat\\(3\\,auto\\)\\]{grid-template-columns:44px 1fr repeat(3,auto)}.scalar-app .grid-cols-\\[auto_1fr\\]{grid-template-columns:auto 1fr}.scalar-app .grid-cols-\\[repeat\\(auto-fill\\,minmax\\(32px\\,1fr\\)\\)\\]{grid-template-columns:repeat(auto-fill,minmax(32px,1fr))}.scalar-app .flex-col{flex-direction:column}.scalar-app .flex-row{flex-direction:row}.scalar-app .flex-wrap{flex-wrap:wrap}.scalar-app .content-between{align-content:space-between}.scalar-app .content-start{align-content:flex-start}.scalar-app .items-center{align-items:center}.scalar-app .items-end{align-items:flex-end}.scalar-app .items-start{align-items:flex-start}.scalar-app .items-stretch{align-items:stretch}.scalar-app .justify-between{justify-content:space-between}.scalar-app .justify-center{justify-content:center}.scalar-app .justify-end{justify-content:flex-end}.scalar-app .justify-start{justify-content:flex-start}.scalar-app .justify-stretch{justify-content:stretch}.scalar-app .\\!gap-2{gap:8px!important}.scalar-app .gap-0\\.5{gap:2px}.scalar-app .gap-0\\.75{gap:3px}.scalar-app .gap-1{gap:4px}.scalar-app .gap-1\\.5{gap:6px}.scalar-app .gap-1\\.75{gap:7px}.scalar-app .gap-2{gap:8px}.scalar-app .gap-2\\.5{gap:10px}.scalar-app .gap-3{gap:12px}.scalar-app .gap-4{gap:16px}.scalar-app .gap-6{gap:24px}.scalar-app .gap-8{gap:32px}.scalar-app .gap-10{gap:40px}.scalar-app .gap-12{gap:48px}.scalar-app .gap-\\[1\\.5px\\]{gap:1.5px}.scalar-app .gap-px{gap:1px}.scalar-app .gap-x-2\\.5{column-gap:10px}:where(.scalar-app .space-x-1>:not(:last-child)){--tw-space-x-reverse:0;margin-inline-start:calc(4px*var(--tw-space-x-reverse));margin-inline-end:calc(4px*calc(1 - var(--tw-space-x-reverse)))}:where(.scalar-app .divide-y>:not(:last-child)){--tw-divide-y-reverse:0;border-bottom-style:var(--tw-border-style);border-top-style:var(--tw-border-style);border-top-width:calc(var(--scalar-border-width)*var(--tw-divide-y-reverse));border-bottom-width:calc(var(--scalar-border-width)*calc(1 - var(--tw-divide-y-reverse)))}.scalar-app .self-center{align-self:center}.scalar-app .truncate{text-overflow:ellipsis;white-space:nowrap;overflow:hidden}.scalar-app .overflow-auto{overflow:auto}.scalar-app .overflow-hidden{overflow:hidden}.scalar-app .overflow-visible{overflow:visible}.scalar-app .overflow-x-auto{overflow-x:auto}.scalar-app .overflow-y-auto{overflow-y:auto}.scalar-app .overflow-y-hidden{overflow-y:hidden}.scalar-app .\\!rounded-none{border-radius:0!important}.scalar-app .rounded{border-radius:var(--scalar-radius)}.scalar-app .rounded-\\[10px\\]{border-radius:10px}.scalar-app .rounded-full{border-radius:9999px}.scalar-app .rounded-lg{border-radius:var(--scalar-radius-lg)}.scalar-app .rounded-md{border-radius:var(--scalar-radius)}.scalar-app .rounded-px{border-radius:1px}.scalar-app .rounded-xl{border-radius:var(--scalar-radius-xl)}.scalar-app .rounded-t{border-top-left-radius:var(--scalar-radius);border-top-right-radius:var(--scalar-radius)}.scalar-app .rounded-t-lg{border-top-left-radius:var(--scalar-radius-lg);border-top-right-radius:var(--scalar-radius-lg)}.scalar-app .rounded-t-none{border-top-left-radius:0;border-top-right-radius:0}.scalar-app .rounded-b{border-bottom-right-radius:var(--scalar-radius);border-bottom-left-radius:var(--scalar-radius)}.scalar-app .rounded-b-lg{border-bottom-right-radius:var(--scalar-radius-lg);border-bottom-left-radius:var(--scalar-radius-lg)}.scalar-app .\\!border-0{border-style:var(--tw-border-style)!important;border-width:0!important}.scalar-app .border{border-style:var(--tw-border-style);border-width:var(--scalar-border-width)}.scalar-app .border-0{border-style:var(--tw-border-style);border-width:0}.scalar-app .border-\\[1\\.5px\\]{border-style:var(--tw-border-style);border-width:1.5px}.scalar-app .border-\\[1px\\]{border-style:var(--tw-border-style);border-width:1px}.scalar-app .border-x{border-inline-style:var(--tw-border-style);border-inline-width:var(--scalar-border-width)}.scalar-app .border-x-0{border-inline-style:var(--tw-border-style);border-inline-width:0}.scalar-app .border-y{border-block-style:var(--tw-border-style);border-block-width:var(--scalar-border-width)}.scalar-app .border-t{border-top-style:var(--tw-border-style);border-top-width:var(--scalar-border-width)}.scalar-app .border-t-0{border-top-style:var(--tw-border-style);border-top-width:0}.scalar-app .\\!border-r{border-right-style:var(--tw-border-style)!important;border-right-width:var(--scalar-border-width)!important}.scalar-app .border-r{border-right-style:var(--tw-border-style);border-right-width:var(--scalar-border-width)}.scalar-app .border-r-0{border-right-style:var(--tw-border-style);border-right-width:0}.scalar-app .border-r-1{border-right-style:var(--tw-border-style);border-right-width:1px}.scalar-app .border-b{border-bottom-style:var(--tw-border-style);border-bottom-width:var(--scalar-border-width)}.scalar-app .border-b-0{border-bottom-style:var(--tw-border-style);border-bottom-width:0}.scalar-app .border-b-\\[1px\\]{border-bottom-style:var(--tw-border-style);border-bottom-width:1px}.scalar-app .border-l{border-left-style:var(--tw-border-style);border-left-width:var(--scalar-border-width)}.scalar-app .border-l-0{border-left-style:var(--tw-border-style);border-left-width:0}.scalar-app .\\!border-none{--tw-border-style:none!important;border-style:none!important}.scalar-app .border-dashed{--tw-border-style:dashed;border-style:dashed}.scalar-app .border-none{--tw-border-style:none;border-style:none}.scalar-app .\\!border-current{border-color:currentColor!important}.scalar-app .border-c-1{border-color:var(--scalar-color-1)}.scalar-app .border-c-3{border-color:var(--scalar-color-3)}.scalar-app .border-c-danger{border-color:var(--scalar-color-danger)}.scalar-app .border-transparent{border-color:#0000}.scalar-app .border-r-transparent{border-right-color:#0000}.scalar-app .bg-b-1{background-color:var(--scalar-background-1)}.scalar-app .bg-b-2{background-color:var(--scalar-background-2)}.scalar-app .bg-b-3{background-color:var(--scalar-background-3)}.scalar-app .bg-b-danger{background-color:var(--scalar-background-danger)}.scalar-app .bg-c-3\\/5{background-color:var(--scalar-color-3)}@supports (color:color-mix(in lab,red,red)){.scalar-app .bg-c-3\\/5{background-color:var(--scalar-color-3)}@supports (color:color-mix(in lab,red,red)){.scalar-app .bg-c-3\\/5{background-color:color-mix(in oklab,var(--scalar-color-3)5%,transparent)}}}.scalar-app .bg-c-accent{background-color:var(--scalar-color-accent)}.scalar-app .bg-current{background-color:currentColor}.scalar-app .bg-grey{background-color:var(--scalar-color-3)}.scalar-app .bg-sidebar-b-1{background-color:var(--scalar-sidebar-background-1,var(--scalar-background-1))}.scalar-app .bg-sidebar-b-active{background-color:var(--scalar-sidebar-item-active-background,var(--scalar-background-2))}.scalar-app .bg-white{background-color:#fff}.scalar-app .bg-none{background-image:none}.scalar-app .fill-current{fill:currentColor}.scalar-app .stroke-2{stroke-width:2px}.scalar-app .stroke-\\[1\\.5\\]{stroke-width:1.5px}.scalar-app .stroke-\\[1\\.75\\]{stroke-width:1.75px}.scalar-app .stroke-\\[2\\.25\\]{stroke-width:2.25px}.scalar-app .object-contain{object-fit:contain}.scalar-app .\\!p-0{padding:0!important}.scalar-app .p-0{padding:0}.scalar-app .p-0\\.5{padding:2px}.scalar-app .p-0\\.75{padding:3px}.scalar-app .p-1{padding:4px}.scalar-app .p-1\\.5{padding:6px}.scalar-app .p-1\\.25{padding:5px}.scalar-app .p-1\\.75{padding:7px}.scalar-app .p-2{padding:8px}.scalar-app .p-3{padding:12px}.scalar-app .p-4{padding:16px}.scalar-app .p-\\[3px\\]{padding:3px}.scalar-app .p-\\[5px\\]{padding:5px}.scalar-app .p-px{padding:1px}.scalar-app .\\!px-3{padding-inline:12px!important}.scalar-app .px-0{padding-inline:0}.scalar-app .px-0\\.5{padding-inline:2px}.scalar-app .px-0\\.75{padding-inline:3px}.scalar-app .px-1{padding-inline:4px}.scalar-app .px-1\\.5{padding-inline:6px}.scalar-app .px-1\\.25{padding-inline:5px}.scalar-app .px-2{padding-inline:8px}.scalar-app .px-2\\.5{padding-inline:10px}.scalar-app .px-3{padding-inline:12px}.scalar-app .px-4{padding-inline:16px}.scalar-app .px-5{padding-inline:20px}.scalar-app .px-6{padding-inline:24px}.scalar-app .px-8{padding-inline:32px}.scalar-app .\\!py-1\\.5{padding-block:6px!important}.scalar-app .py-0{padding-block:0}.scalar-app .py-0\\.5{padding-block:2px}.scalar-app .py-0\\.25{padding-block:1px}.scalar-app .py-0\\.75{padding-block:3px}.scalar-app .py-1{padding-block:4px}.scalar-app .py-1\\.5{padding-block:6px}.scalar-app .py-1\\.25{padding-block:5px}.scalar-app .py-1\\.75{padding-block:7px}.scalar-app .py-2{padding-block:8px}.scalar-app .py-2\\.5{padding-block:10px}.scalar-app .py-3{padding-block:12px}.scalar-app .py-5{padding-block:20px}.scalar-app .py-8{padding-block:32px}.scalar-app .py-px{padding-block:1px}.scalar-app .\\!pt-0{padding-top:0!important}.scalar-app .pt-0{padding-top:0}.scalar-app .pt-2{padding-top:8px}.scalar-app .pt-3{padding-top:12px}.scalar-app .pt-4{padding-top:16px}.scalar-app .pt-6{padding-top:24px}.scalar-app .pt-8{padding-top:32px}.scalar-app .pt-px{padding-top:1px}.scalar-app .pr-0{padding-right:0}.scalar-app .pr-0\\.75{padding-right:3px}.scalar-app .pr-1{padding-right:4px}.scalar-app .pr-1\\.5{padding-right:6px}.scalar-app .pr-2{padding-right:8px}.scalar-app .pr-2\\.5{padding-right:10px}.scalar-app .pr-2\\.25{padding-right:9px}.scalar-app .pr-3{padding-right:12px}.scalar-app .pr-6{padding-right:24px}.scalar-app .pr-8{padding-right:32px}.scalar-app .pr-9{padding-right:36px}.scalar-app .pr-10{padding-right:40px}.scalar-app .pr-12{padding-right:48px}.scalar-app .pr-\\[26px\\]{padding-right:26px}.scalar-app .pb-0{padding-bottom:0}.scalar-app .pb-1\\.5{padding-bottom:6px}.scalar-app .pb-2{padding-bottom:8px}.scalar-app .pb-3{padding-bottom:12px}.scalar-app .pb-5{padding-bottom:20px}.scalar-app .pb-6{padding-bottom:24px}.scalar-app .pb-8{padding-bottom:32px}.scalar-app .pb-14{padding-bottom:56px}.scalar-app .pb-\\[75px\\]{padding-bottom:75px}.scalar-app .\\!pl-3{padding-left:12px!important}.scalar-app .pl-1{padding-left:4px}.scalar-app .pl-1\\.5{padding-left:6px}.scalar-app .pl-1\\.25{padding-left:5px}.scalar-app .pl-2{padding-left:8px}.scalar-app .pl-3{padding-left:12px}.scalar-app .pl-5{padding-left:20px}.scalar-app .pl-6{padding-left:24px}.scalar-app .pl-8\\.5{padding-left:34px}.scalar-app .pl-9{padding-left:36px}.scalar-app .pl-12{padding-left:48px}.scalar-app .pl-px{padding-left:1px}.scalar-app .text-center{text-align:center}.scalar-app .text-left{text-align:left}.scalar-app .text-right{text-align:right}.scalar-app .font-code{font-family:var(--scalar-font-code)}.scalar-app .font-sans{font-family:var(--scalar-font)}.scalar-app .text-3xs{font-size:var(--scalar-font-size-7)}.scalar-app .text-\\[6px\\]{font-size:6px}.scalar-app .text-\\[11px\\]{font-size:11px}.scalar-app .text-\\[21px\\]{font-size:21px}.scalar-app .text-base{font-size:var(--scalar-font-size-3)}.scalar-app .text-sm{font-size:var(--scalar-font-size-4)}.scalar-app .text-xl{font-size:var(--scalar-font-size-1)}.scalar-app .text-xs{font-size:var(--scalar-font-size-5)}.scalar-app .text-xxs{font-size:var(--scalar-font-size-6)}.scalar-app .\\!leading-\\[6px\\]{--tw-leading:6px!important;line-height:6px!important}.scalar-app .leading-2{--tw-leading:var(--scalar-line-height-2);line-height:var(--scalar-line-height-2)}.scalar-app .leading-3{--tw-leading:var(--scalar-line-height-3);line-height:var(--scalar-line-height-3)}.scalar-app .leading-\\[1\\.44\\]{--tw-leading:1.44;line-height:1.44}.scalar-app .leading-\\[7px\\]{--tw-leading:7px;line-height:7px}.scalar-app .leading-\\[20px\\]{--tw-leading:20px;line-height:20px}.scalar-app .leading-\\[21px\\]{--tw-leading:21px;line-height:21px}.scalar-app .leading-\\[22px\\]{--tw-leading:22px;line-height:22px}.scalar-app .leading-\\[normal\\]{--tw-leading:normal;line-height:normal}.scalar-app .leading-none{--tw-leading:1;line-height:1}.scalar-app .leading-normal{--tw-leading:var(--leading-normal);line-height:var(--leading-normal)}.scalar-app .leading-snug{--tw-leading:var(--leading-snug);line-height:var(--leading-snug)}.scalar-app .font-bold{--tw-font-weight:var(--scalar-bold);font-weight:var(--scalar-bold)}.scalar-app .font-medium{--tw-font-weight:var(--scalar-semibold);font-weight:var(--scalar-semibold)}.scalar-app .font-normal{--tw-font-weight:var(--scalar-regular);font-weight:var(--scalar-regular)}.scalar-app .text-balance{text-wrap:balance}.scalar-app .text-pretty{text-wrap:pretty}.scalar-app .break-words{overflow-wrap:break-word}.scalar-app .break-all{word-break:break-all}.scalar-app .text-ellipsis{text-overflow:ellipsis}.scalar-app .whitespace-nowrap{white-space:nowrap}.scalar-app .whitespace-pre{white-space:pre}.scalar-app .whitespace-pre-wrap{white-space:pre-wrap}.scalar-app .\\!text-c-1{color:var(--scalar-color-1)!important}.scalar-app .text-b-1{color:var(--scalar-background-1)}.scalar-app .text-b-2{color:var(--scalar-background-2)}.scalar-app .text-blue{color:var(--scalar-color-blue)}.scalar-app .text-border{color:var(--scalar-border-color)}.scalar-app .text-c-1{color:var(--scalar-color-1)}.scalar-app .text-c-2{color:var(--scalar-color-2)}.scalar-app .text-c-3{color:var(--scalar-color-3)}.scalar-app .text-c-btn{color:var(--scalar-button-1-color)}.scalar-app .text-c-danger{color:var(--scalar-color-danger)}.scalar-app .text-green{color:var(--scalar-color-green)}.scalar-app .text-grey{color:var(--scalar-color-3)}.scalar-app .text-orange{color:var(--scalar-color-orange)}.scalar-app .text-purple{color:var(--scalar-color-purple)}.scalar-app .text-red{color:var(--scalar-color-red)}.scalar-app .text-sidebar-c-2{color:var(--scalar-sidebar-color-2,var(--scalar-color-2))}.scalar-app .text-sidebar-c-active{color:var(--scalar-sidebar-color-active,var(--scalar-sidebar-color-1))}.scalar-app .text-transparent{color:#0000}.scalar-app .text-yellow{color:var(--scalar-color-yellow)}.scalar-app .capitalize{text-transform:capitalize}.scalar-app .lowercase{text-transform:lowercase}.scalar-app .uppercase{text-transform:uppercase}.scalar-app .line-through{text-decoration-line:line-through}.scalar-app .no-underline{text-decoration-line:none}.scalar-app .underline{text-decoration-line:underline}.scalar-app .decoration-c-3{-webkit-text-decoration-color:var(--scalar-color-3);text-decoration-color:var(--scalar-color-3)}.scalar-app .underline-offset-2{text-underline-offset:2px}.scalar-app .opacity-0{opacity:0}.scalar-app .opacity-50{opacity:.5}.scalar-app .opacity-100{opacity:1}.scalar-app .bg-blend-normal{background-blend-mode:normal}.scalar-app .mix-blend-luminosity{mix-blend-mode:luminosity}.scalar-app .shadow{--tw-shadow:var(--scalar-shadow-1);box-shadow:var(--tw-inset-shadow),var(--tw-inset-ring-shadow),var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow)}.scalar-app .shadow-\\[-8px_0_4px_var\\(--scalar-background-1\\)\\]{--tw-shadow:-8px 0 4px var(--tw-shadow-color,var(--scalar-background-1));box-shadow:var(--tw-inset-shadow),var(--tw-inset-ring-shadow),var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow)}.scalar-app .shadow-\\[0_-8px_0_8px_var\\(--scalar-background-1\\)\\,0_0_8px_8px_var\\(--scalar-background-1\\)\\]{--tw-shadow:0 -8px 0 8px var(--tw-shadow-color,var(--scalar-background-1)),0 0 8px 8px var(--tw-shadow-color,var(--scalar-background-1));box-shadow:var(--tw-inset-shadow),var(--tw-inset-ring-shadow),var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow)}.scalar-app .shadow-border{--tw-shadow:inset 0 0 0 var(--tw-shadow-color,calc(var(--scalar-border-width)*2))var(--scalar-border-color);box-shadow:var(--tw-inset-shadow),var(--tw-inset-ring-shadow),var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow)}.scalar-app .shadow-lg{--tw-shadow:var(--scalar-shadow-2);box-shadow:var(--tw-inset-shadow),var(--tw-inset-ring-shadow),var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow)}.scalar-app .shadow-none{--tw-shadow:0 0 #0000;box-shadow:var(--tw-inset-shadow),var(--tw-inset-ring-shadow),var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow)}.scalar-app .outline{outline-style:var(--tw-outline-style);outline-width:1px}.scalar-app .-outline-offset-1{outline-offset:-1px}.scalar-app .-outline-offset-2{outline-offset:-2px}.scalar-app .outline-offset-2{outline-offset:2px}.scalar-app .outline-b-3{outline-color:var(--scalar-background-3)}.scalar-app .outline-c-danger{outline-color:var(--scalar-color-danger)}.scalar-app .blur{--tw-blur:blur(8px);filter:var(--tw-blur,)var(--tw-brightness,)var(--tw-contrast,)var(--tw-grayscale,)var(--tw-hue-rotate,)var(--tw-invert,)var(--tw-saturate,)var(--tw-sepia,)var(--tw-drop-shadow,)}.scalar-app .brightness-90{--tw-brightness:brightness(90%);filter:var(--tw-blur,)var(--tw-brightness,)var(--tw-contrast,)var(--tw-grayscale,)var(--tw-hue-rotate,)var(--tw-invert,)var(--tw-saturate,)var(--tw-sepia,)var(--tw-drop-shadow,)}.scalar-app .brightness-\\[\\.9\\]{--tw-brightness:brightness(.9);filter:var(--tw-blur,)var(--tw-brightness,)var(--tw-contrast,)var(--tw-grayscale,)var(--tw-hue-rotate,)var(--tw-invert,)var(--tw-saturate,)var(--tw-sepia,)var(--tw-drop-shadow,)}.scalar-app .brightness-lifted{--tw-brightness:brightness(var(--scalar-lifted-brightness));filter:var(--tw-blur,)var(--tw-brightness,)var(--tw-contrast,)var(--tw-grayscale,)var(--tw-hue-rotate,)var(--tw-invert,)var(--tw-saturate,)var(--tw-sepia,)var(--tw-drop-shadow,)}.scalar-app .filter{filter:var(--tw-blur,)var(--tw-brightness,)var(--tw-contrast,)var(--tw-grayscale,)var(--tw-hue-rotate,)var(--tw-invert,)var(--tw-saturate,)var(--tw-sepia,)var(--tw-drop-shadow,)}.scalar-app .backdrop-filter{-webkit-backdrop-filter:var(--tw-backdrop-blur,)var(--tw-backdrop-brightness,)var(--tw-backdrop-contrast,)var(--tw-backdrop-grayscale,)var(--tw-backdrop-hue-rotate,)var(--tw-backdrop-invert,)var(--tw-backdrop-opacity,)var(--tw-backdrop-saturate,)var(--tw-backdrop-sepia,);backdrop-filter:var(--tw-backdrop-blur,)var(--tw-backdrop-brightness,)var(--tw-backdrop-contrast,)var(--tw-backdrop-grayscale,)var(--tw-backdrop-hue-rotate,)var(--tw-backdrop-invert,)var(--tw-backdrop-opacity,)var(--tw-backdrop-saturate,)var(--tw-backdrop-sepia,)}.scalar-app .transition{transition-property:color,background-color,border-color,outline-color,text-decoration-color,fill,stroke,--tw-gradient-from,--tw-gradient-via,--tw-gradient-to,opacity,box-shadow,transform,translate,scale,rotate,filter,-webkit-backdrop-filter,backdrop-filter,display,content-visibility,overlay,pointer-events;transition-timing-function:var(--tw-ease,var(--default-transition-timing-function));transition-duration:var(--tw-duration,var(--default-transition-duration))}.scalar-app .transition-colors{transition-property:color,background-color,border-color,outline-color,text-decoration-color,fill,stroke,--tw-gradient-from,--tw-gradient-via,--tw-gradient-to;transition-timing-function:var(--tw-ease,var(--default-transition-timing-function));transition-duration:var(--tw-duration,var(--default-transition-duration))}.scalar-app .transition-opacity{transition-property:opacity;transition-timing-function:var(--tw-ease,var(--default-transition-timing-function));transition-duration:var(--tw-duration,var(--default-transition-duration))}.scalar-app .transition-transform{transition-property:transform,translate,scale,rotate;transition-timing-function:var(--tw-ease,var(--default-transition-timing-function));transition-duration:var(--tw-duration,var(--default-transition-duration))}.scalar-app .transition-none{transition-property:none}.scalar-app .duration-100{--tw-duration:.1s;transition-duration:.1s}.scalar-app .duration-150{--tw-duration:.15s;transition-duration:.15s}.scalar-app .duration-200{--tw-duration:.2s;transition-duration:.2s}.scalar-app .duration-300{--tw-duration:.3s;transition-duration:.3s}.scalar-app .ease-in-out{--tw-ease:var(--ease-in-out);transition-timing-function:var(--ease-in-out)}.scalar-app .outline-none{--tw-outline-style:none;outline-style:none}.scalar-app .select-none{-webkit-user-select:none;user-select:none}.scalar-app .\\[--scalar-address-bar-height\\:32px\\]{--scalar-address-bar-height:32px}.scalar-app .app-drag-region{-webkit-app-region:drag}.scalar-app .app-no-drag-region{-webkit-app-region:no-drag}:is(.scalar-app .\\*\\:flex>*){display:flex}:is(.scalar-app .\\*\\:h-8>*){height:32px}:is(.scalar-app .\\*\\:cursor-pointer>*){cursor:pointer}:is(.scalar-app .\\*\\:items-center>*){align-items:center}:is(.scalar-app .\\*\\:rounded-none>*){border-radius:0}:is(.scalar-app .\\*\\:border-t>*){border-top-style:var(--tw-border-style);border-top-width:var(--scalar-border-width)}:is(.scalar-app .\\*\\:border-b-0>*){border-bottom-style:var(--tw-border-style);border-bottom-width:0}:is(.scalar-app .\\*\\:px-1\\.5>*){padding-inline:6px}:is(.scalar-app .\\*\\:pl-4>*){padding-left:16px}.scalar-app .group-first\\/row\\:border-t-0:is(:where(.group\\/row):first-child *){border-top-style:var(--tw-border-style);border-top-width:0}.scalar-app .group-last\\:border-b-transparent:is(:where(.group):last-child *){border-bottom-color:#0000}.scalar-app .group-last\\/label\\:rounded-br-lg:is(:where(.group\\/label):last-child *){border-bottom-right-radius:var(--scalar-radius-lg)}.scalar-app .group-focus-within\\:flex:is(:where(.group):focus-within *){display:flex}@media(hover:hover){.scalar-app .group-hover\\:block:is(:where(.group):hover *){display:block}.scalar-app .group-hover\\:flex:is(:where(.group):hover *){display:flex}.scalar-app .group-hover\\:hidden:is(:where(.group):hover *){display:none}.scalar-app .group-hover\\:inline:is(:where(.group):hover *){display:inline}.scalar-app .group-hover\\:pr-5:is(:where(.group):hover *){padding-right:20px}.scalar-app .group-hover\\:pr-6:is(:where(.group):hover *){padding-right:24px}.scalar-app .group-hover\\:pr-10:is(:where(.group):hover *){padding-right:40px}.scalar-app .group-hover\\:text-c-1:is(:where(.group):hover *){color:var(--scalar-color-1)}.scalar-app .group-hover\\:opacity-80:is(:where(.group):hover *){opacity:.8}.scalar-app .group-hover\\:opacity-100:is(:where(.group):hover *){opacity:1}.scalar-app .group-hover\\/auth\\:absolute:is(:where(.group\\/auth):hover *){position:absolute}.scalar-app .group-hover\\/auth\\:h-auto:is(:where(.group\\/auth):hover *){height:auto}.scalar-app .group-hover\\/auth\\:border-b:is(:where(.group\\/auth):hover *){border-bottom-style:var(--tw-border-style);border-bottom-width:var(--scalar-border-width)}.scalar-app .group-hover\\/cell\\:opacity-100:is(:where(.group\\/cell):hover *){opacity:1}.scalar-app .group-hover\\/item\\:flex:is(:where(.group\\/item):hover *){display:flex}.scalar-app .group-hover\\/item\\:opacity-100:is(:where(.group\\/item):hover *),.scalar-app .group-hover\\/params\\:opacity-100:is(:where(.group\\/params):hover *){opacity:1}.scalar-app .group-hover\\/row\\:flex:is(:where(.group\\/row):hover *){display:flex}.scalar-app .group-hover\\/scopes-accordion\\:text-c-2:is(:where(.group\\/scopes-accordion):hover *){color:var(--scalar-color-2)}.scalar-app .group-hover\\/upload\\:block:is(:where(.group\\/upload):hover *){display:block}}.scalar-app .group-focus-visible\\:opacity-100:is(:where(.group):focus-visible *){opacity:1}.scalar-app .group-focus-visible\\:outline:is(:where(.group):focus-visible *){outline-style:var(--tw-outline-style);outline-width:1px}.scalar-app .group-has-\\[\\.cm-focused\\]\\:z-1:is(:where(.group):has(.cm-focused) *){z-index:1}.scalar-app .group-has-\\[\\.cm-focused\\]\\:flex:is(:where(.group):has(.cm-focused) *){display:flex}.scalar-app .group-has-\\[\\.cm-focused\\]\\:pr-6:is(:where(.group):has(.cm-focused) *){padding-right:24px}.scalar-app .group-has-\\[\\.cm-focused\\]\\:pr-10:is(:where(.group):has(.cm-focused) *){padding-right:40px}.scalar-app .group-has-\\[\\:focus-visible\\]\\:hidden:is(:where(.group):has(:focus-visible) *){display:none}.scalar-app .group-has-\\[\\:focus-visible\\]\\:opacity-100:is(:where(.group):has(:focus-visible) *){opacity:1}.scalar-app .group-has-\\[\\:focus-visible\\]\\/cell\\:border-c-accent:is(:where(.group\\/cell):has(:focus-visible) *){border-color:var(--scalar-color-accent)}.scalar-app .group-has-\\[\\:focus-visible\\]\\/cell\\:opacity-100:is(:where(.group\\/cell):has(:focus-visible) *){opacity:1}.scalar-app .group-has-\\[\\:focus-visible\\]\\/input\\:block:is(:where(.group\\/input):has(:focus-visible) *){display:block}.scalar-app .group-has-\\[input\\]\\/label\\:mr-0:is(:where(.group\\/label):has(:is(input)) *){margin-right:0}.scalar-app .group-aria-expanded\\/button\\:rotate-180:is(:where(.group\\/button)[aria-expanded=true] *),.scalar-app .group-aria-expanded\\/combobox-button\\:rotate-180:is(:where(.group\\/combobox-button)[aria-expanded=true] *){rotate:180deg}.scalar-app .group-\\[\\.alert\\]\\:bg-b-alert:is(:where(.group).alert *){background-color:var(--scalar-background-alert)}.scalar-app .group-\\[\\.alert\\]\\:bg-transparent:is(:where(.group).alert *){background-color:#0000}.scalar-app .group-\\[\\.alert\\]\\:shadow-none:is(:where(.group).alert *){--tw-shadow:0 0 #0000;box-shadow:var(--tw-inset-shadow),var(--tw-inset-ring-shadow),var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow)}.scalar-app .group-\\[\\.alert\\]\\:outline-orange:is(:where(.group).alert *){outline-color:var(--scalar-color-orange)}.scalar-app .group-\\[\\.error\\]\\:bg-b-danger:is(:where(.group).error *){background-color:var(--scalar-background-danger)}.scalar-app .group-\\[\\.error\\]\\:bg-transparent:is(:where(.group).error *){background-color:#0000}.scalar-app .group-\\[\\.error\\]\\:text-red:is(:where(.group).error *){color:var(--scalar-color-red)}.scalar-app .group-\\[\\.error\\]\\:shadow-none:is(:where(.group).error *){--tw-shadow:0 0 #0000;box-shadow:var(--tw-inset-shadow),var(--tw-inset-ring-shadow),var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow)}.scalar-app .group-\\[\\.error\\]\\:outline-red:is(:where(.group).error *){outline-color:var(--scalar-color-red)}.scalar-app .peer-checked\\:text-c-1:is(:where(.peer):checked~*){color:var(--scalar-color-1)}.scalar-app .peer-has-\\[\\.cm-focused\\]\\:opacity-0:is(:where(.peer):has(.cm-focused)~*){opacity:0}.scalar-app .peer-has-\\[\\.color-selector\\]\\:hidden:is(:where(.peer):has(.color-selector)~*){display:none}.scalar-app .before\\:pointer-events-none:before{content:var(--tw-content);pointer-events:none}.scalar-app .before\\:absolute:before{content:var(--tw-content);position:absolute}.scalar-app .before\\:top-0:before{content:var(--tw-content);top:0}.scalar-app .before\\:left-3:before{content:var(--tw-content);left:12px}.scalar-app .before\\:left-\\[calc\\(\\.75rem_\\+_\\.5px\\)\\]:before{content:var(--tw-content);left:calc(.75rem + .5px)}.scalar-app .before\\:z-1:before{content:var(--tw-content);z-index:1}.scalar-app .before\\:h-\\[calc\\(100\\%_\\+_\\.5px\\)\\]:before{content:var(--tw-content);height:calc(100% + .5px)}.scalar-app .before\\:w-\\[\\.5px\\]:before{content:var(--tw-content);width:.5px}.scalar-app .before\\:bg-border:before{content:var(--tw-content);background-color:var(--scalar-border-color)}.scalar-app .after\\:content-\\[\\\'\\:\\\'\\]:after{--tw-content:":";content:var(--tw-content)}:is(.scalar-app .\\*\\:first\\:line-clamp-1>*):first-child{-webkit-line-clamp:1;-webkit-box-orient:vertical;display:-webkit-box;overflow:hidden}:is(.scalar-app .\\*\\:first\\:rounded-l>*):first-child{border-top-left-radius:var(--scalar-radius);border-bottom-left-radius:var(--scalar-radius)}:is(.scalar-app .\\*\\:first\\:border-t-0>*):first-child,:is(.scalar-app .first\\:\\*\\:border-t-0:first-child>*){border-top-style:var(--tw-border-style);border-top-width:0}:is(.scalar-app .\\*\\:first\\:text-ellipsis>*):first-child{text-overflow:ellipsis}@media(hover:hover){:is(.scalar-app .group-hover\\/auth\\:\\*\\:first\\:line-clamp-none:is(:where(.group\\/auth):hover *)>*):first-child{-webkit-line-clamp:unset;-webkit-box-orient:horizontal;display:block;overflow:visible}}.scalar-app .last\\:mb-0:last-child{margin-bottom:0}.scalar-app .last\\:rounded-b-lg:last-child{border-bottom-right-radius:var(--scalar-radius-lg);border-bottom-left-radius:var(--scalar-radius-lg)}.scalar-app .last\\:border-r-0:last-child{border-right-style:var(--tw-border-style);border-right-width:0}:is(.scalar-app .\\*\\:last\\:rounded-r>*):last-child{border-top-right-radius:var(--scalar-radius);border-bottom-right-radius:var(--scalar-radius)}.scalar-app .last\\:before\\:h-full:last-child:before{content:var(--tw-content);height:100%}.scalar-app .last-of-type\\:first-of-type\\:border-b-0:last-of-type:first-of-type{border-bottom-style:var(--tw-border-style);border-bottom-width:0}.scalar-app .focus-within\\:z-20:focus-within{z-index:20}.scalar-app .focus-within\\:border-\\(--scalar-background-3\\):focus-within{border-color:var(--scalar-background-3)}.scalar-app .focus-within\\:bg-b-1:focus-within{background-color:var(--scalar-background-1)}.scalar-app .focus-within\\:text-c-1:focus-within{color:var(--scalar-color-1)}@media(hover:hover){.scalar-app .hover\\:cursor-default:hover{cursor:default}.scalar-app .hover\\:border-\\(--scalar-background-3\\):hover{border-color:var(--scalar-background-3)}.scalar-app .hover\\:border-inherit:hover{border-color:inherit}.scalar-app .hover\\:bg-b-2:hover{background-color:var(--scalar-background-2)}.scalar-app .hover\\:bg-b-3:hover{background-color:var(--scalar-background-3)}.scalar-app .hover\\:bg-inherit:hover{background-color:inherit}.scalar-app .hover\\:bg-sidebar-b-active:hover{background-color:var(--scalar-sidebar-item-active-background,var(--scalar-background-2))}.scalar-app .hover\\:whitespace-normal:hover{white-space:normal}.scalar-app .hover\\:text-c-1:hover{color:var(--scalar-color-1)}.scalar-app .hover\\:text-c-2:hover{color:var(--scalar-color-2)}.scalar-app .hover\\:underline:hover{text-decoration-line:underline}.scalar-app .hover\\:brightness-75:hover{--tw-brightness:brightness(75%);filter:var(--tw-blur,)var(--tw-brightness,)var(--tw-contrast,)var(--tw-grayscale,)var(--tw-hue-rotate,)var(--tw-invert,)var(--tw-saturate,)var(--tw-sepia,)var(--tw-drop-shadow,)}}.scalar-app .focus\\:border-b-1:focus{border-bottom-style:var(--tw-border-style);border-bottom-width:1px;border-color:var(--scalar-background-1)}.scalar-app .focus\\:text-c-1:focus{color:var(--scalar-color-1)}.scalar-app .focus\\:outline-none:focus{--tw-outline-style:none;outline-style:none}.scalar-app .focus-visible\\:z-10:focus-visible{z-index:10}.scalar-app .active\\:text-c-1:active{color:var(--scalar-color-1)}.scalar-app .disabled\\:cursor-default:disabled{cursor:default}.scalar-app .disabled\\:text-c-2:disabled{color:var(--scalar-color-2)}.scalar-app .has-\\[\\.empty-sidebar-item\\]\\:border-t:has(.empty-sidebar-item){border-top-style:var(--tw-border-style);border-top-width:var(--scalar-border-width)}.scalar-app .has-\\[\\:focus-visible\\]\\:absolute:has(:focus-visible){position:absolute}.scalar-app .has-\\[\\:focus-visible\\]\\:z-1:has(:focus-visible){z-index:1}.scalar-app .has-\\[\\:focus-visible\\]\\:rounded-\\[4px\\]:has(:focus-visible){border-radius:4px}.scalar-app .has-\\[\\:focus-visible\\]\\:bg-b-1:has(:focus-visible){background-color:var(--scalar-background-1)}.scalar-app .has-\\[\\:focus-visible\\]\\:opacity-100:has(:focus-visible){opacity:1}.scalar-app .has-\\[\\:focus-visible\\]\\:outline:has(:focus-visible){outline-style:var(--tw-outline-style);outline-width:1px}@media not all and (min-width:800px){.scalar-app .max-md\\:absolute\\!{position:absolute!important}.scalar-app .max-md\\:w-full\\!{width:100%!important}}@media(min-width:600px){.scalar-app .sm\\:not-sr-only{clip-path:none;white-space:normal;width:auto;height:auto;margin:0;padding:0;position:static;overflow:visible}.scalar-app .sm\\:order-none{order:0}.scalar-app .sm\\:mr-1\\.5{margin-right:6px}.scalar-app .sm\\:mb-1\\.5{margin-bottom:6px}.scalar-app .sm\\:ml-1\\.5{margin-left:6px}.scalar-app .sm\\:flex{display:flex}.scalar-app .sm\\:hidden{display:none}.scalar-app .sm\\:max-w-max{max-width:max-content}.scalar-app .sm\\:min-w-max{min-width:max-content}.scalar-app .sm\\:flex-col{flex-direction:column}.scalar-app .sm\\:flex-row{flex-direction:row}.scalar-app .sm\\:justify-between{justify-content:space-between}.scalar-app .sm\\:gap-px{gap:1px}.scalar-app .sm\\:rounded{border-radius:var(--scalar-radius)}.scalar-app .sm\\:rounded-lg{border-radius:var(--scalar-radius-lg)}.scalar-app .sm\\:px-2{padding-inline:8px}.scalar-app .sm\\:px-3{padding-inline:12px}.scalar-app .sm\\:py-1\\.5{padding-block:6px}:is(.scalar-app .sm\\:\\*\\:rounded-lg>*){border-radius:var(--scalar-radius-lg)}}@media(min-width:800px){.scalar-app .md\\:right-10{right:40px}.scalar-app .md\\:bottom-10{bottom:40px}.scalar-app .md\\:mx-auto{margin-inline:auto}.scalar-app .md\\:-ml-1\\.25{margin-left:-5px}.scalar-app .md\\:ml-1\\.5{margin-left:6px}.scalar-app .md\\:block{display:block}.scalar-app .md\\:flex{display:flex}.scalar-app .md\\:grid{display:grid}.scalar-app .md\\:w-full{width:100%}.scalar-app .md\\:max-w-\\[720px\\]{max-width:720px}.scalar-app .md\\:min-w-fit{min-width:fit-content}.scalar-app .md\\:flex-none{flex:none}.scalar-app .md\\:translate-x-0{--tw-translate-x:0px;translate:var(--tw-translate-x)var(--tw-translate-y)}.scalar-app .md\\:translate-y-0{--tw-translate-y:0px;translate:var(--tw-translate-x)var(--tw-translate-y)}.scalar-app .md\\:grid-cols-\\[1fr_720px_1fr\\]{grid-template-columns:1fr 720px 1fr}.scalar-app .md\\:flex-row{flex-direction:row}.scalar-app .md\\:border-r{border-right-style:var(--tw-border-style);border-right-width:var(--scalar-border-width)}.scalar-app .md\\:border-b-0{border-bottom-style:var(--tw-border-style);border-bottom-width:0}.scalar-app .md\\:p-1\\.5{padding:6px}.scalar-app .md\\:px-0{padding-inline:0}.scalar-app .md\\:px-1\\.5{padding-inline:6px}.scalar-app .md\\:px-2{padding-inline:8px}.scalar-app .md\\:px-2\\.5{padding-inline:10px}.scalar-app .md\\:px-4{padding-inline:16px}.scalar-app .md\\:px-\\[18px\\]{padding-inline:18px}.scalar-app .md\\:py-2\\.5{padding-block:10px}.scalar-app .md\\:pb-2\\.5{padding-bottom:10px}.scalar-app .md\\:pb-\\[37px\\]{padding-bottom:37px}.scalar-app .md\\:pl-0{padding-left:0}:is(.scalar-app .md\\:\\*\\:border-t-0>*){border-top-style:var(--tw-border-style);border-top-width:0}}@media(min-width:1000px){.scalar-app .lg\\:order-none{order:0}.scalar-app .lg\\:-mr-1{margin-right:-4px}.scalar-app .lg\\:mb-0{margin-bottom:0}.scalar-app .lg\\:flex{display:flex}.scalar-app .lg\\:min-h-header{min-height:48px}.scalar-app .lg\\:w-auto{width:auto}.scalar-app .lg\\:max-w-\\[580px\\]{max-width:580px}.scalar-app .lg\\:min-w-\\[580px\\]{min-width:580px}.scalar-app .lg\\:flex-1{flex:1}.scalar-app .lg\\:p-0{padding:0}.scalar-app .lg\\:p-1{padding:4px}.scalar-app .lg\\:px-1{padding-inline:4px}.scalar-app .lg\\:px-2\\.5{padding-inline:10px}.scalar-app .lg\\:pt-1{padding-top:4px}.scalar-app .lg\\:pr-24{padding-right:96px}}@media(min-width:1200px){.scalar-app .xl\\:\\!flex{display:flex!important}.scalar-app .xl\\:flex{display:flex}.scalar-app .xl\\:hidden{display:none}.scalar-app .xl\\:h-fit{height:fit-content}.scalar-app .xl\\:h-full{height:100%}.scalar-app .xl\\:min-h-header{min-height:48px}.scalar-app .xl\\:max-w-\\[720px\\]{max-width:720px}.scalar-app .xl\\:min-w-0{min-width:0}.scalar-app .xl\\:min-w-\\[720px\\]{min-width:720px}.scalar-app .xl\\:flex-row{flex-direction:row}.scalar-app .xl\\:overflow-auto{overflow:auto}.scalar-app .xl\\:overflow-hidden{overflow:hidden}.scalar-app .xl\\:rounded-none{border-radius:0}.scalar-app .xl\\:pr-0\\.5{padding-right:2px}.scalar-app .xl\\:pl-2{padding-left:8px}:is(.scalar-app .\\*\\:xl\\:border-t-0>*){border-top-style:var(--tw-border-style);border-top-width:0}:is(.scalar-app .\\*\\:xl\\:border-l>*){border-left-style:var(--tw-border-style);border-left-width:var(--scalar-border-width)}:is(.scalar-app .\\*\\:first\\:xl\\:border-l-0>*):first-child{border-left-style:var(--tw-border-style);border-left-width:0}}.scalar-app .dark\\:bg-b-2:where(.dark-mode,.dark-mode *){background-color:var(--scalar-background-2)}@media(hover:hover){.scalar-app .hover\\:dark\\:bg-b-2:hover:where(.dark-mode,.dark-mode *){background-color:var(--scalar-background-2)}}.scalar-app .ui-open\\:rotate-90[data-headlessui-state~=open],:where([data-headlessui-state~=open]) :is(.scalar-app .ui-open\\:rotate-90){rotate:90deg}.scalar-app .ui-open\\:rotate-180[data-headlessui-state~=open],:where([data-headlessui-state~=open]) :is(.scalar-app .ui-open\\:rotate-180){rotate:180deg}.scalar-app .last\\:ui-open\\:border-b-0:last-child[data-headlessui-state~=open],:where([data-headlessui-state~=open]) .scalar-app .last\\:ui-open\\:border-b-0:last-child{border-bottom-style:var(--tw-border-style);border-bottom-width:0}.scalar-app .ui-not-open\\:hidden[data-headlessui-state]:not([data-headlessui-state~=open]),:where([data-headlessui-state]:not([data-headlessui-state~=open])) :is(.scalar-app .ui-not-open\\:hidden):not([data-headlessui-state]){display:none}.scalar-app .ui-not-open\\:rotate-0[data-headlessui-state]:not([data-headlessui-state~=open]),:where([data-headlessui-state]:not([data-headlessui-state~=open])) :is(.scalar-app .ui-not-open\\:rotate-0):not([data-headlessui-state]){rotate:none}.scalar-app .ui-checked\\:bg-b-3[data-headlessui-state~=checked],:where([data-headlessui-state~=checked]) :is(.scalar-app .ui-checked\\:bg-b-3){background-color:var(--scalar-background-3)}.scalar-app .ui-active\\:bg-b-2[data-headlessui-state~=active],:where([data-headlessui-state~=active]) :is(.scalar-app .ui-active\\:bg-b-2),:is(.scalar-app .ui-active\\:\\*\\:bg-b-2[data-headlessui-state~=active]>*),:is(:where([data-headlessui-state~=active]) :is(.scalar-app .ui-active\\:\\*\\:bg-b-2)>*){background-color:var(--scalar-background-2)}@media(max-width:720px)and (max-height:480px){.scalar-app .zoomed\\:static{position:static}.scalar-app .zoomed\\:p-1{padding:4px}}.app-platform-mac :is(.scalar-app .mac\\:pl-\\[72px\\]){padding-left:72px}@property --tw-scale-x{syntax:"*";inherits:false;initial-value:1}@property --tw-scale-y{syntax:"*";inherits:false;initial-value:1}@property --tw-scale-z{syntax:"*";inherits:false;initial-value:1}@property --tw-space-x-reverse{syntax:"*";inherits:false;initial-value:0}.nav-item[data-v-507381a3]{cursor:pointer;border-radius:var(--scalar-radius-lg);background:var(--scalar-background-3);border:var(--scalar-border-width)solid var(--scalar-background-2);color:var(--scalar-color-3);flex:1;justify-content:center;align-items:center;min-width:0;padding:4.5px;display:flex;position:relative;overflow:hidden}.dark-mode .nav-item[data-v-507381a3]{background:var(--scalar-background-2)}@supports (color:color-mix(in lab,red,red)){.dark-mode .nav-item[data-v-507381a3]{background:color-mix(in srgb,var(--scalar-background-2),transparent)}}.nav-item-icon-copy[data-v-507381a3]{white-space:nowrap;max-width:100%;-webkit-mask-image:linear-gradient(to left,transparent 0,var(--scalar-background-2)20px);mask-image:linear-gradient(to left,transparent 0,var(--scalar-background-2)20px);overflow:hidden}.nav-item:hover .nav-item-icon-copy[data-v-507381a3]{-webkit-mask-image:linear-gradient(to left,transparent 20px,var(--scalar-background-2)40px);mask-image:linear-gradient(to left,transparent 20px,var(--scalar-background-2)40px)}.nav-item-copy[data-v-507381a3]{max-width:calc(100% - 20px)}.nav-item[data-v-507381a3]:hover{color:var(--scalar-color-1)}.nav-item__active[data-v-507381a3]{background-color:var(--scalar-background-1);color:var(--scalar-color-1);border-color:var(--scalar-border-color)}.dark-mode .nav-item__active[data-v-507381a3]{background-color:var(--scalar-background-2)}.nav-item-close[data-v-507381a3]{border-radius:var(--scalar-radius);stroke-width:1.5px;max-width:20px;color:var(--scalar-color-3);opacity:0;background:0 0;margin-left:-20px;padding:2px;position:absolute;right:3px}.nav-item:hover .nav-item-close[data-v-507381a3]{opacity:1}.nav-item-close[data-v-507381a3]:hover{background-color:var(--scalar-background-4)}.nav-item__active .nav-item-close[data-v-507381a3]:hover{background-color:var(--scalar-background-2)}.download-app-button[data-v-cb45fa05]{box-shadow:0 0 0 .5px var(--scalar-border-color);background:linear-gradient(#ffffffbf,#00000009)}.dark-mode .download-app-button[data-v-cb45fa05]{background:linear-gradient(#ffffff1a,#00000026)}.download-app-button[data-v-cb45fa05]:hover{background:linear-gradient(#00000009,#ffffffbf)}.dark-mode .download-app-button[data-v-cb45fa05]:hover{background:linear-gradient(#00000026,#ffffff1a)}.http-bg-gradient[data-v-076b14a1]{background:linear-gradient(#ffffffbf,#00000009)}.http-bg-gradient[data-v-076b14a1]:hover{background:linear-gradient(#00000009,#ffffffbf)}.dark-mode .http-bg-gradient[data-v-076b14a1]{background:linear-gradient(#ffffff09,#00000026)}.dark-mode .http-bg-gradient[data-v-076b14a1]:hover{background:linear-gradient(#00000026,#ffffff09)}.scroll-timeline-x[data-v-e0578855]{scroll-timeline:--scroll-timeline x;scroll-timeline:--scroll-timeline horizontal;-ms-overflow-style:none;scrollbar-width:none;overflow:auto}.commandmenu[data-v-dd90fe74]{box-shadow:var(--scalar-shadow-2);border-radius:var(--scalar-radius-lg);background-color:var(--scalar-background-1);opacity:0;width:100%;max-width:580px;max-height:60dvh;margin:12px;animation:.3s ease-in-out .1s forwards fadeincommandmenu-dd90fe74;position:fixed;top:150px;left:50%;transform:translate(-50%,10px)}.commandmenu-overlay[data-v-dd90fe74]{cursor:pointer;background:#0003;animation:.3s ease-in-out forwards fadeincommand-dd90fe74;position:fixed;inset:0}@keyframes fadeincommand-dd90fe74{0%{opacity:0}to{opacity:1}}@keyframes fadeincommandmenu-dd90fe74{0%{opacity:0;transform:translate(-50%,10px)}to{opacity:1;transform:translate(-50%)}}.scalar .scalar-app-layout[data-v-45e9730e]{background:var(--scalar-background-1);opacity:0;border:var(--scalar-border-width)solid var(--scalar-border-color);border-radius:8px;width:100%;max-width:1390px;height:calc(100% - 120px);margin:auto;animation:.35s forwards scalarapiclientfadein-45e9730e;position:relative;overflow:hidden}@media(max-width:720px)and (max-height:480px){.scalar .scalar-app-layout[data-v-45e9730e]{height:100%;max-height:90svh}}@keyframes scalarapiclientfadein-45e9730e{0%{opacity:0}to{opacity:1}}.scalar .scalar-app-exit[data-v-45e9730e]{cursor:pointer;z-index:-1;background:#00000038;width:100vw;height:100vh;transition:all .3s ease-in-out;animation:.35s forwards scalardrawerexitfadein-45e9730e;position:fixed;top:0;left:0}.dark-mode .scalar .scalar-app-exit[data-v-45e9730e]{background:#00000073}.scalar .scalar-app-exit[data-v-45e9730e]:before{text-align:center;color:#fff;opacity:.6;font-family:sans-serif;font-size:30px;font-weight:100;line-height:50px;position:absolute;top:0;right:12px}.scalar .scalar-app-exit[data-v-45e9730e]:hover:before{opacity:1}@keyframes scalardrawerexitfadein-45e9730e{0%{opacity:0}to{opacity:1}}.scalar-container[data-v-45e9730e]{visibility:visible;z-index:10000;justify-content:center;align-items:center;width:100%;height:100%;display:flex;position:fixed;top:0;bottom:0;left:0;overflow:hidden}.scalar .url-form-input[data-v-45e9730e]{min-height:auto!important}.scalar .scalar-container[data-v-45e9730e]{line-height:normal}.scalar .scalar-app-header span[data-v-45e9730e]{color:var(--scalar-color-3)}.scalar .scalar-app-header a[data-v-45e9730e]{color:var(--scalar-color-1)}.scalar .scalar-app-header a[data-v-45e9730e]:hover{text-decoration:underline}.scalar-activate[data-v-45e9730e]{cursor:pointer;align-items:center;gap:6px;width:fit-content;margin:0 .75rem .75rem auto;font-size:.875rem;font-weight:600;line-height:24px;display:flex}.scalar-activate-button[data-v-45e9730e]{color:var(--scalar-color-blue);appearance:none;background:0 0;border:none;outline:none;align-items:center;gap:6px;padding:0 .5rem;display:flex}.scalar-activate:hover .scalar-activate-button[data-v-45e9730e]{background:var(--scalar-background-3);border-radius:3px}.open-api-client-button[data-v-f016469d]{cursor:pointer;text-align:center;white-space:nowrap;width:100%;height:31px;font-size:var(--scalar-mini);font-weight:var(--scalar-semibold);border-radius:var(--scalar-radius);box-shadow:0 0 0 .5px var(--scalar-border-color);color:var(--scalar-sidebar-color-1);justify-content:center;align-items:center;gap:6px;padding:9px 12px;line-height:1.385;text-decoration:none;display:flex}.open-api-client-button[data-v-f016469d]:hover{background:var(--scalar-sidebar-item-hover-background,var(--scalar-background-2))}[data-v-103d9d56] .cm-editor{background:0 0;outline:none;height:100%;padding:0}[data-v-103d9d56] .cm-placeholder{color:var(--scalar-color-3)}[data-v-103d9d56] .cm-content{font-family:var(--scalar-font-code);font-size:var(--scalar-small);max-height:20px;padding:8px 0}[data-v-103d9d56] .cm-tooltip{filter:brightness(var(--scalar-lifted-brightness));border-radius:var(--scalar-radius);box-shadow:var(--scalar-shadow-2);background:0 0!important;border:none!important;outline:none!important;overflow:hidden!important}[data-v-103d9d56] .cm-tooltip-autocomplete ul li{padding:3px 6px!important}[data-v-103d9d56] .cm-completionIcon-type:after{color:var(--scalar-color-3)!important}[data-v-103d9d56] .cm-tooltip-autocomplete ul li[aria-selected]{background:var(--scalar-background-2)!important;color:var(--scalar-color-1)!important}[data-v-103d9d56] .cm-tooltip-autocomplete ul{position:relative;padding:6px!important}[data-v-103d9d56] .cm-tooltip-autocomplete ul li:hover{border-radius:3px;color:var(--scalar-color-1)!important;background:var(--scalar-background-3)!important}[data-v-103d9d56] .cm-activeLine,[data-v-103d9d56] .cm-activeLineGutter{background-color:#0000}[data-v-103d9d56] .cm-selectionMatch,[data-v-103d9d56] .cm-matchingBracket{border-radius:var(--scalar-radius);background:var(--scalar-background-4)!important}[data-v-103d9d56] .cm-css-color-picker-wrapper{outline:1px solid var(--scalar-background-3);border-radius:3px;display:inline-flex;overflow:hidden}[data-v-103d9d56] .cm-gutters{color:var(--scalar-color-3);font-size:var(--scalar-small);background-color:#0000;border-right:none;border-radius:0 0 0 3px;line-height:22px}[data-v-103d9d56] .cm-gutters:before{content:"";border-radius:var(--scalar-radius)0 0 var(--scalar-radius);background-color:var(--scalar-background-1);width:calc(100% - 2px);height:calc(100% - 4px);position:absolute;top:2px;left:2px}[data-v-103d9d56] .cm-gutterElement{justify-content:flex-end;align-items:center;display:flex;position:relative;font-family:var(--scalar-font-code)!important;padding-left:0!important;padding-right:6px!important}[data-v-103d9d56] .cm-lineNumbers .cm-gutterElement{min-width:fit-content}[data-v-103d9d56] .cm-gutter+.cm-gutter :not(.cm-foldGutter) .cm-gutterElement{padding-left:0!important}[data-v-103d9d56] .cm-scroller{overflow:auto}.line-wrapping[data-v-103d9d56]:focus-within .cm-content{white-space:break-spaces;word-break:break-all;min-height:fit-content;padding:3px 6px;display:inline-table}.address-bar-history-button[data-v-a93fa60f]:hover{background:var(--scalar-background-3)}.address-bar-history-button[data-v-a93fa60f]:focus-within{background:var(--scalar-background-2)}.description[data-v-92012388] .markdown{font-weight:var(--scalar-semibold);color:var(--scalar-color--1);padding:0;display:block}.description[data-v-92012388] .markdown>:first-child{margin-top:0}[data-v-cb2a35da] .cm-editor{outline:none;width:100%;height:100%}[data-v-cb2a35da] .cm-line{padding:0}[data-v-cb2a35da] .cm-content{font-size:var(--scalar-small);align-items:center;padding:0;display:flex}.scroll-timeline-x[data-v-cb2a35da]{scroll-timeline:--scroll-timeline x;scroll-timeline:--scroll-timeline horizontal;-ms-overflow-style:none}.scroll-timeline-x-hidden[data-v-cb2a35da]{overflow-x:auto}.scroll-timeline-x-hidden[data-v-cb2a35da] .cm-scroller{scrollbar-width:none;-ms-overflow-style:none;padding-right:20px;overflow:auto}.scroll-timeline-x-hidden[data-v-cb2a35da]::-webkit-scrollbar{width:0;height:0;display:none}.scroll-timeline-x-hidden[data-v-cb2a35da] .cm-scroller::-webkit-scrollbar{width:0;height:0;display:none}.scroll-timeline-x-address[data-v-cb2a35da]{scrollbar-width:none;line-height:27px}.scroll-timeline-x-address[data-v-cb2a35da]:after{content:"";cursor:text;width:24px;height:100%;position:absolute;right:0}.scroll-timeline-x-address[data-v-cb2a35da]:empty:before{content:"Enter URL or cURL request";color:var(--scalar-color-3);pointer-events:none}.fade-left[data-v-cb2a35da],.fade-right[data-v-cb2a35da]{content:"";pointer-events:none;z-index:1;height:100%;animation-name:fadein-cb2a35da;animation-duration:1ms;animation-direction:reverse;animation-timeline:--scroll-timeline;position:sticky}.fade-left[data-v-cb2a35da]{background:linear-gradient(-90deg,var(--scalar-address-bar-bg)0%,var(--scalar-address-bar-bg)30%,var(--scalar-address-bar-bg)100%)}@supports (color:color-mix(in lab,red,red)){.fade-left[data-v-cb2a35da]{background:linear-gradient(-90deg,color-mix(in srgb,var(--scalar-address-bar-bg),transparent 100%)0%,color-mix(in srgb,var(--scalar-address-bar-bg),transparent 20%)30%,var(--scalar-address-bar-bg)100%)}}.fade-left[data-v-cb2a35da]{min-width:6px;animation-direction:normal;left:-1px}.fade-right[data-v-cb2a35da]{background:linear-gradient(90deg,var(--scalar-address-bar-bg)0%,var(--scalar-address-bar-bg)30%,var(--scalar-address-bar-bg)100%)}@supports (color:color-mix(in lab,red,red)){.fade-right[data-v-cb2a35da]{background:linear-gradient(90deg,color-mix(in srgb,var(--scalar-address-bar-bg),transparent 100%)0%,color-mix(in srgb,var(--scalar-address-bar-bg),transparent 20%)30%,var(--scalar-address-bar-bg)100%)}}.fade-right[data-v-cb2a35da]{min-width:24px;right:-1px}@keyframes fadein-cb2a35da{0%{opacity:0}1%{opacity:1}}.address-bar-bg-states[data-v-cb2a35da]{--scalar-address-bar-bg:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.address-bar-bg-states[data-v-cb2a35da]{--scalar-address-bar-bg:color-mix(in srgb,var(--scalar-background-1),var(--scalar-background-2))}}.address-bar-bg-states[data-v-cb2a35da]{background:var(--scalar-address-bar-bg)}.address-bar-bg-states[data-v-cb2a35da]:has(.cm-focused){--scalar-address-bar-bg:var(--scalar-background-1);border-color:var(--scalar-border-color);outline:1px solid var(--scalar-color-accent)}.address-bar-bg-states:has(.cm-focused) .fade-left[data-v-cb2a35da],.address-bar-bg-states:has(.cm-focused) .fade-right[data-v-cb2a35da]{--scalar-address-bar-bg:var(--scalar-background-1)}.sidebar-height[data-v-dcff7b49]{min-height:100%}@media(min-width:800px){.sidebar-mask[data-v-dcff7b49]{-webkit-mask-image:linear-gradient(0,transparent 0,transparent 0,var(--scalar-background-2)30px);mask-image:linear-gradient(0,transparent 0,transparent 0,var(--scalar-background-2)30px)}}.resizer[data-v-dcff7b49]{cursor:col-resize;border-right:2px solid #0000;width:5px;transition:border-right-color .3s;position:absolute;top:0;bottom:0;right:0}.resizer[data-v-dcff7b49]:hover,.dragging .resizer[data-v-dcff7b49]{border-right-color:var(--scalar-background-3)}.dragging[data-v-dcff7b49]{cursor:col-resize}.dragging[data-v-dcff7b49]:before{content:"";width:100%;height:100%;display:block;position:absolute}[data-v-c1a50a6e] .cm-editor{padding:0}[data-v-c1a50a6e] .cm-content{font-family:var(--scalar-font);font-size:var(--scalar-small);background-color:#0000;align-items:center;width:100%;padding:5px 8px;display:flex}[data-v-c1a50a6e] .cm-content:has(.cm-pill){padding:5px 8px}[data-v-c1a50a6e] .cm-content .cm-pill:not(:last-of-type){margin-right:.5px}[data-v-c1a50a6e] .cm-content .cm-pill:not(:first-of-type){margin-left:.5px}[data-v-c1a50a6e] .cm-line{text-overflow:ellipsis;word-break:break-word;padding:0;overflow:hidden}.required[data-v-c1a50a6e]:after{content:"Required"}input[data-v-c1a50a6e]::placeholder{color:var(--scalar-color-3)}.scalar-password-input[data-v-c1a50a6e]{text-security:disc;-webkit-text-security:disc;-moz-text-security:disc}@media(min-width:800px){.has-no-import-url,.has-import-url{contain:paint;max-width:100dvw;overflow-x:hidden}.has-no-import-url .scalar-client>main{opacity:1;background:var(--scalar-background-1);animation:.3s ease-in-out forwards transform-restore-layout}.has-import-url .scalar-client>main{opacity:0;border:var(--scalar-border-width)solid var(--scalar-border-color);z-index:10000;border-radius:12px;animation:.3s ease-in-out forwards transform-fade-layout;overflow:hidden;transform:scale(.85)translate(calc(50dvw + 80px))}.has-import-url .scalar-client .sidenav{display:none}.has-no-import-url .scalar-app,.has-import-url .scalar-app{background:var(--scalar-background-1)!important}}@keyframes transform-fade-layout{0%{opacity:0;transform:scale(.85)translate(calc(50dvw + 80px),10px)}to{opacity:1;transform:scale(.85)translate(calc(50dvw + 80px))}}@keyframes transform-restore-layout{0%{opacity:1;transform:scale(.85)translate(calc(50dvw + 80px))}to{opacity:1;transform:scale(1)translate(0)}}.openapi-color{color:var(--scalar-color-green)}.section-flare{position:fixed;top:0;right:-50dvw}.address-bar-history-button[data-v-b45f1e9d]:hover{background:var(--scalar-background-3)}.address-bar-history-button[data-v-b45f1e9d]:focus-within{background:var(--scalar-background-2)}.description[data-v-1b7a32a4] .markdown{font-weight:var(--scalar-semibold);color:var(--scalar-color--1);padding:0;display:block}.description[data-v-1b7a32a4] .markdown>:first-child{margin-top:0}[data-v-e2bff922] .cm-editor{background:0 0;outline:none;height:100%;padding:0}[data-v-e2bff922] .cm-placeholder{color:var(--scalar-color-3)}[data-v-e2bff922] .cm-content{font-family:var(--scalar-font-code);font-size:var(--scalar-small);max-height:20px;padding:8px 0}[data-v-e2bff922] .cm-tooltip{filter:brightness(var(--scalar-lifted-brightness));border-radius:var(--scalar-radius);box-shadow:var(--scalar-shadow-2);background:0 0!important;border:none!important;outline:none!important;overflow:hidden!important}[data-v-e2bff922] .cm-tooltip-autocomplete ul li{padding:3px 6px!important}[data-v-e2bff922] .cm-completionIcon-type:after{color:var(--scalar-color-3)!important}[data-v-e2bff922] .cm-tooltip-autocomplete ul li[aria-selected]{background:var(--scalar-background-2)!important;color:var(--scalar-color-1)!important}[data-v-e2bff922] .cm-tooltip-autocomplete ul{position:relative;padding:6px!important}[data-v-e2bff922] .cm-tooltip-autocomplete ul li:hover{border-radius:3px;color:var(--scalar-color-1)!important;background:var(--scalar-background-3)!important}[data-v-e2bff922] .cm-activeLine,[data-v-e2bff922] .cm-activeLineGutter{background-color:#0000}[data-v-e2bff922] .cm-selectionMatch,[data-v-e2bff922] .cm-matchingBracket{border-radius:var(--scalar-radius);background:var(--scalar-background-4)!important}[data-v-e2bff922] .cm-css-color-picker-wrapper{outline:1px solid var(--scalar-background-3);border-radius:3px;display:inline-flex;overflow:hidden}[data-v-e2bff922] .cm-gutters{color:var(--scalar-color-3);font-size:var(--scalar-small);background-color:#0000;border-right:none;border-radius:0 0 0 3px;line-height:22px}[data-v-e2bff922] .cm-gutters:before{content:"";border-radius:var(--scalar-radius)0 0 var(--scalar-radius);background-color:var(--scalar-background-1);width:calc(100% - 2px);height:calc(100% - 4px);position:absolute;top:2px;left:2px}[data-v-e2bff922] .cm-gutterElement{justify-content:flex-end;align-items:center;display:flex;position:relative;font-family:var(--scalar-font-code)!important;padding-left:0!important;padding-right:6px!important}[data-v-e2bff922] .cm-lineNumbers .cm-gutterElement{min-width:fit-content}[data-v-e2bff922] .cm-gutter+.cm-gutter :not(.cm-foldGutter) .cm-gutterElement{padding-left:0!important}[data-v-e2bff922] .cm-scroller{overflow:auto}.line-wrapping[data-v-e2bff922]:focus-within .cm-content{white-space:break-spaces;word-break:break-all;min-height:fit-content;padding:3px 6px;display:inline-table}.cm-pill{--tw-bg-base:var(--scalar-color-1);color:var(--tw-bg-base);font-size:var(--scalar-small);border-radius:30px;padding:0 9px;display:inline-block;background:var(--tw-bg-base)!important}@supports (color:color-mix(in lab,red,red)){.cm-pill{background:color-mix(in srgb,var(--tw-bg-base),transparent 94%)!important}}.cm-pill.bg-grey{background:var(--scalar-background-3)!important}.dark-mode .cm-pill{background:var(--tw-bg-base)!important}@supports (color:color-mix(in lab,red,red)){.dark-mode .cm-pill{background:color-mix(in srgb,var(--tw-bg-base),transparent 90%)!important}}.cm-pill:first-of-type{margin-left:0}.cm-editor .cm-widgetBuffer{display:none}.cm-foldPlaceholder:hover{color:var(--scalar-color-1)}.cm-foldGutter .cm-gutterElement{font-size:var(--scalar-heading-4);padding:2px!important}.cm-foldGutter .cm-gutterElement:first-of-type{display:none}.cm-foldGutter .cm-gutterElement .cm-foldMarker{padding:2px}.cm-foldGutter .cm-gutterElement:hover .cm-foldMarker{background:var(--scalar-background-2);border-radius:var(--scalar-radius);color:var(--scalar-color-1)}[data-v-80d05ddf] .cm-editor{outline:none;width:100%;height:100%}[data-v-80d05ddf] .cm-line{padding:0}[data-v-80d05ddf] .cm-content{font-size:var(--scalar-small);align-items:center;padding:0;display:flex}.scroll-timeline-x[data-v-80d05ddf]{scroll-timeline:--scroll-timeline x;scroll-timeline:--scroll-timeline horizontal;-ms-overflow-style:none}.scroll-timeline-x-hidden[data-v-80d05ddf]{overflow-x:auto}.scroll-timeline-x-hidden[data-v-80d05ddf] .cm-scroller{scrollbar-width:none;-ms-overflow-style:none;padding-right:20px;overflow:auto}.scroll-timeline-x-hidden[data-v-80d05ddf]::-webkit-scrollbar{width:0;height:0;display:none}.scroll-timeline-x-hidden[data-v-80d05ddf] .cm-scroller::-webkit-scrollbar{width:0;height:0;display:none}.scroll-timeline-x-address[data-v-80d05ddf]{scrollbar-width:none;line-height:27px}.scroll-timeline-x-address[data-v-80d05ddf]:after{content:"";cursor:text;width:24px;height:100%;position:absolute;right:0}.scroll-timeline-x-address[data-v-80d05ddf]:empty:before{content:"Enter URL or cURL request";color:var(--scalar-color-3);pointer-events:none}.fade-left[data-v-80d05ddf],.fade-right[data-v-80d05ddf]{content:"";pointer-events:none;z-index:1;height:100%;animation-name:fadein-80d05ddf;animation-duration:1ms;animation-direction:reverse;animation-timeline:--scroll-timeline;position:sticky}.fade-left[data-v-80d05ddf]{background:linear-gradient(-90deg,var(--scalar-address-bar-bg)0%,var(--scalar-address-bar-bg)30%,var(--scalar-address-bar-bg)100%)}@supports (color:color-mix(in lab,red,red)){.fade-left[data-v-80d05ddf]{background:linear-gradient(-90deg,color-mix(in srgb,var(--scalar-address-bar-bg),transparent 100%)0%,color-mix(in srgb,var(--scalar-address-bar-bg),transparent 20%)30%,var(--scalar-address-bar-bg)100%)}}.fade-left[data-v-80d05ddf]{min-width:6px;animation-direction:normal;left:-1px}.fade-right[data-v-80d05ddf]{background:linear-gradient(90deg,var(--scalar-address-bar-bg)0%,var(--scalar-address-bar-bg)30%,var(--scalar-address-bar-bg)100%)}@supports (color:color-mix(in lab,red,red)){.fade-right[data-v-80d05ddf]{background:linear-gradient(90deg,color-mix(in srgb,var(--scalar-address-bar-bg),transparent 100%)0%,color-mix(in srgb,var(--scalar-address-bar-bg),transparent 20%)30%,var(--scalar-address-bar-bg)100%)}}.fade-right[data-v-80d05ddf]{min-width:24px;right:-1px}@keyframes fadein-80d05ddf{0%{opacity:0}1%{opacity:1}}.address-bar-bg-states[data-v-80d05ddf]{--scalar-address-bar-bg:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.address-bar-bg-states[data-v-80d05ddf]{--scalar-address-bar-bg:color-mix(in srgb,var(--scalar-background-1),var(--scalar-background-2))}}.address-bar-bg-states[data-v-80d05ddf]{background:var(--scalar-address-bar-bg)}.address-bar-bg-states[data-v-80d05ddf]:has(.cm-focused){--scalar-address-bar-bg:var(--scalar-background-1);border-color:var(--scalar-border-color);outline-width:1px;outline-style:solid}.address-bar-bg-states:has(.cm-focused) .fade-left[data-v-80d05ddf],.address-bar-bg-states:has(.cm-focused) .fade-right[data-v-80d05ddf]{--scalar-address-bar-bg:var(--scalar-background-1)}.app-exit-button[data-v-43c7b0fc]{color:#fff;background:#0000001a}.app-exit-button[data-v-43c7b0fc]:hover{background:#ffffff1a}.fade-request-section-content[data-v-f97cc68c]{background:linear-gradient(to left,var(--scalar-background-1)64%,transparent)}.filter-hover[data-v-f97cc68c]{height:100%;padding-left:24px;padding-right:39px;transition:width 0s ease-in-out .2s;position:absolute;right:0;overflow:hidden}.filter-hover[data-v-f97cc68c]:hover,.filter-hover[data-v-f97cc68c]:has(:focus-visible){z-index:10;width:100%}.filter-hover[data-v-f97cc68c]:before{content:"";background-color:var(--scalar-background-1);opacity:0;pointer-events:none;width:100%;height:fit-content;transition:all .3s ease-in-out;position:absolute;top:0;left:0}.filter-hover-item[data-v-f97cc68c]{opacity:0}.filter-hover-item[data-v-f97cc68c]:not(:last-of-type){transform:translateY(3px)}.filter-hover:hover .filter-hover-item[data-v-f97cc68c]{transition:opacity .2s ease-in-out,transform .2s ease-in-out}.filter-hover:hover .filter-hover-item[data-v-f97cc68c]:last-of-type{transition-delay:50ms}.filter-hover:hover .filter-hover-item[data-v-f97cc68c]:nth-last-of-type(2){transition-delay:.1s}.filter-hover:hover .filter-hover-item[data-v-f97cc68c]:nth-last-of-type(3){transition-delay:.15s}.filter-hover:hover .filter-hover-item[data-v-f97cc68c]:nth-last-of-type(4){transition-delay:.2s}.filter-hover:hover .filter-hover-item[data-v-f97cc68c]:nth-last-of-type(5){transition-delay:.25s}.filter-hover:hover .filter-hover-item[data-v-f97cc68c]:nth-last-of-type(6){transition-delay:.3s}.filter-hover:hover .filter-hover-item[data-v-f97cc68c]:nth-last-of-type(7){transition-delay:.35s}.filter-hover:hover .filter-hover-item[data-v-f97cc68c],.filter-hover:has(:focus-visible) .filter-hover-item[data-v-f97cc68c]{opacity:1;transform:translateZ(0)}.filter-hover[data-v-f97cc68c]:hover:before,.filter-hover[data-v-f97cc68c]:has(:focus-visible):before{opacity:.9;-webkit-backdrop-filter:blur(10px);backdrop-filter:blur(10px)}.filter-button[data-v-f97cc68c]{top:50%;transform:translateY(-50%)}.context-bar-group:hover .context-bar-group-hover\\:text-c-1[data-v-f97cc68c],.context-bar-group:has(:focus-visible) .context-bar-group-hover\\:text-c-1[data-v-f97cc68c]{--tw-text-opacity:1;color:rgb(var(--scalar-color-1)/var(--tw-text-opacity))}.context-bar-group:hover .context-bar-group-hover\\:hidden[data-v-f97cc68c],.context-bar-group:has(:focus-visible) .context-bar-group-hover\\:hidden[data-v-f97cc68c]{display:none}.schema>span[data-v-f2ab7aa3]:not(:first-child):before{content:"·";margin:0 .5ch;display:block}.schema>span[data-v-f2ab7aa3]{white-space:nowrap;display:flex}[data-v-2dc74300] .cm-editor{padding:0}[data-v-2dc74300] .cm-content{font-family:var(--scalar-font);font-size:var(--scalar-small);background-color:#0000;align-items:center;width:100%;padding:5px 8px;display:flex}[data-v-2dc74300] .cm-content:has(.cm-pill){padding:5px 8px}[data-v-2dc74300] .cm-content .cm-pill:not(:last-of-type){margin-right:.5px}[data-v-2dc74300] .cm-content .cm-pill:not(:first-of-type){margin-left:.5px}[data-v-2dc74300] .cm-line{text-overflow:ellipsis;padding:0;overflow:hidden}.filemask[data-v-2dc74300]{-webkit-mask-image:linear-gradient(to right,transparent 0,var(--scalar-background-2)20px);mask-image:linear-gradient(to right,transparent 0,var(--scalar-background-2)20px)}[data-v-0a6f7696] .cm-content{font-size:var(--scalar-small)}.form-group[data-v-43df1726]{margin-bottom:1rem}.modal-actions[data-v-43df1726]{justify-content:flex-end;gap:1rem;display:flex}[data-v-3157c3c7] .cm-editor{padding:0}[data-v-3157c3c7] .cm-content{font-family:var(--scalar-font);font-size:var(--scalar-small);background-color:#0000;align-items:center;width:100%;padding:5px 8px;display:flex}[data-v-3157c3c7] .cm-content:has(.cm-pill){padding:5px 8px}[data-v-3157c3c7] .cm-content .cm-pill:not(:last-of-type){margin-right:.5px}[data-v-3157c3c7] .cm-content .cm-pill:not(:first-of-type){margin-left:.5px}[data-v-3157c3c7] .cm-line{text-overflow:ellipsis;word-break:break-word;padding:0;overflow:hidden}.required[data-v-3157c3c7]:after{content:"Required"}input[data-v-3157c3c7]::placeholder{color:var(--scalar-color-3)}.scalar-password-input[data-v-3157c3c7]{text-security:disc;-webkit-text-security:disc;-moz-text-security:disc}.request-section-content[data-v-8c6cdddb]{--scalar-border-width:.5px}.request-section-content-filter[data-v-8c6cdddb]{box-shadow:0 -10px 0 10px var(--scalar-background-1)}.request-item:focus-within .request-meta-buttons[data-v-8c6cdddb]{opacity:1}.group-hover-input[data-v-8c6cdddb]{border-width:var(--scalar-border-width);border-color:#0000}.group:hover .group-hover-input[data-v-8c6cdddb]{background:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.group:hover .group-hover-input[data-v-8c6cdddb]{background:color-mix(in srgb,var(--scalar-background-1),var(--scalar-background-2))}}.group:hover .group-hover-input[data-v-8c6cdddb]{border-color:var(--scalar-border-color)}.group-hover-input[data-v-8c6cdddb]:focus{border-color:var(--scalar-border-color)!important;background:0 0!important}.light-mode .bg-preview[data-v-c02b5bb8]{background-image:url("data:image/svg+xml,%3Csvg xmlns=\'http://www.w3.org/2000/svg\' width=\'16\' height=\'16\' fill=\'%23000\' fill-opacity=\'10%25\'%3E%3Crect width=\'8\' height=\'8\' /%3E%3Crect x=\'8\' y=\'8\' width=\'8\' height=\'8\' /%3E%3C/svg%3E")}.dark-mode .bg-preview[data-v-c02b5bb8]{background-image:url("data:image/svg+xml,%3Csvg xmlns=\'http://www.w3.org/2000/svg\' width=\'16\' height=\'16\' fill=\'%23FFF\' fill-opacity=\'10%25\'%3E%3Crect width=\'8\' height=\'8\' /%3E%3Crect x=\'8\' y=\'8\' width=\'8\' height=\'8\' /%3E%3C/svg%3E")}[data-v-10022578] .cm-editor{font-size:var(--scalar-small);background-color:#0000;outline:none}[data-v-10022578] .cm-gutters{background-color:var(--scalar-background-1);border-radius:var(--scalar-radius)0 0 var(--scalar-radius)}.body-raw[data-v-10022578] .cm-scroller{min-width:100%;overflow:auto}.scalar-code-block[data-v-32d6d6ca] .hljs *{font-size:var(--scalar-small)}.ascii-art-animate .ascii-art-line[data-v-69ebd973]{border-right:1ch solid #0000;animation:4s step-end 1s both typewriter-69ebd973,.5s step-end infinite blinkTextCursor-69ebd973}@keyframes typewriter-69ebd973{0%{width:0}to{width:100%}}@keyframes blinkTextCursor-69ebd973{0%{border-right-color:currentColor}50%{border-right-color:#0000}}.keycap-n[data-v-b1211b87]{background:-webkit-linear-gradient(5deg,transparent 30%,var(--scalar-color-3)50%);-webkit-text-fill-color:transparent;-webkit-background-clip:text;background-clip:text}.keycap-hotkey[data-v-b1211b87]{line-height:26px;position:absolute;top:32px}.scalar-version-number[data-v-159bd9b3]{width:76px;height:76px;font-size:8px;font-family:var(--scalar-font-code);box-shadow:inset 2px 0 0 2px var(--scalar-background-2);text-align:center;text-transform:initial;-webkit-text-decoration-color:var(--scalar-color-3);text-decoration-color:var(--scalar-color-3);border-radius:9px 9px 16px 12px;flex-direction:column;justify-content:center;align-items:center;margin-top:-113px;margin-left:-36px;line-height:11px;display:flex;position:absolute;transform:skewY(13deg)}.scalar-version-number a[data-v-159bd9b3]{background:var(--scalar-background-2);border:.5px solid var(--scalar-border-color);border-radius:3px;padding:2px 4px;font-weight:700;text-decoration:none}.gitbook-show[data-v-159bd9b3]{display:none}.v-enter-active[data-v-57ced68a]{transition:opacity .5s}.v-enter-from[data-v-57ced68a]{opacity:0}.animate-response-heading .response-heading[data-v-aaba9a18]{opacity:1;animation:.2s ease-in-out forwards push-response-aaba9a18}@keyframes push-response-aaba9a18{0%{opacity:1;transform:translateY(0)}to{opacity:0;transform:translateY(-4px)}}.animate-response-heading .animate-response-children[data-v-aaba9a18]{opacity:0;animation:.2s ease-in-out 50ms forwards response-spans-aaba9a18}@keyframes response-spans-aaba9a18{0%{opacity:0;transform:translateY(4px)}to{opacity:1;transform:translateY(0)}}.request-card[data-v-59889f40]{font-size:var(--scalar-font-size-3)}.request-method[data-v-59889f40]{font-family:var(--scalar-font-code);text-transform:uppercase;margin-right:6px}.request-card-footer[data-v-59889f40]{flex-shrink:0;justify-content:flex-end;padding:6px;display:flex}.request-card-footer-addon[data-v-59889f40]{flex:1;align-items:center;min-width:0;display:flex}.request-editor-section[data-v-59889f40]{flex:1;display:flex}.request-card-simple[data-v-59889f40]{font-size:var(--scalar-small);justify-content:space-between;align-items:center;padding:8px 8px 8px 12px;display:flex}.code-snippet[data-v-59889f40]{flex-direction:column;width:100%;display:flex}.resizer[data-v-e2c54c18]{cursor:col-resize;z-index:100;border-right:2px solid #0000;width:5px;transition:border-right-color .3s;position:absolute;top:0;bottom:0;right:0}.scalar-dragging{cursor:col-resize}.resizer:hover,.scalar-dragging .resizer{border-right-color:var(--scalar-background-3)}.scalar-dragging:after{content:"";display:block;position:absolute;inset:0}.ref-search-meta[data-v-0c30b37a]{background:var(--scalar-background-1);border-bottom-left-radius:var(--scalar-radius-lg);border-bottom-right-radius:var(--scalar-radius-lg);font-size:var(--scalar-font-size-4);color:var(--scalar-color-3);font-weight:var(--scalar-semibold);border-top:var(--scalar-border-width)solid var(--scalar-border-color);gap:12px;padding:6px 12px;display:flex}.splash-screen[data-v-af32615f]{opacity:0;animation:.5s ease-in-out forwards fadeIn-af32615f}.logo-icon[data-v-af32615f]{opacity:0;animation:.6s ease-in-out .2s forwards fadeInLogo-af32615f,2s ease-in-out .8s infinite pulse-af32615f}@keyframes fadeIn-af32615f{0%{opacity:0}to{opacity:.9}}@keyframes fadeInLogo-af32615f{0%{opacity:0;transform:scale(.9)}to{opacity:.8;transform:scale(1)}}@keyframes pulse-af32615f{0%,to{opacity:.8}50%{opacity:.6}}.scroll-timeline-x[data-v-981120f2]{scroll-timeline:--scroll-timeline x;scroll-timeline:--scroll-timeline horizontal;-ms-overflow-style:none;scrollbar-width:none;overflow:auto}.scroll-timeline-x[data-v-981120f2]::-webkit-scrollbar{display:none}.commandmenu[data-v-7f3e459b]{box-shadow:var(--scalar-shadow-2);border-radius:var(--scalar-radius-lg);background-color:var(--scalar-background-1);opacity:0;width:100%;max-width:580px;max-height:60dvh;margin:12px;animation:.3s ease-in-out .1s forwards fadeincommandmenu-7f3e459b;position:fixed;top:150px;left:50%;transform:translate(-50%,10px)}.commandmenu-overlay[data-v-7f3e459b]{cursor:pointer;background:#0003;animation:.3s ease-in-out forwards fadeincommand-7f3e459b;position:fixed;inset:0}@keyframes fadeincommand-7f3e459b{0%{opacity:0}to{opacity:1}}@keyframes fadeincommandmenu-7f3e459b{0%{opacity:0;transform:translate(-50%,10px)}to{opacity:1;transform:translate(-50%)}}.empty-sidebar-item-content[data-v-e30bf25b]{display:none}.empty-sidebar-item .empty-sidebar-item-content[data-v-e30bf25b]{display:block}.rabbitjump[data-v-e30bf25b]{opacity:0}.empty-sidebar-item:hover .rabbitjump[data-v-e30bf25b]{opacity:1;animation:.5s step-end infinite rabbitAnimation-e30bf25b}.empty-sidebar-item:hover .rabbitsit[data-v-e30bf25b]{opacity:0;animation:.5s step-end infinite rabbitAnimation2-e30bf25b}.empty-sidebar-item:hover .rabbit-ascii[data-v-e30bf25b]{animation:8s linear infinite rabbitRun-e30bf25b}@keyframes rabbitRun-e30bf25b{0%{transform:translateZ(0)}25%{transform:translate(250px)}25.01%{transform:translate(-250px)}75%{transform:translate(250px)}75.01%{transform:translate(-250px)}to{transform:translateZ(0)}}@keyframes rabbitAnimation-e30bf25b{0%,to{opacity:1}50%{opacity:0}}@keyframes rabbitAnimation2-e30bf25b{0%,to{opacity:0}50%{opacity:1;transform:translateY(-8px)}}.nav-single-tab[data-v-2e741aab]{width:100%;height:100%;color:var(--scalar-color-1);justify-content:center;align-items:center;display:flex;overflow:hidden}.nav-item[data-v-2e741aab]{cursor:pointer;border-radius:var(--scalar-radius-lg);background:var(--scalar-background-3);border:var(--scalar-border-width)solid var(--scalar-background-2);color:var(--scalar-color-3);flex:1;justify-content:center;align-items:center;min-width:0;padding:4.5px 1rem;display:flex;position:relative;overflow:hidden}.dark-mode .nav-item[data-v-2e741aab]{background:var(--scalar-background-2)}@supports (color:color-mix(in lab,red,red)){.dark-mode .nav-item[data-v-2e741aab]{background:color-mix(in srgb,var(--scalar-background-2),transparent)}}.nav-item-icon-copy[data-v-2e741aab]{white-space:nowrap;max-width:100%;-webkit-mask-image:linear-gradient(to left,transparent 0,var(--scalar-background-2)20px);mask-image:linear-gradient(to left,transparent 0,var(--scalar-background-2)20px);overflow:hidden}.nav-item:hover .nav-item-icon-copy[data-v-2e741aab]{-webkit-mask-image:linear-gradient(to left,transparent 20px,var(--scalar-background-2)40px);mask-image:linear-gradient(to left,transparent 20px,var(--scalar-background-2)40px)}.nav-item-copy[data-v-2e741aab]{max-width:calc(100% - 20px)}.nav-item[data-v-2e741aab]:hover{color:var(--scalar-color-1)}.nav-item__active[data-v-2e741aab]{background-color:var(--scalar-background-1);color:var(--scalar-color-1);border-color:var(--scalar-border-color)}.dark-mode .nav-item__active[data-v-2e741aab]{background-color:var(--scalar-background-2)}.nav-item-close[data-v-2e741aab]{border-radius:var(--scalar-radius);stroke-width:1.5px;max-width:20px;color:var(--scalar-color-3);opacity:0;background:0 0;margin-left:-20px;padding:2px;position:absolute;right:3px}.nav-item:hover .nav-item-close[data-v-2e741aab]{opacity:1}.nav-item-close[data-v-2e741aab]:hover{background-color:var(--scalar-background-4)}.nav-item__active .nav-item-close[data-v-2e741aab]:hover{background-color:var(--scalar-background-2)}.download-app-button[data-v-d9bec97b]{box-shadow:0 0 0 .5px var(--scalar-border-color);background:linear-gradient(#ffffffbf,#00000009)}.dark-mode .download-app-button[data-v-d9bec97b]{background:linear-gradient(#ffffff1a,#00000026)}.download-app-button[data-v-d9bec97b]:hover{background:linear-gradient(#00000009,#ffffffbf)}.dark-mode .download-app-button[data-v-d9bec97b]:hover{background:linear-gradient(#00000026,#ffffff1a)}#scalar-client{background-color:var(--scalar-background-2);flex-direction:column;width:100dvw;height:100dvh;display:flex;position:relative}.dark-mode #scalar-client{background-color:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.dark-mode #scalar-client{background-color:color-mix(in srgb,var(--scalar-background-1)65%,black)}}.scalar-collection-auth[data-v-dc159f6f]{border:var(--scalar-border-width)solid var(--scalar-border-color);border-radius:var(--scalar-radius-lg);overflow:hidden}[data-v-6fc24fdf] .cm-editor{padding:0}[data-v-6fc24fdf] .cm-content{font-family:var(--scalar-font);font-size:var(--scalar-small);background-color:#0000;align-items:center;width:100%;padding:5px 8px;display:flex}[data-v-6fc24fdf] .cm-content:has(.cm-pill){padding:5px 8px}[data-v-6fc24fdf] .cm-content .cm-pill:not(:last-of-type){margin-right:.5px}[data-v-6fc24fdf] .cm-content .cm-pill:not(:first-of-type){margin-left:.5px}[data-v-6fc24fdf] .cm-line{text-overflow:ellipsis;padding:0;overflow:hidden}[data-v-28c8509c] .cm-editor{padding:0}[data-v-28c8509c] .cm-content{font-family:var(--scalar-font);font-size:var(--scalar-small);background-color:#0000;align-items:center;width:100%;padding:5px 8px;display:flex}[data-v-28c8509c] .cm-content:has(.cm-pill){padding:5px 8px}[data-v-28c8509c] .cm-content .cm-pill:not(:last-of-type){margin-right:.5px}[data-v-28c8509c] .cm-content .cm-pill:not(:first-of-type){margin-left:.5px}[data-v-28c8509c] .cm-line{text-overflow:ellipsis;padding:0;overflow:hidden}[data-v-7c1a2f6c] .cm-content{min-height:fit-content}[data-v-7c1a2f6c] .cm-scroller{max-width:100%;overflow:auto hidden}.group-hover-input[data-v-5a23cb87]{border-width:var(--scalar-border-width);border-color:#0000}.group:hover .group-hover-input[data-v-5a23cb87]{background:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.group:hover .group-hover-input[data-v-5a23cb87]{background:color-mix(in srgb,var(--scalar-background-1),var(--scalar-background-2))}}.group:hover .group-hover-input[data-v-5a23cb87]{border-color:var(--scalar-border-color)}.group-hover-input[data-v-5a23cb87]:focus{border-color:var(--scalar-border-color)!important;background:0 0!important}.scalar .scalar-app-layout[data-v-9f4696a7]{background:var(--scalar-background-1);opacity:0;border:var(--scalar-border-width)solid var(--scalar-border-color);border-radius:8px;width:100%;max-width:1390px;height:calc(100% - 120px);margin:auto;animation:.35s forwards scalarapiclientfadein-9f4696a7;position:relative;overflow:hidden}@media(max-width:720px)and (max-height:480px){.scalar .scalar-app-layout[data-v-9f4696a7]{height:100%;max-height:90svh}}@keyframes scalarapiclientfadein-9f4696a7{0%{opacity:0}to{opacity:1}}.scalar .scalar-app-exit[data-v-9f4696a7]{cursor:pointer;z-index:-1;background:#00000038;width:100vw;height:100vh;transition:all .3s ease-in-out;animation:.35s forwards scalardrawerexitfadein-9f4696a7;position:fixed;top:0;left:0}.dark-mode .scalar .scalar-app-exit[data-v-9f4696a7]{background:#00000073}.scalar .scalar-app-exit[data-v-9f4696a7]:before{text-align:center;color:#fff;opacity:.6;font-family:sans-serif;font-size:30px;font-weight:100;line-height:50px;position:absolute;top:0;right:12px}.scalar .scalar-app-exit[data-v-9f4696a7]:hover:before{opacity:1}@keyframes scalardrawerexitfadein-9f4696a7{0%{opacity:0}to{opacity:1}}.scalar-container[data-v-9f4696a7]{visibility:visible;z-index:10000;justify-content:center;align-items:center;width:100%;height:100%;display:flex;position:fixed;top:0;bottom:0;left:0;overflow:hidden}.scalar .url-form-input[data-v-9f4696a7]{min-height:auto!important}.scalar .scalar-container[data-v-9f4696a7]{line-height:normal}.scalar .scalar-app-header span[data-v-9f4696a7]{color:var(--scalar-color-3)}.scalar .scalar-app-header a[data-v-9f4696a7]{color:var(--scalar-color-1)}.scalar .scalar-app-header a[data-v-9f4696a7]:hover{text-decoration:underline}.scalar-activate[data-v-9f4696a7]{cursor:pointer;align-items:center;gap:6px;width:fit-content;margin:0 .75rem .75rem auto;font-size:.875rem;font-weight:600;line-height:24px;display:flex}.scalar-activate-button[data-v-9f4696a7]{color:var(--scalar-color-blue);appearance:none;background:0 0;border:none;outline:none;align-items:center;gap:6px;padding:0 .5rem;display:flex}.scalar-activate:hover .scalar-activate-button[data-v-9f4696a7]{background:var(--scalar-background-3);border-radius:3px}.schema>span[data-v-4df72868]:not(:first-child):before{content:"·";margin:0 .5ch;display:block}.schema>span[data-v-4df72868]{white-space:nowrap;display:flex}[data-v-04661eb4] .cm-editor{padding:0}[data-v-04661eb4] .cm-content{font-family:var(--scalar-font);font-size:var(--scalar-small);background-color:#0000;align-items:center;width:100%;padding:5px 8px;display:flex}[data-v-04661eb4] .cm-content:has(.cm-pill){padding:5px 8px}[data-v-04661eb4] .cm-content .cm-pill:not(:last-of-type){margin-right:.5px}[data-v-04661eb4] .cm-content .cm-pill:not(:first-of-type){margin-left:.5px}[data-v-04661eb4] .cm-line{text-overflow:ellipsis;padding:0;overflow:hidden}.filemask[data-v-04661eb4]{-webkit-mask-image:linear-gradient(to right,transparent 0,var(--scalar-background-2)20px);mask-image:linear-gradient(to right,transparent 0,var(--scalar-background-2)20px)}[data-v-9aa4b63a] .cm-content{font-size:var(--scalar-small)}.auth-combobox-position[data-v-0bb98074]{margin-left:120px}.scroll-timeline-x[data-v-0bb98074]{scroll-timeline:--scroll-timeline x;scroll-timeline:--scroll-timeline horizontal;scrollbar-width:none;-ms-overflow-style:none;overflow:auto}.fade-left[data-v-0bb98074],.fade-right[data-v-0bb98074]{content:"";pointer-events:none;height:100%;min-height:24px;animation-name:fadein-0bb98074;animation-duration:1ms;animation-direction:reverse;animation-timeline:--scroll-timeline;position:sticky}.fade-left[data-v-0bb98074]{background:linear-gradient(-90deg,var(--scalar-background-1)0%,var(--scalar-background-1)60%,var(--scalar-background-1)100%)}@supports (color:color-mix(in lab,red,red)){.fade-left[data-v-0bb98074]{background:linear-gradient(-90deg,color-mix(in srgb,var(--scalar-background-1),transparent 100%)0%,color-mix(in srgb,var(--scalar-background-1),transparent 20%)60%,var(--scalar-background-1)100%)}}.fade-left[data-v-0bb98074]{min-width:3px;animation-direction:normal;left:-1px}.fade-right[data-v-0bb98074]{background:linear-gradient(90deg,var(--scalar-background-1)0%,var(--scalar-background-1)60%,var(--scalar-background-1)100%)}@supports (color:color-mix(in lab,red,red)){.fade-right[data-v-0bb98074]{background:linear-gradient(90deg,color-mix(in srgb,var(--scalar-background-1),transparent 100%)0%,color-mix(in srgb,var(--scalar-background-1),transparent 20%)60%,var(--scalar-background-1)100%)}}.fade-right[data-v-0bb98074]{min-width:24px;margin-left:-20px;top:0;right:-1px}@keyframes fadein-0bb98074{0%{opacity:0}15%{opacity:1}}.auth-combobox-position[data-v-3f1067a4]{margin-left:120px}.scroll-timeline-x[data-v-3f1067a4]{scroll-timeline:--scroll-timeline x;scroll-timeline:--scroll-timeline horizontal;scrollbar-width:none;-ms-overflow-style:none;overflow:auto}.fade-left[data-v-3f1067a4],.fade-right[data-v-3f1067a4]{content:"";pointer-events:none;height:100%;min-height:24px;animation-name:fadein-3f1067a4;animation-duration:1ms;animation-direction:reverse;animation-timeline:--scroll-timeline;position:sticky}.fade-left[data-v-3f1067a4]{background:linear-gradient(-90deg,var(--scalar-background-1)0%,var(--scalar-background-1)60%,var(--scalar-background-1)100%)}@supports (color:color-mix(in lab,red,red)){.fade-left[data-v-3f1067a4]{background:linear-gradient(-90deg,color-mix(in srgb,var(--scalar-background-1),transparent 100%)0%,color-mix(in srgb,var(--scalar-background-1),transparent 20%)60%,var(--scalar-background-1)100%)}}.fade-left[data-v-3f1067a4]{min-width:3px;animation-direction:normal;left:-1px}.fade-right[data-v-3f1067a4]{background:linear-gradient(90deg,var(--scalar-background-1)0%,var(--scalar-background-1)60%,var(--scalar-background-1)100%)}@supports (color:color-mix(in lab,red,red)){.fade-right[data-v-3f1067a4]{background:linear-gradient(90deg,color-mix(in srgb,var(--scalar-background-1),transparent 100%)0%,color-mix(in srgb,var(--scalar-background-1),transparent 20%)60%,var(--scalar-background-1)100%)}}.fade-right[data-v-3f1067a4]{min-width:24px;margin-left:-20px;top:0;right:-1px}@keyframes fadein-3f1067a4{0%{opacity:0}15%{opacity:1}}[data-v-2891f052] code.hljs *{font-size:var(--scalar-small)}.request-section-content[data-v-e85e2882]{--scalar-border-width:.5px}.request-section-content-filter[data-v-e85e2882]{box-shadow:0 -10px 0 10px var(--scalar-background-1)}.request-item:focus-within .request-meta-buttons[data-v-e85e2882]{opacity:1}.group-hover-input[data-v-e85e2882]{border-width:var(--scalar-border-width);border-color:#0000}.group:hover .group-hover-input[data-v-e85e2882]{background:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.group:hover .group-hover-input[data-v-e85e2882]{background:color-mix(in srgb,var(--scalar-background-1),var(--scalar-background-2))}}.group:hover .group-hover-input[data-v-e85e2882]{border-color:var(--scalar-border-color)}.group-hover-input[data-v-e85e2882]:focus{border-color:var(--scalar-border-color)!important;background:0 0!important}.light-mode .bg-preview[data-v-0956ad2d]{background-image:url("data:image/svg+xml,%3Csvg xmlns=\'http://www.w3.org/2000/svg\' width=\'16\' height=\'16\' fill=\'%23000\' fill-opacity=\'10%25\'%3E%3Crect width=\'8\' height=\'8\' /%3E%3Crect x=\'8\' y=\'8\' width=\'8\' height=\'8\' /%3E%3C/svg%3E")}.dark-mode .bg-preview[data-v-0956ad2d]{background-image:url("data:image/svg+xml,%3Csvg xmlns=\'http://www.w3.org/2000/svg\' width=\'16\' height=\'16\' fill=\'%23FFF\' fill-opacity=\'10%25\'%3E%3Crect width=\'8\' height=\'8\' /%3E%3Crect x=\'8\' y=\'8\' width=\'8\' height=\'8\' /%3E%3C/svg%3E")}[data-v-85d2902e] .cm-editor{font-size:var(--scalar-small);background-color:#0000;outline:none}[data-v-85d2902e] .cm-gutters{background-color:var(--scalar-background-1);border-radius:var(--scalar-radius)0 0 var(--scalar-radius)}.body-raw[data-v-85d2902e] .cm-scroller{min-width:100%;overflow:auto}.scalar-code-block[data-v-17966bf4] .hljs *{font-size:var(--scalar-small)}.response-body-virtual[data-headlessui-state=open],.response-body-virtual[data-headlessui-state=open] .diclosure-panel{flex-direction:column;flex-grow:1;display:flex}.scalar-version-number[data-v-6d2bdb61]{width:76px;height:76px;font-size:8px;font-family:var(--scalar-font-code);box-shadow:inset 2px 0 0 2px var(--scalar-background-2);text-align:center;text-transform:initial;-webkit-text-decoration-color:var(--scalar-color-3);text-decoration-color:var(--scalar-color-3);border-radius:9px 9px 16px 12px;flex-direction:column;justify-content:center;align-items:center;margin-top:-113px;margin-left:-36px;line-height:11px;display:flex;position:absolute;transform:skewY(13deg)}.scalar-version-number a[data-v-6d2bdb61]{background:var(--scalar-background-2);border:.5px solid var(--scalar-border-color);border-radius:3px;padding:2px 4px;font-weight:700;text-decoration:none}.gitbook-show[data-v-6d2bdb61]{display:none}.v-enter-active[data-v-7ec8af01]{transition:opacity .5s}.v-enter-from[data-v-7ec8af01]{opacity:0}.animate-response-heading .response-heading[data-v-7138ed84]{opacity:1;animation:.2s ease-in-out forwards push-response-7138ed84}@keyframes push-response-7138ed84{0%{opacity:1;transform:translateY(0)}to{opacity:0;transform:translateY(-4px)}}.animate-response-heading .animate-response-children[data-v-7138ed84]{opacity:0;animation:.2s ease-in-out 50ms forwards response-spans-7138ed84}@keyframes response-spans-7138ed84{0%{opacity:0;transform:translateY(4px)}to{opacity:1;transform:translateY(0)}}.ellipsis-position[data-v-01a1ab71]{transform:translate(calc(-100% - 4.5px))}.indent-border-line-offset[data-v-4f5a9d1f]:before{left:var(--v0bed2d4e)}.indent-padding-left[data-v-4f5a9d1f]{padding-left:calc(var(--v57ee1db0) + 6px)}.sidebar-folderitem[data-v-4f5a9d1f] .ellipsis-position{right:6px;transform:none}.search-button-fade[data-v-bca9c474]{background:linear-gradient(var(--scalar-background-1)32px,var(--scalar-background-1)38px,transparent)}@supports (color:color-mix(in lab,red,red)){.search-button-fade[data-v-bca9c474]{background:linear-gradient(var(--scalar-background-1)32px,color-mix(in srgb,var(--scalar-background-1),transparent)38px,transparent)}}.empty-sidebar-item-content[data-v-bca9c474]{display:none}.empty-sidebar-item .empty-sidebar-item-content[data-v-bca9c474]{display:block}.rabbitjump[data-v-bca9c474]{opacity:0}.empty-sidebar-item:hover .rabbitjump[data-v-bca9c474]{opacity:1;animation:.5s step-end infinite rabbitAnimation-bca9c474}.empty-sidebar-item:hover .rabbitsit[data-v-bca9c474]{opacity:0;animation:.5s step-end infinite rabbitAnimation2-bca9c474}.empty-sidebar-item:hover .rabbit-ascii[data-v-bca9c474]{animation:8s linear infinite rabbitRun-bca9c474}@keyframes rabbitRun-bca9c474{0%{transform:translateZ(0)}25%{transform:translate(250px)}25.01%{transform:translate(-250px)}75%{transform:translate(250px)}75.01%{transform:translate(-250px)}to{transform:translateZ(0)}}@keyframes rabbitAnimation-bca9c474{0%,to{opacity:1}50%{opacity:0}}@keyframes rabbitAnimation2-bca9c474{0%,to{opacity:0}50%{opacity:1;transform:translateY(-8px)}}.request-text-color-text[data-v-c508c571]{color:var(--scalar-color-1);background:linear-gradient(var(--scalar-background-1),var(--scalar-background-3));box-shadow:0 0 0 1px var(--scalar-border-color)}@media screen and (max-width:800px){.sidebar-active-hide-layout[data-v-c508c571]{display:none}.sidebar-active-width[data-v-c508c571]{width:100%}}.gitbook-show[data-v-c8df97c6]{display:none}.app-exit-button[data-v-c8df97c6]{color:#fff;background:#0000001a}.app-exit-button[data-v-c8df97c6]:hover{background:#ffffff1a}.request-text-color-text[data-v-57ae0d10]{color:var(--scalar-color-1);background:linear-gradient(var(--scalar-background-1),var(--scalar-background-3));box-shadow:0 0 0 1px var(--scalar-border-color)}@media screen and (max-width:800px){.sidebar-active-hide-layout[data-v-57ae0d10]{display:none}.sidebar-active-width[data-v-57ae0d10]{width:100%}}.group-hover-input[data-v-fced736a]{border-width:var(--scalar-border-width);border-color:#0000}.group:hover .group-hover-input[data-v-fced736a]{background:var(--scalar-background-1)}@supports (color:color-mix(in lab,red,red)){.group:hover .group-hover-input[data-v-fced736a]{background:color-mix(in srgb,var(--scalar-background-1),var(--scalar-background-2))}}.group:hover .group-hover-input[data-v-fced736a]{border-color:var(--scalar-border-color)}.group-hover-input[data-v-fced736a]:focus{border-color:var(--scalar-border-color)!important;background:0 0!important}[data-v-68d5218e] .markdown h2{font-size:var(--scalar-font-size-2)}[data-v-5997a667] .cm-content{min-height:fit-content}[data-v-5997a667] .cm-scroller{max-width:100%;overflow:auto hidden}[data-v-83bfcc8a] .cm-editor{padding:0}[data-v-83bfcc8a] .cm-content{font-family:var(--scalar-font);font-size:var(--scalar-small);background-color:#0000;align-items:center;width:100%;padding:5px 8px;display:flex}[data-v-83bfcc8a] .cm-content:has(.cm-pill){padding:5px 8px}[data-v-83bfcc8a] .cm-content .cm-pill:not(:last-of-type){margin-right:.5px}[data-v-83bfcc8a] .cm-content .cm-pill:not(:first-of-type){margin-left:.5px}[data-v-83bfcc8a] .cm-line{text-overflow:ellipsis;padding:0;overflow:hidden}.scalar-collection-auth[data-v-cc87292e]{border:var(--scalar-border-width)solid var(--scalar-border-color);border-radius:var(--scalar-radius-lg);overflow:hidden}.dragover-asChild[data-v-a89d6a6e],.dragover-above[data-v-a89d6a6e],.dragover-below[data-v-a89d6a6e]{position:relative}.dragover-above[data-v-a89d6a6e]:after,.dragover-below[data-v-a89d6a6e]:after{content:"";background:var(--scalar-color-blue);width:100%;height:3px;display:block;position:absolute;top:-1.5px}@supports (color:color-mix(in lab,red,red)){.dragover-above[data-v-a89d6a6e]:after,.dragover-below[data-v-a89d6a6e]:after{background:color-mix(in srgb,var(--scalar-color-blue),transparent 85%)}}.dragover-above[data-v-a89d6a6e]:after,.dragover-below[data-v-a89d6a6e]:after{pointer-events:none;border-radius:var(--scalar-radius)}.dragover-below[data-v-a89d6a6e]:after{top:initial;bottom:-1.5px}.dragover-asChild[data-v-a89d6a6e]:after{content:"";background:var(--scalar-color-blue);width:100%;height:100%;display:block;position:absolute;top:0;left:0}@supports (color:color-mix(in lab,red,red)){.dragover-asChild[data-v-a89d6a6e]:after{background:color-mix(in srgb,var(--scalar-color-blue),transparent 85%)}}.dragover-asChild[data-v-a89d6a6e]:after{pointer-events:none;border-radius:var(--scalar-radius)}.empty-variable-name[data-v-0b6c70e4]:empty:before{content:"Untitled";color:var(--scalar-color-3)}.form-group[data-v-694018d6]{margin-bottom:1rem}.modal-actions[data-v-694018d6]{justify-content:flex-end;gap:1rem;display:flex}:root{--scalar-loaded-api-reference:true}@property --tw-translate-x{syntax:"*";inherits:false;initial-value:0}@property --tw-translate-y{syntax:"*";inherits:false;initial-value:0}@property --tw-translate-z{syntax:"*";inherits:false;initial-value:0}@property --tw-rotate-x{syntax:"*";inherits:false}@property --tw-rotate-y{syntax:"*";inherits:false}@property --tw-rotate-z{syntax:"*";inherits:false}@property --tw-skew-x{syntax:"*";inherits:false}@property --tw-skew-y{syntax:"*";inherits:false}@property --tw-border-style{syntax:"*";inherits:false;initial-value:solid}@property --tw-leading{syntax:"*";inherits:false}@property --tw-font-weight{syntax:"*";inherits:false}@property --tw-shadow{syntax:"*";inherits:false;initial-value:0 0 #0000}@property --tw-shadow-color{syntax:"*";inherits:false}@property --tw-shadow-alpha{syntax:"<percentage>";inherits:false;initial-value:100%}@property --tw-inset-shadow{syntax:"*";inherits:false;initial-value:0 0 #0000}@property --tw-inset-shadow-color{syntax:"*";inherits:false}@property --tw-inset-shadow-alpha{syntax:"<percentage>";inherits:false;initial-value:100%}@property --tw-ring-color{syntax:"*";inherits:false}@property --tw-ring-shadow{syntax:"*";inherits:false;initial-value:0 0 #0000}@property --tw-inset-ring-color{syntax:"*";inherits:false}@property --tw-inset-ring-shadow{syntax:"*";inherits:false;initial-value:0 0 #0000}@property --tw-ring-inset{syntax:"*";inherits:false}@property --tw-ring-offset-width{syntax:"<length>";inherits:false;initial-value:0}@property --tw-ring-offset-color{syntax:"*";inherits:false;initial-value:#fff}@property --tw-ring-offset-shadow{syntax:"*";inherits:false;initial-value:0 0 #0000}@property --tw-outline-style{syntax:"*";inherits:false;initial-value:solid}@property --tw-blur{syntax:"*";inherits:false}@property --tw-brightness{syntax:"*";inherits:false}@property --tw-contrast{syntax:"*";inherits:false}@property --tw-grayscale{syntax:"*";inherits:false}@property --tw-hue-rotate{syntax:"*";inherits:false}@property --tw-invert{syntax:"*";inherits:false}@property --tw-opacity{syntax:"*";inherits:false}@property --tw-saturate{syntax:"*";inherits:false}@property --tw-sepia{syntax:"*";inherits:false}@property --tw-drop-shadow{syntax:"*";inherits:false}@property --tw-drop-shadow-color{syntax:"*";inherits:false}@property --tw-drop-shadow-alpha{syntax:"<percentage>";inherits:false;initial-value:100%}@property --tw-drop-shadow-size{syntax:"*";inherits:false}@property --tw-duration{syntax:"*";inherits:false}@layer scalar-config{.scalar-api-reference[data-v-097f69f2]{--refs-sidebar-width: var(--scalar-sidebar-width, 0px);--refs-header-height: calc( var(--scalar-custom-header-height, 0px) + var(--scalar-header-height, 0px) );--refs-viewport-offset: calc( var(--refs-header-height, 0px) + var(--refs-content-offset, 0px) );--refs-viewport-height: calc( var(--full-height, 100dvh) - var(--refs-viewport-offset, 0px) );--refs-content-max-width: var(--scalar-content-max-width, 1540px)}.scalar-api-reference.references-classic[data-v-097f69f2]{--refs-content-max-width: var(--scalar-content-max-width, 1420px);min-height:100dvh;--refs-sidebar-width: 0}.scalar-api-reference[data-v-097f69f2]:has(.api-reference-toolbar){--refs-content-offset: 48px}}.references-layout[data-v-097f69f2]{min-height:100dvh;min-width:100%;max-width:100%;flex:1;--full-height: 100dvh;display:grid;grid-template-rows:var(--scalar-header-height, 0px) repeat(2,auto);grid-template-columns:auto 1fr;grid-template-areas:"header header" "navigation rendered" "footer footer";background:var(--scalar-background-1)}.references-editor[data-v-097f69f2]{grid-area:editor;display:flex;min-width:0;background:var(--scalar-background-1)}.references-rendered[data-v-097f69f2]{position:relative;grid-area:rendered;min-width:0;background:var(--scalar-background-1)}.scalar-api-reference.references-classic[data-v-097f69f2],.references-classic .references-rendered[data-v-097f69f2]{height:initial!important;max-height:initial!important}@layer scalar-config{.references-sidebar[data-v-097f69f2]{--refs-sidebar-width: var(--scalar-sidebar-width, 280px)}}.references-footer[data-v-097f69f2]{grid-area:footer}@media(max-width:1000px){.references-layout[data-v-097f69f2]{grid-template-columns:100%;grid-template-rows:var(--scalar-header-height, 0px) 0px auto auto;grid-template-areas:"header" "navigation" "rendered" "footer"}.references-editable[data-v-097f69f2]{grid-template-areas:"header" "navigation" "editor"}.references-rendered[data-v-097f69f2]{position:static}}@media(max-width:1000px){.scalar-api-references-standalone-mobile[data-v-097f69f2]{--scalar-header-height: 50px}}.darklight-reference[data-v-097f69f2]{width:100%;margin-top:auto}')),document.head.appendChild(a)}}catch(r){console.error("vite-plugin-css-injected-by-js",r)}}();
!function(e){"function"==typeof define&&define.amd?define(e):e()}((function(){
"use strict";const e=Object.freeze({status:"aborted"});function t(e,t,n){
function r(n,r){if(n._zod||Object.defineProperty(n,"_zod",{value:{def:r,
constr:i,traits:new Set},enumerable:!1}),n._zod.traits.has(e))return
;n._zod.traits.add(e),t(n,r);const o=i.prototype,a=Object.keys(o)
;for(let e=0;e<a.length;e++){const t=a[e];t in n||(n[t]=o[t].bind(n))}}
const o=n?.Parent??Object;class a extends o{}function i(e){var t
;const o=n?.Parent?new a:this;r(o,e),(t=o._zod).deferred??(t.deferred=[])
;for(const n of o._zod.deferred)n();return o}
return Object.defineProperty(a,"name",{value:e
}),Object.defineProperty(i,"init",{value:r
}),Object.defineProperty(i,Symbol.hasInstance,{
value:t=>!!(n?.Parent&&t instanceof n.Parent)||t?._zod?.traits?.has(e)
}),Object.defineProperty(i,"name",{value:e}),i}const n=Symbol("zod_brand")
;class r extends Error{constructor(){
super("Encountered Promise during synchronous parse. Use .parseAsync() instead.")
}}class o extends Error{constructor(e){
super(`Encountered unidirectional transform during encode: ${e}`),
this.name="ZodEncodeError"}}const a={};function i(e){
return e&&Object.assign(a,e),a}function s(e){
const t=Object.values(e).filter((e=>"number"==typeof e))
;return Object.entries(e).filter((([e,n])=>-1===t.indexOf(+e))).map((([e,t])=>t))
}function l(e,t="|"){return e.map((e=>$(e))).join(t)}function c(e,t){
return"bigint"==typeof t?t.toString():t}function u(e){return{get value(){{
const t=e();return Object.defineProperty(this,"value",{value:t}),t}}}}
function d(e){return null==e}function p(e){
const t=e.startsWith("^")?1:0,n=e.endsWith("$")?e.length-1:e.length
;return e.slice(t,n)}function h(e,t){
const n=(e.toString().split(".")[1]||"").length,r=t.toString()
;let o=(r.split(".")[1]||"").length;if(0===o&&/\d?e-\d?/.test(r)){
const e=r.match(/\d?e-(\d?)/);e?.[1]&&(o=Number.parseInt(e[1]))}const a=n>o?n:o
;return Number.parseInt(e.toFixed(a).replace(".",""))%Number.parseInt(t.toFixed(a).replace(".",""))/10**a
}const f=Symbol("evaluating");function m(e,t,n){let r
;Object.defineProperty(e,t,{get(){if(r!==f)return void 0===r&&(r=f,r=n()),r},
set(n){Object.defineProperty(e,t,{value:n})},configurable:!0})}
function g(e,t,n){Object.defineProperty(e,t,{value:n,writable:!0,enumerable:!0,
configurable:!0})}function v(...e){const t={};for(const n of e){
const e=Object.getOwnPropertyDescriptors(n);Object.assign(t,e)}
return Object.defineProperties({},t)}function b(e){return JSON.stringify(e)}
function y(e){
return e.toLowerCase().trim().replace(/[^\w\s-]/g,"").replace(/[\s_-]+/g,"-").replace(/^-+|-+$/g,"")
}const O="captureStackTrace"in Error?Error.captureStackTrace:(...e)=>{}
;function w(e){return"object"==typeof e&&null!==e&&!Array.isArray(e)}
const x=u((()=>{
if("undefined"!=typeof navigator&&navigator?.userAgent?.includes("Cloudflare"))return!1
;try{return new Function(""),!0}catch(e){return!1}}));function k(e){
if(!1===w(e))return!1;const t=e.constructor;if(void 0===t)return!0
;if("function"!=typeof t)return!0;const n=t.prototype
;return!1!==w(n)&&!1!==Object.prototype.hasOwnProperty.call(n,"isPrototypeOf")}
function S(e){return k(e)?{...e}:Array.isArray(e)?[...e]:e}
const _=new Set(["string","number","symbol"]),T=new Set(["string","number","bigint","boolean","symbol","undefined"])
;function E(e){return e.replace(/[.*+?^${}()|[\]\\]/g,"\\$&")}function A(e,t,n){
const r=new e._zod.constr(t??e._zod.def)
;return t&&!n?.parent||(r._zod.parent=e),r}function C(e){const t=e
;if(!t)return{};if("string"==typeof t)return{error:()=>t}
;if(void 0!==t?.message){
if(void 0!==t?.error)throw new Error("Cannot specify both `message` and `error` params")
;t.error=t.message}return delete t.message,"string"==typeof t.error?{...t,
error:()=>t.error}:t}function $(e){
return"bigint"==typeof e?e.toString()+"n":"string"==typeof e?`"${e}"`:`${e}`}
function P(e){
return Object.keys(e).filter((t=>"optional"===e[t]._zod.optin&&"optional"===e[t]._zod.optout))
}const D={safeint:[Number.MIN_SAFE_INTEGER,Number.MAX_SAFE_INTEGER],
int32:[-2147483648,2147483647],uint32:[0,4294967295],
float32:[-34028234663852886e22,34028234663852886e22],
float64:[-Number.MAX_VALUE,Number.MAX_VALUE]},I={
int64:[BigInt("-9223372036854775808"),BigInt("9223372036854775807")],
uint64:[BigInt(0),BigInt("18446744073709551615")]};function M(e,t){
const n=e._zod.def,r=n.checks
;if(r&&r.length>0)throw new Error(".pick() cannot be used on object schemas containing refinements")
;return A(e,v(e._zod.def,{get shape(){const e={};for(const r in t){
if(!(r in n.shape))throw new Error(`Unrecognized key: "${r}"`)
;t[r]&&(e[r]=n.shape[r])}return g(this,"shape",e),e},checks:[]}))}
function N(e,t){const n=e._zod.def,r=n.checks
;if(r&&r.length>0)throw new Error(".omit() cannot be used on object schemas containing refinements")
;const o=v(e._zod.def,{get shape(){const r={...e._zod.def.shape}
;for(const e in t){
if(!(e in n.shape))throw new Error(`Unrecognized key: "${e}"`);t[e]&&delete r[e]
}return g(this,"shape",r),r},checks:[]});return A(e,o)}function R(e,t){
if(!k(t))throw new Error("Invalid input to extend: expected a plain object")
;const n=e._zod.def.checks;if(n&&n.length>0){const n=e._zod.def.shape
;for(const e in t)if(void 0!==Object.getOwnPropertyDescriptor(n,e))throw new Error("Cannot overwrite keys on object schemas containing refinements. Use `.safeExtend()` instead.")
}const r=v(e._zod.def,{get shape(){const n={...e._zod.def.shape,...t}
;return g(this,"shape",n),n}});return A(e,r)}function L(e,t){
if(!k(t))throw new Error("Invalid input to safeExtend: expected a plain object")
;const n=v(e._zod.def,{get shape(){const n={...e._zod.def.shape,...t}
;return g(this,"shape",n),n}});return A(e,n)}function B(e,t){
const n=v(e._zod.def,{get shape(){const n={...e._zod.def.shape,
...t._zod.def.shape};return g(this,"shape",n),n},get catchall(){
return t._zod.def.catchall},checks:[]});return A(e,n)}function j(e,t,n){
const r=t._zod.def.checks
;if(r&&r.length>0)throw new Error(".partial() cannot be used on object schemas containing refinements")
;const o=v(t._zod.def,{get shape(){const r=t._zod.def.shape,o={...r}
;if(n)for(const t in n){if(!(t in r))throw new Error(`Unrecognized key: "${t}"`)
;n[t]&&(o[t]=e?new e({type:"optional",innerType:r[t]}):r[t])
}else for(const t in r)o[t]=e?new e({type:"optional",innerType:r[t]}):r[t]
;return g(this,"shape",o),o},checks:[]});return A(t,o)}function U(e,t,n){
const r=v(t._zod.def,{get shape(){const r=t._zod.def.shape,o={...r}
;if(n)for(const t in n){if(!(t in o))throw new Error(`Unrecognized key: "${t}"`)
;n[t]&&(o[t]=new e({type:"nonoptional",innerType:r[t]}))
}else for(const t in r)o[t]=new e({type:"nonoptional",innerType:r[t]})
;return g(this,"shape",o),o}});return A(t,r)}function z(e,t=0){
if(!0===e.aborted)return!0
;for(let n=t;n<e.issues.length;n++)if(!0!==e.issues[n]?.continue)return!0
;return!1}function F(e,t){return t.map((t=>{var n;return(n=t).path??(n.path=[]),
t.path.unshift(e),t}))}function Z(e){return"string"==typeof e?e:e?.message}
function Q(e,t,n){const r={...e,path:e.path??[]};if(!e.message){
const o=Z(e.inst?._zod.def?.error?.(e))??Z(t?.error?.(e))??Z(n.customError?.(e))??Z(n.localeError?.(e))??"Invalid input"
;r.message=o}
return delete r.inst,delete r.continue,t?.reportInput||delete r.input,r}
function H(e){
return e instanceof Set?"set":e instanceof Map?"map":e instanceof File?"file":"unknown"
}function V(e){
return Array.isArray(e)?"array":"string"==typeof e?"string":"unknown"}
function q(e){const t=typeof e;switch(t){case"number":
return Number.isNaN(e)?"nan":"number";case"object":{if(null===e)return"null"
;if(Array.isArray(e))return"array";const t=e
;if(t&&Object.getPrototypeOf(t)!==Object.prototype&&"constructor"in t&&t.constructor)return t.constructor.name
}}return t}function W(...e){const[t,n,r]=e;return"string"==typeof t?{message:t,
code:"custom",input:n,inst:r}:{...t}}function X(e){
const t=atob(e),n=new Uint8Array(t.length)
;for(let r=0;r<t.length;r++)n[r]=t.charCodeAt(r);return n}function G(e){let t=""
;for(let n=0;n<e.length;n++)t+=String.fromCharCode(e[n]);return btoa(t)}
const Y=Object.freeze(Object.defineProperty({__proto__:null,
BIGINT_FORMAT_RANGES:I,Class:class{constructor(...e){}},NUMBER_FORMAT_RANGES:D,
aborted:z,allowsEval:x,assert:function(e){},assertEqual:function(e){return e},
assertIs:function(e){},assertNever:function(e){
throw new Error("Unexpected value in exhaustive check")},
assertNotEqual:function(e){return e},assignProp:g,base64ToUint8Array:X,
base64urlToUint8Array:function(e){const t=e.replace(/-/g,"+").replace(/_/g,"/")
;return X(t+"=".repeat((4-t.length%4)%4))},cached:u,captureStackTrace:O,
cleanEnum:function(e){
return Object.entries(e).filter((([e,t])=>Number.isNaN(Number.parseInt(e,10)))).map((e=>e[1]))
},cleanRegex:p,clone:A,cloneDef:function(e){return v(e._zod.def)},
createTransparentProxy:function(e){let t;return new Proxy({},{
get:(n,r,o)=>(t??(t=e()),Reflect.get(t,r,o)),
set:(n,r,o,a)=>(t??(t=e()),Reflect.set(t,r,o,a)),
has:(n,r)=>(t??(t=e()),Reflect.has(t,r)),
deleteProperty:(n,r)=>(t??(t=e()),Reflect.deleteProperty(t,r)),
ownKeys:n=>(t??(t=e()),Reflect.ownKeys(t)),
getOwnPropertyDescriptor:(n,r)=>(t??(t=e()),
Reflect.getOwnPropertyDescriptor(t,r)),
defineProperty:(n,r,o)=>(t??(t=e()),Reflect.defineProperty(t,r,o))})},
defineLazy:m,esc:b,escapeRegex:E,extend:R,finalizeIssue:Q,floatSafeRemainder:h,
getElementAtPath:function(e,t){return t?t.reduce(((e,t)=>e?.[t]),e):e},
getEnumValues:s,getLengthableOrigin:V,getParsedType:e=>{const t=typeof e
;switch(t){case"undefined":return"undefined";case"string":return"string"
;case"number":return Number.isNaN(e)?"nan":"number";case"boolean":
return"boolean";case"function":return"function";case"bigint":return"bigint"
;case"symbol":return"symbol";case"object":
return Array.isArray(e)?"array":null===e?"null":e.then&&"function"==typeof e.then&&e.catch&&"function"==typeof e.catch?"promise":"undefined"!=typeof Map&&e instanceof Map?"map":"undefined"!=typeof Set&&e instanceof Set?"set":"undefined"!=typeof Date&&e instanceof Date?"date":"undefined"!=typeof File&&e instanceof File?"file":"object"
;default:throw new Error(`Unknown data type: ${t}`)}},getSizableOrigin:H,
hexToUint8Array:function(e){const t=e.replace(/^0x/,"")
;if(t.length%2!=0)throw new Error("Invalid hex string length")
;const n=new Uint8Array(t.length/2)
;for(let r=0;r<t.length;r+=2)n[r/2]=Number.parseInt(t.slice(r,r+2),16);return n
},isObject:w,isPlainObject:k,issue:W,joinValues:l,jsonStringifyReplacer:c,
merge:B,mergeDefs:v,normalizeParams:C,nullish:d,numKeys:function(e){let t=0
;for(const n in e)Object.prototype.hasOwnProperty.call(e,n)&&t++;return t},
objectClone:function(e){
return Object.create(Object.getPrototypeOf(e),Object.getOwnPropertyDescriptors(e))
},omit:N,optionalKeys:P,parsedType:q,partial:j,pick:M,prefixIssues:F,
primitiveTypes:T,promiseAllObject:function(e){
const t=Object.keys(e),n=t.map((t=>e[t]));return Promise.all(n).then((e=>{
const n={};for(let r=0;r<t.length;r++)n[t[r]]=e[r];return n}))},
propertyKeyTypes:_,randomString:function(e=10){
const t="abcdefghijklmnopqrstuvwxyz";let n=""
;for(let r=0;r<e;r++)n+=t[Math.floor(26*Math.random())];return n},required:U,
safeExtend:L,shallowClone:S,slugify:y,stringifyPrimitive:$,uint8ArrayToBase64:G,
uint8ArrayToBase64url:function(e){
return G(e).replace(/\+/g,"-").replace(/\//g,"_").replace(/=/g,"")},
uint8ArrayToHex:function(e){
return Array.from(e).map((e=>e.toString(16).padStart(2,"0"))).join("")},
unwrapMessage:Z},Symbol.toStringTag,{value:"Module"})),K=(e,t)=>{
e.name="$ZodError",Object.defineProperty(e,"_zod",{value:e._zod,enumerable:!1}),
Object.defineProperty(e,"issues",{value:t,enumerable:!1
}),e.message=JSON.stringify(t,c,2),Object.defineProperty(e,"toString",{
value:()=>e.message,enumerable:!1})},J=t("$ZodError",K),ee=t("$ZodError",K,{
Parent:Error});function te(e,t=e=>e.message){const n={},r=[]
;for(const o of e.issues)o.path.length>0?(n[o.path[0]]=n[o.path[0]]||[],
n[o.path[0]].push(t(o))):r.push(t(o));return{formErrors:r,fieldErrors:n}}
function ne(e,t=e=>e.message){const n={_errors:[]},r=e=>{
for(const o of e.issues)if("invalid_union"===o.code&&o.errors.length)o.errors.map((e=>r({
issues:e})));else if("invalid_key"===o.code)r({issues:o.issues
});else if("invalid_element"===o.code)r({issues:o.issues
});else if(0===o.path.length)n._errors.push(t(o));else{let e=n,r=0
;for(;r<o.path.length;){const n=o.path[r];r===o.path.length-1?(e[n]=e[n]||{
_errors:[]},e[n]._errors.push(t(o))):e[n]=e[n]||{_errors:[]},e=e[n],r++}}}
;return r(e),n}function re(e,t=e=>e.message){const n={errors:[]},r=(e,o=[])=>{
var a,i
;for(const s of e.issues)if("invalid_union"===s.code&&s.errors.length)s.errors.map((e=>r({
issues:e},s.path)));else if("invalid_key"===s.code)r({issues:s.issues
},s.path);else if("invalid_element"===s.code)r({issues:s.issues},s.path);else{
const e=[...o,...s.path];if(0===e.length){n.errors.push(t(s));continue}
let r=n,l=0;for(;l<e.length;){const n=e[l],o=l===e.length-1
;"string"==typeof n?(r.properties??(r.properties={}),
(a=r.properties)[n]??(a[n]={errors:[]
}),r=r.properties[n]):(r.items??(r.items=[]),(i=r.items)[n]??(i[n]={errors:[]}),
r=r.items[n]),o&&r.errors.push(t(s)),l++}}};return r(e),n}function oe(e){
const t=[],n=e.map((e=>"object"==typeof e?e.key:e))
;for(const r of n)"number"==typeof r?t.push(`[${r}]`):"symbol"==typeof r?t.push(`[${JSON.stringify(String(r))}]`):/[^\w$]/.test(r)?t.push(`[${JSON.stringify(r)}]`):(t.length&&t.push("."),
t.push(r));return t.join("")}function ae(e){
const t=[],n=[...e.issues].sort(((e,t)=>(e.path??[]).length-(t.path??[]).length))
;for(const r of n)t.push(`✖ ${r.message}`),
r.path?.length&&t.push(`  → at ${oe(r.path)}`);return t.join("\n")}
const ie=e=>(t,n,o,a)=>{const s=o?Object.assign(o,{async:!1}):{async:!1
},l=t._zod.run({value:n,issues:[]},s);if(l instanceof Promise)throw new r
;if(l.issues.length){const t=new(a?.Err??e)(l.issues.map((e=>Q(e,s,i()))))
;throw O(t,a?.callee),t}return l.value},se=ie(ee),le=e=>async(t,n,r,o)=>{
const a=r?Object.assign(r,{async:!0}):{async:!0};let s=t._zod.run({value:n,
issues:[]},a);if(s instanceof Promise&&(s=await s),s.issues.length){
const t=new(o?.Err??e)(s.issues.map((e=>Q(e,a,i()))));throw O(t,o?.callee),t}
return s.value},ce=le(ee),ue=e=>(t,n,o)=>{const a=o?{...o,async:!1}:{async:!1
},s=t._zod.run({value:n,issues:[]},a);if(s instanceof Promise)throw new r
;return s.issues.length?{success:!1,
error:new(e??J)(s.issues.map((e=>Q(e,a,i()))))}:{success:!0,data:s.value}
},de=ue(ee),pe=e=>async(t,n,r)=>{const o=r?Object.assign(r,{async:!0}):{async:!0
};let a=t._zod.run({value:n,issues:[]},o)
;return a instanceof Promise&&(a=await a),a.issues.length?{success:!1,
error:new e(a.issues.map((e=>Q(e,o,i()))))}:{success:!0,data:a.value}
},he=pe(ee),fe=e=>(t,n,r)=>{const o=r?Object.assign(r,{direction:"backward"}):{
direction:"backward"};return ie(e)(t,n,o)
},me=fe(ee),ge=e=>(t,n,r)=>ie(e)(t,n,r),ve=ge(ee),be=e=>async(t,n,r)=>{
const o=r?Object.assign(r,{direction:"backward"}):{direction:"backward"}
;return le(e)(t,n,o)
},ye=be(ee),Oe=e=>async(t,n,r)=>le(e)(t,n,r),we=Oe(ee),xe=e=>(t,n,r)=>{
const o=r?Object.assign(r,{direction:"backward"}):{direction:"backward"}
;return ue(e)(t,n,o)
},ke=xe(ee),Se=e=>(t,n,r)=>ue(e)(t,n,r),_e=Se(ee),Te=e=>async(t,n,r)=>{
const o=r?Object.assign(r,{direction:"backward"}):{direction:"backward"}
;return pe(e)(t,n,o)
},Ee=Te(ee),Ae=e=>async(t,n,r)=>pe(e)(t,n,r),Ce=Ae(ee),$e=/^[cC][^\s-]{8,}$/,Pe=/^[0-9a-z]+$/,De=/^[0-9A-HJKMNP-TV-Za-hjkmnp-tv-z]{26}$/,Ie=/^[0-9a-vA-V]{20}$/,Me=/^[A-Za-z0-9]{27}$/,Ne=/^[a-zA-Z0-9_-]{21}$/,Re=/^P(?:(\d+W)|(?!.*W)(?=\d|T\d)(\d+Y)?(\d+M)?(\d+D)?(T(?=\d)(\d+H)?(\d+M)?(\d+([.,]\d+)?S)?)?)$/,Le=/^([0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12})$/,Be=e=>e?new RegExp(`^([0-9a-fA-F]{8}-[0-9a-fA-F]{4}-${e}[0-9a-fA-F]{3}-[89abAB][0-9a-fA-F]{3}-[0-9a-fA-F]{12})$`):/^([0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[1-8][0-9a-fA-F]{3}-[89abAB][0-9a-fA-F]{3}-[0-9a-fA-F]{12}|00000000-0000-0000-0000-000000000000|ffffffff-ffff-ffff-ffff-ffffffffffff)$/,je=Be(4),Ue=Be(6),ze=Be(7),Fe=/^(?!\.)(?!.*\.\.)([A-Za-z0-9_'+\-\.]*)[A-Za-z0-9_+-]@([A-Za-z0-9][A-Za-z0-9\-]*\.)+[A-Za-z]{2,}$/,Ze=/^[^\s@"]{1,64}@[^\s@]{1,255}$/u,Qe=Ze
;function He(){
return new RegExp("^(\\p{Extended_Pictographic}|\\p{Emoji_Component})+$","u")}
const Ve=/^(?:(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])\.){3}(?:25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])$/,qe=/^(([0-9a-fA-F]{1,4}:){7}[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,7}:|([0-9a-fA-F]{1,4}:){1,6}:[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,5}(:[0-9a-fA-F]{1,4}){1,2}|([0-9a-fA-F]{1,4}:){1,4}(:[0-9a-fA-F]{1,4}){1,3}|([0-9a-fA-F]{1,4}:){1,3}(:[0-9a-fA-F]{1,4}){1,4}|([0-9a-fA-F]{1,4}:){1,2}(:[0-9a-fA-F]{1,4}){1,5}|[0-9a-fA-F]{1,4}:((:[0-9a-fA-F]{1,4}){1,6})|:((:[0-9a-fA-F]{1,4}){1,7}|:))$/,We=e=>{
const t=E(e??":")
;return new RegExp(`^(?:[0-9A-F]{2}${t}){5}[0-9A-F]{2}$|^(?:[0-9a-f]{2}${t}){5}[0-9a-f]{2}$`)
},Xe=/^((25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])\.){3}(25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9][0-9]|[0-9])\/([0-9]|[1-2][0-9]|3[0-2])$/,Ge=/^(([0-9a-fA-F]{1,4}:){7}[0-9a-fA-F]{1,4}|::|([0-9a-fA-F]{1,4})?::([0-9a-fA-F]{1,4}:?){0,6})\/(12[0-8]|1[01][0-9]|[1-9]?[0-9])$/,Ye=/^$|^(?:[0-9a-zA-Z+/]{4})*(?:(?:[0-9a-zA-Z+/]{2}==)|(?:[0-9a-zA-Z+/]{3}=))?$/,Ke=/^[A-Za-z0-9_-]*$/,Je=/^(?=.{1,253}\.?$)[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[-0-9a-zA-Z]{0,61}[0-9a-zA-Z])?)*\.?$/,et=/^([a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?\.)+[a-zA-Z]{2,}$/,tt=/^\+[1-9]\d{6,14}$/,nt="(?:(?:\\d\\d[2468][048]|\\d\\d[13579][26]|\\d\\d0[48]|[02468][048]00|[13579][26]00)-02-29|\\d{4}-(?:(?:0[13578]|1[02])-(?:0[1-9]|[12]\\d|3[01])|(?:0[469]|11)-(?:0[1-9]|[12]\\d|30)|(?:02)-(?:0[1-9]|1\\d|2[0-8])))",rt=new RegExp(`^${nt}$`)
;function ot(e){const t="(?:[01]\\d|2[0-3]):[0-5]\\d"
;return"number"==typeof e.precision?-1===e.precision?`${t}`:0===e.precision?`${t}:[0-5]\\d`:`${t}:[0-5]\\d\\.\\d{${e.precision}}`:`${t}(?::[0-5]\\d(?:\\.\\d+)?)?`
}function at(e){return new RegExp(`^${ot(e)}$`)}function it(e){const t=ot({
precision:e.precision}),n=["Z"]
;e.local&&n.push(""),e.offset&&n.push("([+-](?:[01]\\d|2[0-3]):[0-5]\\d)")
;const r=`${t}(?:${n.join("|")})`;return new RegExp(`^${nt}T(?:${r})$`)}
const st=e=>new RegExp(`^${e?`[\\s\\S]{${e?.minimum??0},${e?.maximum??""}}`:"[\\s\\S]*"}$`),lt=/^-?\d+n?$/,ct=/^-?\d+$/,ut=/^-?\d+(?:\.\d+)?$/,dt=/^(?:true|false)$/i,pt=/^null$/i,ht=/^undefined$/i,ft=/^[^A-Z]*$/,mt=/^[^a-z]*$/,gt=/^[0-9a-fA-F]*$/
;function vt(e,t){return new RegExp(`^[A-Za-z0-9+/]{${e}}${t}$`)}function bt(e){
return new RegExp(`^[A-Za-z0-9_-]{${e}}$`)}
const yt=vt(22,"=="),Ot=bt(22),wt=vt(27,"="),xt=bt(27),kt=vt(43,"="),St=bt(43),_t=vt(64,""),Tt=bt(64),Et=vt(86,"=="),At=bt(86),Ct=Object.freeze(Object.defineProperty({
__proto__:null,base64:Ye,base64url:Ke,bigint:lt,boolean:dt,
browserEmail:/^[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*$/,
cidrv4:Xe,cidrv6:Ge,cuid:$e,cuid2:Pe,date:rt,datetime:it,domain:et,duration:Re,
e164:tt,email:Fe,emoji:He,
extendedDuration:/^[-+]?P(?!$)(?:(?:[-+]?\d+Y)|(?:[-+]?\d+[.,]\d+Y$))?(?:(?:[-+]?\d+M)|(?:[-+]?\d+[.,]\d+M$))?(?:(?:[-+]?\d+W)|(?:[-+]?\d+[.,]\d+W$))?(?:(?:[-+]?\d+D)|(?:[-+]?\d+[.,]\d+D$))?(?:T(?=[\d+-])(?:(?:[-+]?\d+H)|(?:[-+]?\d+[.,]\d+H$))?(?:(?:[-+]?\d+M)|(?:[-+]?\d+[.,]\d+M$))?(?:[-+]?\d+(?:[.,]\d+)?S)?)??$/,
guid:Le,hex:gt,hostname:Je,
html5Email:/^[a-zA-Z0-9.!#$%&'*+/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*$/,
idnEmail:Qe,integer:ct,ipv4:Ve,ipv6:qe,ksuid:Me,lowercase:ft,mac:We,
md5_base64:yt,md5_base64url:Ot,md5_hex:/^[0-9a-fA-F]{32}$/,nanoid:Ne,null:pt,
number:ut,
rfc5322Email:/^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/,
sha1_base64:wt,sha1_base64url:xt,sha1_hex:/^[0-9a-fA-F]{40}$/,sha256_base64:kt,
sha256_base64url:St,sha256_hex:/^[0-9a-fA-F]{64}$/,sha384_base64:_t,
sha384_base64url:Tt,sha384_hex:/^[0-9a-fA-F]{96}$/,sha512_base64:Et,
sha512_base64url:At,sha512_hex:/^[0-9a-fA-F]{128}$/,string:st,time:at,ulid:De,
undefined:ht,unicodeEmail:Ze,uppercase:mt,uuid:Be,uuid4:je,uuid6:Ue,uuid7:ze,
xid:Ie},Symbol.toStringTag,{value:"Module"})),$t=t("$ZodCheck",((e,t)=>{var n
;e._zod??(e._zod={}),e._zod.def=t,(n=e._zod).onattach??(n.onattach=[])})),Pt={
number:"number",bigint:"bigint",object:"date"
},Dt=t("$ZodCheckLessThan",((e,t)=>{$t.init(e,t);const n=Pt[typeof t.value]
;e._zod.onattach.push((e=>{
const n=e._zod.bag,r=(t.inclusive?n.maximum:n.exclusiveMaximum)??Number.POSITIVE_INFINITY
;t.value<r&&(t.inclusive?n.maximum=t.value:n.exclusiveMaximum=t.value)
})),e._zod.check=r=>{
(t.inclusive?r.value<=t.value:r.value<t.value)||r.issues.push({origin:n,
code:"too_big",maximum:"object"==typeof t.value?t.value.getTime():t.value,
input:r.value,inclusive:t.inclusive,inst:e,continue:!t.abort})}
})),It=t("$ZodCheckGreaterThan",((e,t)=>{$t.init(e,t);const n=Pt[typeof t.value]
;e._zod.onattach.push((e=>{
const n=e._zod.bag,r=(t.inclusive?n.minimum:n.exclusiveMinimum)??Number.NEGATIVE_INFINITY
;t.value>r&&(t.inclusive?n.minimum=t.value:n.exclusiveMinimum=t.value)
})),e._zod.check=r=>{
(t.inclusive?r.value>=t.value:r.value>t.value)||r.issues.push({origin:n,
code:"too_small",minimum:"object"==typeof t.value?t.value.getTime():t.value,
input:r.value,inclusive:t.inclusive,inst:e,continue:!t.abort})}
})),Mt=t("$ZodCheckMultipleOf",((e,t)=>{$t.init(e,t),e._zod.onattach.push((e=>{
var n;(n=e._zod.bag).multipleOf??(n.multipleOf=t.value)})),e._zod.check=n=>{
if(typeof n.value!=typeof t.value)throw new Error("Cannot mix number and bigint in multiple_of check.")
;("bigint"==typeof n.value?n.value%t.value===BigInt(0):0===h(n.value,t.value))||n.issues.push({
origin:typeof n.value,code:"not_multiple_of",divisor:t.value,input:n.value,
inst:e,continue:!t.abort})}})),Nt=t("$ZodCheckNumberFormat",((e,t)=>{
$t.init(e,t),t.format=t.format||"float64"
;const n=t.format?.includes("int"),r=n?"int":"number",[o,a]=D[t.format]
;e._zod.onattach.push((e=>{const r=e._zod.bag
;r.format=t.format,r.minimum=o,r.maximum=a,n&&(r.pattern=ct)
})),e._zod.check=i=>{const s=i.value;if(n){
if(!Number.isInteger(s))return void i.issues.push({expected:r,format:t.format,
code:"invalid_type",continue:!1,input:s,inst:e})
;if(!Number.isSafeInteger(s))return void(s>0?i.issues.push({input:s,
code:"too_big",maximum:Number.MAX_SAFE_INTEGER,
note:"Integers must be within the safe integer range.",inst:e,origin:r,
inclusive:!0,continue:!t.abort}):i.issues.push({input:s,code:"too_small",
minimum:Number.MIN_SAFE_INTEGER,
note:"Integers must be within the safe integer range.",inst:e,origin:r,
inclusive:!0,continue:!t.abort}))}s<o&&i.issues.push({origin:"number",input:s,
code:"too_small",minimum:o,inclusive:!0,inst:e,continue:!t.abort
}),s>a&&i.issues.push({origin:"number",input:s,code:"too_big",maximum:a,
inclusive:!0,inst:e,continue:!t.abort})}
})),Rt=t("$ZodCheckBigIntFormat",((e,t)=>{$t.init(e,t);const[n,r]=I[t.format]
;e._zod.onattach.push((e=>{const o=e._zod.bag
;o.format=t.format,o.minimum=n,o.maximum=r})),e._zod.check=o=>{const a=o.value
;a<n&&o.issues.push({origin:"bigint",input:a,code:"too_small",minimum:n,
inclusive:!0,inst:e,continue:!t.abort}),a>r&&o.issues.push({origin:"bigint",
input:a,code:"too_big",maximum:r,inclusive:!0,inst:e,continue:!t.abort})}
})),Lt=t("$ZodCheckMaxSize",((e,t)=>{var n
;$t.init(e,t),(n=e._zod.def).when??(n.when=e=>{const t=e.value
;return!d(t)&&void 0!==t.size}),e._zod.onattach.push((e=>{
const n=e._zod.bag.maximum??Number.POSITIVE_INFINITY
;t.maximum<n&&(e._zod.bag.maximum=t.maximum)})),e._zod.check=n=>{const r=n.value
;r.size<=t.maximum||n.issues.push({origin:H(r),code:"too_big",maximum:t.maximum,
inclusive:!0,input:r,inst:e,continue:!t.abort})}
})),Bt=t("$ZodCheckMinSize",((e,t)=>{var n
;$t.init(e,t),(n=e._zod.def).when??(n.when=e=>{const t=e.value
;return!d(t)&&void 0!==t.size}),e._zod.onattach.push((e=>{
const n=e._zod.bag.minimum??Number.NEGATIVE_INFINITY
;t.minimum>n&&(e._zod.bag.minimum=t.minimum)})),e._zod.check=n=>{const r=n.value
;r.size>=t.minimum||n.issues.push({origin:H(r),code:"too_small",
minimum:t.minimum,inclusive:!0,input:r,inst:e,continue:!t.abort})}
})),jt=t("$ZodCheckSizeEquals",((e,t)=>{var n
;$t.init(e,t),(n=e._zod.def).when??(n.when=e=>{const t=e.value
;return!d(t)&&void 0!==t.size}),e._zod.onattach.push((e=>{const n=e._zod.bag
;n.minimum=t.size,n.maximum=t.size,n.size=t.size})),e._zod.check=n=>{
const r=n.value,o=r.size;if(o===t.size)return;const a=o>t.size;n.issues.push({
origin:H(r),...a?{code:"too_big",maximum:t.size}:{code:"too_small",
minimum:t.size},inclusive:!0,exact:!0,input:n.value,inst:e,continue:!t.abort})}
})),Ut=t("$ZodCheckMaxLength",((e,t)=>{var n
;$t.init(e,t),(n=e._zod.def).when??(n.when=e=>{const t=e.value
;return!d(t)&&void 0!==t.length}),e._zod.onattach.push((e=>{
const n=e._zod.bag.maximum??Number.POSITIVE_INFINITY
;t.maximum<n&&(e._zod.bag.maximum=t.maximum)})),e._zod.check=n=>{const r=n.value
;if(r.length<=t.maximum)return;const o=V(r);n.issues.push({origin:o,
code:"too_big",maximum:t.maximum,inclusive:!0,input:r,inst:e,continue:!t.abort})
}})),zt=t("$ZodCheckMinLength",((e,t)=>{var n
;$t.init(e,t),(n=e._zod.def).when??(n.when=e=>{const t=e.value
;return!d(t)&&void 0!==t.length}),e._zod.onattach.push((e=>{
const n=e._zod.bag.minimum??Number.NEGATIVE_INFINITY
;t.minimum>n&&(e._zod.bag.minimum=t.minimum)})),e._zod.check=n=>{const r=n.value
;if(r.length>=t.minimum)return;const o=V(r);n.issues.push({origin:o,
code:"too_small",minimum:t.minimum,inclusive:!0,input:r,inst:e,continue:!t.abort
})}})),Ft=t("$ZodCheckLengthEquals",((e,t)=>{var n
;$t.init(e,t),(n=e._zod.def).when??(n.when=e=>{const t=e.value
;return!d(t)&&void 0!==t.length}),e._zod.onattach.push((e=>{const n=e._zod.bag
;n.minimum=t.length,n.maximum=t.length,n.length=t.length})),e._zod.check=n=>{
const r=n.value,o=r.length;if(o===t.length)return;const a=V(r),i=o>t.length
;n.issues.push({origin:a,...i?{code:"too_big",maximum:t.length}:{
code:"too_small",minimum:t.length},inclusive:!0,exact:!0,input:n.value,inst:e,
continue:!t.abort})}})),Zt=t("$ZodCheckStringFormat",((e,t)=>{var n,r
;$t.init(e,t),e._zod.onattach.push((e=>{const n=e._zod.bag
;n.format=t.format,t.pattern&&(n.patterns??(n.patterns=new Set),
n.patterns.add(t.pattern))})),t.pattern?(n=e._zod).check??(n.check=n=>{
t.pattern.lastIndex=0,t.pattern.test(n.value)||n.issues.push({origin:"string",
code:"invalid_format",format:t.format,input:n.value,...t.pattern?{
pattern:t.pattern.toString()}:{},inst:e,continue:!t.abort})
}):(r=e._zod).check??(r.check=()=>{})})),Qt=t("$ZodCheckRegex",((e,t)=>{
Zt.init(e,t),e._zod.check=n=>{
t.pattern.lastIndex=0,t.pattern.test(n.value)||n.issues.push({origin:"string",
code:"invalid_format",format:"regex",input:n.value,pattern:t.pattern.toString(),
inst:e,continue:!t.abort})}})),Ht=t("$ZodCheckLowerCase",((e,t)=>{
t.pattern??(t.pattern=ft),Zt.init(e,t)})),Vt=t("$ZodCheckUpperCase",((e,t)=>{
t.pattern??(t.pattern=mt),Zt.init(e,t)})),qt=t("$ZodCheckIncludes",((e,t)=>{
$t.init(e,t)
;const n=E(t.includes),r=new RegExp("number"==typeof t.position?`^.{${t.position}}${n}`:n)
;t.pattern=r,e._zod.onattach.push((e=>{const t=e._zod.bag
;t.patterns??(t.patterns=new Set),t.patterns.add(r)})),e._zod.check=n=>{
n.value.includes(t.includes,t.position)||n.issues.push({origin:"string",
code:"invalid_format",format:"includes",includes:t.includes,input:n.value,
inst:e,continue:!t.abort})}})),Wt=t("$ZodCheckStartsWith",((e,t)=>{$t.init(e,t)
;const n=new RegExp(`^${E(t.prefix)}.*`)
;t.pattern??(t.pattern=n),e._zod.onattach.push((e=>{const t=e._zod.bag
;t.patterns??(t.patterns=new Set),t.patterns.add(n)})),e._zod.check=n=>{
n.value.startsWith(t.prefix)||n.issues.push({origin:"string",
code:"invalid_format",format:"starts_with",prefix:t.prefix,input:n.value,inst:e,
continue:!t.abort})}})),Xt=t("$ZodCheckEndsWith",((e,t)=>{$t.init(e,t)
;const n=new RegExp(`.*${E(t.suffix)}$`)
;t.pattern??(t.pattern=n),e._zod.onattach.push((e=>{const t=e._zod.bag
;t.patterns??(t.patterns=new Set),t.patterns.add(n)})),e._zod.check=n=>{
n.value.endsWith(t.suffix)||n.issues.push({origin:"string",
code:"invalid_format",format:"ends_with",suffix:t.suffix,input:n.value,inst:e,
continue:!t.abort})}}));function Gt(e,t,n){
e.issues.length&&t.issues.push(...F(n,e.issues))}
const Yt=t("$ZodCheckProperty",((e,t)=>{$t.init(e,t),e._zod.check=e=>{
const n=t.schema._zod.run({value:e.value[t.property],issues:[]},{})
;if(n instanceof Promise)return n.then((n=>Gt(n,e,t.property)))
;Gt(n,e,t.property)}})),Kt=t("$ZodCheckMimeType",((e,t)=>{$t.init(e,t)
;const n=new Set(t.mime);e._zod.onattach.push((e=>{e._zod.bag.mime=t.mime
})),e._zod.check=r=>{n.has(r.value.type)||r.issues.push({code:"invalid_value",
values:t.mime,input:r.value.type,inst:e,continue:!t.abort})}
})),Jt=t("$ZodCheckOverwrite",((e,t)=>{$t.init(e,t),e._zod.check=e=>{
e.value=t.tx(e.value)}}));class en{constructor(e=[]){
this.content=[],this.indent=0,this&&(this.args=e)}indented(e){
this.indent+=1,e(this),this.indent-=1}write(e){
if("function"==typeof e)return e(this,{execution:"sync"}),void e(this,{
execution:"async"})
;const t=e.split("\n").filter((e=>e)),n=Math.min(...t.map((e=>e.length-e.trimStart().length))),r=t.map((e=>e.slice(n))).map((e=>" ".repeat(2*this.indent)+e))
;for(const o of r)this.content.push(o)}compile(){const e=Function,t=this?.args
;return new e(...t,[...(this?.content??[""]).map((e=>`  ${e}`))].join("\n"))}}
const tn={major:4,minor:3,patch:5},nn=t("$ZodType",((e,t)=>{var n
;e??(e={}),e._zod.def=t,e._zod.bag=e._zod.bag||{},e._zod.version=tn
;const o=[...e._zod.def.checks??[]];e._zod.traits.has("$ZodCheck")&&o.unshift(e)
;for(const r of o)for(const t of r._zod.onattach)t(e)
;if(0===o.length)(n=e._zod).deferred??(n.deferred=[]),
e._zod.deferred?.push((()=>{e._zod.run=e._zod.parse}));else{const t=(e,t,n)=>{
let o,a=z(e);for(const i of t){if(i._zod.def.when){
if(!i._zod.def.when(e))continue}else if(a)continue
;const t=e.issues.length,s=i._zod.check(e)
;if(s instanceof Promise&&!1===n?.async)throw new r
;if(o||s instanceof Promise)o=(o??Promise.resolve()).then((async()=>{await s
;e.issues.length!==t&&(a||(a=z(e,t)))}));else{if(e.issues.length===t)continue
;a||(a=z(e,t))}}return o?o.then((()=>e)):e},n=(n,a,i)=>{
if(z(n))return n.aborted=!0,n;const s=t(a,o,i);if(s instanceof Promise){
if(!1===i.async)throw new r;return s.then((t=>e._zod.parse(t,i)))}
return e._zod.parse(s,i)};e._zod.run=(a,i)=>{
if(i.skipChecks)return e._zod.parse(a,i);if("backward"===i.direction){
const t=e._zod.parse({value:a.value,issues:[]},{...i,skipChecks:!0})
;return t instanceof Promise?t.then((e=>n(e,a,i))):n(t,a,i)}
const s=e._zod.parse(a,i);if(s instanceof Promise){if(!1===i.async)throw new r
;return s.then((e=>t(e,o,i)))}return t(s,o,i)}}m(e,"~standard",(()=>({
validate:t=>{try{const n=de(e,t);return n.success?{value:n.data}:{
issues:n.error?.issues}}catch(n){return he(e,t).then((e=>e.success?{value:e.data
}:{issues:e.error?.issues}))}},vendor:"zod",version:1})))
})),rn=t("$ZodString",((e,t)=>{
nn.init(e,t),e._zod.pattern=[...e?._zod.bag?.patterns??[]].pop()??st(e._zod.bag),
e._zod.parse=(n,r)=>{if(t.coerce)try{n.value=String(n.value)}catch(o){}
return"string"==typeof n.value||n.issues.push({expected:"string",
code:"invalid_type",input:n.value,inst:e}),n}
})),on=t("$ZodStringFormat",((e,t)=>{Zt.init(e,t),rn.init(e,t)
})),an=t("$ZodGUID",((e,t)=>{t.pattern??(t.pattern=Le),on.init(e,t)
})),sn=t("$ZodUUID",((e,t)=>{if(t.version){const e={v1:1,v2:2,v3:3,v4:4,v5:5,
v6:6,v7:7,v8:8}[t.version]
;if(void 0===e)throw new Error(`Invalid UUID version: "${t.version}"`)
;t.pattern??(t.pattern=Be(e))}else t.pattern??(t.pattern=Be());on.init(e,t)
})),ln=t("$ZodEmail",((e,t)=>{t.pattern??(t.pattern=Fe),on.init(e,t)
})),cn=t("$ZodURL",((e,t)=>{on.init(e,t),e._zod.check=n=>{try{
const r=n.value.trim(),o=new URL(r)
;return t.hostname&&(t.hostname.lastIndex=0,t.hostname.test(o.hostname)||n.issues.push({
code:"invalid_format",format:"url",note:"Invalid hostname",
pattern:t.hostname.source,input:n.value,inst:e,continue:!t.abort
})),t.protocol&&(t.protocol.lastIndex=0,
t.protocol.test(o.protocol.endsWith(":")?o.protocol.slice(0,-1):o.protocol)||n.issues.push({
code:"invalid_format",format:"url",note:"Invalid protocol",
pattern:t.protocol.source,input:n.value,inst:e,continue:!t.abort
})),void(t.normalize?n.value=o.href:n.value=r)}catch(r){n.issues.push({
code:"invalid_format",format:"url",input:n.value,inst:e,continue:!t.abort})}}
})),un=t("$ZodEmoji",((e,t)=>{t.pattern??(t.pattern=He()),on.init(e,t)
})),dn=t("$ZodNanoID",((e,t)=>{t.pattern??(t.pattern=Ne),on.init(e,t)
})),pn=t("$ZodCUID",((e,t)=>{t.pattern??(t.pattern=$e),on.init(e,t)
})),hn=t("$ZodCUID2",((e,t)=>{t.pattern??(t.pattern=Pe),on.init(e,t)
})),fn=t("$ZodULID",((e,t)=>{t.pattern??(t.pattern=De),on.init(e,t)
})),mn=t("$ZodXID",((e,t)=>{t.pattern??(t.pattern=Ie),on.init(e,t)
})),gn=t("$ZodKSUID",((e,t)=>{t.pattern??(t.pattern=Me),on.init(e,t)
})),vn=t("$ZodISODateTime",((e,t)=>{t.pattern??(t.pattern=it(t)),on.init(e,t)
})),bn=t("$ZodISODate",((e,t)=>{t.pattern??(t.pattern=rt),on.init(e,t)
})),yn=t("$ZodISOTime",((e,t)=>{t.pattern??(t.pattern=at(t)),on.init(e,t)
})),On=t("$ZodISODuration",((e,t)=>{t.pattern??(t.pattern=Re),on.init(e,t)
})),wn=t("$ZodIPv4",((e,t)=>{
t.pattern??(t.pattern=Ve),on.init(e,t),e._zod.bag.format="ipv4"
})),xn=t("$ZodIPv6",((e,t)=>{
t.pattern??(t.pattern=qe),on.init(e,t),e._zod.bag.format="ipv6",
e._zod.check=n=>{try{new URL(`http://[${n.value}]`)}catch{n.issues.push({
code:"invalid_format",format:"ipv6",input:n.value,inst:e,continue:!t.abort})}}
})),kn=t("$ZodMAC",((e,t)=>{t.pattern??(t.pattern=We(t.delimiter)),on.init(e,t),
e._zod.bag.format="mac"})),Sn=t("$ZodCIDRv4",((e,t)=>{t.pattern??(t.pattern=Xe),
on.init(e,t)})),_n=t("$ZodCIDRv6",((e,t)=>{
t.pattern??(t.pattern=Ge),on.init(e,t),e._zod.check=n=>{
const r=n.value.split("/");try{if(2!==r.length)throw new Error;const[e,t]=r
;if(!t)throw new Error;const n=Number(t);if(`${n}`!==t)throw new Error
;if(n<0||n>128)throw new Error;new URL(`http://[${e}]`)}catch{n.issues.push({
code:"invalid_format",format:"cidrv6",input:n.value,inst:e,continue:!t.abort})}}
}));function Tn(e){if(""===e)return!0;if(e.length%4!=0)return!1;try{
return atob(e),!0}catch{return!1}}const En=t("$ZodBase64",((e,t)=>{
t.pattern??(t.pattern=Ye),
on.init(e,t),e._zod.bag.contentEncoding="base64",e._zod.check=n=>{
Tn(n.value)||n.issues.push({code:"invalid_format",format:"base64",input:n.value,
inst:e,continue:!t.abort})}}));function An(e){if(!Ke.test(e))return!1
;const t=e.replace(/[-_]/g,(e=>"-"===e?"+":"/"))
;return Tn(t.padEnd(4*Math.ceil(t.length/4),"="))}
const Cn=t("$ZodBase64URL",((e,t)=>{
t.pattern??(t.pattern=Ke),on.init(e,t),e._zod.bag.contentEncoding="base64url",
e._zod.check=n=>{An(n.value)||n.issues.push({code:"invalid_format",
format:"base64url",input:n.value,inst:e,continue:!t.abort})}
})),$n=t("$ZodE164",((e,t)=>{t.pattern??(t.pattern=tt),on.init(e,t)}))
;function Pn(e,t=null){try{const n=e.split(".");if(3!==n.length)return!1
;const[r]=n;if(!r)return!1;const o=JSON.parse(atob(r))
;return(!("typ"in o)||"JWT"===o?.typ)&&(!!o.alg&&(!t||"alg"in o&&o.alg===t))
}catch{return!1}}const Dn=t("$ZodJWT",((e,t)=>{on.init(e,t),e._zod.check=n=>{
Pn(n.value,t.alg)||n.issues.push({code:"invalid_format",format:"jwt",
input:n.value,inst:e,continue:!t.abort})}
})),In=t("$ZodCustomStringFormat",((e,t)=>{on.init(e,t),e._zod.check=n=>{
t.fn(n.value)||n.issues.push({code:"invalid_format",format:t.format,
input:n.value,inst:e,continue:!t.abort})}})),Mn=t("$ZodNumber",((e,t)=>{
nn.init(e,t),e._zod.pattern=e._zod.bag.pattern??ut,e._zod.parse=(n,r)=>{
if(t.coerce)try{n.value=Number(n.value)}catch(i){}const o=n.value
;if("number"==typeof o&&!Number.isNaN(o)&&Number.isFinite(o))return n
;const a="number"==typeof o?Number.isNaN(o)?"NaN":Number.isFinite(o)?void 0:"Infinity":void 0
;return n.issues.push({expected:"number",code:"invalid_type",input:o,inst:e,
...a?{received:a}:{}}),n}})),Nn=t("$ZodNumberFormat",((e,t)=>{
Nt.init(e,t),Mn.init(e,t)})),Rn=t("$ZodBoolean",((e,t)=>{
nn.init(e,t),e._zod.pattern=dt,e._zod.parse=(n,r)=>{if(t.coerce)try{
n.value=Boolean(n.value)}catch(a){}const o=n.value
;return"boolean"==typeof o||n.issues.push({expected:"boolean",
code:"invalid_type",input:o,inst:e}),n}})),Ln=t("$ZodBigInt",((e,t)=>{
nn.init(e,t),e._zod.pattern=lt,e._zod.parse=(n,r)=>{if(t.coerce)try{
n.value=BigInt(n.value)}catch(o){}
return"bigint"==typeof n.value||n.issues.push({expected:"bigint",
code:"invalid_type",input:n.value,inst:e}),n}
})),Bn=t("$ZodBigIntFormat",((e,t)=>{Rt.init(e,t),Ln.init(e,t)
})),jn=t("$ZodSymbol",((e,t)=>{nn.init(e,t),e._zod.parse=(t,n)=>{const r=t.value
;return"symbol"==typeof r||t.issues.push({expected:"symbol",code:"invalid_type",
input:r,inst:e}),t}})),Un=t("$ZodUndefined",((e,t)=>{
nn.init(e,t),e._zod.pattern=ht,
e._zod.values=new Set([void 0]),e._zod.optin="optional",
e._zod.optout="optional",e._zod.parse=(t,n)=>{const r=t.value
;return void 0===r||t.issues.push({expected:"undefined",code:"invalid_type",
input:r,inst:e}),t}})),zn=t("$ZodNull",((e,t)=>{
nn.init(e,t),e._zod.pattern=pt,e._zod.values=new Set([null]),
e._zod.parse=(t,n)=>{const r=t.value;return null===r||t.issues.push({
expected:"null",code:"invalid_type",input:r,inst:e}),t}
})),Fn=t("$ZodAny",((e,t)=>{nn.init(e,t),e._zod.parse=e=>e
})),Zn=t("$ZodUnknown",((e,t)=>{nn.init(e,t),e._zod.parse=e=>e
})),Qn=t("$ZodNever",((e,t)=>{nn.init(e,t),e._zod.parse=(t,n)=>(t.issues.push({
expected:"never",code:"invalid_type",input:t.value,inst:e}),t)
})),Hn=t("$ZodVoid",((e,t)=>{nn.init(e,t),e._zod.parse=(t,n)=>{const r=t.value
;return void 0===r||t.issues.push({expected:"void",code:"invalid_type",input:r,
inst:e}),t}})),Vn=t("$ZodDate",((e,t)=>{nn.init(e,t),e._zod.parse=(n,r)=>{
if(t.coerce)try{n.value=new Date(n.value)}catch(i){}
const o=n.value,a=o instanceof Date
;return a&&!Number.isNaN(o.getTime())||n.issues.push({expected:"date",
code:"invalid_type",input:o,...a?{received:"Invalid Date"}:{},inst:e}),n}}))
;function qn(e,t,n){
e.issues.length&&t.issues.push(...F(n,e.issues)),t.value[n]=e.value}
const Wn=t("$ZodArray",((e,t)=>{nn.init(e,t),e._zod.parse=(n,r)=>{
const o=n.value;if(!Array.isArray(o))return n.issues.push({expected:"array",
code:"invalid_type",input:o,inst:e}),n;n.value=Array(o.length);const a=[]
;for(let e=0;e<o.length;e++){const i=o[e],s=t.element._zod.run({value:i,
issues:[]},r);s instanceof Promise?a.push(s.then((t=>qn(t,n,e)))):qn(s,n,e)}
return a.length?Promise.all(a).then((()=>n)):n}}));function Xn(e,t,n,r,o){
if(e.issues.length){if(o&&!(n in r))return;t.issues.push(...F(n,e.issues))}
void 0===e.value?n in r&&(t.value[n]=void 0):t.value[n]=e.value}function Gn(e){
const t=Object.keys(e.shape)
;for(const r of t)if(!e.shape?.[r]?._zod?.traits?.has("$ZodType"))throw new Error(`Invalid element at key "${r}": expected a Zod schema`)
;const n=P(e.shape);return{...e,keys:t,keySet:new Set(t),numKeys:t.length,
optionalKeys:new Set(n)}}function Yn(e,t,n,r,o,a){
const i=[],s=o.keySet,l=o.catchall._zod,c=l.def.type,u="optional"===l.optout
;for(const d in t){if(s.has(d))continue;if("never"===c){i.push(d);continue}
const o=l.run({value:t[d],issues:[]},r)
;o instanceof Promise?e.push(o.then((e=>Xn(e,n,d,t,u)))):Xn(o,n,d,t,u)}
return i.length&&n.issues.push({code:"unrecognized_keys",keys:i,input:t,inst:a
}),e.length?Promise.all(e).then((()=>n)):n}const Kn=t("$ZodObject",((e,t)=>{
nn.init(e,t);const n=Object.getOwnPropertyDescriptor(t,"shape");if(!n?.get){
const e=t.shape;Object.defineProperty(t,"shape",{get:()=>{const n={...e}
;return Object.defineProperty(t,"shape",{value:n}),n}})}const r=u((()=>Gn(t)))
;m(e._zod,"propValues",(()=>{const e=t.shape,n={};for(const t in e){
const r=e[t]._zod;if(r.values){n[t]??(n[t]=new Set)
;for(const e of r.values)n[t].add(e)}}return n}));const o=w,a=t.catchall;let i
;e._zod.parse=(t,n)=>{i??(i=r.value);const s=t.value
;if(!o(s))return t.issues.push({expected:"object",code:"invalid_type",input:s,
inst:e}),t;t.value={};const l=[],c=i.shape;for(const e of i.keys){
const r=c[e],o="optional"===r._zod.optout,a=r._zod.run({value:s[e],issues:[]},n)
;a instanceof Promise?l.push(a.then((n=>Xn(n,t,e,s,o)))):Xn(a,t,e,s,o)}
return a?Yn(l,s,t,n,r.value,e):l.length?Promise.all(l).then((()=>t)):t}
})),Jn=t("$ZodObjectJIT",((e,t)=>{Kn.init(e,t)
;const n=e._zod.parse,r=u((()=>Gn(t)));let o
;const i=w,s=!a.jitless,l=s&&x.value,c=t.catchall;let d;e._zod.parse=(a,u)=>{
d??(d=r.value);const p=a.value
;return i(p)?s&&l&&!1===u?.async&&!0!==u.jitless?(o||(o=(e=>{
const t=new en(["shape","payload","ctx"]),n=r.value,o=e=>{const t=b(e)
;return`shape[${t}]._zod.run({ value: input[${t}], issues: [] }, ctx)`}
;t.write("const input = payload.value;");const a=Object.create(null);let i=0
;for(const r of n.keys)a[r]="key_"+i++;t.write("const newResult = {};")
;for(const r of n.keys){
const n=a[r],i=b(r),s=e[r],l="optional"===s?._zod?.optout
;t.write(`const ${n} = ${o(r)};`),
l?t.write(`\n        if (${n}.issues.length) {\n          if (${i} in input) {\n            payload.issues = payload.issues.concat(${n}.issues.map(iss => ({\n              ...iss,\n              path: iss.path ? [${i}, ...iss.path] : [${i}]\n            })));\n          }\n        }\n        \n        if (${n}.value === undefined) {\n          if (${i} in input) {\n            newResult[${i}] = undefined;\n          }\n        } else {\n          newResult[${i}] = ${n}.value;\n        }\n        \n      `):t.write(`\n        if (${n}.issues.length) {\n          payload.issues = payload.issues.concat(${n}.issues.map(iss => ({\n            ...iss,\n            path: iss.path ? [${i}, ...iss.path] : [${i}]\n          })));\n        }\n        \n        if (${n}.value === undefined) {\n          if (${i} in input) {\n            newResult[${i}] = undefined;\n          }\n        } else {\n          newResult[${i}] = ${n}.value;\n        }\n        \n      `)
}t.write("payload.value = newResult;"),t.write("return payload;")
;const s=t.compile();return(t,n)=>s(e,t,n)
})(t.shape)),a=o(a,u),c?Yn([],p,a,u,d,e):a):n(a,u):(a.issues.push({
expected:"object",code:"invalid_type",input:p,inst:e}),a)}}))
;function er(e,t,n,r){
for(const a of e)if(0===a.issues.length)return t.value=a.value,t
;const o=e.filter((e=>!z(e)))
;return 1===o.length?(t.value=o[0].value,o[0]):(t.issues.push({
code:"invalid_union",input:t.value,inst:n,
errors:e.map((e=>e.issues.map((e=>Q(e,r,i())))))}),t)}
const tr=t("$ZodUnion",((e,t)=>{
nn.init(e,t),m(e._zod,"optin",(()=>t.options.some((e=>"optional"===e._zod.optin))?"optional":void 0)),
m(e._zod,"optout",(()=>t.options.some((e=>"optional"===e._zod.optout))?"optional":void 0)),
m(e._zod,"values",(()=>{
if(t.options.every((e=>e._zod.values)))return new Set(t.options.flatMap((e=>Array.from(e._zod.values))))
})),m(e._zod,"pattern",(()=>{if(t.options.every((e=>e._zod.pattern))){
const e=t.options.map((e=>e._zod.pattern))
;return new RegExp(`^(${e.map((e=>p(e.source))).join("|")})$`)}}))
;const n=1===t.options.length,r=t.options[0]._zod.run;e._zod.parse=(o,a)=>{
if(n)return r(o,a);let i=!1;const s=[];for(const e of t.options){
const t=e._zod.run({value:o.value,issues:[]},a)
;if(t instanceof Promise)s.push(t),i=!0;else{if(0===t.issues.length)return t
;s.push(t)}}return i?Promise.all(s).then((t=>er(t,o,e,a))):er(s,o,e,a)}}))
;function nr(e,t,n,r){const o=e.filter((e=>0===e.issues.length))
;return 1===o.length?(t.value=o[0].value,t):(0===o.length?t.issues.push({
code:"invalid_union",input:t.value,inst:n,
errors:e.map((e=>e.issues.map((e=>Q(e,r,i())))))}):t.issues.push({
code:"invalid_union",input:t.value,inst:n,errors:[],inclusive:!1}),t)}
const rr=t("$ZodXor",((e,t)=>{tr.init(e,t),t.inclusive=!1
;const n=1===t.options.length,r=t.options[0]._zod.run;e._zod.parse=(o,a)=>{
if(n)return r(o,a);let i=!1;const s=[];for(const e of t.options){
const t=e._zod.run({value:o.value,issues:[]},a);t instanceof Promise?(s.push(t),
i=!0):s.push(t)}return i?Promise.all(s).then((t=>nr(t,o,e,a))):nr(s,o,e,a)}
})),or=t("$ZodDiscriminatedUnion",((e,t)=>{t.inclusive=!1,tr.init(e,t)
;const n=e._zod.parse;m(e._zod,"propValues",(()=>{const e={}
;for(const n of t.options){const r=n._zod.propValues
;if(!r||0===Object.keys(r).length)throw new Error(`Invalid discriminated union option at index "${t.options.indexOf(n)}"`)
;for(const[t,n]of Object.entries(r)){e[t]||(e[t]=new Set)
;for(const r of n)e[t].add(r)}}return e}));const r=u((()=>{
const e=t.options,n=new Map;for(const r of e){
const e=r._zod.propValues?.[t.discriminator]
;if(!e||0===e.size)throw new Error(`Invalid discriminated union option at index "${t.options.indexOf(r)}"`)
;for(const t of e){
if(n.has(t))throw new Error(`Duplicate discriminator value "${String(t)}"`)
;n.set(t,r)}}return n}));e._zod.parse=(o,a)=>{const i=o.value
;if(!w(i))return o.issues.push({code:"invalid_type",expected:"object",input:i,
inst:e}),o;const s=r.value.get(i?.[t.discriminator])
;return s?s._zod.run(o,a):t.unionFallback?n(o,a):(o.issues.push({
code:"invalid_union",errors:[],note:"No matching discriminator",
discriminator:t.discriminator,input:i,path:[t.discriminator],inst:e}),o)}
})),ar=t("$ZodIntersection",((e,t)=>{nn.init(e,t),e._zod.parse=(e,n)=>{
const r=e.value,o=t.left._zod.run({value:r,issues:[]},n),a=t.right._zod.run({
value:r,issues:[]},n)
;return o instanceof Promise||a instanceof Promise?Promise.all([o,a]).then((([t,n])=>sr(e,t,n))):sr(e,o,a)
}}));function ir(e,t){if(e===t)return{valid:!0,data:e}
;if(e instanceof Date&&t instanceof Date&&+e==+t)return{valid:!0,data:e}
;if(k(e)&&k(t)){
const n=Object.keys(t),r=Object.keys(e).filter((e=>-1!==n.indexOf(e))),o={...e,
...t};for(const a of r){const n=ir(e[a],t[a]);if(!n.valid)return{valid:!1,
mergeErrorPath:[a,...n.mergeErrorPath]};o[a]=n.data}return{valid:!0,data:o}}
if(Array.isArray(e)&&Array.isArray(t)){if(e.length!==t.length)return{valid:!1,
mergeErrorPath:[]};const n=[];for(let r=0;r<e.length;r++){const o=ir(e[r],t[r])
;if(!o.valid)return{valid:!1,mergeErrorPath:[r,...o.mergeErrorPath]}
;n.push(o.data)}return{valid:!0,data:n}}return{valid:!1,mergeErrorPath:[]}}
function sr(e,t,n){const r=new Map;let o
;for(const s of t.issues)if("unrecognized_keys"===s.code){o??(o=s)
;for(const e of s.keys)r.has(e)||r.set(e,{}),r.get(e).l=!0}else e.issues.push(s)
;for(const s of n.issues)if("unrecognized_keys"===s.code)for(const e of s.keys)r.has(e)||r.set(e,{}),
r.get(e).r=!0;else e.issues.push(s)
;const a=[...r].filter((([,e])=>e.l&&e.r)).map((([e])=>e))
;if(a.length&&o&&e.issues.push({...o,keys:a}),z(e))return e
;const i=ir(t.value,n.value)
;if(!i.valid)throw new Error(`Unmergable intersection. Error path: ${JSON.stringify(i.mergeErrorPath)}`)
;return e.value=i.data,e}const lr=t("$ZodTuple",((e,t)=>{nn.init(e,t)
;const n=t.items;e._zod.parse=(r,o)=>{const a=r.value
;if(!Array.isArray(a))return r.issues.push({input:a,inst:e,expected:"tuple",
code:"invalid_type"}),r;r.value=[]
;const i=[],s=[...n].reverse().findIndex((e=>"optional"!==e._zod.optin)),l=-1===s?0:n.length-s
;if(!t.rest){const t=a.length>n.length,o=a.length<l-1
;if(t||o)return r.issues.push({...t?{code:"too_big",maximum:n.length,
inclusive:!0}:{code:"too_small",minimum:n.length},input:a,inst:e,origin:"array"
}),r}let c=-1;for(const e of n){if(c++,c>=a.length&&c>=l)continue
;const t=e._zod.run({value:a[c],issues:[]},o)
;t instanceof Promise?i.push(t.then((e=>cr(e,r,c)))):cr(t,r,c)}if(t.rest){
const e=a.slice(n.length);for(const n of e){c++;const e=t.rest._zod.run({
value:n,issues:[]},o)
;e instanceof Promise?i.push(e.then((e=>cr(e,r,c)))):cr(e,r,c)}}
return i.length?Promise.all(i).then((()=>r)):r}}));function cr(e,t,n){
e.issues.length&&t.issues.push(...F(n,e.issues)),t.value[n]=e.value}
const ur=t("$ZodRecord",((e,t)=>{nn.init(e,t),e._zod.parse=(n,r)=>{
const o=n.value;if(!k(o))return n.issues.push({expected:"record",
code:"invalid_type",input:o,inst:e}),n;const a=[],s=t.keyType._zod.values;if(s){
n.value={};const i=new Set
;for(const e of s)if("string"==typeof e||"number"==typeof e||"symbol"==typeof e){
i.add("number"==typeof e?e.toString():e);const s=t.valueType._zod.run({
value:o[e],issues:[]},r);s instanceof Promise?a.push(s.then((t=>{
t.issues.length&&n.issues.push(...F(e,t.issues)),n.value[e]=t.value
}))):(s.issues.length&&n.issues.push(...F(e,s.issues)),n.value[e]=s.value)}let l
;for(const e in o)i.has(e)||(l=l??[],l.push(e));l&&l.length>0&&n.issues.push({
code:"unrecognized_keys",input:o,inst:e,keys:l})}else{n.value={}
;for(const s of Reflect.ownKeys(o)){if("__proto__"===s)continue
;let l=t.keyType._zod.run({value:s,issues:[]},r)
;if(l instanceof Promise)throw new Error("Async schemas not supported in object keys currently")
;if("string"==typeof s&&ut.test(s)&&l.issues.length&&l.issues.some((e=>"invalid_type"===e.code&&"number"===e.expected))){
const e=t.keyType._zod.run({value:Number(s),issues:[]},r)
;if(e instanceof Promise)throw new Error("Async schemas not supported in object keys currently")
;0===e.issues.length&&(l=e)}if(l.issues.length){
"loose"===t.mode?n.value[s]=o[s]:n.issues.push({code:"invalid_key",
origin:"record",issues:l.issues.map((e=>Q(e,r,i()))),input:s,path:[s],inst:e})
;continue}const c=t.valueType._zod.run({value:o[s],issues:[]},r)
;c instanceof Promise?a.push(c.then((e=>{
e.issues.length&&n.issues.push(...F(s,e.issues)),n.value[l.value]=e.value
}))):(c.issues.length&&n.issues.push(...F(s,c.issues)),n.value[l.value]=c.value)
}}return a.length?Promise.all(a).then((()=>n)):n}})),dr=t("$ZodMap",((e,t)=>{
nn.init(e,t),e._zod.parse=(n,r)=>{const o=n.value
;if(!(o instanceof Map))return n.issues.push({expected:"map",
code:"invalid_type",input:o,inst:e}),n;const a=[];n.value=new Map
;for(const[i,s]of o){const l=t.keyType._zod.run({value:i,issues:[]
},r),c=t.valueType._zod.run({value:s,issues:[]},r)
;l instanceof Promise||c instanceof Promise?a.push(Promise.all([l,c]).then((([t,a])=>{
pr(t,a,n,i,o,e,r)}))):pr(l,c,n,i,o,e,r)}
return a.length?Promise.all(a).then((()=>n)):n}}));function pr(e,t,n,r,o,a,s){
e.issues.length&&(_.has(typeof r)?n.issues.push(...F(r,e.issues)):n.issues.push({
code:"invalid_key",origin:"map",input:o,inst:a,
issues:e.issues.map((e=>Q(e,s,i())))
})),t.issues.length&&(_.has(typeof r)?n.issues.push(...F(r,t.issues)):n.issues.push({
origin:"map",code:"invalid_element",input:o,inst:a,key:r,
issues:t.issues.map((e=>Q(e,s,i())))})),n.value.set(e.value,t.value)}
const hr=t("$ZodSet",((e,t)=>{nn.init(e,t),e._zod.parse=(n,r)=>{const o=n.value
;if(!(o instanceof Set))return n.issues.push({input:o,inst:e,expected:"set",
code:"invalid_type"}),n;const a=[];n.value=new Set;for(const e of o){
const o=t.valueType._zod.run({value:e,issues:[]},r)
;o instanceof Promise?a.push(o.then((e=>fr(e,n)))):fr(o,n)}
return a.length?Promise.all(a).then((()=>n)):n}}));function fr(e,t){
e.issues.length&&t.issues.push(...e.issues),t.value.add(e.value)}
const mr=t("$ZodEnum",((e,t)=>{nn.init(e,t);const n=s(t.entries),r=new Set(n)
;e._zod.values=r,
e._zod.pattern=new RegExp(`^(${n.filter((e=>_.has(typeof e))).map((e=>"string"==typeof e?E(e):e.toString())).join("|")})$`),
e._zod.parse=(t,o)=>{const a=t.value;return r.has(a)||t.issues.push({
code:"invalid_value",values:n,input:a,inst:e}),t}
})),gr=t("$ZodLiteral",((e,t)=>{
if(nn.init(e,t),0===t.values.length)throw new Error("Cannot create literal schema with no valid values")
;const n=new Set(t.values)
;e._zod.values=n,e._zod.pattern=new RegExp(`^(${t.values.map((e=>"string"==typeof e?E(e):e?E(e.toString()):String(e))).join("|")})$`),
e._zod.parse=(r,o)=>{const a=r.value;return n.has(a)||r.issues.push({
code:"invalid_value",values:t.values,input:a,inst:e}),r}
})),vr=t("$ZodFile",((e,t)=>{nn.init(e,t),e._zod.parse=(t,n)=>{const r=t.value
;return r instanceof File||t.issues.push({expected:"file",code:"invalid_type",
input:r,inst:e}),t}})),br=t("$ZodTransform",((e,t)=>{
nn.init(e,t),e._zod.parse=(n,a)=>{
if("backward"===a.direction)throw new o(e.constructor.name)
;const i=t.transform(n.value,n);if(a.async){
return(i instanceof Promise?i:Promise.resolve(i)).then((e=>(n.value=e,n)))}
if(i instanceof Promise)throw new r;return n.value=i,n}}));function yr(e,t){
return e.issues.length&&void 0===t?{issues:[],value:void 0}:e}
const Or=t("$ZodOptional",((e,t)=>{
nn.init(e,t),e._zod.optin="optional",e._zod.optout="optional",
m(e._zod,"values",(()=>t.innerType._zod.values?new Set([...t.innerType._zod.values,void 0]):void 0)),
m(e._zod,"pattern",(()=>{const e=t.innerType._zod.pattern
;return e?new RegExp(`^(${p(e.source)})?$`):void 0})),e._zod.parse=(e,n)=>{
if("optional"===t.innerType._zod.optin){const r=t.innerType._zod.run(e,n)
;return r instanceof Promise?r.then((t=>yr(t,e.value))):yr(r,e.value)}
return void 0===e.value?e:t.innerType._zod.run(e,n)}
})),wr=t("$ZodExactOptional",((e,t)=>{
Or.init(e,t),m(e._zod,"values",(()=>t.innerType._zod.values)),
m(e._zod,"pattern",(()=>t.innerType._zod.pattern)),
e._zod.parse=(e,n)=>t.innerType._zod.run(e,n)})),xr=t("$ZodNullable",((e,t)=>{
nn.init(e,t),
m(e._zod,"optin",(()=>t.innerType._zod.optin)),m(e._zod,"optout",(()=>t.innerType._zod.optout)),
m(e._zod,"pattern",(()=>{const e=t.innerType._zod.pattern
;return e?new RegExp(`^(${p(e.source)}|null)$`):void 0
})),m(e._zod,"values",(()=>t.innerType._zod.values?new Set([...t.innerType._zod.values,null]):void 0)),
e._zod.parse=(e,n)=>null===e.value?e:t.innerType._zod.run(e,n)
})),kr=t("$ZodDefault",((e,t)=>{
nn.init(e,t),e._zod.optin="optional",m(e._zod,"values",(()=>t.innerType._zod.values)),
e._zod.parse=(e,n)=>{
if("backward"===n.direction)return t.innerType._zod.run(e,n)
;if(void 0===e.value)return e.value=t.defaultValue,e
;const r=t.innerType._zod.run(e,n)
;return r instanceof Promise?r.then((e=>Sr(e,t))):Sr(r,t)}}));function Sr(e,t){
return void 0===e.value&&(e.value=t.defaultValue),e}
const _r=t("$ZodPrefault",((e,t)=>{
nn.init(e,t),e._zod.optin="optional",m(e._zod,"values",(()=>t.innerType._zod.values)),
e._zod.parse=(e,n)=>("backward"===n.direction||void 0===e.value&&(e.value=t.defaultValue),
t.innerType._zod.run(e,n))})),Tr=t("$ZodNonOptional",((e,t)=>{
nn.init(e,t),m(e._zod,"values",(()=>{const e=t.innerType._zod.values
;return e?new Set([...e].filter((e=>void 0!==e))):void 0
})),e._zod.parse=(n,r)=>{const o=t.innerType._zod.run(n,r)
;return o instanceof Promise?o.then((t=>Er(t,e))):Er(o,e)}}));function Er(e,t){
return e.issues.length||void 0!==e.value||e.issues.push({code:"invalid_type",
expected:"nonoptional",input:e.value,inst:t}),e}
const Ar=t("$ZodSuccess",((e,t)=>{nn.init(e,t),e._zod.parse=(e,n)=>{
if("backward"===n.direction)throw new o("ZodSuccess")
;const r=t.innerType._zod.run(e,n)
;return r instanceof Promise?r.then((t=>(e.value=0===t.issues.length,
e))):(e.value=0===r.issues.length,e)}})),Cr=t("$ZodCatch",((e,t)=>{nn.init(e,t),
m(e._zod,"optin",(()=>t.innerType._zod.optin)),
m(e._zod,"optout",(()=>t.innerType._zod.optout)),
m(e._zod,"values",(()=>t.innerType._zod.values)),e._zod.parse=(e,n)=>{
if("backward"===n.direction)return t.innerType._zod.run(e,n)
;const r=t.innerType._zod.run(e,n)
;return r instanceof Promise?r.then((r=>(e.value=r.value,
r.issues.length&&(e.value=t.catchValue({...e,error:{
issues:r.issues.map((e=>Q(e,n,i())))},input:e.value
}),e.issues=[]),e))):(e.value=r.value,r.issues.length&&(e.value=t.catchValue({
...e,error:{issues:r.issues.map((e=>Q(e,n,i())))},input:e.value
}),e.issues=[]),e)}})),$r=t("$ZodNaN",((e,t)=>{
nn.init(e,t),e._zod.parse=(t,n)=>("number"==typeof t.value&&Number.isNaN(t.value)||t.issues.push({
input:t.value,inst:e,expected:"nan",code:"invalid_type"}),t)
})),Pr=t("$ZodPipe",((e,t)=>{
nn.init(e,t),m(e._zod,"values",(()=>t.in._zod.values)),
m(e._zod,"optin",(()=>t.in._zod.optin)),
m(e._zod,"optout",(()=>t.out._zod.optout)),
m(e._zod,"propValues",(()=>t.in._zod.propValues)),e._zod.parse=(e,n)=>{
if("backward"===n.direction){const r=t.out._zod.run(e,n)
;return r instanceof Promise?r.then((e=>Dr(e,t.in,n))):Dr(r,t.in,n)}
const r=t.in._zod.run(e,n)
;return r instanceof Promise?r.then((e=>Dr(e,t.out,n))):Dr(r,t.out,n)}}))
;function Dr(e,t,n){return e.issues.length?(e.aborted=!0,e):t._zod.run({
value:e.value,issues:e.issues},n)}const Ir=t("$ZodCodec",((e,t)=>{
nn.init(e,t),m(e._zod,"values",(()=>t.in._zod.values)),
m(e._zod,"optin",(()=>t.in._zod.optin)),
m(e._zod,"optout",(()=>t.out._zod.optout)),
m(e._zod,"propValues",(()=>t.in._zod.propValues)),e._zod.parse=(e,n)=>{
if("forward"===(n.direction||"forward")){const r=t.in._zod.run(e,n)
;return r instanceof Promise?r.then((e=>Mr(e,t,n))):Mr(r,t,n)}{
const r=t.out._zod.run(e,n)
;return r instanceof Promise?r.then((e=>Mr(e,t,n))):Mr(r,t,n)}}}))
;function Mr(e,t,n){if(e.issues.length)return e.aborted=!0,e
;if("forward"===(n.direction||"forward")){const r=t.transform(e.value,e)
;return r instanceof Promise?r.then((r=>Nr(e,r,t.out,n))):Nr(e,r,t.out,n)}{
const r=t.reverseTransform(e.value,e)
;return r instanceof Promise?r.then((r=>Nr(e,r,t.in,n))):Nr(e,r,t.in,n)}}
function Nr(e,t,n,r){return e.issues.length?(e.aborted=!0,e):n._zod.run({
value:t,issues:e.issues},r)}const Rr=t("$ZodReadonly",((e,t)=>{
nn.init(e,t),m(e._zod,"propValues",(()=>t.innerType._zod.propValues)),
m(e._zod,"values",(()=>t.innerType._zod.values)),
m(e._zod,"optin",(()=>t.innerType?._zod?.optin)),
m(e._zod,"optout",(()=>t.innerType?._zod?.optout)),e._zod.parse=(e,n)=>{
if("backward"===n.direction)return t.innerType._zod.run(e,n)
;const r=t.innerType._zod.run(e,n);return r instanceof Promise?r.then(Lr):Lr(r)}
}));function Lr(e){return e.value=Object.freeze(e.value),e}
const Br=t("$ZodTemplateLiteral",((e,t)=>{nn.init(e,t);const n=[]
;for(const r of t.parts)if("object"==typeof r&&null!==r){
if(!r._zod.pattern)throw new Error(`Invalid template literal part, no pattern found: ${[...r._zod.traits].shift()}`)
;const e=r._zod.pattern instanceof RegExp?r._zod.pattern.source:r._zod.pattern
;if(!e)throw new Error(`Invalid template literal part: ${r._zod.traits}`)
;const t=e.startsWith("^")?1:0,o=e.endsWith("$")?e.length-1:e.length
;n.push(e.slice(t,o))}else{
if(null!==r&&!T.has(typeof r))throw new Error(`Invalid template literal part: ${r}`)
;n.push(E(`${r}`))}
e._zod.pattern=new RegExp(`^${n.join("")}$`),e._zod.parse=(n,r)=>"string"!=typeof n.value?(n.issues.push({
input:n.value,inst:e,expected:"string",code:"invalid_type"
}),n):(e._zod.pattern.lastIndex=0,e._zod.pattern.test(n.value)||n.issues.push({
input:n.value,inst:e,code:"invalid_format",format:t.format??"template_literal",
pattern:e._zod.pattern.source}),n)})),jr=t("$ZodFunction",((e,t)=>(nn.init(e,t),
e._def=t,e._zod.def=t,e.implement=t=>{
if("function"!=typeof t)throw new Error("implement() must be called with a function")
;return function(...n){
const r=e._def.input?se(e._def.input,n):n,o=Reflect.apply(t,this,r)
;return e._def.output?se(e._def.output,o):o}},e.implementAsync=t=>{
if("function"!=typeof t)throw new Error("implementAsync() must be called with a function")
;return async function(...n){
const r=e._def.input?await ce(e._def.input,n):n,o=await Reflect.apply(t,this,r)
;return e._def.output?await ce(e._def.output,o):o}},e._zod.parse=(t,n)=>{
if("function"!=typeof t.value)return t.issues.push({code:"invalid_type",
expected:"function",input:t.value,inst:e}),t
;const r=e._def.output&&"promise"===e._def.output._zod.def.type
;return t.value=r?e.implementAsync(t.value):e.implement(t.value),t
},e.input=(...t)=>{const n=e.constructor;return Array.isArray(t[0])?new n({
type:"function",input:new lr({type:"tuple",items:t[0],rest:t[1]}),
output:e._def.output}):new n({type:"function",input:t[0],output:e._def.output})
},e.output=t=>new(0,e.constructor)({type:"function",input:e._def.input,output:t
}),e))),Ur=t("$ZodPromise",((e,t)=>{
nn.init(e,t),e._zod.parse=(e,n)=>Promise.resolve(e.value).then((e=>t.innerType._zod.run({
value:e,issues:[]},n)))})),zr=t("$ZodLazy",((e,t)=>{
nn.init(e,t),m(e._zod,"innerType",(()=>t.getter())),
m(e._zod,"pattern",(()=>e._zod.innerType?._zod?.pattern)),
m(e._zod,"propValues",(()=>e._zod.innerType?._zod?.propValues)),
m(e._zod,"optin",(()=>e._zod.innerType?._zod?.optin??void 0)),
m(e._zod,"optout",(()=>e._zod.innerType?._zod?.optout??void 0)),
e._zod.parse=(t,n)=>e._zod.innerType._zod.run(t,n)
})),Fr=t("$ZodCustom",((e,t)=>{
$t.init(e,t),nn.init(e,t),e._zod.parse=(e,t)=>e,e._zod.check=n=>{
const r=n.value,o=t.fn(r)
;if(o instanceof Promise)return o.then((t=>Zr(t,n,r,e)));Zr(o,n,r,e)}}))
;function Zr(e,t,n,r){if(!e){const e={code:"custom",input:n,inst:r,
path:[...r._zod.def.path??[]],continue:!r._zod.def.abort}
;r._zod.def.params&&(e.params=r._zod.def.params),t.issues.push(W(e))}}
const Qr=()=>{const e={string:{unit:"حرف",verb:"أن يحوي"},file:{unit:"بايت",
verb:"أن يحوي"},array:{unit:"عنصر",verb:"أن يحوي"},set:{unit:"عنصر",
verb:"أن يحوي"}};function t(t){return e[t]??null}const n={regex:"مدخل",
email:"بريد إلكتروني",url:"رابط",emoji:"إيموجي",uuid:"UUID",uuidv4:"UUIDv4",
uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",
ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"تاريخ ووقت بمعيار ISO",
date:"تاريخ بمعيار ISO",time:"وقت بمعيار ISO",duration:"مدة بمعيار ISO",
ipv4:"عنوان IPv4",ipv6:"عنوان IPv6",cidrv4:"مدى عناوين بصيغة IPv4",
cidrv6:"مدى عناوين بصيغة IPv6",base64:"نَص بترميز base64-encoded",
base64url:"نَص بترميز base64url-encoded",json_string:"نَص على هيئة JSON",
e164:"رقم هاتف بمعيار E.164",jwt:"JWT",template_literal:"مدخل"},r={nan:"NaN"}
;return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`مدخلات غير مقبولة: يفترض إدخال instanceof ${e.expected}، ولكن تم إدخال ${o}`:`مدخلات غير مقبولة: يفترض إدخال ${t}، ولكن تم إدخال ${o}`
}case"invalid_value":
return 1===e.values.length?`مدخلات غير مقبولة: يفترض إدخال ${$(e.values[0])}`:`اختيار غير مقبول: يتوقع انتقاء أحد هذه الخيارات: ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?` أكبر من اللازم: يفترض أن تكون ${e.origin??"القيمة"} ${n} ${e.maximum.toString()} ${r.unit??"عنصر"}`:`أكبر من اللازم: يفترض أن تكون ${e.origin??"القيمة"} ${n} ${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`أصغر من اللازم: يفترض لـ ${e.origin} أن يكون ${n} ${e.minimum.toString()} ${r.unit}`:`أصغر من اللازم: يفترض لـ ${e.origin} أن يكون ${n} ${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`نَص غير مقبول: يجب أن يبدأ بـ "${e.prefix}"`:"ends_with"===t.format?`نَص غير مقبول: يجب أن ينتهي بـ "${t.suffix}"`:"includes"===t.format?`نَص غير مقبول: يجب أن يتضمَّن "${t.includes}"`:"regex"===t.format?`نَص غير مقبول: يجب أن يطابق النمط ${t.pattern}`:`${n[t.format]??e.format} غير مقبول`
}case"not_multiple_of":
return`رقم غير مقبول: يجب أن يكون من مضاعفات ${e.divisor}`
;case"unrecognized_keys":
return`معرف${e.keys.length>1?"ات":""} غريب${e.keys.length>1?"ة":""}: ${l(e.keys,"، ")}`
;case"invalid_key":return`معرف غير مقبول في ${e.origin}`;case"invalid_union":
default:return"مدخل غير مقبول";case"invalid_element":
return`مدخل غير مقبول في ${e.origin}`}}};const Hr=()=>{const e={string:{
unit:"simvol",verb:"olmalıdır"},file:{unit:"bayt",verb:"olmalıdır"},array:{
unit:"element",verb:"olmalıdır"},set:{unit:"element",verb:"olmalıdır"}}
;function t(t){return e[t]??null}const n={regex:"input",email:"email address",
url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",
nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",
ksuid:"KSUID",datetime:"ISO datetime",date:"ISO date",time:"ISO time",
duration:"ISO duration",ipv4:"IPv4 address",ipv6:"IPv6 address",
cidrv4:"IPv4 range",cidrv6:"IPv6 range",base64:"base64-encoded string",
base64url:"base64url-encoded string",json_string:"JSON string",
e164:"E.164 number",jwt:"JWT",template_literal:"input"},r={nan:"NaN"}
;return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Yanlış dəyər: gözlənilən instanceof ${e.expected}, daxil olan ${o}`:`Yanlış dəyər: gözlənilən ${t}, daxil olan ${o}`
}case"invalid_value":
return 1===e.values.length?`Yanlış dəyər: gözlənilən ${$(e.values[0])}`:`Yanlış seçim: aşağıdakılardan biri olmalıdır: ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Çox böyük: gözlənilən ${e.origin??"dəyər"} ${n}${e.maximum.toString()} ${r.unit??"element"}`:`Çox böyük: gözlənilən ${e.origin??"dəyər"} ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Çox kiçik: gözlənilən ${e.origin} ${n}${e.minimum.toString()} ${r.unit}`:`Çox kiçik: gözlənilən ${e.origin} ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Yanlış mətn: "${t.prefix}" ilə başlamalıdır`:"ends_with"===t.format?`Yanlış mətn: "${t.suffix}" ilə bitməlidir`:"includes"===t.format?`Yanlış mətn: "${t.includes}" daxil olmalıdır`:"regex"===t.format?`Yanlış mətn: ${t.pattern} şablonuna uyğun olmalıdır`:`Yanlış ${n[t.format]??e.format}`
}case"not_multiple_of":
return`Yanlış ədəd: ${e.divisor} ilə bölünə bilən olmalıdır`
;case"unrecognized_keys":
return`Tanınmayan açar${e.keys.length>1?"lar":""}: ${l(e.keys,", ")}`
;case"invalid_key":return`${e.origin} daxilində yanlış açar`
;case"invalid_union":default:return"Yanlış dəyər";case"invalid_element":
return`${e.origin} daxilində yanlış dəyər`}}};function Vr(e,t,n,r){
const o=Math.abs(e),a=o%10,i=o%100;return i>=11&&i<=19?r:1===a?t:a>=2&&a<=4?n:r}
const qr=()=>{const e={string:{unit:{one:"сімвал",few:"сімвалы",many:"сімвалаў"
},verb:"мець"},array:{unit:{one:"элемент",few:"элементы",many:"элементаў"},
verb:"мець"},set:{unit:{one:"элемент",few:"элементы",many:"элементаў"},
verb:"мець"},file:{unit:{one:"байт",few:"байты",many:"байтаў"},verb:"мець"}}
;function t(t){return e[t]??null}const n={regex:"увод",email:"email адрас",
url:"URL",emoji:"эмодзі",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",
nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",
ksuid:"KSUID",datetime:"ISO дата і час",date:"ISO дата",time:"ISO час",
duration:"ISO працягласць",ipv4:"IPv4 адрас",ipv6:"IPv6 адрас",
cidrv4:"IPv4 дыяпазон",cidrv6:"IPv6 дыяпазон",base64:"радок у фармаце base64",
base64url:"радок у фармаце base64url",json_string:"JSON радок",
e164:"нумар E.164",jwt:"JWT",template_literal:"увод"},r={nan:"NaN",number:"лік",
array:"масіў"};return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Няправільны ўвод: чакаўся instanceof ${e.expected}, атрымана ${o}`:`Няправільны ўвод: чакаўся ${t}, атрымана ${o}`
}case"invalid_value":
return 1===e.values.length?`Няправільны ўвод: чакалася ${$(e.values[0])}`:`Няправільны варыянт: чакаўся адзін з ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin);if(r){
const t=Vr(Number(e.maximum),r.unit.one,r.unit.few,r.unit.many)
;return`Занадта вялікі: чакалася, што ${e.origin??"значэнне"} павінна ${r.verb} ${n}${e.maximum.toString()} ${t}`
}
return`Занадта вялікі: чакалася, што ${e.origin??"значэнне"} павінна быць ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin);if(r){
const t=Vr(Number(e.minimum),r.unit.one,r.unit.few,r.unit.many)
;return`Занадта малы: чакалася, што ${e.origin} павінна ${r.verb} ${n}${e.minimum.toString()} ${t}`
}
return`Занадта малы: чакалася, што ${e.origin} павінна быць ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Няправільны радок: павінен пачынацца з "${t.prefix}"`:"ends_with"===t.format?`Няправільны радок: павінен заканчвацца на "${t.suffix}"`:"includes"===t.format?`Няправільны радок: павінен змяшчаць "${t.includes}"`:"regex"===t.format?`Няправільны радок: павінен адпавядаць шаблону ${t.pattern}`:`Няправільны ${n[t.format]??e.format}`
}case"not_multiple_of":
return`Няправільны лік: павінен быць кратным ${e.divisor}`
;case"unrecognized_keys":
return`Нераспазнаны ${e.keys.length>1?"ключы":"ключ"}: ${l(e.keys,", ")}`
;case"invalid_key":return`Няправільны ключ у ${e.origin}`;case"invalid_union":
default:return"Няправільны ўвод";case"invalid_element":
return`Няправільнае значэнне ў ${e.origin}`}}};const Wr=()=>{const e={string:{
unit:"символа",verb:"да съдържа"},file:{unit:"байта",verb:"да съдържа"},array:{
unit:"елемента",verb:"да съдържа"},set:{unit:"елемента",verb:"да съдържа"}}
;function t(t){return e[t]??null}const n={regex:"вход",email:"имейл адрес",
url:"URL",emoji:"емоджи",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",
nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",
ksuid:"KSUID",datetime:"ISO време",date:"ISO дата",time:"ISO време",
duration:"ISO продължителност",ipv4:"IPv4 адрес",ipv6:"IPv6 адрес",
cidrv4:"IPv4 диапазон",cidrv6:"IPv6 диапазон",base64:"base64-кодиран низ",
base64url:"base64url-кодиран низ",json_string:"JSON низ",e164:"E.164 номер",
jwt:"JWT",template_literal:"вход"},r={nan:"NaN",number:"число",array:"масив"}
;return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Невалиден вход: очакван instanceof ${e.expected}, получен ${o}`:`Невалиден вход: очакван ${t}, получен ${o}`
}case"invalid_value":
return 1===e.values.length?`Невалиден вход: очакван ${$(e.values[0])}`:`Невалидна опция: очаквано едно от ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Твърде голямо: очаква се ${e.origin??"стойност"} да съдържа ${n}${e.maximum.toString()} ${r.unit??"елемента"}`:`Твърде голямо: очаква се ${e.origin??"стойност"} да бъде ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Твърде малко: очаква се ${e.origin} да съдържа ${n}${e.minimum.toString()} ${r.unit}`:`Твърде малко: очаква се ${e.origin} да бъде ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;if("starts_with"===t.format)return`Невалиден низ: трябва да започва с "${t.prefix}"`
;if("ends_with"===t.format)return`Невалиден низ: трябва да завършва с "${t.suffix}"`
;if("includes"===t.format)return`Невалиден низ: трябва да включва "${t.includes}"`
;if("regex"===t.format)return`Невалиден низ: трябва да съвпада с ${t.pattern}`
;let r="Невалиден"
;return"emoji"===t.format&&(r="Невалидно"),"datetime"===t.format&&(r="Невалидно"),
"date"===t.format&&(r="Невалидна"),
"time"===t.format&&(r="Невалидно"),"duration"===t.format&&(r="Невалидна"),
`${r} ${n[t.format]??e.format}`}case"not_multiple_of":
return`Невалидно число: трябва да бъде кратно на ${e.divisor}`
;case"unrecognized_keys":
return`Неразпознат${e.keys.length>1?"и":""} ключ${e.keys.length>1?"ове":""}: ${l(e.keys,", ")}`
;case"invalid_key":return`Невалиден ключ в ${e.origin}`;case"invalid_union":
default:return"Невалиден вход";case"invalid_element":
return`Невалидна стойност в ${e.origin}`}}};const Xr=()=>{const e={string:{
unit:"caràcters",verb:"contenir"},file:{unit:"bytes",verb:"contenir"},array:{
unit:"elements",verb:"contenir"},set:{unit:"elements",verb:"contenir"}}
;function t(t){return e[t]??null}const n={regex:"entrada",
email:"adreça electrònica",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",
uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",
ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"data i hora ISO",date:"data ISO",
time:"hora ISO",duration:"durada ISO",ipv4:"adreça IPv4",ipv6:"adreça IPv6",
cidrv4:"rang IPv4",cidrv6:"rang IPv6",base64:"cadena codificada en base64",
base64url:"cadena codificada en base64url",json_string:"cadena JSON",
e164:"número E.164",jwt:"JWT",template_literal:"entrada"},r={nan:"NaN"}
;return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Tipus invàlid: s'esperava instanceof ${e.expected}, s'ha rebut ${o}`:`Tipus invàlid: s'esperava ${t}, s'ha rebut ${o}`
}case"invalid_value":
return 1===e.values.length?`Valor invàlid: s'esperava ${$(e.values[0])}`:`Opció invàlida: s'esperava una de ${l(e.values," o ")}`
;case"too_big":{const n=e.inclusive?"com a màxim":"menys de",r=t(e.origin)
;return r?`Massa gran: s'esperava que ${e.origin??"el valor"} contingués ${n} ${e.maximum.toString()} ${r.unit??"elements"}`:`Massa gran: s'esperava que ${e.origin??"el valor"} fos ${n} ${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?"com a mínim":"més de",r=t(e.origin)
;return r?`Massa petit: s'esperava que ${e.origin} contingués ${n} ${e.minimum.toString()} ${r.unit}`:`Massa petit: s'esperava que ${e.origin} fos ${n} ${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Format invàlid: ha de començar amb "${t.prefix}"`:"ends_with"===t.format?`Format invàlid: ha d'acabar amb "${t.suffix}"`:"includes"===t.format?`Format invàlid: ha d'incloure "${t.includes}"`:"regex"===t.format?`Format invàlid: ha de coincidir amb el patró ${t.pattern}`:`Format invàlid per a ${n[t.format]??e.format}`
}case"not_multiple_of":
return`Número invàlid: ha de ser múltiple de ${e.divisor}`
;case"unrecognized_keys":
return`Clau${e.keys.length>1?"s":""} no reconeguda${e.keys.length>1?"s":""}: ${l(e.keys,", ")}`
;case"invalid_key":return`Clau invàlida a ${e.origin}`;case"invalid_union":
default:return"Entrada invàlida";case"invalid_element":
return`Element invàlid a ${e.origin}`}}};const Gr=()=>{const e={string:{
unit:"znaků",verb:"mít"},file:{unit:"bajtů",verb:"mít"},array:{unit:"prvků",
verb:"mít"},set:{unit:"prvků",verb:"mít"}};function t(t){return e[t]??null}
const n={regex:"regulární výraz",email:"e-mailová adresa",url:"URL",
emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",
guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",
datetime:"datum a čas ve formátu ISO",date:"datum ve formátu ISO",
time:"čas ve formátu ISO",duration:"doba trvání ISO",ipv4:"IPv4 adresa",
ipv6:"IPv6 adresa",cidrv4:"rozsah IPv4",cidrv6:"rozsah IPv6",
base64:"řetězec zakódovaný ve formátu base64",
base64url:"řetězec zakódovaný ve formátu base64url",
json_string:"řetězec ve formátu JSON",e164:"číslo E.164",jwt:"JWT",
template_literal:"vstup"},r={nan:"NaN",number:"číslo",string:"řetězec",
function:"funkce",array:"pole"};return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Neplatný vstup: očekáváno instanceof ${e.expected}, obdrženo ${o}`:`Neplatný vstup: očekáváno ${t}, obdrženo ${o}`
}case"invalid_value":
return 1===e.values.length?`Neplatný vstup: očekáváno ${$(e.values[0])}`:`Neplatná možnost: očekávána jedna z hodnot ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Hodnota je příliš velká: ${e.origin??"hodnota"} musí mít ${n}${e.maximum.toString()} ${r.unit??"prvků"}`:`Hodnota je příliš velká: ${e.origin??"hodnota"} musí být ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Hodnota je příliš malá: ${e.origin??"hodnota"} musí mít ${n}${e.minimum.toString()} ${r.unit??"prvků"}`:`Hodnota je příliš malá: ${e.origin??"hodnota"} musí být ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Neplatný řetězec: musí začínat na "${t.prefix}"`:"ends_with"===t.format?`Neplatný řetězec: musí končit na "${t.suffix}"`:"includes"===t.format?`Neplatný řetězec: musí obsahovat "${t.includes}"`:"regex"===t.format?`Neplatný řetězec: musí odpovídat vzoru ${t.pattern}`:`Neplatný formát ${n[t.format]??e.format}`
}case"not_multiple_of":return`Neplatné číslo: musí být násobkem ${e.divisor}`
;case"unrecognized_keys":return`Neznámé klíče: ${l(e.keys,", ")}`
;case"invalid_key":return`Neplatný klíč v ${e.origin}`;case"invalid_union":
default:return"Neplatný vstup";case"invalid_element":
return`Neplatná hodnota v ${e.origin}`}}};const Yr=()=>{const e={string:{
unit:"tegn",verb:"havde"},file:{unit:"bytes",verb:"havde"},array:{
unit:"elementer",verb:"indeholdt"},set:{unit:"elementer",verb:"indeholdt"}}
;function t(t){return e[t]??null}const n={regex:"input",email:"e-mailadresse",
url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",
nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",
ksuid:"KSUID",datetime:"ISO dato- og klokkeslæt",date:"ISO-dato",
time:"ISO-klokkeslæt",duration:"ISO-varighed",ipv4:"IPv4-område",
ipv6:"IPv6-område",cidrv4:"IPv4-spektrum",cidrv6:"IPv6-spektrum",
base64:"base64-kodet streng",base64url:"base64url-kodet streng",
json_string:"JSON-streng",e164:"E.164-nummer",jwt:"JWT",template_literal:"input"
},r={nan:"NaN",string:"streng",number:"tal",boolean:"boolean",array:"liste",
object:"objekt",set:"sæt",file:"fil"};return e=>{switch(e.code){
case"invalid_type":{const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Ugyldigt input: forventede instanceof ${e.expected}, fik ${o}`:`Ugyldigt input: forventede ${t}, fik ${o}`
}case"invalid_value":
return 1===e.values.length?`Ugyldig værdi: forventede ${$(e.values[0])}`:`Ugyldigt valg: forventede en af følgende ${l(e.values,"|")}`
;case"too_big":{
const n=e.inclusive?"<=":"<",o=t(e.origin),a=r[e.origin]??e.origin
;return o?`For stor: forventede ${a??"value"} ${o.verb} ${n} ${e.maximum.toString()} ${o.unit??"elementer"}`:`For stor: forventede ${a??"value"} havde ${n} ${e.maximum.toString()}`
}case"too_small":{
const n=e.inclusive?">=":">",o=t(e.origin),a=r[e.origin]??e.origin
;return o?`For lille: forventede ${a} ${o.verb} ${n} ${e.minimum.toString()} ${o.unit}`:`For lille: forventede ${a} havde ${n} ${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Ugyldig streng: skal starte med "${t.prefix}"`:"ends_with"===t.format?`Ugyldig streng: skal ende med "${t.suffix}"`:"includes"===t.format?`Ugyldig streng: skal indeholde "${t.includes}"`:"regex"===t.format?`Ugyldig streng: skal matche mønsteret ${t.pattern}`:`Ugyldig ${n[t.format]??e.format}`
}case"not_multiple_of":return`Ugyldigt tal: skal være deleligt med ${e.divisor}`
;case"unrecognized_keys":
return`${e.keys.length>1?"Ukendte nøgler":"Ukendt nøgle"}: ${l(e.keys,", ")}`
;case"invalid_key":return`Ugyldig nøgle i ${e.origin}`;case"invalid_union":
return"Ugyldigt input: matcher ingen af de tilladte typer"
;case"invalid_element":return`Ugyldig værdi i ${e.origin}`;default:
return"Ugyldigt input"}}};const Kr=()=>{const e={string:{unit:"Zeichen",
verb:"zu haben"},file:{unit:"Bytes",verb:"zu haben"},array:{unit:"Elemente",
verb:"zu haben"},set:{unit:"Elemente",verb:"zu haben"}};function t(t){
return e[t]??null}const n={regex:"Eingabe",email:"E-Mail-Adresse",url:"URL",
emoji:"Emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",
guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",
datetime:"ISO-Datum und -Uhrzeit",date:"ISO-Datum",time:"ISO-Uhrzeit",
duration:"ISO-Dauer",ipv4:"IPv4-Adresse",ipv6:"IPv6-Adresse",
cidrv4:"IPv4-Bereich",cidrv6:"IPv6-Bereich",base64:"Base64-codierter String",
base64url:"Base64-URL-codierter String",json_string:"JSON-String",
e164:"E.164-Nummer",jwt:"JWT",template_literal:"Eingabe"},r={nan:"NaN",
number:"Zahl",array:"Array"};return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Ungültige Eingabe: erwartet instanceof ${e.expected}, erhalten ${o}`:`Ungültige Eingabe: erwartet ${t}, erhalten ${o}`
}case"invalid_value":
return 1===e.values.length?`Ungültige Eingabe: erwartet ${$(e.values[0])}`:`Ungültige Option: erwartet eine von ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Zu groß: erwartet, dass ${e.origin??"Wert"} ${n}${e.maximum.toString()} ${r.unit??"Elemente"} hat`:`Zu groß: erwartet, dass ${e.origin??"Wert"} ${n}${e.maximum.toString()} ist`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Zu klein: erwartet, dass ${e.origin} ${n}${e.minimum.toString()} ${r.unit} hat`:`Zu klein: erwartet, dass ${e.origin} ${n}${e.minimum.toString()} ist`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Ungültiger String: muss mit "${t.prefix}" beginnen`:"ends_with"===t.format?`Ungültiger String: muss mit "${t.suffix}" enden`:"includes"===t.format?`Ungültiger String: muss "${t.includes}" enthalten`:"regex"===t.format?`Ungültiger String: muss dem Muster ${t.pattern} entsprechen`:`Ungültig: ${n[t.format]??e.format}`
}case"not_multiple_of":
return`Ungültige Zahl: muss ein Vielfaches von ${e.divisor} sein`
;case"unrecognized_keys":
return`${e.keys.length>1?"Unbekannte Schlüssel":"Unbekannter Schlüssel"}: ${l(e.keys,", ")}`
;case"invalid_key":return`Ungültiger Schlüssel in ${e.origin}`
;case"invalid_union":default:return"Ungültige Eingabe";case"invalid_element":
return`Ungültiger Wert in ${e.origin}`}}};const Jr=()=>{const e={string:{
unit:"characters",verb:"to have"},file:{unit:"bytes",verb:"to have"},array:{
unit:"items",verb:"to have"},set:{unit:"items",verb:"to have"},map:{
unit:"entries",verb:"to have"}};function t(t){return e[t]??null}const n={
regex:"input",email:"email address",url:"URL",emoji:"emoji",uuid:"UUID",
uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",
cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO datetime",
date:"ISO date",time:"ISO time",duration:"ISO duration",ipv4:"IPv4 address",
ipv6:"IPv6 address",mac:"MAC address",cidrv4:"IPv4 range",cidrv6:"IPv6 range",
base64:"base64-encoded string",base64url:"base64url-encoded string",
json_string:"JSON string",e164:"E.164 number",jwt:"JWT",template_literal:"input"
},r={nan:"NaN"};return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input)
;return`Invalid input: expected ${t}, received ${r[n]??n}`}case"invalid_value":
return 1===e.values.length?`Invalid input: expected ${$(e.values[0])}`:`Invalid option: expected one of ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Too big: expected ${e.origin??"value"} to have ${n}${e.maximum.toString()} ${r.unit??"elements"}`:`Too big: expected ${e.origin??"value"} to be ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Too small: expected ${e.origin} to have ${n}${e.minimum.toString()} ${r.unit}`:`Too small: expected ${e.origin} to be ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Invalid string: must start with "${t.prefix}"`:"ends_with"===t.format?`Invalid string: must end with "${t.suffix}"`:"includes"===t.format?`Invalid string: must include "${t.includes}"`:"regex"===t.format?`Invalid string: must match pattern ${t.pattern}`:`Invalid ${n[t.format]??e.format}`
}case"not_multiple_of":
return`Invalid number: must be a multiple of ${e.divisor}`
;case"unrecognized_keys":
return`Unrecognized key${e.keys.length>1?"s":""}: ${l(e.keys,", ")}`
;case"invalid_key":return`Invalid key in ${e.origin}`;case"invalid_union":
default:return"Invalid input";case"invalid_element":
return`Invalid value in ${e.origin}`}}};function eo(){return{localeError:Jr()}}
const to=()=>{const e={string:{unit:"karaktrojn",verb:"havi"},file:{
unit:"bajtojn",verb:"havi"},array:{unit:"elementojn",verb:"havi"},set:{
unit:"elementojn",verb:"havi"}};function t(t){return e[t]??null}const n={
regex:"enigo",email:"retadreso",url:"URL",emoji:"emoĝio",uuid:"UUID",
uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",
cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO-datotempo",
date:"ISO-dato",time:"ISO-tempo",duration:"ISO-daŭro",ipv4:"IPv4-adreso",
ipv6:"IPv6-adreso",cidrv4:"IPv4-rango",cidrv6:"IPv6-rango",
base64:"64-ume kodita karaktraro",base64url:"URL-64-ume kodita karaktraro",
json_string:"JSON-karaktraro",e164:"E.164-nombro",jwt:"JWT",
template_literal:"enigo"},r={nan:"NaN",number:"nombro",array:"tabelo",
null:"senvalora"};return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Nevalida enigo: atendiĝis instanceof ${e.expected}, riceviĝis ${o}`:`Nevalida enigo: atendiĝis ${t}, riceviĝis ${o}`
}case"invalid_value":
return 1===e.values.length?`Nevalida enigo: atendiĝis ${$(e.values[0])}`:`Nevalida opcio: atendiĝis unu el ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Tro granda: atendiĝis ke ${e.origin??"valoro"} havu ${n}${e.maximum.toString()} ${r.unit??"elementojn"}`:`Tro granda: atendiĝis ke ${e.origin??"valoro"} havu ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Tro malgranda: atendiĝis ke ${e.origin} havu ${n}${e.minimum.toString()} ${r.unit}`:`Tro malgranda: atendiĝis ke ${e.origin} estu ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Nevalida karaktraro: devas komenciĝi per "${t.prefix}"`:"ends_with"===t.format?`Nevalida karaktraro: devas finiĝi per "${t.suffix}"`:"includes"===t.format?`Nevalida karaktraro: devas inkluzivi "${t.includes}"`:"regex"===t.format?`Nevalida karaktraro: devas kongrui kun la modelo ${t.pattern}`:`Nevalida ${n[t.format]??e.format}`
}case"not_multiple_of":return`Nevalida nombro: devas esti oblo de ${e.divisor}`
;case"unrecognized_keys":
return`Nekonata${e.keys.length>1?"j":""} ŝlosilo${e.keys.length>1?"j":""}: ${l(e.keys,", ")}`
;case"invalid_key":return`Nevalida ŝlosilo en ${e.origin}`;case"invalid_union":
default:return"Nevalida enigo";case"invalid_element":
return`Nevalida valoro en ${e.origin}`}}};const no=()=>{const e={string:{
unit:"caracteres",verb:"tener"},file:{unit:"bytes",verb:"tener"},array:{
unit:"elementos",verb:"tener"},set:{unit:"elementos",verb:"tener"}}
;function t(t){return e[t]??null}const n={regex:"entrada",
email:"dirección de correo electrónico",url:"URL",emoji:"emoji",uuid:"UUID",
uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",
cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"fecha y hora ISO",
date:"fecha ISO",time:"hora ISO",duration:"duración ISO",ipv4:"dirección IPv4",
ipv6:"dirección IPv6",cidrv4:"rango IPv4",cidrv6:"rango IPv6",
base64:"cadena codificada en base64",base64url:"URL codificada en base64",
json_string:"cadena JSON",e164:"número E.164",jwt:"JWT",
template_literal:"entrada"},r={nan:"NaN",string:"texto",number:"número",
boolean:"booleano",array:"arreglo",object:"objeto",set:"conjunto",
file:"archivo",date:"fecha",bigint:"número grande",symbol:"símbolo",
undefined:"indefinido",null:"nulo",function:"función",map:"mapa",
record:"registro",tuple:"tupla",enum:"enumeración",union:"unión",
literal:"literal",promise:"promesa",void:"vacío",never:"nunca",
unknown:"desconocido",any:"cualquiera"};return e=>{switch(e.code){
case"invalid_type":{const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Entrada inválida: se esperaba instanceof ${e.expected}, recibido ${o}`:`Entrada inválida: se esperaba ${t}, recibido ${o}`
}case"invalid_value":
return 1===e.values.length?`Entrada inválida: se esperaba ${$(e.values[0])}`:`Opción inválida: se esperaba una de ${l(e.values,"|")}`
;case"too_big":{
const n=e.inclusive?"<=":"<",o=t(e.origin),a=r[e.origin]??e.origin
;return o?`Demasiado grande: se esperaba que ${a??"valor"} tuviera ${n}${e.maximum.toString()} ${o.unit??"elementos"}`:`Demasiado grande: se esperaba que ${a??"valor"} fuera ${n}${e.maximum.toString()}`
}case"too_small":{
const n=e.inclusive?">=":">",o=t(e.origin),a=r[e.origin]??e.origin
;return o?`Demasiado pequeño: se esperaba que ${a} tuviera ${n}${e.minimum.toString()} ${o.unit}`:`Demasiado pequeño: se esperaba que ${a} fuera ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Cadena inválida: debe comenzar con "${t.prefix}"`:"ends_with"===t.format?`Cadena inválida: debe terminar en "${t.suffix}"`:"includes"===t.format?`Cadena inválida: debe incluir "${t.includes}"`:"regex"===t.format?`Cadena inválida: debe coincidir con el patrón ${t.pattern}`:`Inválido ${n[t.format]??e.format}`
}case"not_multiple_of":
return`Número inválido: debe ser múltiplo de ${e.divisor}`
;case"unrecognized_keys":
return`Llave${e.keys.length>1?"s":""} desconocida${e.keys.length>1?"s":""}: ${l(e.keys,", ")}`
;case"invalid_key":return`Llave inválida en ${r[e.origin]??e.origin}`
;case"invalid_union":default:return"Entrada inválida";case"invalid_element":
return`Valor inválido en ${r[e.origin]??e.origin}`}}};const ro=()=>{const e={
string:{unit:"کاراکتر",verb:"داشته باشد"},file:{unit:"بایت",verb:"داشته باشد"},
array:{unit:"آیتم",verb:"داشته باشد"},set:{unit:"آیتم",verb:"داشته باشد"}}
;function t(t){return e[t]??null}const n={regex:"ورودی",email:"آدرس ایمیل",
url:"URL",emoji:"ایموجی",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",
nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",
ksuid:"KSUID",datetime:"تاریخ و زمان ایزو",date:"تاریخ ایزو",time:"زمان ایزو",
duration:"مدت زمان ایزو",ipv4:"IPv4 آدرس",ipv6:"IPv6 آدرس",cidrv4:"IPv4 دامنه",
cidrv6:"IPv6 دامنه",base64:"base64-encoded رشته",
base64url:"base64url-encoded رشته",json_string:"JSON رشته",e164:"E.164 عدد",
jwt:"JWT",template_literal:"ورودی"},r={nan:"NaN",number:"عدد",array:"آرایه"}
;return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`ورودی نامعتبر: می‌بایست instanceof ${e.expected} می‌بود، ${o} دریافت شد`:`ورودی نامعتبر: می‌بایست ${t} می‌بود، ${o} دریافت شد`
}case"invalid_value":
return 1===e.values.length?`ورودی نامعتبر: می‌بایست ${$(e.values[0])} می‌بود`:`گزینه نامعتبر: می‌بایست یکی از ${l(e.values,"|")} می‌بود`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`خیلی بزرگ: ${e.origin??"مقدار"} باید ${n}${e.maximum.toString()} ${r.unit??"عنصر"} باشد`:`خیلی بزرگ: ${e.origin??"مقدار"} باید ${n}${e.maximum.toString()} باشد`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`خیلی کوچک: ${e.origin} باید ${n}${e.minimum.toString()} ${r.unit} باشد`:`خیلی کوچک: ${e.origin} باید ${n}${e.minimum.toString()} باشد`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`رشته نامعتبر: باید با "${t.prefix}" شروع شود`:"ends_with"===t.format?`رشته نامعتبر: باید با "${t.suffix}" تمام شود`:"includes"===t.format?`رشته نامعتبر: باید شامل "${t.includes}" باشد`:"regex"===t.format?`رشته نامعتبر: باید با الگوی ${t.pattern} مطابقت داشته باشد`:`${n[t.format]??e.format} نامعتبر`
}case"not_multiple_of":return`عدد نامعتبر: باید مضرب ${e.divisor} باشد`
;case"unrecognized_keys":
return`کلید${e.keys.length>1?"های":""} ناشناس: ${l(e.keys,", ")}`
;case"invalid_key":return`کلید ناشناس در ${e.origin}`;case"invalid_union":
default:return"ورودی نامعتبر";case"invalid_element":
return`مقدار نامعتبر در ${e.origin}`}}};const oo=()=>{const e={string:{
unit:"merkkiä",subject:"merkkijonon"},file:{unit:"tavua",subject:"tiedoston"},
array:{unit:"alkiota",subject:"listan"},set:{unit:"alkiota",subject:"joukon"},
number:{unit:"",subject:"luvun"},bigint:{unit:"",subject:"suuren kokonaisluvun"
},int:{unit:"",subject:"kokonaisluvun"},date:{unit:"",subject:"päivämäärän"}}
;function t(t){return e[t]??null}const n={regex:"säännöllinen lauseke",
email:"sähköpostiosoite",url:"URL-osoite",emoji:"emoji",uuid:"UUID",
uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",
cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO-aikaleima",
date:"ISO-päivämäärä",time:"ISO-aika",duration:"ISO-kesto",ipv4:"IPv4-osoite",
ipv6:"IPv6-osoite",cidrv4:"IPv4-alue",cidrv6:"IPv6-alue",
base64:"base64-koodattu merkkijono",base64url:"base64url-koodattu merkkijono",
json_string:"JSON-merkkijono",e164:"E.164-luku",jwt:"JWT",
template_literal:"templaattimerkkijono"},r={nan:"NaN"};return e=>{
switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Virheellinen tyyppi: odotettiin instanceof ${e.expected}, oli ${o}`:`Virheellinen tyyppi: odotettiin ${t}, oli ${o}`
}case"invalid_value":
return 1===e.values.length?`Virheellinen syöte: täytyy olla ${$(e.values[0])}`:`Virheellinen valinta: täytyy olla yksi seuraavista: ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Liian suuri: ${r.subject} täytyy olla ${n}${e.maximum.toString()} ${r.unit}`.trim():`Liian suuri: arvon täytyy olla ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Liian pieni: ${r.subject} täytyy olla ${n}${e.minimum.toString()} ${r.unit}`.trim():`Liian pieni: arvon täytyy olla ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Virheellinen syöte: täytyy alkaa "${t.prefix}"`:"ends_with"===t.format?`Virheellinen syöte: täytyy loppua "${t.suffix}"`:"includes"===t.format?`Virheellinen syöte: täytyy sisältää "${t.includes}"`:"regex"===t.format?`Virheellinen syöte: täytyy vastata säännöllistä lauseketta ${t.pattern}`:`Virheellinen ${n[t.format]??e.format}`
}case"not_multiple_of":
return`Virheellinen luku: täytyy olla luvun ${e.divisor} monikerta`
;case"unrecognized_keys":
return`${e.keys.length>1?"Tuntemattomat avaimet":"Tuntematon avain"}: ${l(e.keys,", ")}`
;case"invalid_key":return"Virheellinen avain tietueessa";case"invalid_union":
return"Virheellinen unioni";case"invalid_element":
return"Virheellinen arvo joukossa";default:return"Virheellinen syöte"}}}
;const ao=()=>{const e={string:{unit:"caractères",verb:"avoir"},file:{
unit:"octets",verb:"avoir"},array:{unit:"éléments",verb:"avoir"},set:{
unit:"éléments",verb:"avoir"}};function t(t){return e[t]??null}const n={
regex:"entrée",email:"adresse e-mail",url:"URL",emoji:"emoji",uuid:"UUID",
uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",
cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"date et heure ISO",
date:"date ISO",time:"heure ISO",duration:"durée ISO",ipv4:"adresse IPv4",
ipv6:"adresse IPv6",cidrv4:"plage IPv4",cidrv6:"plage IPv6",
base64:"chaîne encodée en base64",base64url:"chaîne encodée en base64url",
json_string:"chaîne JSON",e164:"numéro E.164",jwt:"JWT",
template_literal:"entrée"},r={nan:"NaN",number:"nombre",array:"tableau"}
;return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Entrée invalide : instanceof ${e.expected} attendu, ${o} reçu`:`Entrée invalide : ${t} attendu, ${o} reçu`
}case"invalid_value":
return 1===e.values.length?`Entrée invalide : ${$(e.values[0])} attendu`:`Option invalide : une valeur parmi ${l(e.values,"|")} attendue`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Trop grand : ${e.origin??"valeur"} doit ${r.verb} ${n}${e.maximum.toString()} ${r.unit??"élément(s)"}`:`Trop grand : ${e.origin??"valeur"} doit être ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Trop petit : ${e.origin} doit ${r.verb} ${n}${e.minimum.toString()} ${r.unit}`:`Trop petit : ${e.origin} doit être ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Chaîne invalide : doit commencer par "${t.prefix}"`:"ends_with"===t.format?`Chaîne invalide : doit se terminer par "${t.suffix}"`:"includes"===t.format?`Chaîne invalide : doit inclure "${t.includes}"`:"regex"===t.format?`Chaîne invalide : doit correspondre au modèle ${t.pattern}`:`${n[t.format]??e.format} invalide`
}case"not_multiple_of":
return`Nombre invalide : doit être un multiple de ${e.divisor}`
;case"unrecognized_keys":
return`Clé${e.keys.length>1?"s":""} non reconnue${e.keys.length>1?"s":""} : ${l(e.keys,", ")}`
;case"invalid_key":return`Clé invalide dans ${e.origin}`;case"invalid_union":
default:return"Entrée invalide";case"invalid_element":
return`Valeur invalide dans ${e.origin}`}}};const io=()=>{const e={string:{
unit:"caractères",verb:"avoir"},file:{unit:"octets",verb:"avoir"},array:{
unit:"éléments",verb:"avoir"},set:{unit:"éléments",verb:"avoir"}};function t(t){
return e[t]??null}const n={regex:"entrée",email:"adresse courriel",url:"URL",
emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",
guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",
datetime:"date-heure ISO",date:"date ISO",time:"heure ISO",duration:"durée ISO",
ipv4:"adresse IPv4",ipv6:"adresse IPv6",cidrv4:"plage IPv4",cidrv6:"plage IPv6",
base64:"chaîne encodée en base64",base64url:"chaîne encodée en base64url",
json_string:"chaîne JSON",e164:"numéro E.164",jwt:"JWT",
template_literal:"entrée"},r={nan:"NaN"};return e=>{switch(e.code){
case"invalid_type":{const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Entrée invalide : attendu instanceof ${e.expected}, reçu ${o}`:`Entrée invalide : attendu ${t}, reçu ${o}`
}case"invalid_value":
return 1===e.values.length?`Entrée invalide : attendu ${$(e.values[0])}`:`Option invalide : attendu l'une des valeurs suivantes ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"≤":"<",r=t(e.origin)
;return r?`Trop grand : attendu que ${e.origin??"la valeur"} ait ${n}${e.maximum.toString()} ${r.unit}`:`Trop grand : attendu que ${e.origin??"la valeur"} soit ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?"≥":">",r=t(e.origin)
;return r?`Trop petit : attendu que ${e.origin} ait ${n}${e.minimum.toString()} ${r.unit}`:`Trop petit : attendu que ${e.origin} soit ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Chaîne invalide : doit commencer par "${t.prefix}"`:"ends_with"===t.format?`Chaîne invalide : doit se terminer par "${t.suffix}"`:"includes"===t.format?`Chaîne invalide : doit inclure "${t.includes}"`:"regex"===t.format?`Chaîne invalide : doit correspondre au motif ${t.pattern}`:`${n[t.format]??e.format} invalide`
}case"not_multiple_of":
return`Nombre invalide : doit être un multiple de ${e.divisor}`
;case"unrecognized_keys":
return`Clé${e.keys.length>1?"s":""} non reconnue${e.keys.length>1?"s":""} : ${l(e.keys,", ")}`
;case"invalid_key":return`Clé invalide dans ${e.origin}`;case"invalid_union":
default:return"Entrée invalide";case"invalid_element":
return`Valeur invalide dans ${e.origin}`}}};const so=()=>{const e={string:{
label:"מחרוזת",gender:"f"},number:{label:"מספר",gender:"m"},boolean:{
label:"ערך בוליאני",gender:"m"},bigint:{label:"BigInt",gender:"m"},date:{
label:"תאריך",gender:"m"},array:{label:"מערך",gender:"m"},object:{
label:"אובייקט",gender:"m"},null:{label:"ערך ריק (null)",gender:"m"},undefined:{
label:"ערך לא מוגדר (undefined)",gender:"m"},symbol:{label:"סימבול (Symbol)",
gender:"m"},function:{label:"פונקציה",gender:"f"},map:{label:"מפה (Map)",
gender:"f"},set:{label:"קבוצה (Set)",gender:"f"},file:{label:"קובץ",gender:"m"},
promise:{label:"Promise",gender:"m"},NaN:{label:"NaN",gender:"m"},unknown:{
label:"ערך לא ידוע",gender:"m"},value:{label:"ערך",gender:"m"}},t={string:{
unit:"תווים",shortLabel:"קצר",longLabel:"ארוך"},file:{unit:"בייטים",
shortLabel:"קטן",longLabel:"גדול"},array:{unit:"פריטים",shortLabel:"קטן",
longLabel:"גדול"},set:{unit:"פריטים",shortLabel:"קטן",longLabel:"גדול"},number:{
unit:"",shortLabel:"קטן",longLabel:"גדול"}},n=t=>t?e[t]:void 0,r=t=>{
const r=n(t);return r?r.label:t??e.unknown.label},o=e=>`ה${r(e)}`,a=e=>{
const t=n(e);return"f"===(t?.gender??"m")?"צריכה להיות":"צריך להיות"
},i=e=>e?t[e]??null:null,s={regex:{label:"קלט",gender:"m"},email:{
label:"כתובת אימייל",gender:"f"},url:{label:"כתובת רשת",gender:"f"},emoji:{
label:"אימוג'י",gender:"m"},uuid:{label:"UUID",gender:"m"},nanoid:{
label:"nanoid",gender:"m"},guid:{label:"GUID",gender:"m"},cuid:{label:"cuid",
gender:"m"},cuid2:{label:"cuid2",gender:"m"},ulid:{label:"ULID",gender:"m"},
xid:{label:"XID",gender:"m"},ksuid:{label:"KSUID",gender:"m"},datetime:{
label:"תאריך וזמן ISO",gender:"m"},date:{label:"תאריך ISO",gender:"m"},time:{
label:"זמן ISO",gender:"m"},duration:{label:"משך זמן ISO",gender:"m"},ipv4:{
label:"כתובת IPv4",gender:"f"},ipv6:{label:"כתובת IPv6",gender:"f"},cidrv4:{
label:"טווח IPv4",gender:"m"},cidrv6:{label:"טווח IPv6",gender:"m"},base64:{
label:"מחרוזת בבסיס 64",gender:"f"},base64url:{
label:"מחרוזת בבסיס 64 לכתובות רשת",gender:"f"},json_string:{
label:"מחרוזת JSON",gender:"f"},e164:{label:"מספר E.164",gender:"m"},jwt:{
label:"JWT",gender:"m"},ends_with:{label:"קלט",gender:"m"},includes:{
label:"קלט",gender:"m"},lowercase:{label:"קלט",gender:"m"},starts_with:{
label:"קלט",gender:"m"},uppercase:{label:"קלט",gender:"m"}},c={nan:"NaN"}
;return t=>{switch(t.code){case"invalid_type":{
const n=t.expected,o=c[n??""]??r(n),a=q(t.input),i=c[a]??e[a]?.label??a
;return/^[A-Z]/.test(t.expected)?`קלט לא תקין: צריך להיות instanceof ${t.expected}, התקבל ${i}`:`קלט לא תקין: צריך להיות ${o}, התקבל ${i}`
}case"invalid_value":{
if(1===t.values.length)return`ערך לא תקין: הערך חייב להיות ${$(t.values[0])}`
;const e=t.values.map((e=>$(e)))
;if(2===t.values.length)return`ערך לא תקין: האפשרויות המתאימות הן ${e[0]} או ${e[1]}`
;const n=e[e.length-1]
;return`ערך לא תקין: האפשרויות המתאימות הן ${e.slice(0,-1).join(", ")} או ${n}`}
case"too_big":{const e=i(t.origin),n=o(t.origin??"value")
;if("string"===t.origin)return`${e?.longLabel??"ארוך"} מדי: ${n} צריכה להכיל ${t.maximum.toString()} ${e?.unit??""} ${t.inclusive?"או פחות":"לכל היותר"}`.trim()
;if("number"===t.origin){
return`גדול מדי: ${n} צריך להיות ${t.inclusive?`קטן או שווה ל-${t.maximum}`:`קטן מ-${t.maximum}`}`
}if("array"===t.origin||"set"===t.origin){
return`גדול מדי: ${n} ${"set"===t.origin?"צריכה":"צריך"} להכיל ${t.inclusive?`${t.maximum} ${e?.unit??""} או פחות`:`פחות מ-${t.maximum} ${e?.unit??""}`}`.trim()
}const r=t.inclusive?"<=":"<",s=a(t.origin??"value")
;return e?.unit?`${e.longLabel} מדי: ${n} ${s} ${r}${t.maximum.toString()} ${e.unit}`:`${e?.longLabel??"גדול"} מדי: ${n} ${s} ${r}${t.maximum.toString()}`
}case"too_small":{const e=i(t.origin),n=o(t.origin??"value")
;if("string"===t.origin)return`${e?.shortLabel??"קצר"} מדי: ${n} צריכה להכיל ${t.minimum.toString()} ${e?.unit??""} ${t.inclusive?"או יותר":"לפחות"}`.trim()
;if("number"===t.origin){
return`קטן מדי: ${n} צריך להיות ${t.inclusive?`גדול או שווה ל-${t.minimum}`:`גדול מ-${t.minimum}`}`
}if("array"===t.origin||"set"===t.origin){
const r="set"===t.origin?"צריכה":"צריך";if(1===t.minimum&&t.inclusive){
return`קטן מדי: ${n} ${r} להכיל ${t.origin,"לפחות פריט אחד"}`}
return`קטן מדי: ${n} ${r} להכיל ${t.inclusive?`${t.minimum} ${e?.unit??""} או יותר`:`יותר מ-${t.minimum} ${e?.unit??""}`}`.trim()
}const r=t.inclusive?">=":">",s=a(t.origin??"value")
;return e?.unit?`${e.shortLabel} מדי: ${n} ${s} ${r}${t.minimum.toString()} ${e.unit}`:`${e?.shortLabel??"קטן"} מדי: ${n} ${s} ${r}${t.minimum.toString()}`
}case"invalid_format":{const e=t
;if("starts_with"===e.format)return`המחרוזת חייבת להתחיל ב "${e.prefix}"`
;if("ends_with"===e.format)return`המחרוזת חייבת להסתיים ב "${e.suffix}"`
;if("includes"===e.format)return`המחרוזת חייבת לכלול "${e.includes}"`
;if("regex"===e.format)return`המחרוזת חייבת להתאים לתבנית ${e.pattern}`
;const n=s[e.format]
;return`${n?.label??e.format} לא ${"f"===(n?.gender??"m")?"תקינה":"תקין"}`}
case"not_multiple_of":return`מספר לא תקין: חייב להיות מכפלה של ${t.divisor}`
;case"unrecognized_keys":
return`מפתח${t.keys.length>1?"ות":""} לא מזוה${t.keys.length>1?"ים":"ה"}: ${l(t.keys,", ")}`
;case"invalid_key":return"שדה לא תקין באובייקט";case"invalid_union":default:
return"קלט לא תקין";case"invalid_element":
return`ערך לא תקין ב${o(t.origin??"array")}`}}};const lo=()=>{const e={string:{
unit:"karakter",verb:"legyen"},file:{unit:"byte",verb:"legyen"},array:{
unit:"elem",verb:"legyen"},set:{unit:"elem",verb:"legyen"}};function t(t){
return e[t]??null}const n={regex:"bemenet",email:"email cím",url:"URL",
emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",
guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",
datetime:"ISO időbélyeg",date:"ISO dátum",time:"ISO idő",
duration:"ISO időintervallum",ipv4:"IPv4 cím",ipv6:"IPv6 cím",
cidrv4:"IPv4 tartomány",cidrv6:"IPv6 tartomány",base64:"base64-kódolt string",
base64url:"base64url-kódolt string",json_string:"JSON string",e164:"E.164 szám",
jwt:"JWT",template_literal:"bemenet"},r={nan:"NaN",number:"szám",array:"tömb"}
;return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Érvénytelen bemenet: a várt érték instanceof ${e.expected}, a kapott érték ${o}`:`Érvénytelen bemenet: a várt érték ${t}, a kapott érték ${o}`
}case"invalid_value":
return 1===e.values.length?`Érvénytelen bemenet: a várt érték ${$(e.values[0])}`:`Érvénytelen opció: valamelyik érték várt ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Túl nagy: ${e.origin??"érték"} mérete túl nagy ${n}${e.maximum.toString()} ${r.unit??"elem"}`:`Túl nagy: a bemeneti érték ${e.origin??"érték"} túl nagy: ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Túl kicsi: a bemeneti érték ${e.origin} mérete túl kicsi ${n}${e.minimum.toString()} ${r.unit}`:`Túl kicsi: a bemeneti érték ${e.origin} túl kicsi ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Érvénytelen string: "${t.prefix}" értékkel kell kezdődnie`:"ends_with"===t.format?`Érvénytelen string: "${t.suffix}" értékkel kell végződnie`:"includes"===t.format?`Érvénytelen string: "${t.includes}" értéket kell tartalmaznia`:"regex"===t.format?`Érvénytelen string: ${t.pattern} mintának kell megfelelnie`:`Érvénytelen ${n[t.format]??e.format}`
}case"not_multiple_of":
return`Érvénytelen szám: ${e.divisor} többszörösének kell lennie`
;case"unrecognized_keys":
return`Ismeretlen kulcs${e.keys.length>1?"s":""}: ${l(e.keys,", ")}`
;case"invalid_key":return`Érvénytelen kulcs ${e.origin}`;case"invalid_union":
default:return"Érvénytelen bemenet";case"invalid_element":
return`Érvénytelen érték: ${e.origin}`}}};function co(e,t,n){
return 1===Math.abs(e)?t:n}function uo(e){if(!e)return"";const t=e[e.length-1]
;return e+(["ա","ե","ը","ի","ո","ու","օ"].includes(t)?"ն":"ը")}const po=()=>{
const e={string:{unit:{one:"նշան",many:"նշաններ"},verb:"ունենալ"},file:{unit:{
one:"բայթ",many:"բայթեր"},verb:"ունենալ"},array:{unit:{one:"տարր",many:"տարրեր"
},verb:"ունենալ"},set:{unit:{one:"տարր",many:"տարրեր"},verb:"ունենալ"}}
;function t(t){return e[t]??null}const n={regex:"մուտք",email:"էլ. հասցե",
url:"URL",emoji:"էմոջի",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",
nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",
ksuid:"KSUID",datetime:"ISO ամսաթիվ և ժամ",date:"ISO ամսաթիվ",time:"ISO ժամ",
duration:"ISO տևողություն",ipv4:"IPv4 հասցե",ipv6:"IPv6 հասցե",
cidrv4:"IPv4 միջակայք",cidrv6:"IPv6 միջակայք",base64:"base64 ձևաչափով տող",
base64url:"base64url ձևաչափով տող",json_string:"JSON տող",e164:"E.164 համար",
jwt:"JWT",template_literal:"մուտք"},r={nan:"NaN",number:"թիվ",array:"զանգված"}
;return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Սխալ մուտքագրում․ սպասվում էր instanceof ${e.expected}, ստացվել է ${o}`:`Սխալ մուտքագրում․ սպասվում էր ${t}, ստացվել է ${o}`
}case"invalid_value":
return 1===e.values.length?`Սխալ մուտքագրում․ սպասվում էր ${$(e.values[1])}`:`Սխալ տարբերակ․ սպասվում էր հետևյալներից մեկը՝ ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin);if(r){
const t=co(Number(e.maximum),r.unit.one,r.unit.many)
;return`Չափազանց մեծ արժեք․ սպասվում է, որ ${uo(e.origin??"արժեք")} կունենա ${n}${e.maximum.toString()} ${t}`
}
return`Չափազանց մեծ արժեք․ սպասվում է, որ ${uo(e.origin??"արժեք")} լինի ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin);if(r){
const t=co(Number(e.minimum),r.unit.one,r.unit.many)
;return`Չափազանց փոքր արժեք․ սպասվում է, որ ${uo(e.origin)} կունենա ${n}${e.minimum.toString()} ${t}`
}
return`Չափազանց փոքր արժեք․ սպասվում է, որ ${uo(e.origin)} լինի ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Սխալ տող․ պետք է սկսվի "${t.prefix}"-ով`:"ends_with"===t.format?`Սխալ տող․ պետք է ավարտվի "${t.suffix}"-ով`:"includes"===t.format?`Սխալ տող․ պետք է պարունակի "${t.includes}"`:"regex"===t.format?`Սխալ տող․ պետք է համապատասխանի ${t.pattern} ձևաչափին`:`Սխալ ${n[t.format]??e.format}`
}case"not_multiple_of":return`Սխալ թիվ․ պետք է բազմապատիկ լինի ${e.divisor}-ի`
;case"unrecognized_keys":
return`Չճանաչված բանալի${e.keys.length>1?"ներ":""}. ${l(e.keys,", ")}`
;case"invalid_key":return`Սխալ բանալի ${uo(e.origin)}-ում`;case"invalid_union":
default:return"Սխալ մուտքագրում";case"invalid_element":
return`Սխալ արժեք ${uo(e.origin)}-ում`}}};const ho=()=>{const e={string:{
unit:"karakter",verb:"memiliki"},file:{unit:"byte",verb:"memiliki"},array:{
unit:"item",verb:"memiliki"},set:{unit:"item",verb:"memiliki"}};function t(t){
return e[t]??null}const n={regex:"input",email:"alamat email",url:"URL",
emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",
guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",
datetime:"tanggal dan waktu format ISO",date:"tanggal format ISO",
time:"jam format ISO",duration:"durasi format ISO",ipv4:"alamat IPv4",
ipv6:"alamat IPv6",cidrv4:"rentang alamat IPv4",cidrv6:"rentang alamat IPv6",
base64:"string dengan enkode base64",base64url:"string dengan enkode base64url",
json_string:"string JSON",e164:"angka E.164",jwt:"JWT",template_literal:"input"
},r={nan:"NaN"};return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Input tidak valid: diharapkan instanceof ${e.expected}, diterima ${o}`:`Input tidak valid: diharapkan ${t}, diterima ${o}`
}case"invalid_value":
return 1===e.values.length?`Input tidak valid: diharapkan ${$(e.values[0])}`:`Pilihan tidak valid: diharapkan salah satu dari ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Terlalu besar: diharapkan ${e.origin??"value"} memiliki ${n}${e.maximum.toString()} ${r.unit??"elemen"}`:`Terlalu besar: diharapkan ${e.origin??"value"} menjadi ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Terlalu kecil: diharapkan ${e.origin} memiliki ${n}${e.minimum.toString()} ${r.unit}`:`Terlalu kecil: diharapkan ${e.origin} menjadi ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`String tidak valid: harus dimulai dengan "${t.prefix}"`:"ends_with"===t.format?`String tidak valid: harus berakhir dengan "${t.suffix}"`:"includes"===t.format?`String tidak valid: harus menyertakan "${t.includes}"`:"regex"===t.format?`String tidak valid: harus sesuai pola ${t.pattern}`:`${n[t.format]??e.format} tidak valid`
}case"not_multiple_of":
return`Angka tidak valid: harus kelipatan dari ${e.divisor}`
;case"unrecognized_keys":
return`Kunci tidak dikenali ${e.keys.length>1?"s":""}: ${l(e.keys,", ")}`
;case"invalid_key":return`Kunci tidak valid di ${e.origin}`;case"invalid_union":
default:return"Input tidak valid";case"invalid_element":
return`Nilai tidak valid di ${e.origin}`}}};const fo=()=>{const e={string:{
unit:"stafi",verb:"að hafa"},file:{unit:"bæti",verb:"að hafa"},array:{
unit:"hluti",verb:"að hafa"},set:{unit:"hluti",verb:"að hafa"}};function t(t){
return e[t]??null}const n={regex:"gildi",email:"netfang",url:"vefslóð",
emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",
guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",
datetime:"ISO dagsetning og tími",date:"ISO dagsetning",time:"ISO tími",
duration:"ISO tímalengd",ipv4:"IPv4 address",ipv6:"IPv6 address",
cidrv4:"IPv4 range",cidrv6:"IPv6 range",base64:"base64-encoded strengur",
base64url:"base64url-encoded strengur",json_string:"JSON strengur",
e164:"E.164 tölugildi",jwt:"JWT",template_literal:"gildi"},r={nan:"NaN",
number:"númer",array:"fylki"};return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Rangt gildi: Þú slóst inn ${o} þar sem á að vera instanceof ${e.expected}`:`Rangt gildi: Þú slóst inn ${o} þar sem á að vera ${t}`
}case"invalid_value":
return 1===e.values.length?`Rangt gildi: gert ráð fyrir ${$(e.values[0])}`:`Ógilt val: má vera eitt af eftirfarandi ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Of stórt: gert er ráð fyrir að ${e.origin??"gildi"} hafi ${n}${e.maximum.toString()} ${r.unit??"hluti"}`:`Of stórt: gert er ráð fyrir að ${e.origin??"gildi"} sé ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Of lítið: gert er ráð fyrir að ${e.origin} hafi ${n}${e.minimum.toString()} ${r.unit}`:`Of lítið: gert er ráð fyrir að ${e.origin} sé ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Ógildur strengur: verður að byrja á "${t.prefix}"`:"ends_with"===t.format?`Ógildur strengur: verður að enda á "${t.suffix}"`:"includes"===t.format?`Ógildur strengur: verður að innihalda "${t.includes}"`:"regex"===t.format?`Ógildur strengur: verður að fylgja mynstri ${t.pattern}`:`Rangt ${n[t.format]??e.format}`
}case"not_multiple_of":
return`Röng tala: verður að vera margfeldi af ${e.divisor}`
;case"unrecognized_keys":
return`Óþekkt ${e.keys.length>1?"ir lyklar":"ur lykill"}: ${l(e.keys,", ")}`
;case"invalid_key":return`Rangur lykill í ${e.origin}`;case"invalid_union":
default:return"Rangt gildi";case"invalid_element":
return`Rangt gildi í ${e.origin}`}}};const mo=()=>{const e={string:{
unit:"caratteri",verb:"avere"},file:{unit:"byte",verb:"avere"},array:{
unit:"elementi",verb:"avere"},set:{unit:"elementi",verb:"avere"}};function t(t){
return e[t]??null}const n={regex:"input",email:"indirizzo email",url:"URL",
emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",
guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",
datetime:"data e ora ISO",date:"data ISO",time:"ora ISO",duration:"durata ISO",
ipv4:"indirizzo IPv4",ipv6:"indirizzo IPv6",cidrv4:"intervallo IPv4",
cidrv6:"intervallo IPv6",base64:"stringa codificata in base64",
base64url:"URL codificata in base64",json_string:"stringa JSON",
e164:"numero E.164",jwt:"JWT",template_literal:"input"},r={nan:"NaN",
number:"numero",array:"vettore"};return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Input non valido: atteso instanceof ${e.expected}, ricevuto ${o}`:`Input non valido: atteso ${t}, ricevuto ${o}`
}case"invalid_value":
return 1===e.values.length?`Input non valido: atteso ${$(e.values[0])}`:`Opzione non valida: atteso uno tra ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Troppo grande: ${e.origin??"valore"} deve avere ${n}${e.maximum.toString()} ${r.unit??"elementi"}`:`Troppo grande: ${e.origin??"valore"} deve essere ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Troppo piccolo: ${e.origin} deve avere ${n}${e.minimum.toString()} ${r.unit}`:`Troppo piccolo: ${e.origin} deve essere ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Stringa non valida: deve iniziare con "${t.prefix}"`:"ends_with"===t.format?`Stringa non valida: deve terminare con "${t.suffix}"`:"includes"===t.format?`Stringa non valida: deve includere "${t.includes}"`:"regex"===t.format?`Stringa non valida: deve corrispondere al pattern ${t.pattern}`:`Invalid ${n[t.format]??e.format}`
}case"not_multiple_of":
return`Numero non valido: deve essere un multiplo di ${e.divisor}`
;case"unrecognized_keys":
return`Chiav${e.keys.length>1?"i":"e"} non riconosciut${e.keys.length>1?"e":"a"}: ${l(e.keys,", ")}`
;case"invalid_key":return`Chiave non valida in ${e.origin}`;case"invalid_union":
default:return"Input non valido";case"invalid_element":
return`Valore non valido in ${e.origin}`}}};const go=()=>{const e={string:{
unit:"文字",verb:"である"},file:{unit:"バイト",verb:"である"},array:{unit:"要素",verb:"である"},
set:{unit:"要素",verb:"である"}};function t(t){return e[t]??null}const n={
regex:"入力値",email:"メールアドレス",url:"URL",emoji:"絵文字",uuid:"UUID",uuidv4:"UUIDv4",
uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",
ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO日時",date:"ISO日付",time:"ISO時刻",
duration:"ISO期間",ipv4:"IPv4アドレス",ipv6:"IPv6アドレス",cidrv4:"IPv4範囲",
cidrv6:"IPv6範囲",base64:"base64エンコード文字列",base64url:"base64urlエンコード文字列",
json_string:"JSON文字列",e164:"E.164番号",jwt:"JWT",template_literal:"入力値"},r={
nan:"NaN",number:"数値",array:"配列"};return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`無効な入力: instanceof ${e.expected}が期待されましたが、${o}が入力されました`:`無効な入力: ${t}が期待されましたが、${o}が入力されました`
}case"invalid_value":
return 1===e.values.length?`無効な入力: ${$(e.values[0])}が期待されました`:`無効な選択: ${l(e.values,"、")}のいずれかである必要があります`
;case"too_big":{const n=e.inclusive?"以下である":"より小さい",r=t(e.origin)
;return r?`大きすぎる値: ${e.origin??"値"}は${e.maximum.toString()}${r.unit??"要素"}${n}必要があります`:`大きすぎる値: ${e.origin??"値"}は${e.maximum.toString()}${n}必要があります`
}case"too_small":{const n=e.inclusive?"以上である":"より大きい",r=t(e.origin)
;return r?`小さすぎる値: ${e.origin}は${e.minimum.toString()}${r.unit}${n}必要があります`:`小さすぎる値: ${e.origin}は${e.minimum.toString()}${n}必要があります`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`無効な文字列: "${t.prefix}"で始まる必要があります`:"ends_with"===t.format?`無効な文字列: "${t.suffix}"で終わる必要があります`:"includes"===t.format?`無効な文字列: "${t.includes}"を含む必要があります`:"regex"===t.format?`無効な文字列: パターン${t.pattern}に一致する必要があります`:`無効な${n[t.format]??e.format}`
}case"not_multiple_of":return`無効な数値: ${e.divisor}の倍数である必要があります`
;case"unrecognized_keys":
return`認識されていないキー${e.keys.length>1?"群":""}: ${l(e.keys,"、")}`;case"invalid_key":
return`${e.origin}内の無効なキー`;case"invalid_union":default:return"無効な入力"
;case"invalid_element":return`${e.origin}内の無効な値`}}};const vo=()=>{const e={
string:{unit:"სიმბოლო",verb:"უნდა შეიცავდეს"},file:{unit:"ბაიტი",
verb:"უნდა შეიცავდეს"},array:{unit:"ელემენტი",verb:"უნდა შეიცავდეს"},set:{
unit:"ელემენტი",verb:"უნდა შეიცავდეს"}};function t(t){return e[t]??null}
const n={regex:"შეყვანა",email:"ელ-ფოსტის მისამართი",url:"URL",emoji:"ემოჯი",
uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",
cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",
datetime:"თარიღი-დრო",date:"თარიღი",time:"დრო",duration:"ხანგრძლივობა",
ipv4:"IPv4 მისამართი",ipv6:"IPv6 მისამართი",cidrv4:"IPv4 დიაპაზონი",
cidrv6:"IPv6 დიაპაზონი",base64:"base64-კოდირებული სტრინგი",
base64url:"base64url-კოდირებული სტრინგი",json_string:"JSON სტრინგი",
e164:"E.164 ნომერი",jwt:"JWT",template_literal:"შეყვანა"},r={nan:"NaN",
number:"რიცხვი",string:"სტრინგი",boolean:"ბულეანი",function:"ფუნქცია",
array:"მასივი"};return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`არასწორი შეყვანა: მოსალოდნელი instanceof ${e.expected}, მიღებული ${o}`:`არასწორი შეყვანა: მოსალოდნელი ${t}, მიღებული ${o}`
}case"invalid_value":
return 1===e.values.length?`არასწორი შეყვანა: მოსალოდნელი ${$(e.values[0])}`:`არასწორი ვარიანტი: მოსალოდნელია ერთ-ერთი ${l(e.values,"|")}-დან`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`ზედმეტად დიდი: მოსალოდნელი ${e.origin??"მნიშვნელობა"} ${r.verb} ${n}${e.maximum.toString()} ${r.unit}`:`ზედმეტად დიდი: მოსალოდნელი ${e.origin??"მნიშვნელობა"} იყოს ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`ზედმეტად პატარა: მოსალოდნელი ${e.origin} ${r.verb} ${n}${e.minimum.toString()} ${r.unit}`:`ზედმეტად პატარა: მოსალოდნელი ${e.origin} იყოს ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`არასწორი სტრინგი: უნდა იწყებოდეს "${t.prefix}"-ით`:"ends_with"===t.format?`არასწორი სტრინგი: უნდა მთავრდებოდეს "${t.suffix}"-ით`:"includes"===t.format?`არასწორი სტრინგი: უნდა შეიცავდეს "${t.includes}"-ს`:"regex"===t.format?`არასწორი სტრინგი: უნდა შეესაბამებოდეს შაბლონს ${t.pattern}`:`არასწორი ${n[t.format]??e.format}`
}case"not_multiple_of":return`არასწორი რიცხვი: უნდა იყოს ${e.divisor}-ის ჯერადი`
;case"unrecognized_keys":
return`უცნობი გასაღებ${e.keys.length>1?"ები":"ი"}: ${l(e.keys,", ")}`
;case"invalid_key":return`არასწორი გასაღები ${e.origin}-ში`;case"invalid_union":
default:return"არასწორი შეყვანა";case"invalid_element":
return`არასწორი მნიშვნელობა ${e.origin}-ში`}}};const bo=()=>{const e={string:{
unit:"តួអក្សរ",verb:"គួរមាន"},file:{unit:"បៃ",verb:"គួរមាន"},array:{unit:"ធាតុ",
verb:"គួរមាន"},set:{unit:"ធាតុ",verb:"គួរមាន"}};function t(t){return e[t]??null}
const n={regex:"ទិន្នន័យបញ្ចូល",email:"អាសយដ្ឋានអ៊ីមែល",url:"URL",
emoji:"សញ្ញាអារម្មណ៍",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",
nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",
ksuid:"KSUID",datetime:"កាលបរិច្ឆេទ និងម៉ោង ISO",date:"កាលបរិច្ឆេទ ISO",
time:"ម៉ោង ISO",duration:"រយៈពេល ISO",ipv4:"អាសយដ្ឋាន IPv4",
ipv6:"អាសយដ្ឋាន IPv6",cidrv4:"ដែនអាសយដ្ឋាន IPv4",cidrv6:"ដែនអាសយដ្ឋាន IPv6",
base64:"ខ្សែអក្សរអ៊ិកូដ base64",base64url:"ខ្សែអក្សរអ៊ិកូដ base64url",
json_string:"ខ្សែអក្សរ JSON",e164:"លេខ E.164",jwt:"JWT",
template_literal:"ទិន្នន័យបញ្ចូល"},r={nan:"NaN",number:"លេខ",
array:"អារេ (Array)",null:"គ្មានតម្លៃ (null)"};return e=>{switch(e.code){
case"invalid_type":{const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`ទិន្នន័យបញ្ចូលមិនត្រឹមត្រូវ៖ ត្រូវការ instanceof ${e.expected} ប៉ុន្តែទទួលបាន ${o}`:`ទិន្នន័យបញ្ចូលមិនត្រឹមត្រូវ៖ ត្រូវការ ${t} ប៉ុន្តែទទួលបាន ${o}`
}case"invalid_value":
return 1===e.values.length?`ទិន្នន័យបញ្ចូលមិនត្រឹមត្រូវ៖ ត្រូវការ ${$(e.values[0])}`:`ជម្រើសមិនត្រឹមត្រូវ៖ ត្រូវជាមួយក្នុងចំណោម ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`ធំពេក៖ ត្រូវការ ${e.origin??"តម្លៃ"} ${n} ${e.maximum.toString()} ${r.unit??"ធាតុ"}`:`ធំពេក៖ ត្រូវការ ${e.origin??"តម្លៃ"} ${n} ${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`តូចពេក៖ ត្រូវការ ${e.origin} ${n} ${e.minimum.toString()} ${r.unit}`:`តូចពេក៖ ត្រូវការ ${e.origin} ${n} ${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`ខ្សែអក្សរមិនត្រឹមត្រូវ៖ ត្រូវចាប់ផ្តើមដោយ "${t.prefix}"`:"ends_with"===t.format?`ខ្សែអក្សរមិនត្រឹមត្រូវ៖ ត្រូវបញ្ចប់ដោយ "${t.suffix}"`:"includes"===t.format?`ខ្សែអក្សរមិនត្រឹមត្រូវ៖ ត្រូវមាន "${t.includes}"`:"regex"===t.format?`ខ្សែអក្សរមិនត្រឹមត្រូវ៖ ត្រូវតែផ្គូផ្គងនឹងទម្រង់ដែលបានកំណត់ ${t.pattern}`:`មិនត្រឹមត្រូវ៖ ${n[t.format]??e.format}`
}case"not_multiple_of":return`លេខមិនត្រឹមត្រូវ៖ ត្រូវតែជាពហុគុណនៃ ${e.divisor}`
;case"unrecognized_keys":return`រកឃើញសោមិនស្គាល់៖ ${l(e.keys,", ")}`
;case"invalid_key":return`សោមិនត្រឹមត្រូវនៅក្នុង ${e.origin}`
;case"invalid_union":default:return"ទិន្នន័យមិនត្រឹមត្រូវ"
;case"invalid_element":return`ទិន្នន័យមិនត្រឹមត្រូវនៅក្នុង ${e.origin}`}}}
;function yo(){return{localeError:bo()}}const Oo=()=>{const e={string:{
unit:"문자",verb:"to have"},file:{unit:"바이트",verb:"to have"},array:{unit:"개",
verb:"to have"},set:{unit:"개",verb:"to have"}};function t(t){return e[t]??null}
const n={regex:"입력",email:"이메일 주소",url:"URL",emoji:"이모지",uuid:"UUID",
uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",
cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO 날짜시간",
date:"ISO 날짜",time:"ISO 시간",duration:"ISO 기간",ipv4:"IPv4 주소",ipv6:"IPv6 주소",
cidrv4:"IPv4 범위",cidrv6:"IPv6 범위",base64:"base64 인코딩 문자열",
base64url:"base64url 인코딩 문자열",json_string:"JSON 문자열",e164:"E.164 번호",jwt:"JWT",
template_literal:"입력"},r={nan:"NaN"};return e=>{switch(e.code){
case"invalid_type":{const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`잘못된 입력: 예상 타입은 instanceof ${e.expected}, 받은 타입은 ${o}입니다`:`잘못된 입력: 예상 타입은 ${t}, 받은 타입은 ${o}입니다`
}case"invalid_value":
return 1===e.values.length?`잘못된 입력: 값은 ${$(e.values[0])} 이어야 합니다`:`잘못된 옵션: ${l(e.values,"또는 ")} 중 하나여야 합니다`
;case"too_big":{
const n=e.inclusive?"이하":"미만",r="미만"===n?"이어야 합니다":"여야 합니다",o=t(e.origin),a=o?.unit??"요소"
;return o?`${e.origin??"값"}이 너무 큽니다: ${e.maximum.toString()}${a} ${n}${r}`:`${e.origin??"값"}이 너무 큽니다: ${e.maximum.toString()} ${n}${r}`
}case"too_small":{
const n=e.inclusive?"이상":"초과",r="이상"===n?"이어야 합니다":"여야 합니다",o=t(e.origin),a=o?.unit??"요소"
;return o?`${e.origin??"값"}이 너무 작습니다: ${e.minimum.toString()}${a} ${n}${r}`:`${e.origin??"값"}이 너무 작습니다: ${e.minimum.toString()} ${n}${r}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`잘못된 문자열: "${t.prefix}"(으)로 시작해야 합니다`:"ends_with"===t.format?`잘못된 문자열: "${t.suffix}"(으)로 끝나야 합니다`:"includes"===t.format?`잘못된 문자열: "${t.includes}"을(를) 포함해야 합니다`:"regex"===t.format?`잘못된 문자열: 정규식 ${t.pattern} 패턴과 일치해야 합니다`:`잘못된 ${n[t.format]??e.format}`
}case"not_multiple_of":return`잘못된 숫자: ${e.divisor}의 배수여야 합니다`
;case"unrecognized_keys":return`인식할 수 없는 키: ${l(e.keys,", ")}`
;case"invalid_key":return`잘못된 키: ${e.origin}`;case"invalid_union":default:
return"잘못된 입력";case"invalid_element":return`잘못된 값: ${e.origin}`}}}
;const wo=e=>e.charAt(0).toUpperCase()+e.slice(1);function xo(e){
const t=Math.abs(e),n=t%10,r=t%100
;return r>=11&&r<=19||0===n?"many":1===n?"one":"few"}const ko=()=>{const e={
string:{unit:{one:"simbolis",few:"simboliai",many:"simbolių"},verb:{smaller:{
inclusive:"turi būti ne ilgesnė kaip",notInclusive:"turi būti trumpesnė kaip"},
bigger:{inclusive:"turi būti ne trumpesnė kaip",
notInclusive:"turi būti ilgesnė kaip"}}},file:{unit:{one:"baitas",few:"baitai",
many:"baitų"},verb:{smaller:{inclusive:"turi būti ne didesnis kaip",
notInclusive:"turi būti mažesnis kaip"},bigger:{
inclusive:"turi būti ne mažesnis kaip",notInclusive:"turi būti didesnis kaip"}}
},array:{unit:{one:"elementą",few:"elementus",many:"elementų"},verb:{smaller:{
inclusive:"turi turėti ne daugiau kaip",notInclusive:"turi turėti mažiau kaip"},
bigger:{inclusive:"turi turėti ne mažiau kaip",
notInclusive:"turi turėti daugiau kaip"}}},set:{unit:{one:"elementą",
few:"elementus",many:"elementų"},verb:{smaller:{
inclusive:"turi turėti ne daugiau kaip",notInclusive:"turi turėti mažiau kaip"},
bigger:{inclusive:"turi turėti ne mažiau kaip",
notInclusive:"turi turėti daugiau kaip"}}}};function t(t,n,r,o){
const a=e[t]??null;return null===a?a:{unit:a.unit[n],
verb:a.verb[o][r?"inclusive":"notInclusive"]}}const n={regex:"įvestis",
email:"el. pašto adresas",url:"URL",emoji:"jaustukas",uuid:"UUID",
uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",
cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO data ir laikas",
date:"ISO data",time:"ISO laikas",duration:"ISO trukmė",ipv4:"IPv4 adresas",
ipv6:"IPv6 adresas",cidrv4:"IPv4 tinklo prefiksas (CIDR)",
cidrv6:"IPv6 tinklo prefiksas (CIDR)",base64:"base64 užkoduota eilutė",
base64url:"base64url užkoduota eilutė",json_string:"JSON eilutė",
e164:"E.164 numeris",jwt:"JWT",template_literal:"įvestis"},r={nan:"NaN",
number:"skaičius",bigint:"sveikasis skaičius",string:"eilutė",
boolean:"loginė reikšmė",undefined:"neapibrėžta reikšmė",function:"funkcija",
symbol:"simbolis",array:"masyvas",object:"objektas",null:"nulinė reikšmė"}
;return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Gautas tipas ${o}, o tikėtasi - instanceof ${e.expected}`:`Gautas tipas ${o}, o tikėtasi - ${t}`
}case"invalid_value":
return 1===e.values.length?`Privalo būti ${$(e.values[0])}`:`Privalo būti vienas iš ${l(e.values,"|")} pasirinkimų`
;case"too_big":{
const n=r[e.origin]??e.origin,o=t(e.origin,xo(Number(e.maximum)),e.inclusive??!1,"smaller")
;if(o?.verb)return`${wo(n??e.origin??"reikšmė")} ${o.verb} ${e.maximum.toString()} ${o.unit??"elementų"}`
;const a=e.inclusive?"ne didesnis kaip":"mažesnis kaip"
;return`${wo(n??e.origin??"reikšmė")} turi būti ${a} ${e.maximum.toString()} ${o?.unit}`
}case"too_small":{
const n=r[e.origin]??e.origin,o=t(e.origin,xo(Number(e.minimum)),e.inclusive??!1,"bigger")
;if(o?.verb)return`${wo(n??e.origin??"reikšmė")} ${o.verb} ${e.minimum.toString()} ${o.unit??"elementų"}`
;const a=e.inclusive?"ne mažesnis kaip":"didesnis kaip"
;return`${wo(n??e.origin??"reikšmė")} turi būti ${a} ${e.minimum.toString()} ${o?.unit}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Eilutė privalo prasidėti "${t.prefix}"`:"ends_with"===t.format?`Eilutė privalo pasibaigti "${t.suffix}"`:"includes"===t.format?`Eilutė privalo įtraukti "${t.includes}"`:"regex"===t.format?`Eilutė privalo atitikti ${t.pattern}`:`Neteisingas ${n[t.format]??e.format}`
}case"not_multiple_of":return`Skaičius privalo būti ${e.divisor} kartotinis.`
;case"unrecognized_keys":
return`Neatpažint${e.keys.length>1?"i":"as"} rakt${e.keys.length>1?"ai":"as"}: ${l(e.keys,", ")}`
;case"invalid_key":return"Rastas klaidingas raktas";case"invalid_union":default:
return"Klaidinga įvestis";case"invalid_element":{const t=r[e.origin]??e.origin
;return`${wo(t??e.origin??"reikšmė")} turi klaidingą įvestį`}}}};const So=()=>{
const e={string:{unit:"знаци",verb:"да имаат"},file:{unit:"бајти",
verb:"да имаат"},array:{unit:"ставки",verb:"да имаат"},set:{unit:"ставки",
verb:"да имаат"}};function t(t){return e[t]??null}const n={regex:"внес",
email:"адреса на е-пошта",url:"URL",emoji:"емоџи",uuid:"UUID",uuidv4:"UUIDv4",
uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",
ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO датум и време",
date:"ISO датум",time:"ISO време",duration:"ISO времетраење",ipv4:"IPv4 адреса",
ipv6:"IPv6 адреса",cidrv4:"IPv4 опсег",cidrv6:"IPv6 опсег",
base64:"base64-енкодирана низа",base64url:"base64url-енкодирана низа",
json_string:"JSON низа",e164:"E.164 број",jwt:"JWT",template_literal:"внес"},r={
nan:"NaN",number:"број",array:"низа"};return e=>{switch(e.code){
case"invalid_type":{const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Грешен внес: се очекува instanceof ${e.expected}, примено ${o}`:`Грешен внес: се очекува ${t}, примено ${o}`
}case"invalid_value":
return 1===e.values.length?`Invalid input: expected ${$(e.values[0])}`:`Грешана опција: се очекува една ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Премногу голем: се очекува ${e.origin??"вредноста"} да има ${n}${e.maximum.toString()} ${r.unit??"елементи"}`:`Премногу голем: се очекува ${e.origin??"вредноста"} да биде ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Премногу мал: се очекува ${e.origin} да има ${n}${e.minimum.toString()} ${r.unit}`:`Премногу мал: се очекува ${e.origin} да биде ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Неважечка низа: мора да започнува со "${t.prefix}"`:"ends_with"===t.format?`Неважечка низа: мора да завршува со "${t.suffix}"`:"includes"===t.format?`Неважечка низа: мора да вклучува "${t.includes}"`:"regex"===t.format?`Неважечка низа: мора да одгоара на патернот ${t.pattern}`:`Invalid ${n[t.format]??e.format}`
}case"not_multiple_of":return`Грешен број: мора да биде делив со ${e.divisor}`
;case"unrecognized_keys":
return`${e.keys.length>1?"Непрепознаени клучеви":"Непрепознаен клуч"}: ${l(e.keys,", ")}`
;case"invalid_key":return`Грешен клуч во ${e.origin}`;case"invalid_union":
default:return"Грешен внес";case"invalid_element":
return`Грешна вредност во ${e.origin}`}}};const _o=()=>{const e={string:{
unit:"aksara",verb:"mempunyai"},file:{unit:"bait",verb:"mempunyai"},array:{
unit:"elemen",verb:"mempunyai"},set:{unit:"elemen",verb:"mempunyai"}}
;function t(t){return e[t]??null}const n={regex:"input",email:"alamat e-mel",
url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",
nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",
ksuid:"KSUID",datetime:"tarikh masa ISO",date:"tarikh ISO",time:"masa ISO",
duration:"tempoh ISO",ipv4:"alamat IPv4",ipv6:"alamat IPv6",cidrv4:"julat IPv4",
cidrv6:"julat IPv6",base64:"string dikodkan base64",
base64url:"string dikodkan base64url",json_string:"string JSON",
e164:"nombor E.164",jwt:"JWT",template_literal:"input"},r={nan:"NaN",
number:"nombor"};return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Input tidak sah: dijangka instanceof ${e.expected}, diterima ${o}`:`Input tidak sah: dijangka ${t}, diterima ${o}`
}case"invalid_value":
return 1===e.values.length?`Input tidak sah: dijangka ${$(e.values[0])}`:`Pilihan tidak sah: dijangka salah satu daripada ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Terlalu besar: dijangka ${e.origin??"nilai"} ${r.verb} ${n}${e.maximum.toString()} ${r.unit??"elemen"}`:`Terlalu besar: dijangka ${e.origin??"nilai"} adalah ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Terlalu kecil: dijangka ${e.origin} ${r.verb} ${n}${e.minimum.toString()} ${r.unit}`:`Terlalu kecil: dijangka ${e.origin} adalah ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`String tidak sah: mesti bermula dengan "${t.prefix}"`:"ends_with"===t.format?`String tidak sah: mesti berakhir dengan "${t.suffix}"`:"includes"===t.format?`String tidak sah: mesti mengandungi "${t.includes}"`:"regex"===t.format?`String tidak sah: mesti sepadan dengan corak ${t.pattern}`:`${n[t.format]??e.format} tidak sah`
}case"not_multiple_of":return`Nombor tidak sah: perlu gandaan ${e.divisor}`
;case"unrecognized_keys":return`Kunci tidak dikenali: ${l(e.keys,", ")}`
;case"invalid_key":return`Kunci tidak sah dalam ${e.origin}`
;case"invalid_union":default:return"Input tidak sah";case"invalid_element":
return`Nilai tidak sah dalam ${e.origin}`}}};const To=()=>{const e={string:{
unit:"tekens",verb:"heeft"},file:{unit:"bytes",verb:"heeft"},array:{
unit:"elementen",verb:"heeft"},set:{unit:"elementen",verb:"heeft"}}
;function t(t){return e[t]??null}const n={regex:"invoer",email:"emailadres",
url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",
nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",
ksuid:"KSUID",datetime:"ISO datum en tijd",date:"ISO datum",time:"ISO tijd",
duration:"ISO duur",ipv4:"IPv4-adres",ipv6:"IPv6-adres",cidrv4:"IPv4-bereik",
cidrv6:"IPv6-bereik",base64:"base64-gecodeerde tekst",
base64url:"base64 URL-gecodeerde tekst",json_string:"JSON string",
e164:"E.164-nummer",jwt:"JWT",template_literal:"invoer"},r={nan:"NaN",
number:"getal"};return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Ongeldige invoer: verwacht instanceof ${e.expected}, ontving ${o}`:`Ongeldige invoer: verwacht ${t}, ontving ${o}`
}case"invalid_value":
return 1===e.values.length?`Ongeldige invoer: verwacht ${$(e.values[0])}`:`Ongeldige optie: verwacht één van ${l(e.values,"|")}`
;case"too_big":{
const n=e.inclusive?"<=":"<",r=t(e.origin),o="date"===e.origin?"laat":"string"===e.origin?"lang":"groot"
;return r?`Te ${o}: verwacht dat ${e.origin??"waarde"} ${n}${e.maximum.toString()} ${r.unit??"elementen"} ${r.verb}`:`Te ${o}: verwacht dat ${e.origin??"waarde"} ${n}${e.maximum.toString()} is`
}case"too_small":{
const n=e.inclusive?">=":">",r=t(e.origin),o="date"===e.origin?"vroeg":"string"===e.origin?"kort":"klein"
;return r?`Te ${o}: verwacht dat ${e.origin} ${n}${e.minimum.toString()} ${r.unit} ${r.verb}`:`Te ${o}: verwacht dat ${e.origin} ${n}${e.minimum.toString()} is`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Ongeldige tekst: moet met "${t.prefix}" beginnen`:"ends_with"===t.format?`Ongeldige tekst: moet op "${t.suffix}" eindigen`:"includes"===t.format?`Ongeldige tekst: moet "${t.includes}" bevatten`:"regex"===t.format?`Ongeldige tekst: moet overeenkomen met patroon ${t.pattern}`:`Ongeldig: ${n[t.format]??e.format}`
}case"not_multiple_of":
return`Ongeldig getal: moet een veelvoud van ${e.divisor} zijn`
;case"unrecognized_keys":
return`Onbekende key${e.keys.length>1?"s":""}: ${l(e.keys,", ")}`
;case"invalid_key":return`Ongeldige key in ${e.origin}`;case"invalid_union":
default:return"Ongeldige invoer";case"invalid_element":
return`Ongeldige waarde in ${e.origin}`}}};const Eo=()=>{const e={string:{
unit:"tegn",verb:"å ha"},file:{unit:"bytes",verb:"å ha"},array:{
unit:"elementer",verb:"å inneholde"},set:{unit:"elementer",verb:"å inneholde"}}
;function t(t){return e[t]??null}const n={regex:"input",email:"e-postadresse",
url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",
nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",
ksuid:"KSUID",datetime:"ISO dato- og klokkeslett",date:"ISO-dato",
time:"ISO-klokkeslett",duration:"ISO-varighet",ipv4:"IPv4-område",
ipv6:"IPv6-område",cidrv4:"IPv4-spekter",cidrv6:"IPv6-spekter",
base64:"base64-enkodet streng",base64url:"base64url-enkodet streng",
json_string:"JSON-streng",e164:"E.164-nummer",jwt:"JWT",template_literal:"input"
},r={nan:"NaN",number:"tall",array:"liste"};return e=>{switch(e.code){
case"invalid_type":{const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Ugyldig input: forventet instanceof ${e.expected}, fikk ${o}`:`Ugyldig input: forventet ${t}, fikk ${o}`
}case"invalid_value":
return 1===e.values.length?`Ugyldig verdi: forventet ${$(e.values[0])}`:`Ugyldig valg: forventet en av ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`For stor(t): forventet ${e.origin??"value"} til å ha ${n}${e.maximum.toString()} ${r.unit??"elementer"}`:`For stor(t): forventet ${e.origin??"value"} til å ha ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`For lite(n): forventet ${e.origin} til å ha ${n}${e.minimum.toString()} ${r.unit}`:`For lite(n): forventet ${e.origin} til å ha ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Ugyldig streng: må starte med "${t.prefix}"`:"ends_with"===t.format?`Ugyldig streng: må ende med "${t.suffix}"`:"includes"===t.format?`Ugyldig streng: må inneholde "${t.includes}"`:"regex"===t.format?`Ugyldig streng: må matche mønsteret ${t.pattern}`:`Ugyldig ${n[t.format]??e.format}`
}case"not_multiple_of":
return`Ugyldig tall: må være et multiplum av ${e.divisor}`
;case"unrecognized_keys":
return`${e.keys.length>1?"Ukjente nøkler":"Ukjent nøkkel"}: ${l(e.keys,", ")}`
;case"invalid_key":return`Ugyldig nøkkel i ${e.origin}`;case"invalid_union":
default:return"Ugyldig input";case"invalid_element":
return`Ugyldig verdi i ${e.origin}`}}};const Ao=()=>{const e={string:{
unit:"harf",verb:"olmalıdır"},file:{unit:"bayt",verb:"olmalıdır"},array:{
unit:"unsur",verb:"olmalıdır"},set:{unit:"unsur",verb:"olmalıdır"}}
;function t(t){return e[t]??null}const n={regex:"giren",email:"epostagâh",
url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",
nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",
ksuid:"KSUID",datetime:"ISO hengâmı",date:"ISO tarihi",time:"ISO zamanı",
duration:"ISO müddeti",ipv4:"IPv4 nişânı",ipv6:"IPv6 nişânı",
cidrv4:"IPv4 menzili",cidrv6:"IPv6 menzili",base64:"base64-şifreli metin",
base64url:"base64url-şifreli metin",json_string:"JSON metin",
e164:"E.164 sayısı",jwt:"JWT",template_literal:"giren"},r={nan:"NaN",
number:"numara",array:"saf",null:"gayb"};return e=>{switch(e.code){
case"invalid_type":{const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Fâsit giren: umulan instanceof ${e.expected}, alınan ${o}`:`Fâsit giren: umulan ${t}, alınan ${o}`
}case"invalid_value":
return 1===e.values.length?`Fâsit giren: umulan ${$(e.values[0])}`:`Fâsit tercih: mûteberler ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Fazla büyük: ${e.origin??"value"}, ${n}${e.maximum.toString()} ${r.unit??"elements"} sahip olmalıydı.`:`Fazla büyük: ${e.origin??"value"}, ${n}${e.maximum.toString()} olmalıydı.`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Fazla küçük: ${e.origin}, ${n}${e.minimum.toString()} ${r.unit} sahip olmalıydı.`:`Fazla küçük: ${e.origin}, ${n}${e.minimum.toString()} olmalıydı.`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Fâsit metin: "${t.prefix}" ile başlamalı.`:"ends_with"===t.format?`Fâsit metin: "${t.suffix}" ile bitmeli.`:"includes"===t.format?`Fâsit metin: "${t.includes}" ihtivâ etmeli.`:"regex"===t.format?`Fâsit metin: ${t.pattern} nakşına uymalı.`:`Fâsit ${n[t.format]??e.format}`
}case"not_multiple_of":return`Fâsit sayı: ${e.divisor} katı olmalıydı.`
;case"unrecognized_keys":
return`Tanınmayan anahtar ${e.keys.length>1?"s":""}: ${l(e.keys,", ")}`
;case"invalid_key":return`${e.origin} için tanınmayan anahtar var.`
;case"invalid_union":return"Giren tanınamadı.";case"invalid_element":
return`${e.origin} için tanınmayan kıymet var.`;default:
return"Kıymet tanınamadı."}}};const Co=()=>{const e={string:{unit:"توکي",
verb:"ولري"},file:{unit:"بایټس",verb:"ولري"},array:{unit:"توکي",verb:"ولري"},
set:{unit:"توکي",verb:"ولري"}};function t(t){return e[t]??null}const n={
regex:"ورودي",email:"بریښنالیک",url:"یو آر ال",emoji:"ایموجي",uuid:"UUID",
uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",
cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"نیټه او وخت",
date:"نېټه",time:"وخت",duration:"موده",ipv4:"د IPv4 پته",ipv6:"د IPv6 پته",
cidrv4:"د IPv4 ساحه",cidrv6:"د IPv6 ساحه",base64:"base64-encoded متن",
base64url:"base64url-encoded متن",json_string:"JSON متن",e164:"د E.164 شمېره",
jwt:"JWT",template_literal:"ورودي"},r={nan:"NaN",number:"عدد",array:"ارې"}
;return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`ناسم ورودي: باید instanceof ${e.expected} وای, مګر ${o} ترلاسه شو`:`ناسم ورودي: باید ${t} وای, مګر ${o} ترلاسه شو`
}case"invalid_value":
return 1===e.values.length?`ناسم ورودي: باید ${$(e.values[0])} وای`:`ناسم انتخاب: باید یو له ${l(e.values,"|")} څخه وای`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`ډیر لوی: ${e.origin??"ارزښت"} باید ${n}${e.maximum.toString()} ${r.unit??"عنصرونه"} ولري`:`ډیر لوی: ${e.origin??"ارزښت"} باید ${n}${e.maximum.toString()} وي`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`ډیر کوچنی: ${e.origin} باید ${n}${e.minimum.toString()} ${r.unit} ولري`:`ډیر کوچنی: ${e.origin} باید ${n}${e.minimum.toString()} وي`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`ناسم متن: باید د "${t.prefix}" سره پیل شي`:"ends_with"===t.format?`ناسم متن: باید د "${t.suffix}" سره پای ته ورسيږي`:"includes"===t.format?`ناسم متن: باید "${t.includes}" ولري`:"regex"===t.format?`ناسم متن: باید د ${t.pattern} سره مطابقت ولري`:`${n[t.format]??e.format} ناسم دی`
}case"not_multiple_of":return`ناسم عدد: باید د ${e.divisor} مضرب وي`
;case"unrecognized_keys":
return`ناسم ${e.keys.length>1?"کلیډونه":"کلیډ"}: ${l(e.keys,", ")}`
;case"invalid_key":return`ناسم کلیډ په ${e.origin} کې`;case"invalid_union":
default:return"ناسمه ورودي";case"invalid_element":
return`ناسم عنصر په ${e.origin} کې`}}};const $o=()=>{const e={string:{
unit:"znaków",verb:"mieć"},file:{unit:"bajtów",verb:"mieć"},array:{
unit:"elementów",verb:"mieć"},set:{unit:"elementów",verb:"mieć"}};function t(t){
return e[t]??null}const n={regex:"wyrażenie",email:"adres email",url:"URL",
emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",
guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",
datetime:"data i godzina w formacie ISO",date:"data w formacie ISO",
time:"godzina w formacie ISO",duration:"czas trwania ISO",ipv4:"adres IPv4",
ipv6:"adres IPv6",cidrv4:"zakres IPv4",cidrv6:"zakres IPv6",
base64:"ciąg znaków zakodowany w formacie base64",
base64url:"ciąg znaków zakodowany w formacie base64url",
json_string:"ciąg znaków w formacie JSON",e164:"liczba E.164",jwt:"JWT",
template_literal:"wejście"},r={nan:"NaN",number:"liczba",array:"tablica"}
;return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Nieprawidłowe dane wejściowe: oczekiwano instanceof ${e.expected}, otrzymano ${o}`:`Nieprawidłowe dane wejściowe: oczekiwano ${t}, otrzymano ${o}`
}case"invalid_value":
return 1===e.values.length?`Nieprawidłowe dane wejściowe: oczekiwano ${$(e.values[0])}`:`Nieprawidłowa opcja: oczekiwano jednej z wartości ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Za duża wartość: oczekiwano, że ${e.origin??"wartość"} będzie mieć ${n}${e.maximum.toString()} ${r.unit??"elementów"}`:`Zbyt duż(y/a/e): oczekiwano, że ${e.origin??"wartość"} będzie wynosić ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Za mała wartość: oczekiwano, że ${e.origin??"wartość"} będzie mieć ${n}${e.minimum.toString()} ${r.unit??"elementów"}`:`Zbyt mał(y/a/e): oczekiwano, że ${e.origin??"wartość"} będzie wynosić ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Nieprawidłowy ciąg znaków: musi zaczynać się od "${t.prefix}"`:"ends_with"===t.format?`Nieprawidłowy ciąg znaków: musi kończyć się na "${t.suffix}"`:"includes"===t.format?`Nieprawidłowy ciąg znaków: musi zawierać "${t.includes}"`:"regex"===t.format?`Nieprawidłowy ciąg znaków: musi odpowiadać wzorcowi ${t.pattern}`:`Nieprawidłow(y/a/e) ${n[t.format]??e.format}`
}case"not_multiple_of":
return`Nieprawidłowa liczba: musi być wielokrotnością ${e.divisor}`
;case"unrecognized_keys":
return`Nierozpoznane klucze${e.keys.length>1?"s":""}: ${l(e.keys,", ")}`
;case"invalid_key":return`Nieprawidłowy klucz w ${e.origin}`
;case"invalid_union":default:return"Nieprawidłowe dane wejściowe"
;case"invalid_element":return`Nieprawidłowa wartość w ${e.origin}`}}}
;const Po=()=>{const e={string:{unit:"caracteres",verb:"ter"},file:{
unit:"bytes",verb:"ter"},array:{unit:"itens",verb:"ter"},set:{unit:"itens",
verb:"ter"}};function t(t){return e[t]??null}const n={regex:"padrão",
email:"endereço de e-mail",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",
uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",
ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"data e hora ISO",date:"data ISO",
time:"hora ISO",duration:"duração ISO",ipv4:"endereço IPv4",
ipv6:"endereço IPv6",cidrv4:"faixa de IPv4",cidrv6:"faixa de IPv6",
base64:"texto codificado em base64",base64url:"URL codificada em base64",
json_string:"texto JSON",e164:"número E.164",jwt:"JWT",
template_literal:"entrada"},r={nan:"NaN",number:"número",null:"nulo"}
;return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Tipo inválido: esperado instanceof ${e.expected}, recebido ${o}`:`Tipo inválido: esperado ${t}, recebido ${o}`
}case"invalid_value":
return 1===e.values.length?`Entrada inválida: esperado ${$(e.values[0])}`:`Opção inválida: esperada uma das ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Muito grande: esperado que ${e.origin??"valor"} tivesse ${n}${e.maximum.toString()} ${r.unit??"elementos"}`:`Muito grande: esperado que ${e.origin??"valor"} fosse ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Muito pequeno: esperado que ${e.origin} tivesse ${n}${e.minimum.toString()} ${r.unit}`:`Muito pequeno: esperado que ${e.origin} fosse ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Texto inválido: deve começar com "${t.prefix}"`:"ends_with"===t.format?`Texto inválido: deve terminar com "${t.suffix}"`:"includes"===t.format?`Texto inválido: deve incluir "${t.includes}"`:"regex"===t.format?`Texto inválido: deve corresponder ao padrão ${t.pattern}`:`${n[t.format]??e.format} inválido`
}case"not_multiple_of":
return`Número inválido: deve ser múltiplo de ${e.divisor}`
;case"unrecognized_keys":
return`Chave${e.keys.length>1?"s":""} desconhecida${e.keys.length>1?"s":""}: ${l(e.keys,", ")}`
;case"invalid_key":return`Chave inválida em ${e.origin}`;case"invalid_union":
return"Entrada inválida";case"invalid_element":
return`Valor inválido em ${e.origin}`;default:return"Campo inválido"}}}
;function Do(e,t,n,r){const o=Math.abs(e),a=o%10,i=o%100
;return i>=11&&i<=19?r:1===a?t:a>=2&&a<=4?n:r}const Io=()=>{const e={string:{
unit:{one:"символ",few:"символа",many:"символов"},verb:"иметь"},file:{unit:{
one:"байт",few:"байта",many:"байт"},verb:"иметь"},array:{unit:{one:"элемент",
few:"элемента",many:"элементов"},verb:"иметь"},set:{unit:{one:"элемент",
few:"элемента",many:"элементов"},verb:"иметь"}};function t(t){return e[t]??null}
const n={regex:"ввод",email:"email адрес",url:"URL",emoji:"эмодзи",uuid:"UUID",
uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",
cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO дата и время",
date:"ISO дата",time:"ISO время",duration:"ISO длительность",ipv4:"IPv4 адрес",
ipv6:"IPv6 адрес",cidrv4:"IPv4 диапазон",cidrv6:"IPv6 диапазон",
base64:"строка в формате base64",base64url:"строка в формате base64url",
json_string:"JSON строка",e164:"номер E.164",jwt:"JWT",template_literal:"ввод"
},r={nan:"NaN",number:"число",array:"массив"};return e=>{switch(e.code){
case"invalid_type":{const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Неверный ввод: ожидалось instanceof ${e.expected}, получено ${o}`:`Неверный ввод: ожидалось ${t}, получено ${o}`
}case"invalid_value":
return 1===e.values.length?`Неверный ввод: ожидалось ${$(e.values[0])}`:`Неверный вариант: ожидалось одно из ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin);if(r){
const t=Do(Number(e.maximum),r.unit.one,r.unit.few,r.unit.many)
;return`Слишком большое значение: ожидалось, что ${e.origin??"значение"} будет иметь ${n}${e.maximum.toString()} ${t}`
}
return`Слишком большое значение: ожидалось, что ${e.origin??"значение"} будет ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin);if(r){
const t=Do(Number(e.minimum),r.unit.one,r.unit.few,r.unit.many)
;return`Слишком маленькое значение: ожидалось, что ${e.origin} будет иметь ${n}${e.minimum.toString()} ${t}`
}
return`Слишком маленькое значение: ожидалось, что ${e.origin} будет ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Неверная строка: должна начинаться с "${t.prefix}"`:"ends_with"===t.format?`Неверная строка: должна заканчиваться на "${t.suffix}"`:"includes"===t.format?`Неверная строка: должна содержать "${t.includes}"`:"regex"===t.format?`Неверная строка: должна соответствовать шаблону ${t.pattern}`:`Неверный ${n[t.format]??e.format}`
}case"not_multiple_of":return`Неверное число: должно быть кратным ${e.divisor}`
;case"unrecognized_keys":
return`Нераспознанн${e.keys.length>1?"ые":"ый"} ключ${e.keys.length>1?"и":""}: ${l(e.keys,", ")}`
;case"invalid_key":return`Неверный ключ в ${e.origin}`;case"invalid_union":
default:return"Неверные входные данные";case"invalid_element":
return`Неверное значение в ${e.origin}`}}};const Mo=()=>{const e={string:{
unit:"znakov",verb:"imeti"},file:{unit:"bajtov",verb:"imeti"},array:{
unit:"elementov",verb:"imeti"},set:{unit:"elementov",verb:"imeti"}}
;function t(t){return e[t]??null}const n={regex:"vnos",email:"e-poštni naslov",
url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",
nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",
ksuid:"KSUID",datetime:"ISO datum in čas",date:"ISO datum",time:"ISO čas",
duration:"ISO trajanje",ipv4:"IPv4 naslov",ipv6:"IPv6 naslov",
cidrv4:"obseg IPv4",cidrv6:"obseg IPv6",base64:"base64 kodiran niz",
base64url:"base64url kodiran niz",json_string:"JSON niz",e164:"E.164 številka",
jwt:"JWT",template_literal:"vnos"},r={nan:"NaN",number:"število",array:"tabela"}
;return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Neveljaven vnos: pričakovano instanceof ${e.expected}, prejeto ${o}`:`Neveljaven vnos: pričakovano ${t}, prejeto ${o}`
}case"invalid_value":
return 1===e.values.length?`Neveljaven vnos: pričakovano ${$(e.values[0])}`:`Neveljavna možnost: pričakovano eno izmed ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Preveliko: pričakovano, da bo ${e.origin??"vrednost"} imelo ${n}${e.maximum.toString()} ${r.unit??"elementov"}`:`Preveliko: pričakovano, da bo ${e.origin??"vrednost"} ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Premajhno: pričakovano, da bo ${e.origin} imelo ${n}${e.minimum.toString()} ${r.unit}`:`Premajhno: pričakovano, da bo ${e.origin} ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Neveljaven niz: mora se začeti z "${t.prefix}"`:"ends_with"===t.format?`Neveljaven niz: mora se končati z "${t.suffix}"`:"includes"===t.format?`Neveljaven niz: mora vsebovati "${t.includes}"`:"regex"===t.format?`Neveljaven niz: mora ustrezati vzorcu ${t.pattern}`:`Neveljaven ${n[t.format]??e.format}`
}case"not_multiple_of":
return`Neveljavno število: mora biti večkratnik ${e.divisor}`
;case"unrecognized_keys":
return`Neprepoznan${e.keys.length>1?"i ključi":" ključ"}: ${l(e.keys,", ")}`
;case"invalid_key":return`Neveljaven ključ v ${e.origin}`;case"invalid_union":
default:return"Neveljaven vnos";case"invalid_element":
return`Neveljavna vrednost v ${e.origin}`}}};const No=()=>{const e={string:{
unit:"tecken",verb:"att ha"},file:{unit:"bytes",verb:"att ha"},array:{
unit:"objekt",verb:"att innehålla"},set:{unit:"objekt",verb:"att innehålla"}}
;function t(t){return e[t]??null}const n={regex:"reguljärt uttryck",
email:"e-postadress",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",
uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",
ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO-datum och tid",
date:"ISO-datum",time:"ISO-tid",duration:"ISO-varaktighet",
ipv4:"IPv4-intervall",ipv6:"IPv6-intervall",cidrv4:"IPv4-spektrum",
cidrv6:"IPv6-spektrum",base64:"base64-kodad sträng",
base64url:"base64url-kodad sträng",json_string:"JSON-sträng",
e164:"E.164-nummer",jwt:"JWT",template_literal:"mall-literal"},r={nan:"NaN",
number:"antal",array:"lista"};return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Ogiltig inmatning: förväntat instanceof ${e.expected}, fick ${o}`:`Ogiltig inmatning: förväntat ${t}, fick ${o}`
}case"invalid_value":
return 1===e.values.length?`Ogiltig inmatning: förväntat ${$(e.values[0])}`:`Ogiltigt val: förväntade en av ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`För stor(t): förväntade ${e.origin??"värdet"} att ha ${n}${e.maximum.toString()} ${r.unit??"element"}`:`För stor(t): förväntat ${e.origin??"värdet"} att ha ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`För lite(t): förväntade ${e.origin??"värdet"} att ha ${n}${e.minimum.toString()} ${r.unit}`:`För lite(t): förväntade ${e.origin??"värdet"} att ha ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Ogiltig sträng: måste börja med "${t.prefix}"`:"ends_with"===t.format?`Ogiltig sträng: måste sluta med "${t.suffix}"`:"includes"===t.format?`Ogiltig sträng: måste innehålla "${t.includes}"`:"regex"===t.format?`Ogiltig sträng: måste matcha mönstret "${t.pattern}"`:`Ogiltig(t) ${n[t.format]??e.format}`
}case"not_multiple_of":
return`Ogiltigt tal: måste vara en multipel av ${e.divisor}`
;case"unrecognized_keys":
return`${e.keys.length>1?"Okända nycklar":"Okänd nyckel"}: ${l(e.keys,", ")}`
;case"invalid_key":return`Ogiltig nyckel i ${e.origin??"värdet"}`
;case"invalid_union":default:return"Ogiltig input";case"invalid_element":
return`Ogiltigt värde i ${e.origin??"värdet"}`}}};const Ro=()=>{const e={
string:{unit:"எழுத்துக்கள்",verb:"கொண்டிருக்க வேண்டும்"},file:{unit:"பைட்டுகள்",
verb:"கொண்டிருக்க வேண்டும்"},array:{unit:"உறுப்புகள்",
verb:"கொண்டிருக்க வேண்டும்"},set:{unit:"உறுப்புகள்",verb:"கொண்டிருக்க வேண்டும்"}
};function t(t){return e[t]??null}const n={regex:"உள்ளீடு",
email:"மின்னஞ்சல் முகவரி",url:"URL",emoji:"emoji",uuid:"UUID",uuidv4:"UUIDv4",
uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",
ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO தேதி நேரம்",date:"ISO தேதி",
time:"ISO நேரம்",duration:"ISO கால அளவு",ipv4:"IPv4 முகவரி",ipv6:"IPv6 முகவரி",
cidrv4:"IPv4 வரம்பு",cidrv6:"IPv6 வரம்பு",base64:"base64-encoded சரம்",
base64url:"base64url-encoded சரம்",json_string:"JSON சரம்",e164:"E.164 எண்",
jwt:"JWT",template_literal:"input"},r={nan:"NaN",number:"எண்",array:"அணி",
null:"வெறுமை"};return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`தவறான உள்ளீடு: எதிர்பார்க்கப்பட்டது instanceof ${e.expected}, பெறப்பட்டது ${o}`:`தவறான உள்ளீடு: எதிர்பார்க்கப்பட்டது ${t}, பெறப்பட்டது ${o}`
}case"invalid_value":
return 1===e.values.length?`தவறான உள்ளீடு: எதிர்பார்க்கப்பட்டது ${$(e.values[0])}`:`தவறான விருப்பம்: எதிர்பார்க்கப்பட்டது ${l(e.values,"|")} இல் ஒன்று`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`மிக பெரியது: எதிர்பார்க்கப்பட்டது ${e.origin??"மதிப்பு"} ${n}${e.maximum.toString()} ${r.unit??"உறுப்புகள்"} ஆக இருக்க வேண்டும்`:`மிக பெரியது: எதிர்பார்க்கப்பட்டது ${e.origin??"மதிப்பு"} ${n}${e.maximum.toString()} ஆக இருக்க வேண்டும்`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`மிகச் சிறியது: எதிர்பார்க்கப்பட்டது ${e.origin} ${n}${e.minimum.toString()} ${r.unit} ஆக இருக்க வேண்டும்`:`மிகச் சிறியது: எதிர்பார்க்கப்பட்டது ${e.origin} ${n}${e.minimum.toString()} ஆக இருக்க வேண்டும்`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`தவறான சரம்: "${t.prefix}" இல் தொடங்க வேண்டும்`:"ends_with"===t.format?`தவறான சரம்: "${t.suffix}" இல் முடிவடைய வேண்டும்`:"includes"===t.format?`தவறான சரம்: "${t.includes}" ஐ உள்ளடக்க வேண்டும்`:"regex"===t.format?`தவறான சரம்: ${t.pattern} முறைபாட்டுடன் பொருந்த வேண்டும்`:`தவறான ${n[t.format]??e.format}`
}case"not_multiple_of":return`தவறான எண்: ${e.divisor} இன் பலமாக இருக்க வேண்டும்`
;case"unrecognized_keys":
return`அடையாளம் தெரியாத விசை${e.keys.length>1?"கள்":""}: ${l(e.keys,", ")}`
;case"invalid_key":return`${e.origin} இல் தவறான விசை`;case"invalid_union":
default:return"தவறான உள்ளீடு";case"invalid_element":
return`${e.origin} இல் தவறான மதிப்பு`}}};const Lo=()=>{const e={string:{
unit:"ตัวอักษร",verb:"ควรมี"},file:{unit:"ไบต์",verb:"ควรมี"},array:{
unit:"รายการ",verb:"ควรมี"},set:{unit:"รายการ",verb:"ควรมี"}};function t(t){
return e[t]??null}const n={regex:"ข้อมูลที่ป้อน",email:"ที่อยู่อีเมล",url:"URL",
emoji:"อิโมจิ",uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",
guid:"GUID",cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",
datetime:"วันที่เวลาแบบ ISO",date:"วันที่แบบ ISO",time:"เวลาแบบ ISO",
duration:"ช่วงเวลาแบบ ISO",ipv4:"ที่อยู่ IPv4",ipv6:"ที่อยู่ IPv6",
cidrv4:"ช่วง IP แบบ IPv4",cidrv6:"ช่วง IP แบบ IPv6",base64:"ข้อความแบบ Base64",
base64url:"ข้อความแบบ Base64 สำหรับ URL",json_string:"ข้อความแบบ JSON",
e164:"เบอร์โทรศัพท์ระหว่างประเทศ (E.164)",jwt:"โทเคน JWT",
template_literal:"ข้อมูลที่ป้อน"},r={nan:"NaN",number:"ตัวเลข",
array:"อาร์เรย์ (Array)",null:"ไม่มีค่า (null)"};return e=>{switch(e.code){
case"invalid_type":{const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`ประเภทข้อมูลไม่ถูกต้อง: ควรเป็น instanceof ${e.expected} แต่ได้รับ ${o}`:`ประเภทข้อมูลไม่ถูกต้อง: ควรเป็น ${t} แต่ได้รับ ${o}`
}case"invalid_value":
return 1===e.values.length?`ค่าไม่ถูกต้อง: ควรเป็น ${$(e.values[0])}`:`ตัวเลือกไม่ถูกต้อง: ควรเป็นหนึ่งใน ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"ไม่เกิน":"น้อยกว่า",r=t(e.origin)
;return r?`เกินกำหนด: ${e.origin??"ค่า"} ควรมี${n} ${e.maximum.toString()} ${r.unit??"รายการ"}`:`เกินกำหนด: ${e.origin??"ค่า"} ควรมี${n} ${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?"อย่างน้อย":"มากกว่า",r=t(e.origin)
;return r?`น้อยกว่ากำหนด: ${e.origin} ควรมี${n} ${e.minimum.toString()} ${r.unit}`:`น้อยกว่ากำหนด: ${e.origin} ควรมี${n} ${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`รูปแบบไม่ถูกต้อง: ข้อความต้องขึ้นต้นด้วย "${t.prefix}"`:"ends_with"===t.format?`รูปแบบไม่ถูกต้อง: ข้อความต้องลงท้ายด้วย "${t.suffix}"`:"includes"===t.format?`รูปแบบไม่ถูกต้อง: ข้อความต้องมี "${t.includes}" อยู่ในข้อความ`:"regex"===t.format?`รูปแบบไม่ถูกต้อง: ต้องตรงกับรูปแบบที่กำหนด ${t.pattern}`:`รูปแบบไม่ถูกต้อง: ${n[t.format]??e.format}`
}case"not_multiple_of":
return`ตัวเลขไม่ถูกต้อง: ต้องเป็นจำนวนที่หารด้วย ${e.divisor} ได้ลงตัว`
;case"unrecognized_keys":return`พบคีย์ที่ไม่รู้จัก: ${l(e.keys,", ")}`
;case"invalid_key":return`คีย์ไม่ถูกต้องใน ${e.origin}`;case"invalid_union":
return"ข้อมูลไม่ถูกต้อง: ไม่ตรงกับรูปแบบยูเนียนที่กำหนดไว้"
;case"invalid_element":return`ข้อมูลไม่ถูกต้องใน ${e.origin}`;default:
return"ข้อมูลไม่ถูกต้อง"}}};const Bo=()=>{const e={string:{unit:"karakter",
verb:"olmalı"},file:{unit:"bayt",verb:"olmalı"},array:{unit:"öğe",verb:"olmalı"
},set:{unit:"öğe",verb:"olmalı"}};function t(t){return e[t]??null}const n={
regex:"girdi",email:"e-posta adresi",url:"URL",emoji:"emoji",uuid:"UUID",
uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",
cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO tarih ve saat",
date:"ISO tarih",time:"ISO saat",duration:"ISO süre",ipv4:"IPv4 adresi",
ipv6:"IPv6 adresi",cidrv4:"IPv4 aralığı",cidrv6:"IPv6 aralığı",
base64:"base64 ile şifrelenmiş metin",
base64url:"base64url ile şifrelenmiş metin",json_string:"JSON dizesi",
e164:"E.164 sayısı",jwt:"JWT",template_literal:"Şablon dizesi"},r={nan:"NaN"}
;return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Geçersiz değer: beklenen instanceof ${e.expected}, alınan ${o}`:`Geçersiz değer: beklenen ${t}, alınan ${o}`
}case"invalid_value":
return 1===e.values.length?`Geçersiz değer: beklenen ${$(e.values[0])}`:`Geçersiz seçenek: aşağıdakilerden biri olmalı: ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Çok büyük: beklenen ${e.origin??"değer"} ${n}${e.maximum.toString()} ${r.unit??"öğe"}`:`Çok büyük: beklenen ${e.origin??"değer"} ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Çok küçük: beklenen ${e.origin} ${n}${e.minimum.toString()} ${r.unit}`:`Çok küçük: beklenen ${e.origin} ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Geçersiz metin: "${t.prefix}" ile başlamalı`:"ends_with"===t.format?`Geçersiz metin: "${t.suffix}" ile bitmeli`:"includes"===t.format?`Geçersiz metin: "${t.includes}" içermeli`:"regex"===t.format?`Geçersiz metin: ${t.pattern} desenine uymalı`:`Geçersiz ${n[t.format]??e.format}`
}case"not_multiple_of":return`Geçersiz sayı: ${e.divisor} ile tam bölünebilmeli`
;case"unrecognized_keys":
return`Tanınmayan anahtar${e.keys.length>1?"lar":""}: ${l(e.keys,", ")}`
;case"invalid_key":return`${e.origin} içinde geçersiz anahtar`
;case"invalid_union":default:return"Geçersiz değer";case"invalid_element":
return`${e.origin} içinde geçersiz değer`}}};const jo=()=>{const e={string:{
unit:"символів",verb:"матиме"},file:{unit:"байтів",verb:"матиме"},array:{
unit:"елементів",verb:"матиме"},set:{unit:"елементів",verb:"матиме"}}
;function t(t){return e[t]??null}const n={regex:"вхідні дані",
email:"адреса електронної пошти",url:"URL",emoji:"емодзі",uuid:"UUID",
uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",
cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"дата та час ISO",
date:"дата ISO",time:"час ISO",duration:"тривалість ISO",ipv4:"адреса IPv4",
ipv6:"адреса IPv6",cidrv4:"діапазон IPv4",cidrv6:"діапазон IPv6",
base64:"рядок у кодуванні base64",base64url:"рядок у кодуванні base64url",
json_string:"рядок JSON",e164:"номер E.164",jwt:"JWT",
template_literal:"вхідні дані"},r={nan:"NaN",number:"число",array:"масив"}
;return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Неправильні вхідні дані: очікується instanceof ${e.expected}, отримано ${o}`:`Неправильні вхідні дані: очікується ${t}, отримано ${o}`
}case"invalid_value":
return 1===e.values.length?`Неправильні вхідні дані: очікується ${$(e.values[0])}`:`Неправильна опція: очікується одне з ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Занадто велике: очікується, що ${e.origin??"значення"} ${r.verb} ${n}${e.maximum.toString()} ${r.unit??"елементів"}`:`Занадто велике: очікується, що ${e.origin??"значення"} буде ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Занадто мале: очікується, що ${e.origin} ${r.verb} ${n}${e.minimum.toString()} ${r.unit}`:`Занадто мале: очікується, що ${e.origin} буде ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Неправильний рядок: повинен починатися з "${t.prefix}"`:"ends_with"===t.format?`Неправильний рядок: повинен закінчуватися на "${t.suffix}"`:"includes"===t.format?`Неправильний рядок: повинен містити "${t.includes}"`:"regex"===t.format?`Неправильний рядок: повинен відповідати шаблону ${t.pattern}`:`Неправильний ${n[t.format]??e.format}`
}case"not_multiple_of":
return`Неправильне число: повинно бути кратним ${e.divisor}`
;case"unrecognized_keys":
return`Нерозпізнаний ключ${e.keys.length>1?"і":""}: ${l(e.keys,", ")}`
;case"invalid_key":return`Неправильний ключ у ${e.origin}`;case"invalid_union":
default:return"Неправильні вхідні дані";case"invalid_element":
return`Неправильне значення у ${e.origin}`}}};function Uo(){return{
localeError:jo()}}const zo=()=>{const e={string:{unit:"حروف",verb:"ہونا"},file:{
unit:"بائٹس",verb:"ہونا"},array:{unit:"آئٹمز",verb:"ہونا"},set:{unit:"آئٹمز",
verb:"ہونا"}};function t(t){return e[t]??null}const n={regex:"ان پٹ",
email:"ای میل ایڈریس",url:"یو آر ایل",emoji:"ایموجی",uuid:"یو یو آئی ڈی",
uuidv4:"یو یو آئی ڈی وی 4",uuidv6:"یو یو آئی ڈی وی 6",nanoid:"نینو آئی ڈی",
guid:"جی یو آئی ڈی",cuid:"سی یو آئی ڈی",cuid2:"سی یو آئی ڈی 2",
ulid:"یو ایل آئی ڈی",xid:"ایکس آئی ڈی",ksuid:"کے ایس یو آئی ڈی",
datetime:"آئی ایس او ڈیٹ ٹائم",date:"آئی ایس او تاریخ",time:"آئی ایس او وقت",
duration:"آئی ایس او مدت",ipv4:"آئی پی وی 4 ایڈریس",ipv6:"آئی پی وی 6 ایڈریس",
cidrv4:"آئی پی وی 4 رینج",cidrv6:"آئی پی وی 6 رینج",
base64:"بیس 64 ان کوڈڈ سٹرنگ",base64url:"بیس 64 یو آر ایل ان کوڈڈ سٹرنگ",
json_string:"جے ایس او این سٹرنگ",e164:"ای 164 نمبر",jwt:"جے ڈبلیو ٹی",
template_literal:"ان پٹ"},r={nan:"NaN",number:"نمبر",array:"آرے",null:"نل"}
;return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`غلط ان پٹ: instanceof ${e.expected} متوقع تھا، ${o} موصول ہوا`:`غلط ان پٹ: ${t} متوقع تھا، ${o} موصول ہوا`
}case"invalid_value":
return 1===e.values.length?`غلط ان پٹ: ${$(e.values[0])} متوقع تھا`:`غلط آپشن: ${l(e.values,"|")} میں سے ایک متوقع تھا`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`بہت بڑا: ${e.origin??"ویلیو"} کے ${n}${e.maximum.toString()} ${r.unit??"عناصر"} ہونے متوقع تھے`:`بہت بڑا: ${e.origin??"ویلیو"} کا ${n}${e.maximum.toString()} ہونا متوقع تھا`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`بہت چھوٹا: ${e.origin} کے ${n}${e.minimum.toString()} ${r.unit} ہونے متوقع تھے`:`بہت چھوٹا: ${e.origin} کا ${n}${e.minimum.toString()} ہونا متوقع تھا`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`غلط سٹرنگ: "${t.prefix}" سے شروع ہونا چاہیے`:"ends_with"===t.format?`غلط سٹرنگ: "${t.suffix}" پر ختم ہونا چاہیے`:"includes"===t.format?`غلط سٹرنگ: "${t.includes}" شامل ہونا چاہیے`:"regex"===t.format?`غلط سٹرنگ: پیٹرن ${t.pattern} سے میچ ہونا چاہیے`:`غلط ${n[t.format]??e.format}`
}case"not_multiple_of":return`غلط نمبر: ${e.divisor} کا مضاعف ہونا چاہیے`
;case"unrecognized_keys":
return`غیر تسلیم شدہ کی${e.keys.length>1?"ز":""}: ${l(e.keys,"، ")}`
;case"invalid_key":return`${e.origin} میں غلط کی`;case"invalid_union":default:
return"غلط ان پٹ";case"invalid_element":return`${e.origin} میں غلط ویلیو`}}}
;const Fo=()=>{const e={string:{unit:"belgi",verb:"bo‘lishi kerak"},file:{
unit:"bayt",verb:"bo‘lishi kerak"},array:{unit:"element",verb:"bo‘lishi kerak"},
set:{unit:"element",verb:"bo‘lishi kerak"}};function t(t){return e[t]??null}
const n={regex:"kirish",email:"elektron pochta manzili",url:"URL",emoji:"emoji",
uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",
cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",
datetime:"ISO sana va vaqti",date:"ISO sana",time:"ISO vaqt",
duration:"ISO davomiylik",ipv4:"IPv4 manzil",ipv6:"IPv6 manzil",
mac:"MAC manzil",cidrv4:"IPv4 diapazon",cidrv6:"IPv6 diapazon",
base64:"base64 kodlangan satr",base64url:"base64url kodlangan satr",
json_string:"JSON satr",e164:"E.164 raqam",jwt:"JWT",template_literal:"kirish"
},r={nan:"NaN",number:"raqam",array:"massiv"};return e=>{switch(e.code){
case"invalid_type":{const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Noto‘g‘ri kirish: kutilgan instanceof ${e.expected}, qabul qilingan ${o}`:`Noto‘g‘ri kirish: kutilgan ${t}, qabul qilingan ${o}`
}case"invalid_value":
return 1===e.values.length?`Noto‘g‘ri kirish: kutilgan ${$(e.values[0])}`:`Noto‘g‘ri variant: quyidagilardan biri kutilgan ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Juda katta: kutilgan ${e.origin??"qiymat"} ${n}${e.maximum.toString()} ${r.unit} ${r.verb}`:`Juda katta: kutilgan ${e.origin??"qiymat"} ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Juda kichik: kutilgan ${e.origin} ${n}${e.minimum.toString()} ${r.unit} ${r.verb}`:`Juda kichik: kutilgan ${e.origin} ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Noto‘g‘ri satr: "${t.prefix}" bilan boshlanishi kerak`:"ends_with"===t.format?`Noto‘g‘ri satr: "${t.suffix}" bilan tugashi kerak`:"includes"===t.format?`Noto‘g‘ri satr: "${t.includes}" ni o‘z ichiga olishi kerak`:"regex"===t.format?`Noto‘g‘ri satr: ${t.pattern} shabloniga mos kelishi kerak`:`Noto‘g‘ri ${n[t.format]??e.format}`
}case"not_multiple_of":
return`Noto‘g‘ri raqam: ${e.divisor} ning karralisi bo‘lishi kerak`
;case"unrecognized_keys":
return`Noma’lum kalit${e.keys.length>1?"lar":""}: ${l(e.keys,", ")}`
;case"invalid_key":return`${e.origin} dagi kalit noto‘g‘ri`;case"invalid_union":
default:return"Noto‘g‘ri kirish";case"invalid_element":
return`${e.origin} da noto‘g‘ri qiymat`}}};const Zo=()=>{const e={string:{
unit:"ký tự",verb:"có"},file:{unit:"byte",verb:"có"},array:{unit:"phần tử",
verb:"có"},set:{unit:"phần tử",verb:"có"}};function t(t){return e[t]??null}
const n={regex:"đầu vào",email:"địa chỉ email",url:"URL",emoji:"emoji",
uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",
cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",
datetime:"ngày giờ ISO",date:"ngày ISO",time:"giờ ISO",
duration:"khoảng thời gian ISO",ipv4:"địa chỉ IPv4",ipv6:"địa chỉ IPv6",
cidrv4:"dải IPv4",cidrv6:"dải IPv6",base64:"chuỗi mã hóa base64",
base64url:"chuỗi mã hóa base64url",json_string:"chuỗi JSON",e164:"số E.164",
jwt:"JWT",template_literal:"đầu vào"},r={nan:"NaN",number:"số",array:"mảng"}
;return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Đầu vào không hợp lệ: mong đợi instanceof ${e.expected}, nhận được ${o}`:`Đầu vào không hợp lệ: mong đợi ${t}, nhận được ${o}`
}case"invalid_value":
return 1===e.values.length?`Đầu vào không hợp lệ: mong đợi ${$(e.values[0])}`:`Tùy chọn không hợp lệ: mong đợi một trong các giá trị ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Quá lớn: mong đợi ${e.origin??"giá trị"} ${r.verb} ${n}${e.maximum.toString()} ${r.unit??"phần tử"}`:`Quá lớn: mong đợi ${e.origin??"giá trị"} ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Quá nhỏ: mong đợi ${e.origin} ${r.verb} ${n}${e.minimum.toString()} ${r.unit}`:`Quá nhỏ: mong đợi ${e.origin} ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Chuỗi không hợp lệ: phải bắt đầu bằng "${t.prefix}"`:"ends_with"===t.format?`Chuỗi không hợp lệ: phải kết thúc bằng "${t.suffix}"`:"includes"===t.format?`Chuỗi không hợp lệ: phải bao gồm "${t.includes}"`:"regex"===t.format?`Chuỗi không hợp lệ: phải khớp với mẫu ${t.pattern}`:`${n[t.format]??e.format} không hợp lệ`
}case"not_multiple_of":return`Số không hợp lệ: phải là bội số của ${e.divisor}`
;case"unrecognized_keys":return`Khóa không được nhận dạng: ${l(e.keys,", ")}`
;case"invalid_key":return`Khóa không hợp lệ trong ${e.origin}`
;case"invalid_union":default:return"Đầu vào không hợp lệ";case"invalid_element":
return`Giá trị không hợp lệ trong ${e.origin}`}}};const Qo=()=>{const e={
string:{unit:"字符",verb:"包含"},file:{unit:"字节",verb:"包含"},array:{unit:"项",
verb:"包含"},set:{unit:"项",verb:"包含"}};function t(t){return e[t]??null}const n={
regex:"输入",email:"电子邮件",url:"URL",emoji:"表情符号",uuid:"UUID",uuidv4:"UUIDv4",
uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",cuid:"cuid",cuid2:"cuid2",
ulid:"ULID",xid:"XID",ksuid:"KSUID",datetime:"ISO日期时间",date:"ISO日期",
time:"ISO时间",duration:"ISO时长",ipv4:"IPv4地址",ipv6:"IPv6地址",cidrv4:"IPv4网段",
cidrv6:"IPv6网段",base64:"base64编码字符串",base64url:"base64url编码字符串",
json_string:"JSON字符串",e164:"E.164号码",jwt:"JWT",template_literal:"输入"},r={
nan:"NaN",number:"数字",array:"数组",null:"空值(null)"};return e=>{switch(e.code){
case"invalid_type":{const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`无效输入：期望 instanceof ${e.expected}，实际接收 ${o}`:`无效输入：期望 ${t}，实际接收 ${o}`
}case"invalid_value":
return 1===e.values.length?`无效输入：期望 ${$(e.values[0])}`:`无效选项：期望以下之一 ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`数值过大：期望 ${e.origin??"值"} ${n}${e.maximum.toString()} ${r.unit??"个元素"}`:`数值过大：期望 ${e.origin??"值"} ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`数值过小：期望 ${e.origin} ${n}${e.minimum.toString()} ${r.unit}`:`数值过小：期望 ${e.origin} ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`无效字符串：必须以 "${t.prefix}" 开头`:"ends_with"===t.format?`无效字符串：必须以 "${t.suffix}" 结尾`:"includes"===t.format?`无效字符串：必须包含 "${t.includes}"`:"regex"===t.format?`无效字符串：必须满足正则表达式 ${t.pattern}`:`无效${n[t.format]??e.format}`
}case"not_multiple_of":return`无效数字：必须是 ${e.divisor} 的倍数`
;case"unrecognized_keys":return`出现未知的键(key): ${l(e.keys,", ")}`
;case"invalid_key":return`${e.origin} 中的键(key)无效`;case"invalid_union":default:
return"无效输入";case"invalid_element":return`${e.origin} 中包含无效值(value)`}}}
;const Ho=()=>{const e={string:{unit:"字元",verb:"擁有"},file:{unit:"位元組",verb:"擁有"
},array:{unit:"項目",verb:"擁有"},set:{unit:"項目",verb:"擁有"}};function t(t){
return e[t]??null}const n={regex:"輸入",email:"郵件地址",url:"URL",emoji:"emoji",
uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",
cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",
datetime:"ISO 日期時間",date:"ISO 日期",time:"ISO 時間",duration:"ISO 期間",
ipv4:"IPv4 位址",ipv6:"IPv6 位址",cidrv4:"IPv4 範圍",cidrv6:"IPv6 範圍",
base64:"base64 編碼字串",base64url:"base64url 編碼字串",json_string:"JSON 字串",
e164:"E.164 數值",jwt:"JWT",template_literal:"輸入"},r={nan:"NaN"};return e=>{
switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`無效的輸入值：預期為 instanceof ${e.expected}，但收到 ${o}`:`無效的輸入值：預期為 ${t}，但收到 ${o}`
}case"invalid_value":
return 1===e.values.length?`無效的輸入值：預期為 ${$(e.values[0])}`:`無效的選項：預期為以下其中之一 ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`數值過大：預期 ${e.origin??"值"} 應為 ${n}${e.maximum.toString()} ${r.unit??"個元素"}`:`數值過大：預期 ${e.origin??"值"} 應為 ${n}${e.maximum.toString()}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`數值過小：預期 ${e.origin} 應為 ${n}${e.minimum.toString()} ${r.unit}`:`數值過小：預期 ${e.origin} 應為 ${n}${e.minimum.toString()}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`無效的字串：必須以 "${t.prefix}" 開頭`:"ends_with"===t.format?`無效的字串：必須以 "${t.suffix}" 結尾`:"includes"===t.format?`無效的字串：必須包含 "${t.includes}"`:"regex"===t.format?`無效的字串：必須符合格式 ${t.pattern}`:`無效的 ${n[t.format]??e.format}`
}case"not_multiple_of":return`無效的數字：必須為 ${e.divisor} 的倍數`
;case"unrecognized_keys":
return`無法識別的鍵值${e.keys.length>1?"們":""}：${l(e.keys,"、")}`;case"invalid_key":
return`${e.origin} 中有無效的鍵值`;case"invalid_union":default:return"無效的輸入值"
;case"invalid_element":return`${e.origin} 中有無效的值`}}};const Vo=()=>{const e={
string:{unit:"àmi",verb:"ní"},file:{unit:"bytes",verb:"ní"},array:{unit:"nkan",
verb:"ní"},set:{unit:"nkan",verb:"ní"}};function t(t){return e[t]??null}
const n={regex:"ẹ̀rọ ìbáwọlé",email:"àdírẹ́sì ìmẹ́lì",url:"URL",emoji:"emoji",
uuid:"UUID",uuidv4:"UUIDv4",uuidv6:"UUIDv6",nanoid:"nanoid",guid:"GUID",
cuid:"cuid",cuid2:"cuid2",ulid:"ULID",xid:"XID",ksuid:"KSUID",
datetime:"àkókò ISO",date:"ọjọ́ ISO",time:"àkókò ISO",
duration:"àkókò tó pé ISO",ipv4:"àdírẹ́sì IPv4",ipv6:"àdírẹ́sì IPv6",
cidrv4:"àgbègbè IPv4",cidrv6:"àgbègbè IPv6",base64:"ọ̀rọ̀ tí a kọ́ ní base64",
base64url:"ọ̀rọ̀ base64url",json_string:"ọ̀rọ̀ JSON",e164:"nọ́mbà E.164",
jwt:"JWT",template_literal:"ẹ̀rọ ìbáwọlé"},r={nan:"NaN",number:"nọ́mbà",
array:"akopọ"};return e=>{switch(e.code){case"invalid_type":{
const t=r[e.expected]??e.expected,n=q(e.input),o=r[n]??n
;return/^[A-Z]/.test(e.expected)?`Ìbáwọlé aṣìṣe: a ní láti fi instanceof ${e.expected}, àmọ̀ a rí ${o}`:`Ìbáwọlé aṣìṣe: a ní láti fi ${t}, àmọ̀ a rí ${o}`
}case"invalid_value":
return 1===e.values.length?`Ìbáwọlé aṣìṣe: a ní láti fi ${$(e.values[0])}`:`Àṣàyàn aṣìṣe: yan ọ̀kan lára ${l(e.values,"|")}`
;case"too_big":{const n=e.inclusive?"<=":"<",r=t(e.origin)
;return r?`Tó pọ̀ jù: a ní láti jẹ́ pé ${e.origin??"iye"} ${r.verb} ${n}${e.maximum} ${r.unit}`:`Tó pọ̀ jù: a ní láti jẹ́ ${n}${e.maximum}`
}case"too_small":{const n=e.inclusive?">=":">",r=t(e.origin)
;return r?`Kéré ju: a ní láti jẹ́ pé ${e.origin} ${r.verb} ${n}${e.minimum} ${r.unit}`:`Kéré ju: a ní láti jẹ́ ${n}${e.minimum}`
}case"invalid_format":{const t=e
;return"starts_with"===t.format?`Ọ̀rọ̀ aṣìṣe: gbọ́dọ̀ bẹ̀rẹ̀ pẹ̀lú "${t.prefix}"`:"ends_with"===t.format?`Ọ̀rọ̀ aṣìṣe: gbọ́dọ̀ parí pẹ̀lú "${t.suffix}"`:"includes"===t.format?`Ọ̀rọ̀ aṣìṣe: gbọ́dọ̀ ní "${t.includes}"`:"regex"===t.format?`Ọ̀rọ̀ aṣìṣe: gbọ́dọ̀ bá àpẹẹrẹ mu ${t.pattern}`:`Aṣìṣe: ${n[t.format]??e.format}`
}case"not_multiple_of":
return`Nọ́mbà aṣìṣe: gbọ́dọ̀ jẹ́ èyà pípín ti ${e.divisor}`
;case"unrecognized_keys":return`Bọtìnì àìmọ̀: ${l(e.keys,", ")}`
;case"invalid_key":return`Bọtìnì aṣìṣe nínú ${e.origin}`;case"invalid_union":
default:return"Ìbáwọlé aṣìṣe";case"invalid_element":
return`Iye aṣìṣe nínú ${e.origin}`}}}
;const qo=Object.freeze(Object.defineProperty({__proto__:null,ar:function(){
return{localeError:Qr()}},az:function(){return{localeError:Hr()}},be:function(){
return{localeError:qr()}},bg:function(){return{localeError:Wr()}},ca:function(){
return{localeError:Xr()}},cs:function(){return{localeError:Gr()}},da:function(){
return{localeError:Yr()}},de:function(){return{localeError:Kr()}},en:eo,
eo:function(){return{localeError:to()}},es:function(){return{localeError:no()}},
fa:function(){return{localeError:ro()}},fi:function(){return{localeError:oo()}},
fr:function(){return{localeError:ao()}},frCA:function(){return{localeError:io()}
},he:function(){return{localeError:so()}},hu:function(){return{localeError:lo()}
},hy:function(){return{localeError:po()}},id:function(){return{localeError:ho()}
},is:function(){return{localeError:fo()}},it:function(){return{localeError:mo()}
},ja:function(){return{localeError:go()}},ka:function(){return{localeError:vo()}
},kh:function(){return yo()},km:yo,ko:function(){return{localeError:Oo()}},
lt:function(){return{localeError:ko()}},mk:function(){return{localeError:So()}},
ms:function(){return{localeError:_o()}},nl:function(){return{localeError:To()}},
no:function(){return{localeError:Eo()}},ota:function(){return{localeError:Ao()}
},pl:function(){return{localeError:$o()}},ps:function(){return{localeError:Co()}
},pt:function(){return{localeError:Po()}},ru:function(){return{localeError:Io()}
},sl:function(){return{localeError:Mo()}},sv:function(){return{localeError:No()}
},ta:function(){return{localeError:Ro()}},th:function(){return{localeError:Lo()}
},tr:function(){return{localeError:Bo()}},ua:function(){return Uo()},uk:Uo,
ur:function(){return{localeError:zo()}},uz:function(){return{localeError:Fo()}},
vi:function(){return{localeError:Zo()}},yo:function(){return{localeError:Vo()}},
zhCN:function(){return{localeError:Qo()}},zhTW:function(){return{
localeError:Ho()}}},Symbol.toStringTag,{value:"Module"}));var Wo
;const Xo=Symbol("ZodOutput"),Go=Symbol("ZodInput");class Yo{constructor(){
this._map=new WeakMap,this._idmap=new Map}add(e,...t){const n=t[0]
;return this._map.set(e,n),
n&&"object"==typeof n&&"id"in n&&this._idmap.set(n.id,e),this}clear(){
return this._map=new WeakMap,this._idmap=new Map,this}remove(e){
const t=this._map.get(e)
;return t&&"object"==typeof t&&"id"in t&&this._idmap.delete(t.id),
this._map.delete(e),this}get(e){const t=e._zod.parent;if(t){const n={
...this.get(t)??{}};delete n.id;const r={...n,...this._map.get(e)}
;return Object.keys(r).length?r:void 0}return this._map.get(e)}has(e){
return this._map.has(e)}}function Ko(){return new Yo}
(Wo=globalThis).__zod_globalRegistry??(Wo.__zod_globalRegistry=Ko())
;const Jo=globalThis.__zod_globalRegistry;function ea(e,t){return new e({
type:"string",...C(t)})}function ta(e,t){return new e({type:"string",coerce:!0,
...C(t)})}function na(e,t){return new e({type:"string",format:"email",
check:"string_format",abort:!1,...C(t)})}function ra(e,t){return new e({
type:"string",format:"guid",check:"string_format",abort:!1,...C(t)})}
function oa(e,t){return new e({type:"string",format:"uuid",
check:"string_format",abort:!1,...C(t)})}function aa(e,t){return new e({
type:"string",format:"uuid",check:"string_format",abort:!1,version:"v4",...C(t)
})}function ia(e,t){return new e({type:"string",format:"uuid",
check:"string_format",abort:!1,version:"v6",...C(t)})}function sa(e,t){
return new e({type:"string",format:"uuid",check:"string_format",abort:!1,
version:"v7",...C(t)})}function la(e,t){return new e({type:"string",
format:"url",check:"string_format",abort:!1,...C(t)})}function ca(e,t){
return new e({type:"string",format:"emoji",check:"string_format",abort:!1,
...C(t)})}function ua(e,t){return new e({type:"string",format:"nanoid",
check:"string_format",abort:!1,...C(t)})}function da(e,t){return new e({
type:"string",format:"cuid",check:"string_format",abort:!1,...C(t)})}
function pa(e,t){return new e({type:"string",format:"cuid2",
check:"string_format",abort:!1,...C(t)})}function ha(e,t){return new e({
type:"string",format:"ulid",check:"string_format",abort:!1,...C(t)})}
function fa(e,t){return new e({type:"string",format:"xid",check:"string_format",
abort:!1,...C(t)})}function ma(e,t){return new e({type:"string",format:"ksuid",
check:"string_format",abort:!1,...C(t)})}function ga(e,t){return new e({
type:"string",format:"ipv4",check:"string_format",abort:!1,...C(t)})}
function va(e,t){return new e({type:"string",format:"ipv6",
check:"string_format",abort:!1,...C(t)})}function ba(e,t){return new e({
type:"string",format:"mac",check:"string_format",abort:!1,...C(t)})}
function ya(e,t){return new e({type:"string",format:"cidrv4",
check:"string_format",abort:!1,...C(t)})}function Oa(e,t){return new e({
type:"string",format:"cidrv6",check:"string_format",abort:!1,...C(t)})}
function wa(e,t){return new e({type:"string",format:"base64",
check:"string_format",abort:!1,...C(t)})}function xa(e,t){return new e({
type:"string",format:"base64url",check:"string_format",abort:!1,...C(t)})}
function ka(e,t){return new e({type:"string",format:"e164",
check:"string_format",abort:!1,...C(t)})}function Sa(e,t){return new e({
type:"string",format:"jwt",check:"string_format",abort:!1,...C(t)})}const _a={
Any:null,Minute:-1,Second:0,Millisecond:3,Microsecond:6};function Ta(e,t){
return new e({type:"string",format:"datetime",check:"string_format",offset:!1,
local:!1,precision:null,...C(t)})}function Ea(e,t){return new e({type:"string",
format:"date",check:"string_format",...C(t)})}function Aa(e,t){return new e({
type:"string",format:"time",check:"string_format",precision:null,...C(t)})}
function Ca(e,t){return new e({type:"string",format:"duration",
check:"string_format",...C(t)})}function $a(e,t){return new e({type:"number",
checks:[],...C(t)})}function Pa(e,t){return new e({type:"number",coerce:!0,
checks:[],...C(t)})}function Da(e,t){return new e({type:"number",
check:"number_format",abort:!1,format:"safeint",...C(t)})}function Ia(e,t){
return new e({type:"number",check:"number_format",abort:!1,format:"float32",
...C(t)})}function Ma(e,t){return new e({type:"number",check:"number_format",
abort:!1,format:"float64",...C(t)})}function Na(e,t){return new e({
type:"number",check:"number_format",abort:!1,format:"int32",...C(t)})}
function Ra(e,t){return new e({type:"number",check:"number_format",abort:!1,
format:"uint32",...C(t)})}function La(e,t){return new e({type:"boolean",...C(t)
})}function Ba(e,t){return new e({type:"boolean",coerce:!0,...C(t)})}
function ja(e,t){return new e({type:"bigint",...C(t)})}function Ua(e,t){
return new e({type:"bigint",coerce:!0,...C(t)})}function za(e,t){return new e({
type:"bigint",check:"bigint_format",abort:!1,format:"int64",...C(t)})}
function Fa(e,t){return new e({type:"bigint",check:"bigint_format",abort:!1,
format:"uint64",...C(t)})}function Za(e,t){return new e({type:"symbol",...C(t)})
}function Qa(e,t){return new e({type:"undefined",...C(t)})}function Ha(e,t){
return new e({type:"null",...C(t)})}function Va(e){return new e({type:"any"})}
function qa(e){return new e({type:"unknown"})}function Wa(e,t){return new e({
type:"never",...C(t)})}function Xa(e,t){return new e({type:"void",...C(t)})}
function Ga(e,t){return new e({type:"date",...C(t)})}function Ya(e,t){
return new e({type:"date",coerce:!0,...C(t)})}function Ka(e,t){return new e({
type:"nan",...C(t)})}function Ja(e,t){return new Dt({check:"less_than",...C(t),
value:e,inclusive:!1})}function ei(e,t){return new Dt({check:"less_than",
...C(t),value:e,inclusive:!0})}function ti(e,t){return new It({
check:"greater_than",...C(t),value:e,inclusive:!1})}function ni(e,t){
return new It({check:"greater_than",...C(t),value:e,inclusive:!0})}
function ri(e){return ti(0,e)}function oi(e){return Ja(0,e)}function ai(e){
return ei(0,e)}function ii(e){return ni(0,e)}function si(e,t){return new Mt({
check:"multiple_of",...C(t),value:e})}function li(e,t){return new Lt({
check:"max_size",...C(t),maximum:e})}function ci(e,t){return new Bt({
check:"min_size",...C(t),minimum:e})}function ui(e,t){return new jt({
check:"size_equals",...C(t),size:e})}function di(e,t){return new Ut({
check:"max_length",...C(t),maximum:e})}function pi(e,t){return new zt({
check:"min_length",...C(t),minimum:e})}function hi(e,t){return new Ft({
check:"length_equals",...C(t),length:e})}function fi(e,t){return new Qt({
check:"string_format",format:"regex",...C(t),pattern:e})}function mi(e){
return new Ht({check:"string_format",format:"lowercase",...C(e)})}
function gi(e){return new Vt({check:"string_format",format:"uppercase",...C(e)})
}function vi(e,t){return new qt({check:"string_format",format:"includes",
...C(t),includes:e})}function bi(e,t){return new Wt({check:"string_format",
format:"starts_with",...C(t),prefix:e})}function yi(e,t){return new Xt({
check:"string_format",format:"ends_with",...C(t),suffix:e})}function Oi(e,t,n){
return new Yt({check:"property",property:e,schema:t,...C(n)})}function wi(e,t){
return new Kt({check:"mime_type",mime:e,...C(t)})}function xi(e){return new Jt({
check:"overwrite",tx:e})}function ki(e){return xi((t=>t.normalize(e)))}
function Si(){return xi((e=>e.trim()))}function _i(){
return xi((e=>e.toLowerCase()))}function Ti(){return xi((e=>e.toUpperCase()))}
function Ei(){return xi((e=>y(e)))}function Ai(e,t,n){return new e({
type:"array",element:t,...C(n)})}function Ci(e,t){return new e({type:"file",
...C(t)})}function $i(e,t,n){const r=C(n);r.abort??(r.abort=!0);return new e({
type:"custom",check:"custom",fn:t,...r})}function Pi(e,t,n){return new e({
type:"custom",check:"custom",fn:t,...C(n)})}function Di(e){
const t=Ii((n=>(n.addIssue=e=>{
if("string"==typeof e)n.issues.push(W(e,n.value,t._zod.def));else{const r=e
;r.fatal&&(r.continue=!1),
r.code??(r.code="custom"),r.input??(r.input=n.value),r.inst??(r.inst=t),
r.continue??(r.continue=!t._zod.def.abort),n.issues.push(W(r))}},e(n.value,n))))
;return t}function Ii(e,t){const n=new $t({check:"custom",...C(t)})
;return n._zod.check=e,n}function Mi(e){const t=new $t({check:"describe"})
;return t._zod.onattach=[t=>{const n=Jo.get(t)??{};Jo.add(t,{...n,description:e
})}],t._zod.check=()=>{},t}function Ni(e){const t=new $t({check:"meta"})
;return t._zod.onattach=[t=>{const n=Jo.get(t)??{};Jo.add(t,{...n,...e})
}],t._zod.check=()=>{},t}function Ri(e,t){const n=C(t)
;let r=n.truthy??["true","1","yes","on","y","enabled"],o=n.falsy??["false","0","no","off","n","disabled"]
;"sensitive"!==n.case&&(r=r.map((e=>"string"==typeof e?e.toLowerCase():e)),
o=o.map((e=>"string"==typeof e?e.toLowerCase():e)))
;const a=new Set(r),i=new Set(o),s=e.Codec??Ir,l=e.Boolean??Rn,c=new s({
type:"pipe",in:new(e.String??rn)({type:"string",error:n.error}),out:new l({
type:"boolean",error:n.error}),transform:(e,t)=>{let r=e
;return"sensitive"!==n.case&&(r=r.toLowerCase()),
!!a.has(r)||!i.has(r)&&(t.issues.push({code:"invalid_value",
expected:"stringbool",values:[...a,...i],input:t.value,inst:c,continue:!1}),{})
},reverseTransform:(e,t)=>!0===e?r[0]||"true":o[0]||"false",error:n.error})
;return c}function Li(e,t,n,r={}){const o=C(r),a={...C(r),check:"string_format",
type:"string",format:t,fn:"function"==typeof n?n:e=>n.test(e),...o}
;n instanceof RegExp&&(a.pattern=n);return new e(a)}function Bi(e){
let t=e?.target??"draft-2020-12"
;return"draft-4"===t&&(t="draft-04"),"draft-7"===t&&(t="draft-07"),{
processors:e.processors??{},metadataRegistry:e?.metadata??Jo,target:t,
unrepresentable:e?.unrepresentable??"throw",override:e?.override??(()=>{}),
io:e?.io??"output",counter:0,seen:new Map,cycles:e?.cycles??"ref",
reused:e?.reused??"inline",external:e?.external??void 0}}function ji(e,t,n={
path:[],schemaPath:[]}){var r;const o=e._zod.def,a=t.seen.get(e);if(a){a.count++
;return n.schemaPath.includes(e)&&(a.cycle=n.path),a.schema}const i={schema:{},
count:1,cycle:void 0,path:n.path};t.seen.set(e,i)
;const s=e._zod.toJSONSchema?.();if(s)i.schema=s;else{const r={...n,
schemaPath:[...n.schemaPath,e],path:n.path}
;if(e._zod.processJSONSchema)e._zod.processJSONSchema(t,i.schema,r);else{
const n=i.schema,a=t.processors[o.type]
;if(!a)throw new Error(`[toJSONSchema]: Non-representable type encountered: ${o.type}`)
;a(e,t,n,r)}const a=e._zod.parent
;a&&(i.ref||(i.ref=a),ji(a,t,r),t.seen.get(a).isParent=!0)}
const l=t.metadataRegistry.get(e)
;l&&Object.assign(i.schema,l),"input"===t.io&&Fi(e)&&(delete i.schema.examples,
delete i.schema.default),
"input"===t.io&&i.schema._prefault&&((r=i.schema).default??(r.default=i.schema._prefault)),
delete i.schema._prefault;return t.seen.get(e).schema}function Ui(e,t){
const n=e.seen.get(t)
;if(!n)throw new Error("Unprocessed schema. This is a bug in Zod.")
;const r=new Map;for(const a of e.seen.entries()){
const t=e.metadataRegistry.get(a[0])?.id;if(t){const e=r.get(t)
;if(e&&e!==a[0])throw new Error(`Duplicate schema id "${t}" detected during JSON Schema conversion. Two different schemas cannot share the same id when converted together.`)
;r.set(t,a[0])}}const o=t=>{if(t[1].schema.$ref)return
;const r=t[1],{ref:o,defId:a}=(t=>{
const r="draft-2020-12"===e.target?"$defs":"definitions";if(e.external){
const n=e.external.registry.get(t[0])?.id,o=e.external.uri??(e=>e);if(n)return{
ref:o(n)};const a=t[1].defId??t[1].schema.id??"schema"+e.counter++
;return t[1].defId=a,{defId:a,ref:`${o("__shared")}#/${r}/${a}`}}
if(t[1]===n)return{ref:"#"}
;const o=`#/${r}/`,a=t[1].schema.id??"__schema"+e.counter++;return{defId:a,
ref:o+a}})(t);r.def={...r.schema},a&&(r.defId=a);const i=r.schema
;for(const e in i)delete i[e];i.$ref=o}
;if("throw"===e.cycles)for(const a of e.seen.entries()){const e=a[1]
;if(e.cycle)throw new Error(`Cycle detected: #/${e.cycle?.join("/")}/<root>\n\nSet the \`cycles\` parameter to \`"ref"\` to resolve cyclical schemas with defs.`)
}for(const a of e.seen.entries()){const n=a[1];if(t===a[0]){o(a);continue}
if(e.external){const n=e.external.registry.get(a[0])?.id;if(t!==a[0]&&n){o(a)
;continue}}const r=e.metadataRegistry.get(a[0])?.id
;r?o(a):(n.cycle||n.count>1&&"ref"===e.reused)&&o(a)}}function zi(e,t){
const n=e.seen.get(t)
;if(!n)throw new Error("Unprocessed schema. This is a bug in Zod.");const r=t=>{
const n=e.seen.get(t);if(null===n.ref)return;const o=n.def??n.schema,a={...o
},i=n.ref;if(n.ref=null,i){r(i);const n=e.seen.get(i),s=n.schema
;!s.$ref||"draft-07"!==e.target&&"draft-04"!==e.target&&"openapi-3.0"!==e.target?Object.assign(o,s):(o.allOf=o.allOf??[],
o.allOf.push(s)),Object.assign(o,a)
;if(t._zod.parent===i)for(const e in o)"$ref"!==e&&"allOf"!==e&&(e in a||delete o[e])
;if(s.$ref)for(const e in o)"$ref"!==e&&"allOf"!==e&&e in n.def&&JSON.stringify(o[e])===JSON.stringify(n.def[e])&&delete o[e]
}const s=t._zod.parent;if(s&&s!==i){r(s);const t=e.seen.get(s)
;if(t?.schema.$ref&&(o.$ref=t.schema.$ref,
t.def))for(const e in o)"$ref"!==e&&"allOf"!==e&&e in t.def&&JSON.stringify(o[e])===JSON.stringify(t.def[e])&&delete o[e]
}e.override({zodSchema:t,jsonSchema:o,path:n.path??[]})}
;for(const s of[...e.seen.entries()].reverse())r(s[0]);const o={}
;if("draft-2020-12"===e.target?o.$schema="https://json-schema.org/draft/2020-12/schema":"draft-07"===e.target?o.$schema="http://json-schema.org/draft-07/schema#":"draft-04"===e.target?o.$schema="http://json-schema.org/draft-04/schema#":e.target,
e.external?.uri){const n=e.external.registry.get(t)?.id
;if(!n)throw new Error("Schema is missing an `id` property")
;o.$id=e.external.uri(n)}Object.assign(o,n.def??n.schema)
;const a=e.external?.defs??{};for(const s of e.seen.entries()){const e=s[1]
;e.def&&e.defId&&(a[e.defId]=e.def)}
e.external||Object.keys(a).length>0&&("draft-2020-12"===e.target?o.$defs=a:o.definitions=a)
;try{const n=JSON.parse(JSON.stringify(o))
;return Object.defineProperty(n,"~standard",{value:{...t["~standard"],
jsonSchema:{input:Qi(t,"input",e.processors),output:Qi(t,"output",e.processors)}
},enumerable:!1,writable:!1}),n}catch(i){
throw new Error("Error converting schema to JSON.")}}function Fi(e,t){
const n=t??{seen:new Set};if(n.seen.has(e))return!1;n.seen.add(e)
;const r=e._zod.def;if("transform"===r.type)return!0
;if("array"===r.type)return Fi(r.element,n)
;if("set"===r.type)return Fi(r.valueType,n)
;if("lazy"===r.type)return Fi(r.getter(),n)
;if("promise"===r.type||"optional"===r.type||"nonoptional"===r.type||"nullable"===r.type||"readonly"===r.type||"default"===r.type||"prefault"===r.type)return Fi(r.innerType,n)
;if("intersection"===r.type)return Fi(r.left,n)||Fi(r.right,n)
;if("record"===r.type||"map"===r.type)return Fi(r.keyType,n)||Fi(r.valueType,n)
;if("pipe"===r.type)return Fi(r.in,n)||Fi(r.out,n);if("object"===r.type){
for(const e in r.shape)if(Fi(r.shape[e],n))return!0;return!1}
if("union"===r.type){for(const e of r.options)if(Fi(e,n))return!0;return!1}
if("tuple"===r.type){for(const e of r.items)if(Fi(e,n))return!0
;return!(!r.rest||!Fi(r.rest,n))}return!1}const Zi=(e,t={})=>n=>{const r=Bi({
...n,processors:t});return ji(e,r),Ui(r,e),zi(r,e)},Qi=(e,t,n={})=>r=>{
const{libraryOptions:o,target:a}=r??{},i=Bi({...o??{},target:a,io:t,processors:n
});return ji(e,i),Ui(i,e),zi(i,e)},Hi={guid:"uuid",url:"uri",
datetime:"date-time",json_string:"json-string",regex:""},Vi=(e,t,n,r)=>{
const o=n;o.type="string"
;const{minimum:a,maximum:i,format:s,patterns:l,contentEncoding:c}=e._zod.bag
;if("number"==typeof a&&(o.minLength=a),
"number"==typeof i&&(o.maxLength=i),s&&(o.format=Hi[s]??s,
""===o.format&&delete o.format,
"time"===s&&delete o.format),c&&(o.contentEncoding=c),l&&l.size>0){
const e=[...l]
;1===e.length?o.pattern=e[0].source:e.length>1&&(o.allOf=[...e.map((e=>({
..."draft-07"===t.target||"draft-04"===t.target||"openapi-3.0"===t.target?{
type:"string"}:{},pattern:e.source})))])}},qi=(e,t,n,r)=>{
const o=n,{minimum:a,maximum:i,format:s,multipleOf:l,exclusiveMaximum:c,exclusiveMinimum:u}=e._zod.bag
;"string"==typeof s&&s.includes("int")?o.type="integer":o.type="number",
"number"==typeof u&&("draft-04"===t.target||"openapi-3.0"===t.target?(o.minimum=u,
o.exclusiveMinimum=!0):o.exclusiveMinimum=u),
"number"==typeof a&&(o.minimum=a,"number"==typeof u&&"draft-04"!==t.target&&(u>=a?delete o.minimum:delete o.exclusiveMinimum)),
"number"==typeof c&&("draft-04"===t.target||"openapi-3.0"===t.target?(o.maximum=c,
o.exclusiveMaximum=!0):o.exclusiveMaximum=c),
"number"==typeof i&&(o.maximum=i,"number"==typeof c&&"draft-04"!==t.target&&(c<=i?delete o.maximum:delete o.exclusiveMaximum)),
"number"==typeof l&&(o.multipleOf=l)},Wi=(e,t,n,r)=>{n.type="boolean"
},Xi=(e,t,n,r)=>{
if("throw"===t.unrepresentable)throw new Error("BigInt cannot be represented in JSON Schema")
},Gi=(e,t,n,r)=>{
if("throw"===t.unrepresentable)throw new Error("Symbols cannot be represented in JSON Schema")
},Yi=(e,t,n,r)=>{
"openapi-3.0"===t.target?(n.type="string",n.nullable=!0,n.enum=[null]):n.type="null"
},Ki=(e,t,n,r)=>{
if("throw"===t.unrepresentable)throw new Error("Undefined cannot be represented in JSON Schema")
},Ji=(e,t,n,r)=>{
if("throw"===t.unrepresentable)throw new Error("Void cannot be represented in JSON Schema")
},es=(e,t,n,r)=>{n.not={}},ts=(e,t,n,r)=>{},ns=(e,t,n,r)=>{},rs=(e,t,n,r)=>{
if("throw"===t.unrepresentable)throw new Error("Date cannot be represented in JSON Schema")
},os=(e,t,n,r)=>{const o=s(e._zod.def.entries)
;o.every((e=>"number"==typeof e))&&(n.type="number"),
o.every((e=>"string"==typeof e))&&(n.type="string"),n.enum=o},as=(e,t,n,r)=>{
const o=e._zod.def,a=[];for(const i of o.values)if(void 0===i){
if("throw"===t.unrepresentable)throw new Error("Literal `undefined` cannot be represented in JSON Schema")
}else if("bigint"==typeof i){
if("throw"===t.unrepresentable)throw new Error("BigInt literals cannot be represented in JSON Schema")
;a.push(Number(i))}else a.push(i);if(0===a.length);else if(1===a.length){
const e=a[0]
;n.type=null===e?"null":typeof e,"draft-04"===t.target||"openapi-3.0"===t.target?n.enum=[e]:n.const=e
}else a.every((e=>"number"==typeof e))&&(n.type="number"),
a.every((e=>"string"==typeof e))&&(n.type="string"),
a.every((e=>"boolean"==typeof e))&&(n.type="boolean"),
a.every((e=>null===e))&&(n.type="null"),n.enum=a},is=(e,t,n,r)=>{
if("throw"===t.unrepresentable)throw new Error("NaN cannot be represented in JSON Schema")
},ss=(e,t,n,r)=>{const o=n,a=e._zod.pattern
;if(!a)throw new Error("Pattern not found in template literal");o.type="string",
o.pattern=a.source},ls=(e,t,n,r)=>{const o=n,a={type:"string",format:"binary",
contentEncoding:"binary"},{minimum:i,maximum:s,mime:l}=e._zod.bag
;void 0!==i&&(a.minLength=i),
void 0!==s&&(a.maxLength=s),l?1===l.length?(a.contentMediaType=l[0],
Object.assign(o,a)):(Object.assign(o,a),o.anyOf=l.map((e=>({contentMediaType:e
})))):Object.assign(o,a)},cs=(e,t,n,r)=>{n.type="boolean"},us=(e,t,n,r)=>{
if("throw"===t.unrepresentable)throw new Error("Custom types cannot be represented in JSON Schema")
},ds=(e,t,n,r)=>{
if("throw"===t.unrepresentable)throw new Error("Function types cannot be represented in JSON Schema")
},ps=(e,t,n,r)=>{
if("throw"===t.unrepresentable)throw new Error("Transforms cannot be represented in JSON Schema")
},hs=(e,t,n,r)=>{
if("throw"===t.unrepresentable)throw new Error("Map cannot be represented in JSON Schema")
},fs=(e,t,n,r)=>{
if("throw"===t.unrepresentable)throw new Error("Set cannot be represented in JSON Schema")
},ms=(e,t,n,r)=>{const o=n,a=e._zod.def,{minimum:i,maximum:s}=e._zod.bag
;"number"==typeof i&&(o.minItems=i),
"number"==typeof s&&(o.maxItems=s),o.type="array",o.items=ji(a.element,t,{...r,
path:[...r.path,"items"]})},gs=(e,t,n,r)=>{const o=n,a=e._zod.def
;o.type="object",o.properties={};const i=a.shape
;for(const c in i)o.properties[c]=ji(i[c],t,{...r,
path:[...r.path,"properties",c]})
;const s=new Set(Object.keys(i)),l=new Set([...s].filter((e=>{
const n=a.shape[e]._zod;return"input"===t.io?void 0===n.optin:void 0===n.optout
})))
;l.size>0&&(o.required=Array.from(l)),"never"===a.catchall?._zod.def.type?o.additionalProperties=!1:a.catchall?a.catchall&&(o.additionalProperties=ji(a.catchall,t,{
...r,path:[...r.path,"additionalProperties"]
})):"output"===t.io&&(o.additionalProperties=!1)},vs=(e,t,n,r)=>{
const o=e._zod.def,a=!1===o.inclusive,i=o.options.map(((e,n)=>ji(e,t,{...r,
path:[...r.path,a?"oneOf":"anyOf",n]})));a?n.oneOf=i:n.anyOf=i},bs=(e,t,n,r)=>{
const o=e._zod.def,a=ji(o.left,t,{...r,path:[...r.path,"allOf",0]
}),i=ji(o.right,t,{...r,path:[...r.path,"allOf",1]
}),s=e=>"allOf"in e&&1===Object.keys(e).length,l=[...s(a)?a.allOf:[a],...s(i)?i.allOf:[i]]
;n.allOf=l},ys=(e,t,n,r)=>{const o=n,a=e._zod.def;o.type="array"
;const i="draft-2020-12"===t.target?"prefixItems":"items",s="draft-2020-12"===t.target||"openapi-3.0"===t.target?"items":"additionalItems",l=a.items.map(((e,n)=>ji(e,t,{
...r,path:[...r.path,i,n]}))),c=a.rest?ji(a.rest,t,{...r,
path:[...r.path,s,..."openapi-3.0"===t.target?[a.items.length]:[]]}):null
;"draft-2020-12"===t.target?(o.prefixItems=l,
c&&(o.items=c)):"openapi-3.0"===t.target?(o.items={anyOf:l
},c&&o.items.anyOf.push(c),
o.minItems=l.length,c||(o.maxItems=l.length)):(o.items=l,
c&&(o.additionalItems=c));const{minimum:u,maximum:d}=e._zod.bag
;"number"==typeof u&&(o.minItems=u),"number"==typeof d&&(o.maxItems=d)
},Os=(e,t,n,r)=>{const o=n,a=e._zod.def;o.type="object"
;const i=a.keyType,s=i._zod.bag,l=s?.patterns;if("loose"===a.mode&&l&&l.size>0){
const e=ji(a.valueType,t,{...r,path:[...r.path,"patternProperties","*"]})
;o.patternProperties={};for(const t of l)o.patternProperties[t.source]=e
}else"draft-07"!==t.target&&"draft-2020-12"!==t.target||(o.propertyNames=ji(a.keyType,t,{
...r,path:[...r.path,"propertyNames"]
})),o.additionalProperties=ji(a.valueType,t,{...r,
path:[...r.path,"additionalProperties"]});const c=i._zod.values;if(c){
const e=[...c].filter((e=>"string"==typeof e||"number"==typeof e))
;e.length>0&&(o.required=e)}},ws=(e,t,n,r)=>{
const o=e._zod.def,a=ji(o.innerType,t,r),i=t.seen.get(e)
;"openapi-3.0"===t.target?(i.ref=o.innerType,n.nullable=!0):n.anyOf=[a,{
type:"null"}]},xs=(e,t,n,r)=>{const o=e._zod.def;ji(o.innerType,t,r)
;t.seen.get(e).ref=o.innerType},ks=(e,t,n,r)=>{const o=e._zod.def
;ji(o.innerType,t,r)
;t.seen.get(e).ref=o.innerType,n.default=JSON.parse(JSON.stringify(o.defaultValue))
},Ss=(e,t,n,r)=>{const o=e._zod.def;ji(o.innerType,t,r)
;t.seen.get(e).ref=o.innerType,
"input"===t.io&&(n._prefault=JSON.parse(JSON.stringify(o.defaultValue)))
},_s=(e,t,n,r)=>{const o=e._zod.def;ji(o.innerType,t,r);let a
;t.seen.get(e).ref=o.innerType;try{a=o.catchValue(void 0)}catch{
throw new Error("Dynamic catch values are not supported in JSON Schema")}
n.default=a},Ts=(e,t,n,r)=>{
const o=e._zod.def,a="input"===t.io?"transform"===o.in._zod.def.type?o.out:o.in:o.out
;ji(a,t,r);t.seen.get(e).ref=a},Es=(e,t,n,r)=>{const o=e._zod.def
;ji(o.innerType,t,r);t.seen.get(e).ref=o.innerType,n.readOnly=!0
},As=(e,t,n,r)=>{const o=e._zod.def;ji(o.innerType,t,r)
;t.seen.get(e).ref=o.innerType},Cs=(e,t,n,r)=>{const o=e._zod.def
;ji(o.innerType,t,r);t.seen.get(e).ref=o.innerType},$s=(e,t,n,r)=>{
const o=e._zod.innerType;ji(o,t,r);t.seen.get(e).ref=o},Ps={string:Vi,number:qi,
boolean:Wi,bigint:Xi,symbol:Gi,null:Yi,undefined:Ki,void:Ji,never:es,any:ts,
unknown:ns,date:rs,enum:os,literal:as,nan:is,template_literal:ss,file:ls,
success:cs,custom:us,function:ds,transform:ps,map:hs,set:fs,array:ms,object:gs,
union:vs,intersection:bs,tuple:ys,record:Os,nullable:ws,nonoptional:xs,
default:ks,prefault:Ss,catch:_s,pipe:Ts,readonly:Es,promise:As,optional:Cs,
lazy:$s};function Ds(e,t){if("_idmap"in e){const n=e,r=Bi({...t,processors:Ps
}),o={};for(const e of n._idmap.entries()){const[t,n]=e;ji(n,r)}const a={},i={
registry:n,uri:t?.uri,defs:o};r.external=i;for(const e of n._idmap.entries()){
const[t,n]=e;Ui(r,n),a[t]=zi(r,n)}if(Object.keys(o).length>0){
const e="draft-2020-12"===r.target?"$defs":"definitions";a.__shared={[e]:o}}
return{schemas:a}}const n=Bi({...t,processors:Ps})
;return ji(e,n),Ui(n,e),zi(n,e)}const Is=Object.freeze(Object.defineProperty({
__proto__:null},Symbol.toStringTag,{value:"Module"
})),Ms=Object.freeze(Object.defineProperty({__proto__:null,$ZodAny:Fn,
$ZodArray:Wn,$ZodAsyncError:r,$ZodBase64:En,$ZodBase64URL:Cn,$ZodBigInt:Ln,
$ZodBigIntFormat:Bn,$ZodBoolean:Rn,$ZodCIDRv4:Sn,$ZodCIDRv6:_n,$ZodCUID:pn,
$ZodCUID2:hn,$ZodCatch:Cr,$ZodCheck:$t,$ZodCheckBigIntFormat:Rt,
$ZodCheckEndsWith:Xt,$ZodCheckGreaterThan:It,$ZodCheckIncludes:qt,
$ZodCheckLengthEquals:Ft,$ZodCheckLessThan:Dt,$ZodCheckLowerCase:Ht,
$ZodCheckMaxLength:Ut,$ZodCheckMaxSize:Lt,$ZodCheckMimeType:Kt,
$ZodCheckMinLength:zt,$ZodCheckMinSize:Bt,$ZodCheckMultipleOf:Mt,
$ZodCheckNumberFormat:Nt,$ZodCheckOverwrite:Jt,$ZodCheckProperty:Yt,
$ZodCheckRegex:Qt,$ZodCheckSizeEquals:jt,$ZodCheckStartsWith:Wt,
$ZodCheckStringFormat:Zt,$ZodCheckUpperCase:Vt,$ZodCodec:Ir,$ZodCustom:Fr,
$ZodCustomStringFormat:In,$ZodDate:Vn,$ZodDefault:kr,$ZodDiscriminatedUnion:or,
$ZodE164:$n,$ZodEmail:ln,$ZodEmoji:un,$ZodEncodeError:o,$ZodEnum:mr,$ZodError:J,
$ZodExactOptional:wr,$ZodFile:vr,$ZodFunction:jr,$ZodGUID:an,$ZodIPv4:wn,
$ZodIPv6:xn,$ZodISODate:bn,$ZodISODateTime:vn,$ZodISODuration:On,$ZodISOTime:yn,
$ZodIntersection:ar,$ZodJWT:Dn,$ZodKSUID:gn,$ZodLazy:zr,$ZodLiteral:gr,
$ZodMAC:kn,$ZodMap:dr,$ZodNaN:$r,$ZodNanoID:dn,$ZodNever:Qn,$ZodNonOptional:Tr,
$ZodNull:zn,$ZodNullable:xr,$ZodNumber:Mn,$ZodNumberFormat:Nn,$ZodObject:Kn,
$ZodObjectJIT:Jn,$ZodOptional:Or,$ZodPipe:Pr,$ZodPrefault:_r,$ZodPromise:Ur,
$ZodReadonly:Rr,$ZodRealError:ee,$ZodRecord:ur,$ZodRegistry:Yo,$ZodSet:hr,
$ZodString:rn,$ZodStringFormat:on,$ZodSuccess:Ar,$ZodSymbol:jn,
$ZodTemplateLiteral:Br,$ZodTransform:br,$ZodTuple:lr,$ZodType:nn,$ZodULID:fn,
$ZodURL:cn,$ZodUUID:sn,$ZodUndefined:Un,$ZodUnion:tr,$ZodUnknown:Zn,$ZodVoid:Hn,
$ZodXID:mn,$ZodXor:rr,$brand:n,$constructor:t,$input:Go,$output:Xo,Doc:en,
JSONSchema:Is,JSONSchemaGenerator:class{get metadataRegistry(){
return this.ctx.metadataRegistry}get target(){return this.ctx.target}
get unrepresentable(){return this.ctx.unrepresentable}get override(){
return this.ctx.override}get io(){return this.ctx.io}get counter(){
return this.ctx.counter}set counter(e){this.ctx.counter=e}get seen(){
return this.ctx.seen}constructor(e){let t=e?.target??"draft-2020-12"
;"draft-4"===t&&(t="draft-04"),"draft-7"===t&&(t="draft-07"),this.ctx=Bi({
processors:Ps,target:t,...e?.metadata&&{metadata:e.metadata},
...e?.unrepresentable&&{unrepresentable:e.unrepresentable},...e?.override&&{
override:e.override},...e?.io&&{io:e.io}})}process(e,t={path:[],schemaPath:[]}){
return ji(e,this.ctx,t)}emit(e,t){
t&&(t.cycles&&(this.ctx.cycles=t.cycles),t.reused&&(this.ctx.reused=t.reused),
t.external&&(this.ctx.external=t.external)),Ui(this.ctx,e)
;const n=zi(this.ctx,e),{"~standard":r,...o}=n;return o}},NEVER:e,
TimePrecision:_a,_any:Va,_array:Ai,_base64:wa,_base64url:xa,_bigint:ja,
_boolean:La,_catch:function(e,t,n){return new e({type:"catch",innerType:t,
catchValue:"function"==typeof n?n:()=>n})},_check:Ii,_cidrv4:ya,_cidrv6:Oa,
_coercedBigint:Ua,_coercedBoolean:Ba,_coercedDate:Ya,_coercedNumber:Pa,
_coercedString:ta,_cuid:da,_cuid2:pa,_custom:$i,_date:Ga,_decode:ge,
_decodeAsync:Oe,_default:function(e,t,n){return new e({type:"default",
innerType:t,get defaultValue(){return"function"==typeof n?n():S(n)}})},
_discriminatedUnion:function(e,t,n,r){return new e({type:"union",options:n,
discriminator:t,...C(r)})},_e164:ka,_email:na,_emoji:ca,_encode:fe,
_encodeAsync:be,_endsWith:yi,_enum:function(e,t,n){return new e({type:"enum",
entries:Array.isArray(t)?Object.fromEntries(t.map((e=>[e,e]))):t,...C(n)})},
_file:Ci,_float32:Ia,_float64:Ma,_gt:ti,_gte:ni,_guid:ra,_includes:vi,_int:Da,
_int32:Na,_int64:za,_intersection:function(e,t,n){return new e({
type:"intersection",left:t,right:n})},_ipv4:ga,_ipv6:va,_isoDate:Ea,
_isoDateTime:Ta,_isoDuration:Ca,_isoTime:Aa,_jwt:Sa,_ksuid:ma,
_lazy:function(e,t){return new e({type:"lazy",getter:t})},_length:hi,
_literal:function(e,t,n){return new e({type:"literal",
values:Array.isArray(t)?t:[t],...C(n)})},_lowercase:mi,_lt:Ja,_lte:ei,_mac:ba,
_map:function(e,t,n,r){return new e({type:"map",keyType:t,valueType:n,...C(r)})
},_max:ei,_maxLength:di,_maxSize:li,_mime:wi,_min:ni,_minLength:pi,_minSize:ci,
_multipleOf:si,_nan:Ka,_nanoid:ua,_nativeEnum:function(e,t,n){return new e({
type:"enum",entries:t,...C(n)})},_negative:oi,_never:Wa,_nonnegative:ii,
_nonoptional:function(e,t,n){return new e({type:"nonoptional",innerType:t,
...C(n)})},_nonpositive:ai,_normalize:ki,_null:Ha,_nullable:function(e,t){
return new e({type:"nullable",innerType:t})},_number:$a,_optional:function(e,t){
return new e({type:"optional",innerType:t})},_overwrite:xi,_parse:ie,
_parseAsync:le,_pipe:function(e,t,n){return new e({type:"pipe",in:t,out:n})},
_positive:ri,_promise:function(e,t){return new e({type:"promise",innerType:t})},
_property:Oi,_readonly:function(e,t){return new e({type:"readonly",innerType:t})
},_record:function(e,t,n,r){return new e({type:"record",keyType:t,valueType:n,
...C(r)})},_refine:Pi,_regex:fi,_safeDecode:Se,_safeDecodeAsync:Ae,
_safeEncode:xe,_safeEncodeAsync:Te,_safeParse:ue,_safeParseAsync:pe,
_set:function(e,t,n){return new e({type:"set",valueType:t,...C(n)})},_size:ui,
_slugify:Ei,_startsWith:bi,_string:ea,_stringFormat:Li,_stringbool:Ri,
_success:function(e,t){return new e({type:"success",innerType:t})},
_superRefine:Di,_symbol:Za,_templateLiteral:function(e,t,n){return new e({
type:"template_literal",parts:t,...C(n)})},_toLowerCase:_i,_toUpperCase:Ti,
_transform:function(e,t){return new e({type:"transform",transform:t})},_trim:Si,
_tuple:function(e,t,n,r){const o=n instanceof nn;return new e({type:"tuple",
items:t,rest:o?n:null,...C(o?r:n)})},_uint32:Ra,_uint64:Fa,_ulid:ha,
_undefined:Qa,_union:function(e,t,n){return new e({type:"union",options:t,
...C(n)})},_unknown:qa,_uppercase:gi,_url:la,_uuid:oa,_uuidv4:aa,_uuidv6:ia,
_uuidv7:sa,_void:Xa,_xid:fa,_xor:function(e,t,n){return new e({type:"union",
options:t,inclusive:!1,...C(n)})},clone:A,config:i,
createStandardJSONSchemaMethod:Qi,createToJSONSchemaMethod:Zi,decode:ve,
decodeAsync:we,describe:Mi,encode:me,encodeAsync:ye,extractDefs:Ui,finalize:zi,
flattenError:te,formatError:ne,globalConfig:a,globalRegistry:Jo,
initializeContext:Bi,isValidBase64:Tn,isValidBase64URL:An,isValidJWT:Pn,
locales:qo,meta:Ni,parse:se,parseAsync:ce,prettifyError:ae,process:ji,
regexes:Ct,registry:Ko,safeDecode:_e,safeDecodeAsync:Ce,safeEncode:ke,
safeEncodeAsync:Ee,safeParse:de,safeParseAsync:he,toDotPath:oe,toJSONSchema:Ds,
treeifyError:re,util:Y,version:tn},Symbol.toStringTag,{value:"Module"
})),Ns=Object.freeze(Object.defineProperty({__proto__:null,endsWith:yi,gt:ti,
gte:ni,includes:vi,length:hi,lowercase:mi,lt:Ja,lte:ei,maxLength:di,maxSize:li,
mime:wi,minLength:pi,minSize:ci,multipleOf:si,negative:oi,nonnegative:ii,
nonpositive:ai,normalize:ki,overwrite:xi,positive:ri,property:Oi,regex:fi,
size:ui,slugify:Ei,startsWith:bi,toLowerCase:_i,toUpperCase:Ti,trim:Si,
uppercase:gi},Symbol.toStringTag,{value:"Module"
})),Rs=t("ZodISODateTime",((e,t)=>{vn.init(e,t),ul.init(e,t)}));function Ls(e){
return Ta(Rs,e)}const Bs=t("ZodISODate",((e,t)=>{bn.init(e,t),ul.init(e,t)}))
;function js(e){return Ea(Bs,e)}const Us=t("ZodISOTime",((e,t)=>{
yn.init(e,t),ul.init(e,t)}));function zs(e){return Aa(Us,e)}
const Fs=t("ZodISODuration",((e,t)=>{On.init(e,t),ul.init(e,t)}))
;function Zs(e){return Ca(Fs,e)}const Qs=Object.freeze(Object.defineProperty({
__proto__:null,ZodISODate:Bs,ZodISODateTime:Rs,ZodISODuration:Fs,ZodISOTime:Us,
date:js,datetime:Ls,duration:Zs,time:zs},Symbol.toStringTag,{value:"Module"
})),Hs=(e,t)=>{J.init(e,t),e.name="ZodError",Object.defineProperties(e,{format:{
value:t=>ne(e,t)},flatten:{value:t=>te(e,t)},addIssue:{value:t=>{
e.issues.push(t),e.message=JSON.stringify(e.issues,c,2)}},addIssues:{value:t=>{
e.issues.push(...t),e.message=JSON.stringify(e.issues,c,2)}},isEmpty:{
get:()=>0===e.issues.length}})},Vs=t("ZodError",Hs),qs=t("ZodError",Hs,{
Parent:Error
}),Ws=ie(qs),Xs=le(qs),Gs=ue(qs),Ys=pe(qs),Ks=fe(qs),Js=ge(qs),el=be(qs),tl=Oe(qs),nl=xe(qs),rl=Se(qs),ol=Te(qs),al=Ae(qs),il=t("ZodType",((e,t)=>(nn.init(e,t),
Object.assign(e["~standard"],{jsonSchema:{input:Qi(e,"input"),
output:Qi(e,"output")}
}),e.toJSONSchema=Zi(e,{}),e.def=t,e.type=t.type,Object.defineProperty(e,"_def",{
value:t}),e.check=(...n)=>e.clone(v(t,{
checks:[...t.checks??[],...n.map((e=>"function"==typeof e?{_zod:{check:e,def:{
check:"custom"},onattach:[]}}:e))]}),{parent:!0
}),e.with=e.check,e.clone=(t,n)=>A(e,t,n),
e.brand=()=>e,e.register=(t,n)=>(t.add(e,n),e),e.parse=(t,n)=>Ws(e,t,n,{
callee:e.parse
}),e.safeParse=(t,n)=>Gs(e,t,n),e.parseAsync=async(t,n)=>Xs(e,t,n,{
callee:e.parseAsync
}),e.safeParseAsync=async(t,n)=>Ys(e,t,n),e.spa=e.safeParseAsync,
e.encode=(t,n)=>Ks(e,t,n),
e.decode=(t,n)=>Js(e,t,n),e.encodeAsync=async(t,n)=>el(e,t,n),
e.decodeAsync=async(t,n)=>tl(e,t,n),
e.safeEncode=(t,n)=>nl(e,t,n),e.safeDecode=(t,n)=>rl(e,t,n),
e.safeEncodeAsync=async(t,n)=>ol(e,t,n),e.safeDecodeAsync=async(t,n)=>al(e,t,n),
e.refine=(t,n)=>e.check(Ju(t,n)),
e.superRefine=t=>e.check(ed(t)),e.overwrite=t=>e.check(xi(t)),
e.optional=()=>bu(e),
e.exactOptional=()=>Ou(e),e.nullable=()=>xu(e),e.nullish=()=>bu(xu(e)),
e.nonoptional=t=>Cu(e,t),
e.array=()=>Bc(e),e.or=t=>Hc([e,t]),e.and=t=>Yc(e,t),e.transform=t=>Lu(e,gu(t)),
e.default=t=>_u(e,t),e.prefault=t=>Eu(e,t),e.catch=t=>Iu(e,t),e.pipe=t=>Lu(e,t),
e.readonly=()=>zu(e),e.describe=t=>{const n=e.clone();return Jo.add(n,{
description:t}),n},Object.defineProperty(e,"description",{
get:()=>Jo.get(e)?.description,configurable:!0}),e.meta=(...t)=>{
if(0===t.length)return Jo.get(e);const n=e.clone();return Jo.add(n,t[0]),n
},e.isOptional=()=>e.safeParse(void 0).success,
e.isNullable=()=>e.safeParse(null).success,
e.apply=t=>t(e),e))),sl=t("_ZodString",((e,t)=>{
rn.init(e,t),il.init(e,t),e._zod.processJSONSchema=(t,n,r)=>Vi(e,t,n)
;const n=e._zod.bag
;e.format=n.format??null,e.minLength=n.minimum??null,e.maxLength=n.maximum??null,
e.regex=(...t)=>e.check(fi(...t)),
e.includes=(...t)=>e.check(vi(...t)),e.startsWith=(...t)=>e.check(bi(...t)),
e.endsWith=(...t)=>e.check(yi(...t)),
e.min=(...t)=>e.check(pi(...t)),e.max=(...t)=>e.check(di(...t)),
e.length=(...t)=>e.check(hi(...t)),
e.nonempty=(...t)=>e.check(pi(1,...t)),e.lowercase=t=>e.check(mi(t)),
e.uppercase=t=>e.check(gi(t)),
e.trim=()=>e.check(Si()),e.normalize=(...t)=>e.check(ki(...t)),
e.toLowerCase=()=>e.check(_i()),
e.toUpperCase=()=>e.check(Ti()),e.slugify=()=>e.check(Ei())
})),ll=t("ZodString",((e,t)=>{
rn.init(e,t),sl.init(e,t),e.email=t=>e.check(na(dl,t)),
e.url=t=>e.check(la(Ol,t)),
e.jwt=t=>e.check(Sa(Jl,t)),e.emoji=t=>e.check(ca(kl,t)),
e.guid=t=>e.check(ra(hl,t)),
e.uuid=t=>e.check(oa(ml,t)),e.uuidv4=t=>e.check(aa(ml,t)),
e.uuidv6=t=>e.check(ia(ml,t)),
e.uuidv7=t=>e.check(sa(ml,t)),e.nanoid=t=>e.check(ua(_l,t)),
e.guid=t=>e.check(ra(hl,t)),
e.cuid=t=>e.check(da(El,t)),e.cuid2=t=>e.check(pa(Cl,t)),
e.ulid=t=>e.check(ha(Pl,t)),
e.base64=t=>e.check(wa(ql,t)),e.base64url=t=>e.check(xa(Xl,t)),
e.xid=t=>e.check(fa(Il,t)),
e.ksuid=t=>e.check(ma(Nl,t)),e.ipv4=t=>e.check(ga(Ll,t)),
e.ipv6=t=>e.check(va(zl,t)),
e.cidrv4=t=>e.check(ya(Zl,t)),e.cidrv6=t=>e.check(Oa(Hl,t)),
e.e164=t=>e.check(ka(Yl,t)),
e.datetime=t=>e.check(Ls(t)),e.date=t=>e.check(js(t)),
e.time=t=>e.check(zs(t)),e.duration=t=>e.check(Zs(t))}));function cl(e){
return ea(ll,e)}const ul=t("ZodStringFormat",((e,t)=>{on.init(e,t),sl.init(e,t)
})),dl=t("ZodEmail",((e,t)=>{ln.init(e,t),ul.init(e,t)}));function pl(e){
return na(dl,e)}const hl=t("ZodGUID",((e,t)=>{an.init(e,t),ul.init(e,t)}))
;function fl(e){return ra(hl,e)}const ml=t("ZodUUID",((e,t)=>{
sn.init(e,t),ul.init(e,t)}));function gl(e){return oa(ml,e)}function vl(e){
return aa(ml,e)}function bl(e){return ia(ml,e)}function yl(e){return sa(ml,e)}
const Ol=t("ZodURL",((e,t)=>{cn.init(e,t),ul.init(e,t)}));function wl(e){
return la(Ol,e)}function xl(e){return la(Ol,{protocol:/^https?$/,hostname:et,
...C(e)})}const kl=t("ZodEmoji",((e,t)=>{un.init(e,t),ul.init(e,t)}))
;function Sl(e){return ca(kl,e)}const _l=t("ZodNanoID",((e,t)=>{
dn.init(e,t),ul.init(e,t)}));function Tl(e){return ua(_l,e)}
const El=t("ZodCUID",((e,t)=>{pn.init(e,t),ul.init(e,t)}));function Al(e){
return da(El,e)}const Cl=t("ZodCUID2",((e,t)=>{hn.init(e,t),ul.init(e,t)}))
;function $l(e){return pa(Cl,e)}const Pl=t("ZodULID",((e,t)=>{
fn.init(e,t),ul.init(e,t)}));function Dl(e){return ha(Pl,e)}
const Il=t("ZodXID",((e,t)=>{mn.init(e,t),ul.init(e,t)}));function Ml(e){
return fa(Il,e)}const Nl=t("ZodKSUID",((e,t)=>{gn.init(e,t),ul.init(e,t)}))
;function Rl(e){return ma(Nl,e)}const Ll=t("ZodIPv4",((e,t)=>{
wn.init(e,t),ul.init(e,t)}));function Bl(e){return ga(Ll,e)}
const jl=t("ZodMAC",((e,t)=>{kn.init(e,t),ul.init(e,t)}));function Ul(e){
return ba(jl,e)}const zl=t("ZodIPv6",((e,t)=>{xn.init(e,t),ul.init(e,t)}))
;function Fl(e){return va(zl,e)}const Zl=t("ZodCIDRv4",((e,t)=>{
Sn.init(e,t),ul.init(e,t)}));function Ql(e){return ya(Zl,e)}
const Hl=t("ZodCIDRv6",((e,t)=>{_n.init(e,t),ul.init(e,t)}));function Vl(e){
return Oa(Hl,e)}const ql=t("ZodBase64",((e,t)=>{En.init(e,t),ul.init(e,t)}))
;function Wl(e){return wa(ql,e)}const Xl=t("ZodBase64URL",((e,t)=>{Cn.init(e,t),
ul.init(e,t)}));function Gl(e){return xa(Xl,e)}const Yl=t("ZodE164",((e,t)=>{
$n.init(e,t),ul.init(e,t)}));function Kl(e){return ka(Yl,e)}
const Jl=t("ZodJWT",((e,t)=>{Dn.init(e,t),ul.init(e,t)}));function ec(e){
return Sa(Jl,e)}const tc=t("ZodCustomStringFormat",((e,t)=>{
In.init(e,t),ul.init(e,t)}));function nc(e,t,n={}){return Li(tc,e,t,n)}
function rc(e){return Li(tc,"hostname",Je,e)}function oc(e){
return Li(tc,"hex",gt,e)}function ac(e,t){
const n=`${e}_${t?.enc??"hex"}`,r=Ct[n]
;if(!r)throw new Error(`Unrecognized hash format: ${n}`);return Li(tc,n,r,t)}
const ic=t("ZodNumber",((e,t)=>{
Mn.init(e,t),il.init(e,t),e._zod.processJSONSchema=(t,n,r)=>qi(e,t,n),
e.gt=(t,n)=>e.check(ti(t,n)),
e.gte=(t,n)=>e.check(ni(t,n)),e.min=(t,n)=>e.check(ni(t,n)),
e.lt=(t,n)=>e.check(Ja(t,n)),
e.lte=(t,n)=>e.check(ei(t,n)),e.max=(t,n)=>e.check(ei(t,n)),
e.int=t=>e.check(cc(t)),e.safe=t=>e.check(cc(t)),e.positive=t=>e.check(ti(0,t)),
e.nonnegative=t=>e.check(ni(0,t)),
e.negative=t=>e.check(Ja(0,t)),e.nonpositive=t=>e.check(ei(0,t)),
e.multipleOf=(t,n)=>e.check(si(t,n)),
e.step=(t,n)=>e.check(si(t,n)),e.finite=()=>e;const n=e._zod.bag
;e.minValue=Math.max(n.minimum??Number.NEGATIVE_INFINITY,n.exclusiveMinimum??Number.NEGATIVE_INFINITY)??null,
e.maxValue=Math.min(n.maximum??Number.POSITIVE_INFINITY,n.exclusiveMaximum??Number.POSITIVE_INFINITY)??null,
e.isInt=(n.format??"").includes("int")||Number.isSafeInteger(n.multipleOf??.5),
e.isFinite=!0,e.format=n.format??null}));function sc(e){return $a(ic,e)}
const lc=t("ZodNumberFormat",((e,t)=>{Nn.init(e,t),ic.init(e,t)}))
;function cc(e){return Da(lc,e)}function uc(e){return Ia(lc,e)}function dc(e){
return Ma(lc,e)}function pc(e){return Na(lc,e)}function hc(e){return Ra(lc,e)}
const fc=t("ZodBoolean",((e,t)=>{
Rn.init(e,t),il.init(e,t),e._zod.processJSONSchema=(e,t,n)=>Wi(0,0,t)}))
;function mc(e){return La(fc,e)}const gc=t("ZodBigInt",((e,t)=>{
Ln.init(e,t),il.init(e,t),
e._zod.processJSONSchema=(e,t,n)=>Xi(0,e),e.gte=(t,n)=>e.check(ni(t,n)),
e.min=(t,n)=>e.check(ni(t,n)),
e.gt=(t,n)=>e.check(ti(t,n)),e.gte=(t,n)=>e.check(ni(t,n)),
e.min=(t,n)=>e.check(ni(t,n)),
e.lt=(t,n)=>e.check(Ja(t,n)),e.lte=(t,n)=>e.check(ei(t,n)),
e.max=(t,n)=>e.check(ei(t,n)),
e.positive=t=>e.check(ti(BigInt(0),t)),e.negative=t=>e.check(Ja(BigInt(0),t)),
e.nonpositive=t=>e.check(ei(BigInt(0),t)),
e.nonnegative=t=>e.check(ni(BigInt(0),t)),e.multipleOf=(t,n)=>e.check(si(t,n))
;const n=e._zod.bag
;e.minValue=n.minimum??null,e.maxValue=n.maximum??null,e.format=n.format??null
}));function vc(e){return ja(gc,e)}const bc=t("ZodBigIntFormat",((e,t)=>{
Bn.init(e,t),gc.init(e,t)}));function yc(e){return za(bc,e)}function Oc(e){
return Fa(bc,e)}const wc=t("ZodSymbol",((e,t)=>{
jn.init(e,t),il.init(e,t),e._zod.processJSONSchema=(e,t,n)=>Gi(0,e)}))
;function xc(e){return Za(wc,e)}const kc=t("ZodUndefined",((e,t)=>{Un.init(e,t),
il.init(e,t),e._zod.processJSONSchema=(e,t,n)=>Ki(0,e)}));function Sc(e){
return Qa(kc,e)}const _c=t("ZodNull",((e,t)=>{
zn.init(e,t),il.init(e,t),e._zod.processJSONSchema=(e,t,n)=>Yi(0,e,t)}))
;function Tc(e){return Ha(_c,e)}const Ec=t("ZodAny",((e,t)=>{
Fn.init(e,t),il.init(e,t),e._zod.processJSONSchema=(e,t,n)=>{}}));function Ac(){
return Va(Ec)}const Cc=t("ZodUnknown",((e,t)=>{
Zn.init(e,t),il.init(e,t),e._zod.processJSONSchema=(e,t,n)=>{}}));function $c(){
return qa(Cc)}const Pc=t("ZodNever",((e,t)=>{
Qn.init(e,t),il.init(e,t),e._zod.processJSONSchema=(e,t,n)=>es(0,0,t)}))
;function Dc(e){return Wa(Pc,e)}const Ic=t("ZodVoid",((e,t)=>{
Hn.init(e,t),il.init(e,t),e._zod.processJSONSchema=(e,t,n)=>Ji(0,e)}))
;function Mc(e){return Xa(Ic,e)}const Nc=t("ZodDate",((e,t)=>{
Vn.init(e,t),il.init(e,t),
e._zod.processJSONSchema=(e,t,n)=>rs(0,e),e.min=(t,n)=>e.check(ni(t,n)),
e.max=(t,n)=>e.check(ei(t,n));const n=e._zod.bag
;e.minDate=n.minimum?new Date(n.minimum):null,
e.maxDate=n.maximum?new Date(n.maximum):null}));function Rc(e){return Ga(Nc,e)}
const Lc=t("ZodArray",((e,t)=>{
Wn.init(e,t),il.init(e,t),e._zod.processJSONSchema=(t,n,r)=>ms(e,t,n,r),
e.element=t.element,
e.min=(t,n)=>e.check(pi(t,n)),e.nonempty=t=>e.check(pi(1,t)),
e.max=(t,n)=>e.check(di(t,n)),
e.length=(t,n)=>e.check(hi(t,n)),e.unwrap=()=>e.element}));function Bc(e,t){
return Ai(Lc,e,t)}function jc(e){const t=e._zod.def.shape
;return cu(Object.keys(t))}const Uc=t("ZodObject",((e,t)=>{
Jn.init(e,t),il.init(e,t),
e._zod.processJSONSchema=(t,n,r)=>gs(e,t,n,r),m(e,"shape",(()=>t.shape)),
e.keyof=()=>cu(Object.keys(e._zod.def.shape)),e.catchall=t=>e.clone({
...e._zod.def,catchall:t}),e.passthrough=()=>e.clone({...e._zod.def,
catchall:$c()}),e.loose=()=>e.clone({...e._zod.def,catchall:$c()
}),e.strict=()=>e.clone({...e._zod.def,catchall:Dc()}),e.strip=()=>e.clone({
...e._zod.def,catchall:void 0
}),e.extend=t=>R(e,t),e.safeExtend=t=>L(e,t),e.merge=t=>B(e,t),e.pick=t=>M(e,t),
e.omit=t=>N(e,t),e.partial=(...t)=>j(vu,e,t[0]),e.required=(...t)=>U(Au,e,t[0])
}));function zc(e,t){const n={type:"object",shape:e??{},...C(t)}
;return new Uc(n)}function Fc(e,t){return new Uc({type:"object",shape:e,
catchall:Dc(),...C(t)})}function Zc(e,t){return new Uc({type:"object",shape:e,
catchall:$c(),...C(t)})}const Qc=t("ZodUnion",((e,t)=>{
tr.init(e,t),il.init(e,t),
e._zod.processJSONSchema=(t,n,r)=>vs(e,t,n,r),e.options=t.options}))
;function Hc(e,t){return new Qc({type:"union",options:e,...C(t)})}
const Vc=t("ZodXor",((e,t)=>{
Qc.init(e,t),rr.init(e,t),e._zod.processJSONSchema=(t,n,r)=>vs(e,t,n,r),
e.options=t.options}));function qc(e,t){return new Vc({type:"union",options:e,
inclusive:!1,...C(t)})}const Wc=t("ZodDiscriminatedUnion",((e,t)=>{Qc.init(e,t),
or.init(e,t)}));function Xc(e,t,n){return new Wc({type:"union",options:t,
discriminator:e,...C(n)})}const Gc=t("ZodIntersection",((e,t)=>{
ar.init(e,t),il.init(e,t),e._zod.processJSONSchema=(t,n,r)=>bs(e,t,n,r)}))
;function Yc(e,t){return new Gc({type:"intersection",left:e,right:t})}
const Kc=t("ZodTuple",((e,t)=>{
lr.init(e,t),il.init(e,t),e._zod.processJSONSchema=(t,n,r)=>ys(e,t,n,r),
e.rest=t=>e.clone({...e._zod.def,rest:t})}));function Jc(e,t,n){
const r=t instanceof nn;return new Kc({type:"tuple",items:e,rest:r?t:null,
...C(r?n:t)})}const eu=t("ZodRecord",((e,t)=>{
ur.init(e,t),il.init(e,t),e._zod.processJSONSchema=(t,n,r)=>Os(e,t,n,r),
e.keyType=t.keyType,e.valueType=t.valueType}));function tu(e,t,n){
return new eu({type:"record",keyType:e,valueType:t,...C(n)})}function nu(e,t,n){
const r=A(e);return r._zod.values=void 0,new eu({type:"record",keyType:r,
valueType:t,...C(n)})}function ru(e,t,n){return new eu({type:"record",keyType:e,
valueType:t,mode:"loose",...C(n)})}const ou=t("ZodMap",((e,t)=>{
dr.init(e,t),il.init(e,t),
e._zod.processJSONSchema=(e,t,n)=>hs(0,e),e.keyType=t.keyType,
e.valueType=t.valueType,
e.min=(...t)=>e.check(ci(...t)),e.nonempty=t=>e.check(ci(1,t)),
e.max=(...t)=>e.check(li(...t)),e.size=(...t)=>e.check(ui(...t))}))
;function au(e,t,n){return new ou({type:"map",keyType:e,valueType:t,...C(n)})}
const iu=t("ZodSet",((e,t)=>{
hr.init(e,t),il.init(e,t),e._zod.processJSONSchema=(e,t,n)=>fs(0,e),
e.min=(...t)=>e.check(ci(...t)),
e.nonempty=t=>e.check(ci(1,t)),e.max=(...t)=>e.check(li(...t)),
e.size=(...t)=>e.check(ui(...t))}));function su(e,t){return new iu({type:"set",
valueType:e,...C(t)})}const lu=t("ZodEnum",((e,t)=>{
mr.init(e,t),il.init(e,t),e._zod.processJSONSchema=(t,n,r)=>os(e,0,n),
e.enum=t.entries,e.options=Object.values(t.entries)
;const n=new Set(Object.keys(t.entries));e.extract=(e,r)=>{const o={}
;for(const a of e){if(!n.has(a))throw new Error(`Key ${a} not found in enum`)
;o[a]=t.entries[a]}return new lu({...t,checks:[],...C(r),entries:o})
},e.exclude=(e,r)=>{const o={...t.entries};for(const t of e){
if(!n.has(t))throw new Error(`Key ${t} not found in enum`);delete o[t]}
return new lu({...t,checks:[],...C(r),entries:o})}}));function cu(e,t){
const n=Array.isArray(e)?Object.fromEntries(e.map((e=>[e,e]))):e;return new lu({
type:"enum",entries:n,...C(t)})}function uu(e,t){return new lu({type:"enum",
entries:e,...C(t)})}const du=t("ZodLiteral",((e,t)=>{
gr.init(e,t),il.init(e,t),e._zod.processJSONSchema=(t,n,r)=>as(e,t,n),
e.values=new Set(t.values),Object.defineProperty(e,"value",{get(){
if(t.values.length>1)throw new Error("This schema contains multiple valid literal values. Use `.values` instead.")
;return t.values[0]}})}));function pu(e,t){return new du({type:"literal",
values:Array.isArray(e)?e:[e],...C(t)})}const hu=t("ZodFile",((e,t)=>{
vr.init(e,t),
il.init(e,t),e._zod.processJSONSchema=(t,n,r)=>ls(e,0,n),e.min=(t,n)=>e.check(ci(t,n)),
e.max=(t,n)=>e.check(li(t,n)),
e.mime=(t,n)=>e.check(wi(Array.isArray(t)?t:[t],n))}));function fu(e){
return Ci(hu,e)}const mu=t("ZodTransform",((e,t)=>{
br.init(e,t),il.init(e,t),e._zod.processJSONSchema=(e,t,n)=>ps(0,e),
e._zod.parse=(n,r)=>{if("backward"===r.direction)throw new o(e.constructor.name)
;n.addIssue=r=>{if("string"==typeof r)n.issues.push(W(r,n.value,t));else{
const t=r
;t.fatal&&(t.continue=!1),t.code??(t.code="custom"),t.input??(t.input=n.value),
t.inst??(t.inst=e),n.issues.push(W(t))}};const a=t.transform(n.value,n)
;return a instanceof Promise?a.then((e=>(n.value=e,n))):(n.value=a,n)}}))
;function gu(e){return new mu({type:"transform",transform:e})}
const vu=t("ZodOptional",((e,t)=>{
Or.init(e,t),il.init(e,t),e._zod.processJSONSchema=(t,n,r)=>Cs(e,t,0,r),
e.unwrap=()=>e._zod.def.innerType}));function bu(e){return new vu({
type:"optional",innerType:e})}const yu=t("ZodExactOptional",((e,t)=>{
wr.init(e,t),
il.init(e,t),e._zod.processJSONSchema=(t,n,r)=>Cs(e,t,0,r),e.unwrap=()=>e._zod.def.innerType
}));function Ou(e){return new yu({type:"optional",innerType:e})}
const wu=t("ZodNullable",((e,t)=>{
xr.init(e,t),il.init(e,t),e._zod.processJSONSchema=(t,n,r)=>ws(e,t,n,r),
e.unwrap=()=>e._zod.def.innerType}));function xu(e){return new wu({
type:"nullable",innerType:e})}function ku(e){return bu(xu(e))}
const Su=t("ZodDefault",((e,t)=>{
kr.init(e,t),il.init(e,t),e._zod.processJSONSchema=(t,n,r)=>ks(e,t,n,r),
e.unwrap=()=>e._zod.def.innerType,e.removeDefault=e.unwrap}));function _u(e,t){
return new Su({type:"default",innerType:e,get defaultValue(){
return"function"==typeof t?t():S(t)}})}const Tu=t("ZodPrefault",((e,t)=>{
_r.init(e,t),
il.init(e,t),e._zod.processJSONSchema=(t,n,r)=>Ss(e,t,n,r),e.unwrap=()=>e._zod.def.innerType
}));function Eu(e,t){return new Tu({type:"prefault",innerType:e,
get defaultValue(){return"function"==typeof t?t():S(t)}})}
const Au=t("ZodNonOptional",((e,t)=>{
Tr.init(e,t),il.init(e,t),e._zod.processJSONSchema=(t,n,r)=>xs(e,t,0,r),
e.unwrap=()=>e._zod.def.innerType}));function Cu(e,t){return new Au({
type:"nonoptional",innerType:e,...C(t)})}const $u=t("ZodSuccess",((e,t)=>{
Ar.init(e,t),
il.init(e,t),e._zod.processJSONSchema=(e,t,n)=>cs(0,0,t),e.unwrap=()=>e._zod.def.innerType
}));function Pu(e){return new $u({type:"success",innerType:e})}
const Du=t("ZodCatch",((e,t)=>{
Cr.init(e,t),il.init(e,t),e._zod.processJSONSchema=(t,n,r)=>_s(e,t,n,r),
e.unwrap=()=>e._zod.def.innerType,e.removeCatch=e.unwrap}));function Iu(e,t){
return new Du({type:"catch",innerType:e,catchValue:"function"==typeof t?t:()=>t
})}const Mu=t("ZodNaN",((e,t)=>{
$r.init(e,t),il.init(e,t),e._zod.processJSONSchema=(e,t,n)=>is(0,e)}))
;function Nu(e){return Ka(Mu,e)}const Ru=t("ZodPipe",((e,t)=>{
Pr.init(e,t),il.init(e,t),
e._zod.processJSONSchema=(t,n,r)=>Ts(e,t,0,r),e.in=t.in,e.out=t.out}))
;function Lu(e,t){return new Ru({type:"pipe",in:e,out:t})}
const Bu=t("ZodCodec",((e,t)=>{Ru.init(e,t),Ir.init(e,t)}));function ju(e,t,n){
return new Bu({type:"pipe",in:e,out:t,transform:n.decode,
reverseTransform:n.encode})}const Uu=t("ZodReadonly",((e,t)=>{
Rr.init(e,t),il.init(e,t),
e._zod.processJSONSchema=(t,n,r)=>Es(e,t,n,r),e.unwrap=()=>e._zod.def.innerType
}));function zu(e){return new Uu({type:"readonly",innerType:e})}
const Fu=t("ZodTemplateLiteral",((e,t)=>{
Br.init(e,t),il.init(e,t),e._zod.processJSONSchema=(t,n,r)=>ss(e,0,n)}))
;function Zu(e,t){return new Fu({type:"template_literal",parts:e,...C(t)})}
const Qu=t("ZodLazy",((e,t)=>{
zr.init(e,t),il.init(e,t),e._zod.processJSONSchema=(t,n,r)=>$s(e,t,0,r),
e.unwrap=()=>e._zod.def.getter()}));function Hu(e){return new Qu({type:"lazy",
getter:e})}const Vu=t("ZodPromise",((e,t)=>{
Ur.init(e,t),il.init(e,t),e._zod.processJSONSchema=(t,n,r)=>As(e,t,0,r),
e.unwrap=()=>e._zod.def.innerType}));function qu(e){return new Vu({
type:"promise",innerType:e})}const Wu=t("ZodFunction",((e,t)=>{
jr.init(e,t),il.init(e,t),e._zod.processJSONSchema=(e,t,n)=>ds(0,e)}))
;function Xu(e){return new Wu({type:"function",
input:Array.isArray(e?.input)?Jc(e?.input):e?.input??Bc($c()),
output:e?.output??$c()})}const Gu=t("ZodCustom",((e,t)=>{
Fr.init(e,t),il.init(e,t),e._zod.processJSONSchema=(e,t,n)=>us(0,e)}))
;function Yu(e){const t=new $t({check:"custom"});return t._zod.check=e,t}
function Ku(e,t){return $i(Gu,e??(()=>!0),t)}function Ju(e,t={}){
return Pi(Gu,e,t)}function ed(e){return Di(e)}const td=Mi,nd=Ni
;function rd(e,t={}){const n=new Gu({type:"custom",check:"custom",
fn:t=>t instanceof e,abort:!0,...C(t)})
;return n._zod.bag.Class=e,n._zod.check=t=>{
t.value instanceof e||t.issues.push({code:"invalid_type",expected:e.name,
input:t.value,inst:n,path:[...n._zod.def.path??[]]})},n}const od=(...e)=>Ri({
Codec:Bu,Boolean:fc,String:ll},...e);function ad(e){
const t=Hu((()=>Hc([cl(e),sc(),mc(),Tc(),Bc(t),tu(cl(),t)])));return t}
function id(e,t){return Lu(gu(e),t)}
const sd=Object.freeze(Object.defineProperty({__proto__:null,ZodAny:Ec,
ZodArray:Lc,ZodBase64:ql,ZodBase64URL:Xl,ZodBigInt:gc,ZodBigIntFormat:bc,
ZodBoolean:fc,ZodCIDRv4:Zl,ZodCIDRv6:Hl,ZodCUID:El,ZodCUID2:Cl,ZodCatch:Du,
ZodCodec:Bu,ZodCustom:Gu,ZodCustomStringFormat:tc,ZodDate:Nc,ZodDefault:Su,
ZodDiscriminatedUnion:Wc,ZodE164:Yl,ZodEmail:dl,ZodEmoji:kl,ZodEnum:lu,
ZodExactOptional:yu,ZodFile:hu,ZodFunction:Wu,ZodGUID:hl,ZodIPv4:Ll,ZodIPv6:zl,
ZodIntersection:Gc,ZodJWT:Jl,ZodKSUID:Nl,ZodLazy:Qu,ZodLiteral:du,ZodMAC:jl,
ZodMap:ou,ZodNaN:Mu,ZodNanoID:_l,ZodNever:Pc,ZodNonOptional:Au,ZodNull:_c,
ZodNullable:wu,ZodNumber:ic,ZodNumberFormat:lc,ZodObject:Uc,ZodOptional:vu,
ZodPipe:Ru,ZodPrefault:Tu,ZodPromise:Vu,ZodReadonly:Uu,ZodRecord:eu,ZodSet:iu,
ZodString:ll,ZodStringFormat:ul,ZodSuccess:$u,ZodSymbol:wc,
ZodTemplateLiteral:Fu,ZodTransform:mu,ZodTuple:Kc,ZodType:il,ZodULID:Pl,
ZodURL:Ol,ZodUUID:ml,ZodUndefined:kc,ZodUnion:Qc,ZodUnknown:Cc,ZodVoid:Ic,
ZodXID:Il,ZodXor:Vc,_ZodString:sl,_default:_u,_function:Xu,any:Ac,array:Bc,
base64:Wl,base64url:Gl,bigint:vc,boolean:mc,catch:Iu,check:Yu,cidrv4:Ql,
cidrv6:Vl,codec:ju,cuid:Al,cuid2:$l,custom:Ku,date:Rc,describe:td,
discriminatedUnion:Xc,e164:Kl,email:pl,emoji:Sl,enum:cu,exactOptional:Ou,
file:fu,float32:uc,float64:dc,function:Xu,guid:fl,hash:ac,hex:oc,hostname:rc,
httpUrl:xl,instanceof:rd,int:cc,int32:pc,int64:yc,intersection:Yc,ipv4:Bl,
ipv6:Fl,json:ad,jwt:ec,keyof:jc,ksuid:Rl,lazy:Hu,literal:pu,looseObject:Zc,
looseRecord:ru,mac:Ul,map:au,meta:nd,nan:Nu,nanoid:Tl,nativeEnum:uu,never:Dc,
nonoptional:Cu,null:Tc,nullable:xu,nullish:ku,number:sc,object:zc,optional:bu,
partialRecord:nu,pipe:Lu,prefault:Eu,preprocess:id,promise:qu,readonly:zu,
record:tu,refine:Ju,set:su,strictObject:Fc,string:cl,stringFormat:nc,
stringbool:od,success:Pu,superRefine:ed,symbol:xc,templateLiteral:Zu,
transform:gu,tuple:Jc,uint32:hc,uint64:Oc,ulid:Dl,undefined:Sc,union:Hc,
unknown:$c,url:wl,uuid:gl,uuidv4:vl,uuidv6:bl,uuidv7:yl,void:Mc,xid:Ml,xor:qc
},Symbol.toStringTag,{value:"Module"}));var ld;ld||(ld={});const cd={...sd,
...Ns,iso:Qs
},ud=new Set(["$schema","$ref","$defs","definitions","$id","id","$comment","$anchor","$vocabulary","$dynamicRef","$dynamicAnchor","type","enum","const","anyOf","oneOf","allOf","not","properties","required","additionalProperties","patternProperties","propertyNames","minProperties","maxProperties","items","prefixItems","additionalItems","minItems","maxItems","uniqueItems","contains","minContains","maxContains","minLength","maxLength","pattern","format","minimum","maximum","exclusiveMinimum","exclusiveMaximum","multipleOf","description","default","contentEncoding","contentMediaType","contentSchema","unevaluatedItems","unevaluatedProperties","if","then","else","dependentSchemas","dependentRequired","nullable","readOnly"])
;function dd(e,t){if(void 0!==e.not){
if("object"==typeof e.not&&0===Object.keys(e.not).length)return cd.never()
;throw new Error("not is not supported in Zod (except { not: {} } for never)")}
if(void 0!==e.unevaluatedItems)throw new Error("unevaluatedItems is not supported")
;if(void 0!==e.unevaluatedProperties)throw new Error("unevaluatedProperties is not supported")
;if(void 0!==e.if||void 0!==e.then||void 0!==e.else)throw new Error("Conditional schemas (if/then/else) are not supported")
;if(void 0!==e.dependentSchemas||void 0!==e.dependentRequired)throw new Error("dependentSchemas and dependentRequired are not supported")
;if(e.$ref){const n=e.$ref;if(t.refs.has(n))return t.refs.get(n)
;if(t.processing.has(n))return cd.lazy((()=>{
if(!t.refs.has(n))throw new Error(`Circular reference not resolved: ${n}`)
;return t.refs.get(n)}));t.processing.add(n);const r=function(e,t){
if(!e.startsWith("#"))throw new Error("External $ref is not supported, only local refs (#/...) are allowed")
;const n=e.slice(1).split("/").filter(Boolean)
;if(0===n.length)return t.rootSchema
;const r="draft-2020-12"===t.version?"$defs":"definitions";if(n[0]===r){
const r=n[1];if(!r||!t.defs[r])throw new Error(`Reference not found: ${e}`)
;return t.defs[r]}throw new Error(`Reference not found: ${e}`)}(n,t),o=pd(r,t)
;return t.refs.set(n,o),t.processing.delete(n),o}if(void 0!==e.enum){
const n=e.enum
;if("openapi-3.0"===t.version&&!0===e.nullable&&1===n.length&&null===n[0])return cd.null()
;if(0===n.length)return cd.never();if(1===n.length)return cd.literal(n[0])
;if(n.every((e=>"string"==typeof e)))return cd.enum(n)
;const r=n.map((e=>cd.literal(e)))
;return r.length<2?r[0]:cd.union([r[0],r[1],...r.slice(2)])}
if(void 0!==e.const)return cd.literal(e.const);const n=e.type
;if(Array.isArray(n)){const r=n.map((n=>dd({...e,type:n},t)))
;return 0===r.length?cd.never():1===r.length?r[0]:cd.union(r)}
if(!n)return cd.any();let r;switch(n){case"string":{let t=cd.string()
;if(e.format){const n=e.format
;"email"===n?t=t.check(cd.email()):"uri"===n||"uri-reference"===n?t=t.check(cd.url()):"uuid"===n||"guid"===n?t=t.check(cd.uuid()):"date-time"===n?t=t.check(cd.iso.datetime()):"date"===n?t=t.check(cd.iso.date()):"time"===n?t=t.check(cd.iso.time()):"duration"===n?t=t.check(cd.iso.duration()):"ipv4"===n?t=t.check(cd.ipv4()):"ipv6"===n?t=t.check(cd.ipv6()):"mac"===n?t=t.check(cd.mac()):"cidr"===n?t=t.check(cd.cidrv4()):"cidr-v6"===n?t=t.check(cd.cidrv6()):"base64"===n?t=t.check(cd.base64()):"base64url"===n?t=t.check(cd.base64url()):"e164"===n?t=t.check(cd.e164()):"jwt"===n?t=t.check(cd.jwt()):"emoji"===n?t=t.check(cd.emoji()):"nanoid"===n?t=t.check(cd.nanoid()):"cuid"===n?t=t.check(cd.cuid()):"cuid2"===n?t=t.check(cd.cuid2()):"ulid"===n?t=t.check(cd.ulid()):"xid"===n?t=t.check(cd.xid()):"ksuid"===n&&(t=t.check(cd.ksuid()))
}
"number"==typeof e.minLength&&(t=t.min(e.minLength)),"number"==typeof e.maxLength&&(t=t.max(e.maxLength)),
e.pattern&&(t=t.regex(new RegExp(e.pattern))),r=t;break}case"number":
case"integer":{let t="integer"===n?cd.number().int():cd.number()
;"number"==typeof e.minimum&&(t=t.min(e.minimum)),
"number"==typeof e.maximum&&(t=t.max(e.maximum)),
"number"==typeof e.exclusiveMinimum?t=t.gt(e.exclusiveMinimum):!0===e.exclusiveMinimum&&"number"==typeof e.minimum&&(t=t.gt(e.minimum)),
"number"==typeof e.exclusiveMaximum?t=t.lt(e.exclusiveMaximum):!0===e.exclusiveMaximum&&"number"==typeof e.maximum&&(t=t.lt(e.maximum)),
"number"==typeof e.multipleOf&&(t=t.multipleOf(e.multipleOf)),r=t;break}
case"boolean":r=cd.boolean();break;case"null":r=cd.null();break;case"object":{
const n={},o=e.properties||{},a=new Set(e.required||[])
;for(const[e,r]of Object.entries(o)){const o=pd(r,t)
;n[e]=a.has(e)?o:o.optional()}if(e.propertyNames){
const o=pd(e.propertyNames,t),a=e.additionalProperties&&"object"==typeof e.additionalProperties?pd(e.additionalProperties,t):cd.any()
;if(0===Object.keys(n).length){r=cd.record(o,a);break}
const i=cd.object(n).passthrough(),s=cd.looseRecord(o,a);r=cd.intersection(i,s)
;break}if(e.patternProperties){const o=e.patternProperties,a=Object.keys(o),i=[]
;for(const e of a){const n=pd(o[e],t),r=cd.string().regex(new RegExp(e))
;i.push(cd.looseRecord(r,n))}const s=[]
;if(Object.keys(n).length>0&&s.push(cd.object(n).passthrough()),
s.push(...i),0===s.length)r=cd.object({}).passthrough();else if(1===s.length)r=s[0];else{
let e=cd.intersection(s[0],s[1])
;for(let t=2;t<s.length;t++)e=cd.intersection(e,s[t]);r=e}break}
const i=cd.object(n)
;r=!1===e.additionalProperties?i.strict():"object"==typeof e.additionalProperties?i.catchall(pd(e.additionalProperties,t)):i.passthrough()
;break}case"array":{const n=e.prefixItems,o=e.items;if(n&&Array.isArray(n)){
const a=n.map((e=>pd(e,t))),i=o&&"object"==typeof o&&!Array.isArray(o)?pd(o,t):void 0
;r=i?cd.tuple(a).rest(i):cd.tuple(a),
"number"==typeof e.minItems&&(r=r.check(cd.minLength(e.minItems))),
"number"==typeof e.maxItems&&(r=r.check(cd.maxLength(e.maxItems)))
}else if(Array.isArray(o)){
const n=o.map((e=>pd(e,t))),a=e.additionalItems&&"object"==typeof e.additionalItems?pd(e.additionalItems,t):void 0
;r=a?cd.tuple(n).rest(a):cd.tuple(n),
"number"==typeof e.minItems&&(r=r.check(cd.minLength(e.minItems))),
"number"==typeof e.maxItems&&(r=r.check(cd.maxLength(e.maxItems)))
}else if(void 0!==o){const n=pd(o,t);let a=cd.array(n)
;"number"==typeof e.minItems&&(a=a.min(e.minItems)),
"number"==typeof e.maxItems&&(a=a.max(e.maxItems)),r=a}else r=cd.array(cd.any())
;break}default:throw new Error(`Unsupported type: ${n}`)}
return e.description&&(r=r.describe(e.description)),
void 0!==e.default&&(r=r.default(e.default)),r}function pd(e,t){
if("boolean"==typeof e)return e?cd.any():cd.never();let n=dd(e,t)
;const r=e.type||void 0!==e.enum||void 0!==e.const
;if(e.anyOf&&Array.isArray(e.anyOf)){
const o=e.anyOf.map((e=>pd(e,t))),a=cd.union(o);n=r?cd.intersection(n,a):a}
if(e.oneOf&&Array.isArray(e.oneOf)){
const o=e.oneOf.map((e=>pd(e,t))),a=cd.xor(o);n=r?cd.intersection(n,a):a}
if(e.allOf&&Array.isArray(e.allOf))if(0===e.allOf.length)n=r?n:cd.any();else{
let o=r?n:pd(e.allOf[0],t)
;for(let n=r?0:1;n<e.allOf.length;n++)o=cd.intersection(o,pd(e.allOf[n],t));n=o}
!0===e.nullable&&"openapi-3.0"===t.version&&(n=cd.nullable(n)),
!0===e.readOnly&&(n=cd.readonly(n))
;const o={},a=["$id","id","$comment","$anchor","$vocabulary","$dynamicRef","$dynamicAnchor"]
;for(const s of a)s in e&&(o[s]=e[s])
;const i=["contentEncoding","contentMediaType","contentSchema"]
;for(const s of i)s in e&&(o[s]=e[s])
;for(const s of Object.keys(e))ud.has(s)||(o[s]=e[s])
;return Object.keys(o).length>0&&t.registry.add(n,o),n}function hd(e){
return ta(ll,e)}const fd=Object.freeze(Object.defineProperty({__proto__:null,
bigint:function(e){return Ua(gc,e)},boolean:function(e){return Ba(fc,e)},
date:function(e){return Ya(Nc,e)},number:function(e){return Pa(ic,e)},string:hd
},Symbol.toStringTag,{value:"Module"}));i(eo())
;const md=Object.freeze(Object.defineProperty({__proto__:null,$brand:n,
$input:Go,$output:Xo,NEVER:e,TimePrecision:_a,ZodAny:Ec,ZodArray:Lc,
ZodBase64:ql,ZodBase64URL:Xl,ZodBigInt:gc,ZodBigIntFormat:bc,ZodBoolean:fc,
ZodCIDRv4:Zl,ZodCIDRv6:Hl,ZodCUID:El,ZodCUID2:Cl,ZodCatch:Du,ZodCodec:Bu,
ZodCustom:Gu,ZodCustomStringFormat:tc,ZodDate:Nc,ZodDefault:Su,
ZodDiscriminatedUnion:Wc,ZodE164:Yl,ZodEmail:dl,ZodEmoji:kl,ZodEnum:lu,
ZodError:Vs,ZodExactOptional:yu,ZodFile:hu,get ZodFirstPartyTypeKind(){return ld
},ZodFunction:Wu,ZodGUID:hl,ZodIPv4:Ll,ZodIPv6:zl,ZodISODate:Bs,
ZodISODateTime:Rs,ZodISODuration:Fs,ZodISOTime:Us,ZodIntersection:Gc,
ZodIssueCode:{invalid_type:"invalid_type",too_big:"too_big",
too_small:"too_small",invalid_format:"invalid_format",
not_multiple_of:"not_multiple_of",unrecognized_keys:"unrecognized_keys",
invalid_union:"invalid_union",invalid_key:"invalid_key",
invalid_element:"invalid_element",invalid_value:"invalid_value",custom:"custom"
},ZodJWT:Jl,ZodKSUID:Nl,ZodLazy:Qu,ZodLiteral:du,ZodMAC:jl,ZodMap:ou,ZodNaN:Mu,
ZodNanoID:_l,ZodNever:Pc,ZodNonOptional:Au,ZodNull:_c,ZodNullable:wu,
ZodNumber:ic,ZodNumberFormat:lc,ZodObject:Uc,ZodOptional:vu,ZodPipe:Ru,
ZodPrefault:Tu,ZodPromise:Vu,ZodReadonly:Uu,ZodRealError:qs,ZodRecord:eu,
ZodSet:iu,ZodString:ll,ZodStringFormat:ul,ZodSuccess:$u,ZodSymbol:wc,
ZodTemplateLiteral:Fu,ZodTransform:mu,ZodTuple:Kc,ZodType:il,ZodULID:Pl,
ZodURL:Ol,ZodUUID:ml,ZodUndefined:kc,ZodUnion:Qc,ZodUnknown:Cc,ZodVoid:Ic,
ZodXID:Il,ZodXor:Vc,_ZodString:sl,_default:_u,_function:Xu,any:Ac,array:Bc,
base64:Wl,base64url:Gl,bigint:vc,boolean:mc,catch:Iu,check:Yu,cidrv4:Ql,
cidrv6:Vl,clone:A,codec:ju,coerce:fd,config:i,core:Ms,cuid:Al,cuid2:$l,
custom:Ku,date:Rc,decode:Js,decodeAsync:tl,describe:td,discriminatedUnion:Xc,
e164:Kl,email:pl,emoji:Sl,encode:Ks,encodeAsync:el,endsWith:yi,enum:cu,
exactOptional:Ou,file:fu,flattenError:te,float32:uc,float64:dc,formatError:ne,
fromJSONSchema:function(e,t){if("boolean"==typeof e)return e?cd.any():cd.never()
;const n=function(e,t){const n=e.$schema
;return"https://json-schema.org/draft/2020-12/schema"===n?"draft-2020-12":"http://json-schema.org/draft-07/schema#"===n?"draft-7":"http://json-schema.org/draft-04/schema#"===n?"draft-4":t??"draft-2020-12"
}(e,t?.defaultTarget);return pd(e,{version:n,defs:e.$defs||e.definitions||{},
refs:new Map,processing:new Set,rootSchema:e,registry:t?.registry??Jo})},
function:Xu,getErrorMap:function(){return i().customError},globalRegistry:Jo,
gt:ti,gte:ni,guid:fl,hash:ac,hex:oc,hostname:rc,httpUrl:xl,includes:vi,
instanceof:rd,int:cc,int32:pc,int64:yc,intersection:Yc,ipv4:Bl,ipv6:Fl,iso:Qs,
json:ad,jwt:ec,keyof:jc,ksuid:Rl,lazy:Hu,length:hi,literal:pu,locales:qo,
looseObject:Zc,looseRecord:ru,lowercase:mi,lt:Ja,lte:ei,mac:Ul,map:au,
maxLength:di,maxSize:li,meta:nd,mime:wi,minLength:pi,minSize:ci,multipleOf:si,
nan:Nu,nanoid:Tl,nativeEnum:uu,negative:oi,never:Dc,nonnegative:ii,
nonoptional:Cu,nonpositive:ai,normalize:ki,null:Tc,nullable:xu,nullish:ku,
number:sc,object:zc,optional:bu,overwrite:xi,parse:Ws,parseAsync:Xs,
partialRecord:nu,pipe:Lu,positive:ri,prefault:Eu,preprocess:id,prettifyError:ae,
promise:qu,property:Oi,readonly:zu,record:tu,refine:Ju,regex:fi,regexes:Ct,
registry:Ko,safeDecode:rl,safeDecodeAsync:al,safeEncode:nl,safeEncodeAsync:ol,
safeParse:Gs,safeParseAsync:Ys,set:su,setErrorMap:function(e){i({customError:e})
},size:ui,slugify:Ei,startsWith:bi,strictObject:Fc,string:cl,stringFormat:nc,
stringbool:od,success:Pu,superRefine:ed,symbol:xc,templateLiteral:Zu,
toJSONSchema:Ds,toLowerCase:_i,toUpperCase:Ti,transform:gu,treeifyError:re,
trim:Si,tuple:Jc,uint32:hc,uint64:Oc,ulid:Dl,undefined:Sc,union:Hc,unknown:$c,
uppercase:gi,url:wl,util:Y,uuid:gl,uuidv4:vl,uuidv6:bl,uuidv7:yl,void:Mc,xid:Ml,
xor:qc},Symbol.toStringTag,{value:"Module"})),gd=zc({title:cl().optional(),
component:$c(),props:tu(cl(),Ac()).optional()}),vd=zc({
"request.section":Bc(gd).optional(),"response.section":Bc(gd).optional()
}),bd=zc({onBeforeRequest:Xu({input:[zc({request:rd(Request)})]}).optional(),
onResponseReceived:Xu({input:[zc({response:rd(Response),operation:tu(cl(),Ac())
})]}).optional()}),yd=Xu({input:[],output:zc({name:cl(),views:vd.optional(),
hooks:bd.optional()})
}),Od="https://api.scalar.com/request-proxy",wd="https://proxy.scalar.com",xd=md.object({
title:md.string().optional(),slug:md.string().optional(),
authentication:md.any().optional(),baseServerURL:md.string().optional(),
hideClientButton:md.boolean().optional().default(!1).catch(!1),
proxyUrl:md.string().optional(),
searchHotKey:md.enum(["a","b","c","d","e","f","g","h","i","j","k","l","m","n","o","p","q","r","s","t","u","v","w","x","y","z"]).optional(),
servers:md.array(md.any()).optional(),
showSidebar:md.boolean().optional().default(!0).catch(!0),
showDeveloperTools:md.enum(["always","localhost","never"]).optional().default("localhost").catch("localhost"),
showToolbar:md.enum(["always","localhost","never"]).optional().default("localhost").catch("localhost"),
operationTitleSource:md.enum(["summary","path"]).optional().default("summary").catch("summary"),
theme:md.enum(["alternate","default","moon","purple","solarized","bluePlanet","deepSpace","saturn","kepler","elysiajs","fastify","mars","laserwave","none"]).optional().default("default").catch("default"),
_integration:md.enum(["adonisjs","astro","docusaurus","dotnet","elysiajs","express","fastapi","fastify","go","hono","html","laravel","litestar","nestjs","nextjs","nitro","nuxt","platformatic","react","rust","svelte","vue"]).nullable().optional(),
onRequestSent:md.function({input:[md.string()],output:md.void()}).optional(),
persistAuth:md.boolean().optional().default(!1).catch(!1),
plugins:md.array(yd).optional(),telemetry:md.boolean().optional().default(!0)
}),kd=md.object({default:md.boolean().default(!1).optional().catch(!1),
url:md.string().optional(),
content:md.union([md.string(),md.null(),md.record(md.string(),md.any()),md.function({
input:[],output:md.record(md.string(),md.any())})]).optional(),
title:md.string().optional(),slug:md.string().optional(),spec:md.object({
url:md.string().optional(),
content:md.union([md.string(),md.null(),md.record(md.string(),md.any()),md.function({
input:[],output:md.record(md.string(),md.any())})]).optional()}).optional()})
;xd.extend(kd.shape);const Sd=zc({name:cl().regex(/^x-/),component:$c(),
renderer:$c().optional()}),_d=zc({component:$c(),renderer:$c().optional(),
props:tu(cl(),Ac()).optional()}),Td=zc({"content.end":Bc(_d).optional()
}),Ed=Xu({input:[],output:zc({name:cl(),extensions:Bc(Sd),views:Td.optional()})
}),Ad=Ku(),Cd=xd.extend({
layout:cu(["modern","classic"]).optional().default("modern").catch("modern"),
proxy:cl().optional(),fetch:Ad.optional(),plugins:Bc(Ed).optional(),
isEditable:mc().optional().default(!1).catch(!1),
isLoading:mc().optional().default(!1).catch(!1),
hideModels:mc().optional().default(!1).catch(!1),
documentDownloadType:cu(["yaml","json","both","direct","none"]).optional().default("both").catch("both"),
hideDownloadButton:mc().optional(),
hideTestRequestButton:mc().optional().default(!1).catch(!1),
hideSearch:mc().optional().default(!1).catch(!1),
showOperationId:mc().optional().default(!1).catch(!1),darkMode:mc().optional(),
forceDarkModeState:cu(["dark","light"]).optional(),
hideDarkModeToggle:mc().optional().default(!1).catch(!1),
metaData:Ac().optional(),favicon:cl().optional(),
hiddenClients:Hc([tu(cl(),Hc([mc(),Bc(cl())])),Bc(cl()),pu(!0)]).optional(),
defaultHttpClient:zc({targetKey:Ku(),clientKey:cl()}).optional(),
customCss:cl().optional(),onSpecUpdate:Xu({input:[cl()],output:Mc()
}).optional(),onServerChange:Xu({input:[cl()],output:Mc()}).optional(),
onDocumentSelect:Xu({input:[]}).optional(),onLoaded:Xu().optional(),
onBeforeRequest:Xu({input:[zc({request:rd(Request)})]}).optional(),
onShowMore:Xu({input:[cl()]}).optional(),onSidebarClick:Xu({input:[cl()]
}).optional(),pathRouting:zc({basePath:cl()}).optional(),
generateHeadingSlug:Xu({input:[zc({slug:cl().default("headingSlug")})],
output:cl()}).optional(),generateModelSlug:Xu({input:[zc({
name:cl().default("modelName")})],output:cl()}).optional(),generateTagSlug:Xu({
input:[zc({name:cl().default("tagName")})],output:cl()}).optional(),
generateOperationSlug:Xu({input:[zc({path:cl(),operationId:cl().optional(),
method:cl(),summary:cl().optional()})],output:cl()}).optional(),
generateWebhookSlug:Xu({input:[zc({name:cl(),method:cl().optional()})],
output:cl()}).optional(),redirect:Xu({input:[cl()],
output:cl().nullable().optional()}).optional(),
withDefaultFonts:mc().optional().default(!0).catch(!0),
defaultOpenAllTags:mc().optional().default(!1).catch(!1),
expandAllModelSections:mc().optional().default(!1).catch(!1),
expandAllResponses:mc().optional().default(!1).catch(!1),
tagsSorter:Hc([pu("alpha"),Xu({input:[Ac(),Ac()],output:sc()})]).optional(),
operationsSorter:Hc([pu("alpha"),pu("method"),Xu({input:[Ac(),Ac()],output:sc()
})]).optional(),
orderSchemaPropertiesBy:Hc([pu("alpha"),pu("preserve")]).optional().default("alpha").catch("alpha"),
orderRequiredPropertiesFirst:mc().optional().default(!0).catch(!0)
}),$d=Cd.extend(kd.shape).transform((e=>(e.hideDownloadButton&&(console.warn("[DEPRECATED] You're using the deprecated 'hideDownloadButton' attribute. Use 'documentDownloadType: 'none'' instead."),
e.documentDownloadType="none"),
e.spec?.url&&(console.warn("[DEPRECATED] You're using the deprecated 'spec.url' attribute. Remove the spec prefix and move the 'url' attribute to the top level."),
e.url=e.spec.url,
delete e.spec),e.spec?.content&&(console.warn("[DEPRECATED] You're using the deprecated 'spec.content' attribute. Remove the spec prefix and move the 'content' attribute to the top level."),
e.content=e.spec.content,
delete e.spec),e.proxy&&(console.warn("[DEPRECATED] You're using the deprecated 'proxy' attribute, rename it to 'proxyUrl' or update the package."),
e.proxyUrl||(e.proxyUrl=e.proxy),
delete e.proxy),e.proxyUrl===Od&&(console.warn(`[DEPRECATED] Warning: configuration.proxyUrl points to our old proxy (${Od}).`),
console.warn(`[DEPRECATED] We are overwriting the value and use the new proxy URL (${wd}) instead.`),
console.warn(`[DEPRECATED] Action Required: You should manually update your configuration to use the new URL (${wd}). Read more: https://github.com/scalar/scalar`),
e.proxyUrl=wd),
e.showToolbar&&"localhost"!==e.showToolbar&&(console.warn("[DEPRECATED] You're using the deprecated 'showToolbar' attribute. Use 'showDeveloperTools' instead."),
e.showDeveloperTools=e.showToolbar,delete e.showToolbar),e)));function Pd(e,t){
const n=[],r=t.resolveKeyData||(e=>e.key),o=t.resolveValueData||(e=>e.value)
;for(const[a,i]of Object.entries(e))n.push(...(Array.isArray(i)?i:[i]).map((e=>{
const n={key:a,value:e},i=o(n)
;return"object"==typeof i?Pd(i,t):Array.isArray(i)?i:{
["function"==typeof t.key?t.key(n):t.key]:r(n),
["function"==typeof t.value?t.value(n):t.value]:i}})).flat());return n}
function Dd(e,t){return Object.entries(e).map((([e,n])=>{
if("object"==typeof n&&(n=Dd(n,t)),t.resolve){const r=t.resolve({key:e,value:n})
;if(void 0!==r)return r}
return"number"==typeof n&&(n=n.toString()),"string"==typeof n&&t.wrapValue&&(n=n.replace(new RegExp(t.wrapValue,"g"),`\\${t.wrapValue}`),
n=`${t.wrapValue}${n}${t.wrapValue}`),`${e}${t.keyValueSeparator||""}${n}`
})).join(t.entrySeparator||"")}zc({
cdn:cl().optional().default("https://cdn.jsdelivr.net/npm/@scalar/api-reference"),
pageTitle:cl().optional().default("Scalar API Reference")})
;const Id=new Set(["title","titleTemplate","script","style","noscript"]),Md=new Set(["base","meta","link","style","script","noscript"]),Nd=new Set(["title","titleTemplate","templateParams","base","htmlAttrs","bodyAttrs","meta","link","style","script","noscript"]),Rd=new Set(["base","title","titleTemplate","bodyAttrs","htmlAttrs","templateParams"]),Ld=new Set(["tagPosition","tagPriority","tagDuplicateStrategy","children","innerHTML","textContent","processTemplateParams"]),Bd="undefined"!=typeof window
;function jd(e){let t=9
;for(let n=0;n<e.length;)t=Math.imul(t^e.charCodeAt(n++),9**9)
;return(65536+(t^t>>>9)).toString(16).substring(1,8).toLowerCase()}
function Ud(e){if(e._h)return e._h;if(e._d)return jd(e._d)
;let t=`${e.tag}:${e.textContent||e.innerHTML||""}:`
;for(const n in e.props)t+=`${n}:${String(e.props[n])},`;return jd(t)}
const zd=e=>({keyValue:e,metaKey:"property"}),Fd=e=>({keyValue:e}),Zd={
appleItunesApp:{unpack:{entrySeparator:", ",
resolve:({key:e,value:t})=>`${Vd(e)}=${t}`}},
articleExpirationTime:zd("article:expiration_time"),
articleModifiedTime:zd("article:modified_time"),
articlePublishedTime:zd("article:published_time"),
bookReleaseDate:zd("book:release_date"),charset:{metaKey:"charset"},
contentSecurityPolicy:{unpack:{entrySeparator:"; ",
resolve:({key:e,value:t})=>`${Vd(e)} ${t}`},metaKey:"http-equiv"},contentType:{
metaKey:"http-equiv"},defaultStyle:{metaKey:"http-equiv"},
fbAppId:zd("fb:app_id"),msapplicationConfig:Fd("msapplication-Config"),
msapplicationTileColor:Fd("msapplication-TileColor"),
msapplicationTileImage:Fd("msapplication-TileImage"),
ogAudioSecureUrl:zd("og:audio:secure_url"),ogAudioUrl:zd("og:audio"),
ogImageSecureUrl:zd("og:image:secure_url"),ogImageUrl:zd("og:image"),
ogSiteName:zd("og:site_name"),ogVideoSecureUrl:zd("og:video:secure_url"),
ogVideoUrl:zd("og:video"),profileFirstName:zd("profile:first_name"),
profileLastName:zd("profile:last_name"),profileUsername:zd("profile:username"),
refresh:{metaKey:"http-equiv",unpack:{entrySeparator:";",
resolve({key:e,value:t}){if("seconds"===e)return`${t}`}}},robots:{unpack:{
entrySeparator:", ",
resolve:({key:e,value:t})=>"boolean"==typeof t?`${Vd(e)}`:`${Vd(e)}:${t}`}},
xUaCompatible:{metaKey:"http-equiv"}
},Qd=new Set(["og","book","article","profile"]);function Hd(e){
const t=Vd(e),n=t.indexOf(":")
;return Qd.has(t.substring(0,n))?"property":Zd[e]?.metaKey||"name"}
function Vd(e){
const t=e.replace(/([A-Z])/g,"-$1").toLowerCase(),n=t.indexOf("-"),r=t.substring(0,n)
;return"twitter"===r||Qd.has(r)?e.replace(/([A-Z])/g,":$1").toLowerCase():t}
function qd(e){if(Array.isArray(e))return e.map((e=>qd(e)))
;if("object"!=typeof e||Array.isArray(e))return e;const t={}
;for(const n in e)Object.prototype.hasOwnProperty.call(e,n)&&(t[Vd(n)]=qd(e[n]))
;return t}function Wd(e,t){const n=Zd[t]
;return"refresh"===t?`${e.seconds};url=${e.url}`:Dd(qd(e),{
keyValueSeparator:"=",entrySeparator:", ",
resolve:({value:e,key:t})=>null===e?"":"boolean"==typeof e?`${t}`:void 0,
...n?.unpack})}
const Xd=new Set(["og:image","og:video","og:audio","twitter:image"])
;function Gd(e){const t={};for(const n in e){
if(!Object.prototype.hasOwnProperty.call(e,n))continue;const r=e[n]
;"false"!==String(r)&&n&&(t[n]=r)}return t}function Yd(e,t){
const n=Gd(t),r=Vd(e),o=Hd(r);if(Xd.has(r)){const t={}
;for(const r in n)Object.prototype.hasOwnProperty.call(n,r)&&(t[`${e}${"url"===r?"":`${r[0].toUpperCase()}${r.slice(1)}`}`]=n[r])
;return Kd(t).sort(((e,t)=>(e[o]?.length||0)-(t[o]?.length||0)))}return[{[o]:r,
...n}]}function Kd(e){const t=[],n={};for(const o in e){
if(!Object.prototype.hasOwnProperty.call(e,o))continue;const r=e[o]
;if(Array.isArray(r))for(const e of r)t.push(..."string"==typeof e?Kd({[o]:e
}):Yd(o,e));else if("object"==typeof r&&r){if(Xd.has(Vd(o))){t.push(...Yd(o,r))
;continue}n[o]=Gd(r)}else n[o]=r}const r=Pd(n,{key:({key:e})=>Hd(e),
value:({key:e})=>"charset"===e?"charset":"content",
resolveKeyData:({key:e})=>function(e){return Zd[e]?.keyValue||Vd(e)}(e),
resolveValueData:({value:e,key:t})=>null===e?"_null":"object"==typeof e?Wd(e,t):"number"==typeof e?e.toString():e
});return[...t,...r].map((e=>("_null"===e.content&&(e.content=null),e)))}
function Jd(e,t,n,r){
const o=r||np("object"!=typeof t||"function"==typeof t||t instanceof Promise?{
["script"===e||"noscript"===e||"style"===e?"innerHTML":"textContent"]:t}:{...t
},"templateParams"===e||"titleTemplate"===e)
;if(o instanceof Promise)return o.then((r=>Jd(e,t,n,r)));const a={tag:e,props:o}
;for(const i of Ld){const e=void 0!==a.props[i]?a.props[i]:n[i]
;void 0!==e&&(("innerHTML"!==i&&"textContent"!==i&&"children"!==i||Id.has(a.tag))&&(a["children"===i?"innerHTML":i]=e),
delete a.props[i])}
return a.props.body&&(a.tagPosition="bodyClose",delete a.props.body),
"script"===a.tag&&"object"==typeof a.innerHTML&&(a.innerHTML=JSON.stringify(a.innerHTML),
a.props.type=a.props.type||"application/json"),
Array.isArray(a.props.content)?a.props.content.map((e=>({...a,props:{...a.props,
content:e}}))):a}function ep(e,t){const n="class"===e?" ":";"
;return t&&"object"==typeof t&&!Array.isArray(t)&&(t=Object.entries(t).filter((([,e])=>e)).map((([t,n])=>"style"===e?`${t}:${n}`:t))),
String(Array.isArray(t)?t.join(n):t)?.split(n).filter((e=>Boolean(e.trim()))).join(n)
}function tp(e,t,n,r){for(let o=r;o<n.length;o+=1){const r=n[o]
;if("class"!==r&&"style"!==r){
if(e[r]instanceof Promise)return e[r].then((a=>(e[r]=a,tp(e,t,n,o))))
;if(!t&&!Ld.has(r)){const t=String(e[r]),n=r.startsWith("data-")
;"true"===t||""===t?e[r]=!n||"true":e[r]||(n&&"false"===t?e[r]="false":delete e[r])
}}else e[r]=ep(r,e[r])}}function np(e,t=!1){const n=tp(e,t,Object.keys(e),0)
;return n instanceof Promise?n.then((()=>e)):e}const rp=10;function op(e,t,n){
for(let r=n;r<t.length;r+=1){const n=t[r]
;if(n instanceof Promise)return n.then((n=>(t[r]=n,op(e,t,r))))
;Array.isArray(n)?e.push(...n):e.push(n)}}function ap(e){
const t=[],n=e.resolvedInput;for(const i in n){
if(!Object.prototype.hasOwnProperty.call(n,i))continue;const r=n[i]
;if(void 0!==r&&Nd.has(i))if(Array.isArray(r))for(const n of r)t.push(Jd(i,n,e));else t.push(Jd(i,r,e))
}if(0===t.length)return[];const r=[]
;return o=op(r,t,0),a=()=>r.map(((t,n)=>(t._e=e._i,
e.mode&&(t._m=e.mode),t._p=(e._i<<rp)+n,t))),o instanceof Promise?o.then(a):a(o)
;var o,a}
const ip=new Set(["onload","onerror","onabort","onprogress","onloadstart"]),sp={
base:-10,title:10},lp={critical:-80,high:-10,low:20};function cp(e){
const t=e.tagPriority;if("number"==typeof t)return t;let n=100
;return"meta"===e.tag?"content-security-policy"===e.props["http-equiv"]?n=-30:e.props.charset?n=-20:"viewport"===e.props.name&&(n=-15):"link"===e.tag&&"preconnect"===e.props.rel?n=20:e.tag in sp&&(n=sp[e.tag]),
t&&t in lp?n+lp[t]:n}const up=[{prefix:"before:",offset:-1},{prefix:"after:",
offset:1}],dp=["name","property","http-equiv"];function pp(e){
const{props:t,tag:n}=e;if(Rd.has(n))return n
;if("link"===n&&"canonical"===t.rel)return"canonical"
;if(t.charset)return"charset";if(t.id)return`${n}:id:${t.id}`
;for(const r of dp)if(void 0!==t[r])return`${n}:${r}:${t[r]}`;return!1}
const hp="%separator";const fp=new RegExp(`${hp}(?:\\s*${hp})*`,"g")
;function mp(e,t,n,r=!1){if("string"!=typeof e||!e.includes("%"))return e
;let o=e;try{o=decodeURI(e)}catch{}const a=o.match(/%\w+(?:\.\w+)?/g)
;if(!a)return e;const i=e.includes(hp)
;return e=e.replace(/%\w+(?:\.\w+)?/g,(e=>{if(e===hp||!a.includes(e))return e
;const n=function(e,t,n=!1){let r
;if("s"===t||"pageTitle"===t)r=e.pageTitle;else if(t.includes(".")){
const n=t.indexOf(".");r=e[t.substring(0,n)]?.[t.substring(n+1)]}else r=e[t]
;if(void 0!==r)return n?(r||"").replace(/"/g,'\\"'):r||""}(t,e.slice(1),r)
;return void 0!==n?n:e
})).trim(),i&&(e.endsWith(hp)&&(e=e.slice(0,-10)),e.startsWith(hp)&&(e=e.slice(10)),
e=e.replace(fp,n).trim()),e}function gp(e,t){
return null==e?t||null:"function"==typeof e?e(t):e}function vp(e,t={}){
const n=t.delayFn||(e=>setTimeout(e,10))
;return e._domDebouncedUpdatePromise=e._domDebouncedUpdatePromise||new Promise((r=>n((()=>async function(e,t={}){
const n=t.document||e.resolvedOptions.document;if(!n||!e.dirty)return;const r={
shouldRender:!0,tags:[]}
;return await e.hooks.callHook("dom:beforeRender",r),r.shouldRender?(e._domUpdatePromise||(e._domUpdatePromise=new Promise((async t=>{
const r=(await e.resolveTags()).map((e=>({tag:e,id:Md.has(e.tag)?Ud(e):e.tag,
shouldRender:!0})));let o=e._dom;if(!o){o={elMap:{htmlAttrs:n.documentElement,
bodyAttrs:n.body}};const e=new Set;for(const t of["body","head"]){
const r=n[t]?.children;for(const t of r){const n=t.tagName.toLowerCase()
;if(!Md.has(n))continue;const r={tag:n,
props:await np(t.getAttributeNames().reduce(((e,n)=>({...e,[n]:t.getAttribute(n)
})),{})),innerHTML:t.innerHTML},a=pp(r);let i=a,s=1
;for(;i&&e.has(i);)i=`${a}:${s++}`
;i&&(r._d=i,e.add(i)),o.elMap[t.getAttribute("data-hid")||Ud(r)]=t}}}
function a(e,t,n){const r=`${e}:${t}`
;o.sideEffects[r]=n,delete o.pendingSideEffects[r]}
function i({id:e,$el:t,tag:r}){const i=r.tag.endsWith("Attrs")
;if(o.elMap[e]=t,i||(r.textContent&&r.textContent!==t.textContent&&(t.textContent=r.textContent),
r.innerHTML&&r.innerHTML!==t.innerHTML&&(t.innerHTML=r.innerHTML),
a(e,"el",(()=>{o.elMap[e]?.remove(),delete o.elMap[e]
}))),r._eventHandlers)for(const o in r._eventHandlers)Object.prototype.hasOwnProperty.call(r._eventHandlers,o)&&""!==t.getAttribute(`data-${o}`)&&(("bodyAttrs"===r.tag?n.defaultView:t).addEventListener(o.substring(2),r._eventHandlers[o].bind(t)),
t.setAttribute(`data-${o}`,""));for(const n in r.props){
if(!Object.prototype.hasOwnProperty.call(r.props,n))continue
;const o=r.props[n],s=`attr:${n}`;if("class"===n){if(!o)continue
;for(const n of o.split(" "))i&&a(e,`${s}:${n}`,(()=>t.classList.remove(n))),
!t.classList.contains(n)&&t.classList.add(n)}else if("style"===n){if(!o)continue
;for(const n of o.split(";")){
const r=n.indexOf(":"),o=n.substring(0,r).trim(),i=n.substring(r+1).trim()
;a(e,`${s}:${o}`,(()=>{t.style.removeProperty(o)})),t.style.setProperty(o,i)}
}else t.getAttribute(n)!==o&&t.setAttribute(n,!0===o?"":String(o)),
i&&a(e,s,(()=>t.removeAttribute(n)))}}o.pendingSideEffects={...o.sideEffects
},o.sideEffects={};const s=[],l={bodyClose:void 0,bodyOpen:void 0,head:void 0}
;for(const e of r){const{tag:t,shouldRender:r,id:a}=e
;r&&("title"!==t.tag?(e.$el=e.$el||o.elMap[a],
e.$el?i(e):Md.has(t.tag)&&s.push(e)):n.title=t.textContent)}for(const e of s){
const t=e.tag.tagPosition||"head"
;e.$el=n.createElement(e.tag.tag),i(e),l[t]=l[t]||n.createDocumentFragment(),
l[t].appendChild(e.$el)}
for(const c of r)await e.hooks.callHook("dom:renderTag",c,n,a)
;l.head&&n.head.appendChild(l.head),
l.bodyOpen&&n.body.insertBefore(l.bodyOpen,n.body.firstChild),
l.bodyClose&&n.body.appendChild(l.bodyClose)
;for(const e in o.pendingSideEffects)o.pendingSideEffects[e]()
;e._dom=o,await e.hooks.callHook("dom:rendered",{renders:r}),t()
})).finally((()=>{e._domUpdatePromise=void 0,e.dirty=!1
}))),e._domUpdatePromise):void 0}(e,t).then((()=>{
delete e._domDebouncedUpdatePromise,r()}))))))}function bp(e){return t=>{
const n=t.resolvedOptions.document?.head.querySelector('script[id="unhead:payload"]')?.innerHTML||!1
;return n&&t.push(JSON.parse(n)),{mode:"client",hooks:{"entries:updated":t=>{
vp(t,e)}}}}}function yp(e,t={},n){for(const r in e){
const o=e[r],a=n?`${n}:${r}`:r
;"object"==typeof o&&null!==o?yp(o,t,a):"function"==typeof o&&(t[a]=o)}return t}
const Op={run:e=>e()},wp=void 0!==console.createTask?console.createTask:()=>Op
;function xp(e,t){const n=t.shift(),r=wp(n)
;return e.reduce(((e,n)=>e.then((()=>r.run((()=>n(...t)))))),Promise.resolve())}
function kp(e,t){const n=t.shift(),r=wp(n)
;return Promise.all(e.map((e=>r.run((()=>e(...t))))))}function Sp(e,t){
for(const n of[...e])n(t)}class _p{constructor(){
this._hooks={},this._before=void 0,
this._after=void 0,this._deprecatedMessages=void 0,
this._deprecatedHooks={},this.hook=this.hook.bind(this),
this.callHook=this.callHook.bind(this),
this.callHookWith=this.callHookWith.bind(this)}hook(e,t,n={}){
if(!e||"function"!=typeof t)return()=>{};const r=e;let o
;for(;this._deprecatedHooks[e];)o=this._deprecatedHooks[e],e=o.to
;if(o&&!n.allowDeprecated){let e=o.message
;e||(e=`${r} hook has been deprecated`+(o.to?`, please use ${o.to}`:"")),
this._deprecatedMessages||(this._deprecatedMessages=new Set),
this._deprecatedMessages.has(e)||(console.warn(e),
this._deprecatedMessages.add(e))}if(!t.name)try{Object.defineProperty(t,"name",{
get:()=>"_"+e.replace(/\W+/g,"_")+"_hook_cb",configurable:!0})}catch{}
return this._hooks[e]=this._hooks[e]||[],this._hooks[e].push(t),()=>{
t&&(this.removeHook(e,t),t=void 0)}}hookOnce(e,t){
let n,r=(...e)=>("function"==typeof n&&n(),n=void 0,r=void 0,t(...e))
;return n=this.hook(e,r),n}removeHook(e,t){if(this._hooks[e]){
const n=this._hooks[e].indexOf(t)
;-1!==n&&this._hooks[e].splice(n,1),0===this._hooks[e].length&&delete this._hooks[e]
}}deprecateHook(e,t){this._deprecatedHooks[e]="string"==typeof t?{to:t}:t
;const n=this._hooks[e]||[];delete this._hooks[e]
;for(const r of n)this.hook(e,r)}deprecateHooks(e){
Object.assign(this._deprecatedHooks,e)
;for(const t in e)this.deprecateHook(t,e[t])}addHooks(e){
const t=yp(e),n=Object.keys(t).map((e=>this.hook(e,t[e])));return()=>{
for(const e of n.splice(0,n.length))e()}}removeHooks(e){const t=yp(e)
;for(const n in t)this.removeHook(n,t[n])}removeAllHooks(){
for(const e in this._hooks)delete this._hooks[e]}callHook(e,...t){
return t.unshift(e),this.callHookWith(xp,e,...t)}callHookParallel(e,...t){
return t.unshift(e),this.callHookWith(kp,e,...t)}callHookWith(e,t,...n){
const r=this._before||this._after?{name:t,args:n,context:{}}:void 0
;this._before&&Sp(this._before,r)
;const o=e(t in this._hooks?[...this._hooks[t]]:[],n)
;return o instanceof Promise?o.finally((()=>{this._after&&r&&Sp(this._after,r)
})):(this._after&&r&&Sp(this._after,r),o)}beforeEach(e){
return this._before=this._before||[],this._before.push(e),()=>{
if(void 0!==this._before){const t=this._before.indexOf(e)
;-1!==t&&this._before.splice(t,1)}}}afterEach(e){
return this._after=this._after||[],this._after.push(e),()=>{
if(void 0!==this._after){const t=this._after.indexOf(e)
;-1!==t&&this._after.splice(t,1)}}}}
const Tp=new Set(["templateParams","htmlAttrs","bodyAttrs"]),Ep={hooks:{
"tag:normalise":({tag:e})=>{e.props.hid&&(e.key=e.props.hid,delete e.props.hid),
e.props.vmid&&(e.key=e.props.vmid,
delete e.props.vmid),e.props.key&&(e.key=e.props.key,delete e.props.key)
;const t=pp(e)
;!t||t.startsWith("meta:og:")||t.startsWith("meta:twitter:")||delete e.key
;const n=t||!!e.key&&`${e.tag}:${e.key}`;n&&(e._d=n)},"tags:resolve":e=>{
const t=Object.create(null);for(const r of e.tags){
const e=(r.key?`${r.tag}:${r.key}`:r._d)||Ud(r),n=t[e];if(n){
let o=r?.tagDuplicateStrategy;if(!o&&Tp.has(r.tag)&&(o="merge"),"merge"===o){
const o=n.props
;o.style&&r.props.style&&(";"!==o.style[o.style.length-1]&&(o.style+=";"),
r.props.style=`${o.style} ${r.props.style}`),
o.class&&r.props.class?r.props.class=`${o.class} ${r.props.class}`:o.class&&(r.props.class=o.class),
t[e].props={...o,...r.props};continue}if(r._e===n._e){
n._duped=n._duped||[],r._d=`${n._d}:${n._duped.length+1}`,n._duped.push(r)
;continue}if(cp(r)>cp(n))continue}
r.innerHTML||r.textContent||0!==Object.keys(r.props).length||!Md.has(r.tag)?t[e]=r:delete t[e]
}const n=[];for(const r in t){const e=t[r],o=e._duped
;n.push(e),o&&(delete e._duped,n.push(...o))}
e.tags=n,e.tags=e.tags.filter((e=>!("meta"===e.tag&&(e.props.name||e.props.property)&&!e.props.content)))
}}},Ap=new Set(["script","link","bodyAttrs"]),Cp=e=>({hooks:{"tags:resolve":t=>{
for(const n of t.tags){if(!Ap.has(n.tag))continue;const t=n.props
;for(const r in t){if("o"!==r[0]||"n"!==r[1])continue
;if(!Object.prototype.hasOwnProperty.call(t,r))continue;const o=t[r]
;"function"==typeof o&&(e.ssr&&ip.has(r)?t[r]=`this.dataset.${r}fired = true`:delete t[r],
n._eventHandlers=n._eventHandlers||{},n._eventHandlers[r]=o)}
e.ssr&&n._eventHandlers&&(n.props.src||n.props.href)&&(n.key=n.key||jd(n.props.src||n.props.href))
}},"dom:renderTag":({$el:e,tag:t})=>{const n=e?.dataset;if(n)for(const r in n){
if(!r.endsWith("fired"))continue;const n=r.slice(0,-5)
;ip.has(n)&&t._eventHandlers?.[n]?.call(e,new Event(n.substring(2)))}}}
}),$p=new Set(["link","style","script","noscript"]),Pp={hooks:{
"tag:normalise":({tag:e})=>{
e.key&&$p.has(e.tag)&&(e.props["data-hid"]=e._h=jd(e.key))}}},Dp={mode:"server",
hooks:{"tags:beforeResolve":e=>{const t={};let n=!1
;for(const r of e.tags)"server"!==r._m||"titleTemplate"!==r.tag&&"templateParams"!==r.tag&&"title"!==r.tag||(t[r.tag]="title"===r.tag||"titleTemplate"===r.tag?r.textContent:r.props,
n=!0);n&&e.tags.push({tag:"script",innerHTML:JSON.stringify(t),props:{
id:"unhead:payload",type:"application/json"}})}}},Ip={hooks:{"tags:resolve":e=>{
for(const t of e.tags)if("string"==typeof t.tagPriority)for(const{prefix:n,offset:r}of up){
if(!t.tagPriority.startsWith(n))continue
;const o=t.tagPriority.substring(n.length),a=e.tags.find((e=>e._d===o))?._p
;if(void 0!==a){t._p=a+r;break}}e.tags.sort(((e,t)=>{const n=cp(e),r=cp(t)
;return n<r?-1:n>r?1:e._p-t._p}))}}},Mp={meta:"content",link:"href",
htmlAttrs:"lang"},Np=["innerHTML","textContent"],Rp=e=>({hooks:{
"tags:resolve":t=>{const{tags:n}=t;let r;for(let e=0;e<n.length;e+=1){
"templateParams"===n[e].tag&&(r=t.tags.splice(e,1)[0].props,e-=1)}
const o=r||{},a=o.separator||"|"
;delete o.separator,o.pageTitle=mp(o.pageTitle||n.find((e=>"title"===e.tag))?.textContent||"",o,a)
;for(const e of n){if(!1===e.processTemplateParams)continue;const t=Mp[e.tag]
;if(t&&"string"==typeof e.props[t])e.props[t]=mp(e.props[t],o,a);else if(e.processTemplateParams||"titleTemplate"===e.tag||"title"===e.tag)for(const n of Np)"string"==typeof e[n]&&(e[n]=mp(e[n],o,a,"script"===e.tag&&e.props.type.endsWith("json")))
}e._templateParams=o,e._separator=a},"tags:afterResolve":({tags:t})=>{let n
;for(let e=0;e<t.length;e+=1){const r=t[e]
;"title"===r.tag&&!1!==r.processTemplateParams&&(n=r)}
n?.textContent&&(n.textContent=mp(n.textContent,e._templateParams,e._separator))
}}}),Lp={hooks:{"tags:resolve":e=>{const{tags:t}=e;let n,r
;for(let o=0;o<t.length;o+=1){const e=t[o]
;"title"===e.tag?n=e:"titleTemplate"===e.tag&&(r=e)}if(r&&n){
const t=gp(r.textContent,n.textContent)
;null!==t?n.textContent=t||n.textContent:e.tags.splice(e.tags.indexOf(n),1)
}else if(r){const e=gp(r.textContent)
;null!==e&&(r.textContent=e,r.tag="title",r=void 0)}
r&&e.tags.splice(e.tags.indexOf(r),1)}}},Bp={hooks:{"tags:afterResolve":e=>{
for(const t of e.tags)"string"==typeof t.innerHTML&&(!t.innerHTML||"application/ld+json"!==t.props.type&&"application/json"!==t.props.type?t.innerHTML=t.innerHTML.replace(new RegExp(`</${t.tag}`,"g"),`<\\/${t.tag}`):t.innerHTML=t.innerHTML.replace(/</g,"\\u003C"))
}}};let jp;function Up(e={}){const t=function(e={}){const t=new _p
;t.addHooks(e.hooks||{}),e.document=e.document||(Bd?document:void 0)
;const n=!e.document,r=()=>{s.dirty=!0,t.callHook("entries:updated",s)}
;let o=0,a=[];const i=[],s={plugins:i,dirty:!1,resolvedOptions:e,hooks:t,
headEntries:()=>a,use(e){const r="function"==typeof e?e(s):e
;r.key&&i.some((e=>e.key===r.key))||(i.push(r),
zp(r.mode,n)&&t.addHooks(r.hooks||{}))},push(e,t){delete t?.head;const i={
_i:o++,input:e,...t};return zp(i.mode,n)&&(a.push(i),r()),{dispose(){
a=a.filter((e=>e._i!==i._i)),r()},patch(e){
for(const t of a)t._i===i._i&&(t.input=i.input=e);r()}}},async resolveTags(){
const e={tags:[],entries:[...a]};await t.callHook("entries:resolve",e)
;for(const n of e.entries){const r=n.resolvedInput||n.input
;if(n.resolvedInput=await(n.transform?n.transform(r):r),
n.resolvedInput)for(const o of await ap(n)){const r={tag:o,entry:n,
resolvedOptions:s.resolvedOptions}
;await t.callHook("tag:normalise",r),e.tags.push(r.tag)}}
return await t.callHook("tags:beforeResolve",e),
await t.callHook("tags:resolve",e),
await t.callHook("tags:afterResolve",e),e.tags},ssr:n}
;return[Ep,Dp,Cp,Pp,Ip,Rp,Lp,Bp,...e?.plugins||[]].forEach((e=>s.use(e))),
s.hooks.callHook("init",s),s}(e);return t.use(bp()),jp=t}function zp(e,t){
return!e||"server"===e&&t||"client"===e&&!t}function Fp(e){
const t=Object.create(null);for(const n of e.split(","))t[n]=1;return e=>e in t}
const Zp={},Qp=[],Hp=()=>{},Vp=()=>!1,qp=e=>111===e.charCodeAt(0)&&110===e.charCodeAt(1)&&(e.charCodeAt(2)>122||e.charCodeAt(2)<97),Wp=e=>e.startsWith("onUpdate:"),Xp=Object.assign,Gp=(e,t)=>{
const n=e.indexOf(t);n>-1&&e.splice(n,1)
},Yp=Object.prototype.hasOwnProperty,Kp=(e,t)=>Yp.call(e,t),Jp=Array.isArray,eh=e=>"[object Map]"===ch(e),th=e=>"[object Set]"===ch(e),nh=e=>"[object Date]"===ch(e),rh=e=>"function"==typeof e,oh=e=>"string"==typeof e,ah=e=>"symbol"==typeof e,ih=e=>null!==e&&"object"==typeof e,sh=e=>(ih(e)||rh(e))&&rh(e.then)&&rh(e.catch),lh=Object.prototype.toString,ch=e=>lh.call(e),uh=e=>ch(e).slice(8,-1),dh=e=>"[object Object]"===ch(e),ph=e=>oh(e)&&"NaN"!==e&&"-"!==e[0]&&""+parseInt(e,10)===e,hh=Fp(",key,ref,ref_for,ref_key,onVnodeBeforeMount,onVnodeMounted,onVnodeBeforeUpdate,onVnodeUpdated,onVnodeBeforeUnmount,onVnodeUnmounted"),fh=e=>{
const t=Object.create(null);return n=>t[n]||(t[n]=e(n))
},mh=/-\w/g,gh=fh((e=>e.replace(mh,(e=>e.slice(1).toUpperCase())))),vh=/\B([A-Z])/g,bh=fh((e=>e.replace(vh,"-$1").toLowerCase())),yh=fh((e=>e.charAt(0).toUpperCase()+e.slice(1))),Oh=fh((e=>e?`on${yh(e)}`:"")),wh=(e,t)=>!Object.is(e,t),xh=(e,...t)=>{
for(let n=0;n<e.length;n++)e[n](...t)},kh=(e,t,n,r=!1)=>{
Object.defineProperty(e,t,{configurable:!0,enumerable:!1,writable:r,value:n})
},Sh=e=>{const t=parseFloat(e);return isNaN(t)?e:t},_h=e=>{
const t=oh(e)?Number(e):NaN;return isNaN(t)?e:t};let Th
;const Eh=()=>Th||(Th="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:"undefined"!=typeof window?window:"undefined"!=typeof global?global:{})
;function Ah(e){if(Jp(e)){const t={};for(let n=0;n<e.length;n++){
const r=e[n],o=oh(r)?Dh(r):Ah(r);if(o)for(const e in o)t[e]=o[e]}return t}
if(oh(e)||ih(e))return e}
const Ch=/;(?![^(]*\))/g,$h=/:([^]+)/,Ph=/\/\*[^]*?\*\//g;function Dh(e){
const t={};return e.replace(Ph,"").split(Ch).forEach((e=>{if(e){
const n=e.split($h);n.length>1&&(t[n[0].trim()]=n[1].trim())}})),t}
function Ih(e){let t="";if(oh(e))t=e;else if(Jp(e))for(let n=0;n<e.length;n++){
const r=Ih(e[n]);r&&(t+=r+" ")}else if(ih(e))for(const n in e)e[n]&&(t+=n+" ")
;return t.trim()}function Mh(e){if(!e)return null;let{class:t,style:n}=e
;return t&&!oh(t)&&(e.class=Ih(t)),n&&(e.style=Ah(n)),e}
const Nh=Fp("itemscope,allowfullscreen,formnovalidate,ismap,nomodule,novalidate,readonly")
;function Rh(e){return!!e||""===e}function Lh(e,t){if(e===t)return!0
;let n=nh(e),r=nh(t);if(n||r)return!(!n||!r)&&e.getTime()===t.getTime()
;if(n=ah(e),r=ah(t),n||r)return e===t
;if(n=Jp(e),r=Jp(t),n||r)return!(!n||!r)&&function(e,t){
if(e.length!==t.length)return!1;let n=!0
;for(let r=0;n&&r<e.length;r++)n=Lh(e[r],t[r]);return n}(e,t)
;if(n=ih(e),r=ih(t),n||r){if(!n||!r)return!1
;if(Object.keys(e).length!==Object.keys(t).length)return!1;for(const n in e){
const r=e.hasOwnProperty(n),o=t.hasOwnProperty(n)
;if(r&&!o||!r&&o||!Lh(e[n],t[n]))return!1}}return String(e)===String(t)}
function Bh(e,t){return e.findIndex((e=>Lh(e,t)))}
const jh=e=>!(!e||!0!==e.__v_isRef),Uh=e=>oh(e)?e:null==e?"":Jp(e)||ih(e)&&(e.toString===lh||!rh(e.toString))?jh(e)?Uh(e.value):JSON.stringify(e,zh,2):String(e),zh=(e,t)=>jh(t)?zh(e,t.value):eh(t)?{
[`Map(${t.size})`]:[...t.entries()].reduce(((e,[t,n],r)=>(e[Fh(t,r)+" =>"]=n,
e)),{})}:th(t)?{[`Set(${t.size})`]:[...t.values()].map((e=>Fh(e)))
}:ah(t)?Fh(t):!ih(t)||Jp(t)||dh(t)?t:String(t),Fh=(e,t="")=>{var n
;return ah(e)?`Symbol(${null!=(n=e.description)?n:t})`:e};function Zh(e){
return null==e?"initial":"string"==typeof e?""===e?" ":e:String(e)}let Qh,Hh
;class Vh{constructor(e=!1){
this.detached=e,this._active=!0,this._on=0,this.effects=[],
this.cleanups=[],this._isPaused=!1,
this.parent=Qh,!e&&Qh&&(this.index=(Qh.scopes||(Qh.scopes=[])).push(this)-1)}
get active(){return this._active}pause(){if(this._active){let e,t
;if(this._isPaused=!0,
this.scopes)for(e=0,t=this.scopes.length;e<t;e++)this.scopes[e].pause();for(e=0,
t=this.effects.length;e<t;e++)this.effects[e].pause()}}resume(){
if(this._active&&this._isPaused){let e,t
;if(this._isPaused=!1,this.scopes)for(e=0,
t=this.scopes.length;e<t;e++)this.scopes[e].resume()
;for(e=0,t=this.effects.length;e<t;e++)this.effects[e].resume()}}run(e){
if(this._active){const t=Qh;try{return Qh=this,e()}finally{Qh=t}}}on(){
1==++this._on&&(this.prevScope=Qh,Qh=this)}off(){
this._on>0&&0==--this._on&&(Qh=this.prevScope,this.prevScope=void 0)}stop(e){
if(this._active){let t,n
;for(this._active=!1,t=0,n=this.effects.length;t<n;t++)this.effects[t].stop()
;for(this.effects.length=0,t=0,n=this.cleanups.length;t<n;t++)this.cleanups[t]()
;if(this.cleanups.length=0,this.scopes){
for(t=0,n=this.scopes.length;t<n;t++)this.scopes[t].stop(!0)
;this.scopes.length=0}if(!this.detached&&this.parent&&!e){
const e=this.parent.scopes.pop();e&&e!==this&&(this.parent.scopes[this.index]=e,
e.index=this.index)}this.parent=void 0}}}function qh(e){return new Vh(e)}
function Wh(){return Qh}function Xh(e,t=!1){Qh&&Qh.cleanups.push(e)}
const Gh=new WeakSet;class Yh{constructor(e){
this.fn=e,this.deps=void 0,this.depsTail=void 0,
this.flags=5,this.next=void 0,this.cleanup=void 0,
this.scheduler=void 0,Qh&&Qh.active&&Qh.effects.push(this)}pause(){
this.flags|=64}resume(){
64&this.flags&&(this.flags&=-65,Gh.has(this)&&(Gh.delete(this),this.trigger()))}
notify(){2&this.flags&&!(32&this.flags)||8&this.flags||tf(this)}run(){
if(!(1&this.flags))return this.fn();this.flags|=2,mf(this),of(this)
;const e=Hh,t=df;Hh=this,df=!0;try{return this.fn()}finally{
af(this),Hh=e,df=t,this.flags&=-3}}stop(){if(1&this.flags){
for(let e=this.deps;e;e=e.nextDep)cf(e);this.deps=this.depsTail=void 0,mf(this),
this.onStop&&this.onStop(),this.flags&=-2}}trigger(){
64&this.flags?Gh.add(this):this.scheduler?this.scheduler():this.runIfDirty()}
runIfDirty(){sf(this)&&this.run()}get dirty(){return sf(this)}}let Kh,Jh,ef=0
;function tf(e,t=!1){if(e.flags|=8,t)return e.next=Jh,void(Jh=e);e.next=Kh,Kh=e}
function nf(){ef++}function rf(){if(--ef>0)return;if(Jh){let e=Jh
;for(Jh=void 0;e;){const t=e.next;e.next=void 0,e.flags&=-9,e=t}}let e
;for(;Kh;){let n=Kh;for(Kh=void 0;n;){const r=n.next
;if(n.next=void 0,n.flags&=-9,1&n.flags)try{n.trigger()}catch(t){e||(e=t)}n=r}}
if(e)throw e}function of(e){
for(let t=e.deps;t;t=t.nextDep)t.version=-1,t.prevActiveLink=t.dep.activeLink,
t.dep.activeLink=t}function af(e){let t,n=e.depsTail,r=n;for(;r;){
const e=r.prevDep
;-1===r.version?(r===n&&(n=e),cf(r),uf(r)):t=r,r.dep.activeLink=r.prevActiveLink,
r.prevActiveLink=void 0,r=e}e.deps=t,e.depsTail=n}function sf(e){
for(let t=e.deps;t;t=t.nextDep)if(t.dep.version!==t.version||t.dep.computed&&(lf(t.dep.computed)||t.dep.version!==t.version))return!0
;return!!e._dirty}function lf(e){if(4&e.flags&&!(16&e.flags))return
;if(e.flags&=-17,e.globalVersion===gf)return
;if(e.globalVersion=gf,!e.isSSR&&128&e.flags&&(!e.deps&&!e._dirty||!sf(e)))return
;e.flags|=2;const t=e.dep,n=Hh,r=df;Hh=e,df=!0;try{of(e);const n=e.fn(e._value)
;(0===t.version||wh(n,e._value))&&(e.flags|=128,e._value=n,t.version++)
}catch(o){throw t.version++,o}finally{Hh=n,df=r,af(e),e.flags&=-3}}
function cf(e,t=!1){const{dep:n,prevSub:r,nextSub:o}=e
;if(r&&(r.nextSub=o,e.prevSub=void 0),
o&&(o.prevSub=r,e.nextSub=void 0),n.subs===e&&(n.subs=r,!r&&n.computed)){
n.computed.flags&=-5;for(let e=n.computed.deps;e;e=e.nextDep)cf(e,!0)}
t||--n.sc||!n.map||n.map.delete(n.key)}function uf(e){
const{prevDep:t,nextDep:n}=e
;t&&(t.nextDep=n,e.prevDep=void 0),n&&(n.prevDep=t,e.nextDep=void 0)}let df=!0
;const pf=[];function hf(){pf.push(df),df=!1}function ff(){const e=pf.pop()
;df=void 0===e||e}function mf(e){const{cleanup:t}=e;if(e.cleanup=void 0,t){
const e=Hh;Hh=void 0;try{t()}finally{Hh=e}}}let gf=0;class vf{constructor(e,t){
this.sub=e,
this.dep=t,this.version=t.version,this.nextDep=this.prevDep=this.nextSub=this.prevSub=this.prevActiveLink=void 0
}}class bf{constructor(e){this.computed=e,this.version=0,this.activeLink=void 0,
this.subs=void 0,this.map=void 0,this.key=void 0,this.sc=0,this.__v_skip=!0}
track(e){if(!Hh||!df||Hh===this.computed)return;let t=this.activeLink
;if(void 0===t||t.sub!==Hh)t=this.activeLink=new vf(Hh,this),
Hh.deps?(t.prevDep=Hh.depsTail,
Hh.depsTail.nextDep=t,Hh.depsTail=t):Hh.deps=Hh.depsTail=t,
yf(t);else if(-1===t.version&&(t.version=this.version,t.nextDep)){
const e=t.nextDep
;e.prevDep=t.prevDep,t.prevDep&&(t.prevDep.nextDep=e),t.prevDep=Hh.depsTail,
t.nextDep=void 0,Hh.depsTail.nextDep=t,Hh.depsTail=t,Hh.deps===t&&(Hh.deps=e)}
return t}trigger(e){this.version++,gf++,this.notify(e)}notify(e){nf();try{0
;for(let e=this.subs;e;e=e.prevSub)e.sub.notify()&&e.sub.dep.notify()}finally{
rf()}}}function yf(e){if(e.dep.sc++,4&e.sub.flags){const t=e.dep.computed
;if(t&&!e.dep.subs){t.flags|=20;for(let e=t.deps;e;e=e.nextDep)yf(e)}
const n=e.dep.subs;n!==e&&(e.prevSub=n,n&&(n.nextSub=e)),e.dep.subs=e}}
const Of=new WeakMap,wf=Symbol(""),xf=Symbol(""),kf=Symbol("")
;function Sf(e,t,n){if(df&&Hh){let t=Of.get(e);t||Of.set(e,t=new Map)
;let r=t.get(n);r||(t.set(n,r=new bf),r.map=t,r.key=n),r.track()}}
function _f(e,t,n,r,o,a){const i=Of.get(e);if(!i)return void gf++;const s=e=>{
e&&e.trigger()};if(nf(),"clear"===t)i.forEach(s);else{const o=Jp(e),a=o&&ph(n)
;if(o&&"length"===n){const e=Number(r);i.forEach(((t,n)=>{
("length"===n||n===kf||!ah(n)&&n>=e)&&s(t)}))
}else switch((void 0!==n||i.has(void 0))&&s(i.get(n)),a&&s(i.get(kf)),t){
case"add":o?a&&s(i.get("length")):(s(i.get(wf)),eh(e)&&s(i.get(xf)));break
;case"delete":o||(s(i.get(wf)),eh(e)&&s(i.get(xf)));break;case"set":
eh(e)&&s(i.get(wf))}}rf()}function Tf(e){const t=hm(e)
;return t===e?t:(Sf(t,0,kf),dm(e)?t:t.map(mm))}function Ef(e){
return Sf(e=hm(e),0,kf),e}function Af(e,t){
return um(e)?cm(e)?gm(mm(t)):gm(t):mm(t)}const Cf={__proto__:null,
[Symbol.iterator](){return $f(this,Symbol.iterator,(e=>Af(this,e)))},
concat(...e){return Tf(this).concat(...e.map((e=>Jp(e)?Tf(e):e)))},entries(){
return $f(this,"entries",(e=>(e[1]=Af(this,e[1]),e)))},every(e,t){
return Df(this,"every",e,t,void 0,arguments)},filter(e,t){
return Df(this,"filter",e,t,(e=>e.map((e=>Af(this,e)))),arguments)},find(e,t){
return Df(this,"find",e,t,(e=>Af(this,e)),arguments)},findIndex(e,t){
return Df(this,"findIndex",e,t,void 0,arguments)},findLast(e,t){
return Df(this,"findLast",e,t,(e=>Af(this,e)),arguments)},findLastIndex(e,t){
return Df(this,"findLastIndex",e,t,void 0,arguments)},forEach(e,t){
return Df(this,"forEach",e,t,void 0,arguments)},includes(...e){
return Mf(this,"includes",e)},indexOf(...e){return Mf(this,"indexOf",e)},
join(e){return Tf(this).join(e)},lastIndexOf(...e){
return Mf(this,"lastIndexOf",e)},map(e,t){
return Df(this,"map",e,t,void 0,arguments)},pop(){return Nf(this,"pop")},
push(...e){return Nf(this,"push",e)},reduce(e,...t){return If(this,"reduce",e,t)
},reduceRight(e,...t){return If(this,"reduceRight",e,t)},shift(){
return Nf(this,"shift")},some(e,t){return Df(this,"some",e,t,void 0,arguments)},
splice(...e){return Nf(this,"splice",e)},toReversed(){
return Tf(this).toReversed()},toSorted(e){return Tf(this).toSorted(e)},
toSpliced(...e){return Tf(this).toSpliced(...e)},unshift(...e){
return Nf(this,"unshift",e)},values(){return $f(this,"values",(e=>Af(this,e)))}}
;function $f(e,t,n){const r=Ef(e),o=r[t]();return r===e||dm(e)||(o._next=o.next,
o.next=()=>{const e=o._next();return e.done||(e.value=n(e.value)),e}),o}
const Pf=Array.prototype;function Df(e,t,n,r,o,a){
const i=Ef(e),s=i!==e&&!dm(e),l=i[t];if(l!==Pf[t]){const t=l.apply(e,a)
;return s?mm(t):t}let c=n;i!==e&&(s?c=function(t,r){
return n.call(this,Af(e,t),r,e)}:n.length>2&&(c=function(t,r){
return n.call(this,t,r,e)}));const u=l.call(i,c,r);return s&&o?o(u):u}
function If(e,t,n,r){const o=Ef(e);let a=n
;return o!==e&&(dm(e)?n.length>3&&(a=function(t,r,o){return n.call(this,t,r,o,e)
}):a=function(t,r,o){return n.call(this,t,Af(e,r),o,e)}),o[t](a,...r)}
function Mf(e,t,n){const r=hm(e);Sf(r,0,kf);const o=r[t](...n)
;return-1!==o&&!1!==o||!pm(n[0])?o:(n[0]=hm(n[0]),r[t](...n))}
function Nf(e,t,n=[]){hf(),nf();const r=hm(e)[t].apply(e,n);return rf(),ff(),r}
const Rf=Fp("__proto__,__v_isRef,__isVue"),Lf=new Set(Object.getOwnPropertyNames(Symbol).filter((e=>"arguments"!==e&&"caller"!==e)).map((e=>Symbol[e])).filter(ah))
;function Bf(e){ah(e)||(e=String(e));const t=hm(this)
;return Sf(t,0,e),t.hasOwnProperty(e)}class jf{constructor(e=!1,t=!1){
this._isReadonly=e,this._isShallow=t}get(e,t,n){
if("__v_skip"===t)return e.__v_skip;const r=this._isReadonly,o=this._isShallow
;if("__v_isReactive"===t)return!r;if("__v_isReadonly"===t)return r
;if("__v_isShallow"===t)return o
;if("__v_raw"===t)return n===(r?o?om:rm:o?nm:tm).get(e)||Object.getPrototypeOf(e)===Object.getPrototypeOf(n)?e:void 0
;const a=Jp(e);if(!r){let e;if(a&&(e=Cf[t]))return e
;if("hasOwnProperty"===t)return Bf}const i=Reflect.get(e,t,vm(e)?e:n)
;if(ah(t)?Lf.has(t):Rf(t))return i;if(r||Sf(e,0,t),o)return i;if(vm(i)){
const e=a&&ph(t)?i:i.value;return r&&ih(e)?im(e):e}return ih(i)?r?im(i):am(i):i}
}class Uf extends jf{constructor(e=!1){super(!1,e)}set(e,t,n,r){let o=e[t]
;const a=Jp(e)&&ph(t);if(!this._isShallow){const e=um(o)
;if(dm(n)||um(n)||(o=hm(o),n=hm(n)),!a&&vm(o)&&!vm(n))return e||(o.value=n),!0}
const i=a?Number(t)<e.length:Kp(e,t),s=Reflect.set(e,t,n,vm(e)?e:r)
;return e===hm(r)&&(i?wh(n,o)&&_f(e,"set",t,n):_f(e,"add",t,n)),s}
deleteProperty(e,t){const n=Kp(e,t);e[t];const r=Reflect.deleteProperty(e,t)
;return r&&n&&_f(e,"delete",t,void 0),r}has(e,t){const n=Reflect.has(e,t)
;return ah(t)&&Lf.has(t)||Sf(e,0,t),n}ownKeys(e){
return Sf(e,0,Jp(e)?"length":wf),Reflect.ownKeys(e)}}class zf extends jf{
constructor(e=!1){super(!0,e)}set(e,t){return!0}deleteProperty(e,t){return!0}}
const Ff=new Uf,Zf=new zf,Qf=new Uf(!0),Hf=new zf(!0),Vf=e=>e,qf=e=>Reflect.getPrototypeOf(e)
;function Wf(e){return function(...t){
return"delete"!==e&&("clear"===e?void 0:this)}}function Xf(e,t){const n={get(n){
const r=this.__v_raw,o=hm(r),a=hm(n);e||(wh(n,a)&&Sf(o,0,n),Sf(o,0,a))
;const{has:i}=qf(o),s=t?Vf:e?gm:mm
;return i.call(o,n)?s(r.get(n)):i.call(o,a)?s(r.get(a)):void(r!==o&&r.get(n))},
get size(){const t=this.__v_raw;return!e&&Sf(hm(t),0,wf),t.size},has(t){
const n=this.__v_raw,r=hm(n),o=hm(t)
;return e||(wh(t,o)&&Sf(r,0,t),Sf(r,0,o)),t===o?n.has(t):n.has(t)||n.has(o)},
forEach(n,r){const o=this,a=o.__v_raw,i=hm(a),s=t?Vf:e?gm:mm
;return!e&&Sf(i,0,wf),a.forEach(((e,t)=>n.call(r,s(e),s(t),o)))}};Xp(n,e?{
add:Wf("add"),set:Wf("set"),delete:Wf("delete"),clear:Wf("clear")}:{add(e){
t||dm(e)||um(e)||(e=hm(e));const n=hm(this)
;return qf(n).has.call(n,e)||(n.add(e),_f(n,"add",e,e)),this},set(e,n){
t||dm(n)||um(n)||(n=hm(n));const r=hm(this),{has:o,get:a}=qf(r)
;let i=o.call(r,e);i||(e=hm(e),i=o.call(r,e));const s=a.call(r,e)
;return r.set(e,n),i?wh(n,s)&&_f(r,"set",e,n):_f(r,"add",e,n),this},delete(e){
const t=hm(this),{has:n,get:r}=qf(t);let o=n.call(t,e)
;o||(e=hm(e),o=n.call(t,e)),r&&r.call(t,e);const a=t.delete(e)
;return o&&_f(t,"delete",e,void 0),a},clear(){
const e=hm(this),t=0!==e.size,n=e.clear();return t&&_f(e,"clear",void 0,void 0),
n}});return["keys","values","entries",Symbol.iterator].forEach((r=>{
n[r]=function(e,t,n){return function(...r){
const o=this.__v_raw,a=hm(o),i=eh(a),s="entries"===e||e===Symbol.iterator&&i,l="keys"===e&&i,c=o[e](...r),u=n?Vf:t?gm:mm
;return!t&&Sf(a,0,l?xf:wf),{next(){const{value:e,done:t}=c.next();return t?{
value:e,done:t}:{value:s?[u(e[0]),u(e[1])]:u(e),done:t}},[Symbol.iterator](){
return this}}}}(r,e,t)})),n}function Gf(e,t){const n=Xf(e,t)
;return(t,r,o)=>"__v_isReactive"===r?!e:"__v_isReadonly"===r?e:"__v_raw"===r?t:Reflect.get(Kp(n,r)&&r in t?n:t,r,o)
}const Yf={get:Gf(!1,!1)},Kf={get:Gf(!1,!0)},Jf={get:Gf(!0,!1)},em={
get:Gf(!0,!0)},tm=new WeakMap,nm=new WeakMap,rm=new WeakMap,om=new WeakMap
;function am(e){return um(e)?e:lm(e,!1,Ff,Yf,tm)}function im(e){
return lm(e,!0,Zf,Jf,rm)}function sm(e){return lm(e,!0,Hf,em,om)}
function lm(e,t,n,r,o){if(!ih(e))return e
;if(e.__v_raw&&(!t||!e.__v_isReactive))return e
;const a=(i=e).__v_skip||!Object.isExtensible(i)?0:function(e){switch(e){
case"Object":case"Array":return 1;case"Map":case"Set":case"WeakMap":
case"WeakSet":return 2;default:return 0}}(uh(i));var i;if(0===a)return e
;const s=o.get(e);if(s)return s;const l=new Proxy(e,2===a?r:n)
;return o.set(e,l),l}function cm(e){
return um(e)?cm(e.__v_raw):!(!e||!e.__v_isReactive)}function um(e){
return!(!e||!e.__v_isReadonly)}function dm(e){return!(!e||!e.__v_isShallow)}
function pm(e){return!!e&&!!e.__v_raw}function hm(e){const t=e&&e.__v_raw
;return t?hm(t):e}function fm(e){
return!Kp(e,"__v_skip")&&Object.isExtensible(e)&&kh(e,"__v_skip",!0),e}
const mm=e=>ih(e)?am(e):e,gm=e=>ih(e)?im(e):e;function vm(e){
return!!e&&!0===e.__v_isRef}function bm(e){return Om(e,!1)}function ym(e){
return Om(e,!0)}function Om(e,t){return vm(e)?e:new wm(e,t)}class wm{
constructor(e,t){
this.dep=new bf,this.__v_isRef=!0,this.__v_isShallow=!1,this._rawValue=t?e:hm(e),
this._value=t?e:mm(e),this.__v_isShallow=t}get value(){
return this.dep.track(),this._value}set value(e){
const t=this._rawValue,n=this.__v_isShallow||dm(e)||um(e)
;e=n?e:hm(e),wh(e,t)&&(this._rawValue=e,
this._value=n?e:mm(e),this.dep.trigger())}}function xm(e){return vm(e)?e.value:e
}function km(e){return rh(e)?e():xm(e)}const Sm={
get:(e,t,n)=>"__v_raw"===t?e:xm(Reflect.get(e,t,n)),set:(e,t,n,r)=>{const o=e[t]
;return vm(o)&&!vm(n)?(o.value=n,!0):Reflect.set(e,t,n,r)}};function _m(e){
return cm(e)?e:new Proxy(e,Sm)}class Tm{constructor(e){
this.__v_isRef=!0,this._value=void 0
;const t=this.dep=new bf,{get:n,set:r}=e(t.track.bind(t),t.trigger.bind(t))
;this._get=n,this._set=r}get value(){return this._value=this._get()}
set value(e){this._set(e)}}function Em(e){return new Tm(e)}function Am(e){
const t=Jp(e)?new Array(e.length):{};for(const n in e)t[n]=Dm(e,n);return t}
class Cm{constructor(e,t,n){
this._object=e,this._key=t,this._defaultValue=n,this.__v_isRef=!0,
this._value=void 0,this._raw=hm(e);let r=!0,o=e;if(!Jp(e)||!ph(String(t)))do{
r=!pm(o)||dm(o)}while(r&&(o=o.__v_raw));this._shallow=r}get value(){
let e=this._object[this._key]
;return this._shallow&&(e=xm(e)),this._value=void 0===e?this._defaultValue:e}
set value(e){if(this._shallow&&vm(this._raw[this._key])){
const t=this._object[this._key];if(vm(t))return void(t.value=e)}
this._object[this._key]=e}get dep(){return function(e,t){const n=Of.get(e)
;return n&&n.get(t)}(this._raw,this._key)}}class $m{constructor(e){
this._getter=e,this.__v_isRef=!0,this.__v_isReadonly=!0,this._value=void 0}
get value(){return this._value=this._getter()}}function Pm(e,t,n){
return vm(e)?e:rh(e)?new $m(e):ih(e)&&arguments.length>1?Dm(e,t,n):bm(e)}
function Dm(e,t,n){return new Cm(e,t,n)}class Im{constructor(e,t,n){
this.fn=e,this.setter=t,
this._value=void 0,this.dep=new bf(this),this.__v_isRef=!0,
this.deps=void 0,this.depsTail=void 0,
this.flags=16,this.globalVersion=gf-1,this.next=void 0,
this.effect=this,this.__v_isReadonly=!t,this.isSSR=n}notify(){if(this.flags|=16,
!(8&this.flags)&&Hh!==this)return tf(this,!0),!0}get value(){
const e=this.dep.track()
;return lf(this),e&&(e.version=this.dep.version),this._value}set value(e){
this.setter&&this.setter(e)}}const Mm={},Nm=new WeakMap;let Rm
;function Lm(e,t,n=Zp){
const{immediate:r,deep:o,once:a,scheduler:i,augmentJob:s,call:l}=n,c=e=>o?e:dm(e)||!1===o||0===o?Bm(e,1):Bm(e)
;let u,d,p,h,f=!1,m=!1
;if(vm(e)?(d=()=>e.value,f=dm(e)):cm(e)?(d=()=>c(e),f=!0):Jp(e)?(m=!0,
f=e.some((e=>cm(e)||dm(e))),
d=()=>e.map((e=>vm(e)?e.value:cm(e)?c(e):rh(e)?l?l(e,2):e():void 0))):d=rh(e)?t?l?()=>l(e,2):e:()=>{
if(p){hf();try{p()}finally{ff()}}const t=Rm;Rm=u;try{return l?l(e,3,[h]):e(h)
}finally{Rm=t}}:Hp,t&&o){const e=d,t=!0===o?1/0:o;d=()=>Bm(e(),t)}
const g=Wh(),v=()=>{u.stop(),g&&g.active&&Gp(g.effects,u)};if(a&&t){const e=t
;t=(...t)=>{e(...t),v()}}let b=m?new Array(e.length).fill(Mm):Mm;const y=e=>{
if(1&u.flags&&(u.dirty||e))if(t){const e=u.run()
;if(o||f||(m?e.some(((e,t)=>wh(e,b[t]))):wh(e,b))){p&&p();const n=Rm;Rm=u;try{
const n=[e,b===Mm?void 0:m&&b[0]===Mm?[]:b,h];b=e,l?l(t,3,n):t(...n)}finally{
Rm=n}}}else u.run()}
;return s&&s(y),u=new Yh(d),u.scheduler=i?()=>i(y,!1):y,h=e=>function(e,t=!1,n=Rm){
if(n){let t=Nm.get(n);t||Nm.set(n,t=[]),t.push(e)}}(e,!1,u),p=u.onStop=()=>{
const e=Nm.get(u);if(e){if(l)l(e,4);else for(const t of e)t();Nm.delete(u)}
},t?r?y(!0):b=u.run():i?i(y.bind(null,!0),!0):u.run(),
v.pause=u.pause.bind(u),v.resume=u.resume.bind(u),v.stop=v,v}
function Bm(e,t=1/0,n){if(t<=0||!ih(e)||e.__v_skip)return e
;if(((n=n||new Map).get(e)||0)>=t)return e
;if(n.set(e,t),t--,vm(e))Bm(e.value,t,n);else if(Jp(e))for(let r=0;r<e.length;r++)Bm(e[r],t,n);else if(th(e)||eh(e))e.forEach((e=>{
Bm(e,t,n)}));else if(dh(e)){for(const r in e)Bm(e[r],t,n)
;for(const r of Object.getOwnPropertySymbols(e))Object.prototype.propertyIsEnumerable.call(e,r)&&Bm(e[r],t,n)
}return e}function jm(e,t,n,r){try{return r?e(...r):e()}catch(o){zm(o,t,n)}}
function Um(e,t,n,r){if(rh(e)){const o=jm(e,t,n,r)
;return o&&sh(o)&&o.catch((e=>{zm(e,t,n)})),o}if(Jp(e)){const o=[]
;for(let a=0;a<e.length;a++)o.push(Um(e[a],t,n,r));return o}}
function zm(e,t,n,r=!0){t&&t.vnode
;const{errorHandler:o,throwUnhandledErrorInProduction:a}=t&&t.appContext.config||Zp
;if(t){let r=t.parent
;const a=t.proxy,i=`https://vuejs.org/error-reference/#runtime-${n}`;for(;r;){
const t=r.ec;if(t)for(let n=0;n<t.length;n++)if(!1===t[n](e,a,i))return
;r=r.parent}if(o)return hf(),jm(o,null,10,[e,a,i]),void ff()}
!function(e,t,n,r=!0,o=!1){if(o)throw e;console.error(e)}(e,0,0,r,a)}const Fm=[]
;let Zm=-1;const Qm=[];let Hm=null,Vm=0;const qm=Promise.resolve();let Wm=null
;function Xm(e){const t=Wm||qm;return e?t.then(this?e.bind(this):e):t}
function Gm(e){if(!(1&e.flags)){const t=tg(e),n=Fm[Fm.length-1]
;!n||!(2&e.flags)&&t>=tg(n)?Fm.push(e):Fm.splice(function(e){
let t=Zm+1,n=Fm.length;for(;t<n;){const r=t+n>>>1,o=Fm[r],a=tg(o)
;a<e||a===e&&2&o.flags?t=r+1:n=r}return t}(t),0,e),e.flags|=1,Ym()}}
function Ym(){Wm||(Wm=qm.then(ng))}function Km(e){
Jp(e)?Qm.push(...e):Hm&&-1===e.id?Hm.splice(Vm+1,0,e):1&e.flags||(Qm.push(e),
e.flags|=1),Ym()}function Jm(e,t,n=Zm+1){for(;n<Fm.length;n++){const t=Fm[n]
;if(t&&2&t.flags){if(e&&t.id!==e.uid)continue
;Fm.splice(n,1),n--,4&t.flags&&(t.flags&=-2),t(),4&t.flags||(t.flags&=-2)}}}
function eg(e){if(Qm.length){const e=[...new Set(Qm)].sort(((e,t)=>tg(e)-tg(t)))
;if(Qm.length=0,Hm)return void Hm.push(...e);for(Hm=e,Vm=0;Vm<Hm.length;Vm++){
const e=Hm[Vm];4&e.flags&&(e.flags&=-2),8&e.flags||e(),e.flags&=-2}Hm=null,Vm=0}
}const tg=e=>null==e.id?2&e.flags?-1:1/0:e.id;function ng(e){try{
for(Zm=0;Zm<Fm.length;Zm++){const e=Fm[Zm]
;!e||8&e.flags||(4&e.flags&&(e.flags&=-2),
jm(e,e.i,e.i?15:14),4&e.flags||(e.flags&=-2))}}finally{for(;Zm<Fm.length;Zm++){
const e=Fm[Zm];e&&(e.flags&=-2)}
Zm=-1,Fm.length=0,eg(),Wm=null,(Fm.length||Qm.length)&&ng()}}let rg=null,og=null
;function ag(e){const t=rg;return rg=e,og=e&&e.type.__scopeId||null,t}
function ig(e,t=rg,n){if(!t)return e;if(e._n)return e;const r=(...n)=>{
r._d&&Fb(-1);const o=ag(t);let a;try{a=e(...n)}finally{ag(o),r._d&&Fb(1)}
return a};return r._n=!0,r._c=!0,r._d=!0,r}function sg(e,t){
if(null===rg)return e;const n=xy(rg),r=e.dirs||(e.dirs=[])
;for(let o=0;o<t.length;o++){let[e,a,i,s=Zp]=t[o];e&&(rh(e)&&(e={mounted:e,
updated:e}),e.deep&&Bm(a),r.push({dir:e,instance:n,value:a,oldValue:void 0,
arg:i,modifiers:s}))}return e}function lg(e,t,n,r){const o=e.dirs,a=t&&t.dirs
;for(let i=0;i<o.length;i++){const s=o[i];a&&(s.oldValue=a[i].value)
;let l=s.dir[r];l&&(hf(),Um(l,n,8,[e.el,s,e,t]),ff())}}function cg(e,t){if(uy){
let n=uy.provides;const r=uy.parent&&uy.parent.provides
;r===n&&(n=uy.provides=Object.create(r)),n[e]=t}}function ug(e,t,n=!1){
const r=dy();if(r||Yv){
let o=Yv?Yv._context.provides:r?null==r.parent||r.ce?r.vnode.appContext&&r.vnode.appContext.provides:r.parent.provides:void 0
;if(o&&e in o)return o[e]
;if(arguments.length>1)return n&&rh(t)?t.call(r&&r.proxy):t}}function dg(){
return!(!dy()&&!Yv)}const pg=Symbol.for("v-scx"),hg=()=>ug(pg);function fg(e,t){
return gg(e,null,t)}function mg(e,t,n){return gg(e,t,n)}function gg(e,t,n=Zp){
const{immediate:r,deep:o,flush:a,once:i}=n,s=Xp({},n),l=t&&r||!t&&"post"!==a
;let c;if(vy)if("sync"===a){const e=hg()
;c=e.__watcherHandles||(e.__watcherHandles=[])}else if(!l){const e=()=>{}
;return e.stop=Hp,e.resume=Hp,e.pause=Hp,e}const u=uy
;s.call=(e,t,n)=>Um(e,u,t,n);let d=!1;"post"===a?s.scheduler=e=>{
_b(e,u&&u.suspense)}:"sync"!==a&&(d=!0,s.scheduler=(e,t)=>{t?e():Gm(e)
}),s.augmentJob=e=>{t&&(e.flags|=4),d&&(e.flags|=2,u&&(e.id=u.uid,e.i=u))}
;const p=Lm(e,t,s);return vy&&(c?c.push(p):l&&p()),p}function vg(e,t,n){
const r=this.proxy,o=oh(e)?e.includes(".")?bg(r,e):()=>r[e]:e.bind(r,r);let a
;rh(t)?a=t:(a=t.handler,n=t);const i=fy(this),s=gg(o,a.bind(r),n);return i(),s}
function bg(e,t){const n=t.split(".");return()=>{let t=e
;for(let e=0;e<n.length&&t;e++)t=t[n[e]];return t}}
const yg=Symbol("_vte"),Og=e=>e.__isTeleport,wg=e=>e&&(e.disabled||""===e.disabled),xg=e=>e&&(e.defer||""===e.defer),kg=e=>"undefined"!=typeof SVGElement&&e instanceof SVGElement,Sg=e=>"function"==typeof MathMLElement&&e instanceof MathMLElement,_g=(e,t)=>{
const n=e&&e.to;if(oh(n)){if(t){return t(n)}return null}return n},Tg={
name:"Teleport",__isTeleport:!0,process(e,t,n,r,o,a,i,s,l,c){
const{mc:u,pc:d,pbc:p,o:{insert:h,querySelector:f,createText:m,createComment:g}}=c,v=wg(t.props)
;let{shapeFlag:b,children:y,dynamicChildren:O}=t;if(null==e){
const e=t.el=m(""),c=t.anchor=m("");h(e,n,r),h(c,n,r);const d=(e,t)=>{
16&b&&u(y,e,t,o,a,i,s,l)},p=()=>{const e=t.target=_g(t.props,f),n=$g(e,t,m,h)
;e&&("svg"!==i&&kg(e)?i="svg":"mathml"!==i&&Sg(e)&&(i="mathml"),
o&&o.isCE&&(o.ce._teleportTargets||(o.ce._teleportTargets=new Set)).add(e),
v||(d(e,n),Cg(t,!1)))}
;v&&(d(n,c),Cg(t,!0)),xg(t.props)?(t.el.__isMounted=!1,_b((()=>{
p(),delete t.el.__isMounted}),a)):p()}else{
if(xg(t.props)&&!1===e.el.__isMounted)return void _b((()=>{
Tg.process(e,t,n,r,o,a,i,s,l,c)}),a);t.el=e.el,t.targetStart=e.targetStart
;const u=t.anchor=e.anchor,h=t.target=e.target,m=t.targetAnchor=e.targetAnchor,g=wg(e.props),b=g?n:h,y=g?u:m
;if("svg"===i||kg(h)?i="svg":("mathml"===i||Sg(h))&&(i="mathml"),
O?(p(e.dynamicChildren,O,b,o,a,i,s),
Cb(e,t,!0)):l||d(e,t,b,y,o,a,i,s,!1),v)g?t.props&&e.props&&t.props.to!==e.props.to&&(t.props.to=e.props.to):Eg(t,n,u,c,1);else if((t.props&&t.props.to)!==(e.props&&e.props.to)){
const e=t.target=_g(t.props,f);e&&Eg(t,e,null,c,0)}else g&&Eg(t,h,m,c,1);Cg(t,v)
}},remove(e,t,n,{um:r,o:{remove:o}},a){
const{shapeFlag:i,children:s,anchor:l,targetStart:c,targetAnchor:u,target:d,props:p}=e
;if(d&&(o(c),o(u)),a&&o(l),16&i){const e=a||!wg(p);for(let o=0;o<s.length;o++){
const a=s[o];r(a,t,n,e,!!a.dynamicChildren)}}},move:Eg,
hydrate:function(e,t,n,r,o,a,{o:{nextSibling:i,parentNode:s,querySelector:l,insert:c,createText:u}},d){
function p(e,t,l,c){
t.anchor=d(i(e),t,s(e),n,r,o,a),t.targetStart=l,t.targetAnchor=c}
const h=t.target=_g(t.props,l),f=wg(t.props);if(h){const s=h._lpa||h.firstChild
;if(16&t.shapeFlag)if(f)p(e,t,s,s&&i(s));else{t.anchor=i(e);let l=s;for(;l;){
if(l&&8===l.nodeType)if("teleport start anchor"===l.data)t.targetStart=l;else if("teleport anchor"===l.data){
t.targetAnchor=l,h._lpa=t.targetAnchor&&i(t.targetAnchor);break}l=i(l)}
t.targetAnchor||$g(h,t,u,c),d(s&&i(s),t,h,n,r,o,a)}Cg(t,f)
}else f&&16&t.shapeFlag&&p(e,t,e,i(e));return t.anchor&&i(t.anchor)}}
;function Eg(e,t,n,{o:{insert:r},m:o},a=2){0===a&&r(e.targetAnchor,t,n)
;const{el:i,anchor:s,shapeFlag:l,children:c,props:u}=e,d=2===a
;if(d&&r(i,t,n),(!d||wg(u))&&16&l)for(let p=0;p<c.length;p++)o(c[p],t,n,2)
;d&&r(s,t,n)}const Ag=Tg;function Cg(e,t){const n=e.ctx;if(n&&n.ut){let r,o
;for(t?(r=e.el,
o=e.anchor):(r=e.targetStart,o=e.targetAnchor);r&&r!==o;)1===r.nodeType&&r.setAttribute("data-v-owner",n.uid),
r=r.nextSibling;n.ut()}}function $g(e,t,n,r){
const o=t.targetStart=n(""),a=t.targetAnchor=n("")
;return o[yg]=a,e&&(r(o,e),r(a,e)),a}
const Pg=Symbol("_leaveCb"),Dg=Symbol("_enterCb");const Ig=[Function,Array],Mg={
mode:String,appear:Boolean,persisted:Boolean,onBeforeEnter:Ig,onEnter:Ig,
onAfterEnter:Ig,onEnterCancelled:Ig,onBeforeLeave:Ig,onLeave:Ig,onAfterLeave:Ig,
onLeaveCancelled:Ig,onBeforeAppear:Ig,onAppear:Ig,onAfterAppear:Ig,
onAppearCancelled:Ig},Ng=e=>{const t=e.subTree
;return t.component?Ng(t.component):t};function Rg(e){let t=e[0]
;if(e.length>1)for(const n of e)if(n.type!==Rb){t=n;break}return t}const Lg={
name:"BaseTransition",props:Mg,setup(e,{slots:t}){const n=dy(),r=function(){
const e={isMounted:!1,isLeaving:!1,isUnmounting:!1,leavingVNodes:new Map}
;return iv((()=>{e.isMounted=!0})),cv((()=>{e.isUnmounting=!0})),e}()
;return()=>{const o=t.default&&Zg(t.default(),!0);if(!o||!o.length)return
;const a=Rg(o),i=hm(e),{mode:s}=i;if(r.isLeaving)return Ug(a);const l=zg(a)
;if(!l)return Ug(a);let c=jg(l,i,r,n,(e=>c=e));l.type!==Rb&&Fg(l,c)
;let u=n.subTree&&zg(n.subTree);if(u&&u.type!==Rb&&!qb(u,l)&&Ng(n).type!==Rb){
let e=jg(u,i,r,n)
;if(Fg(u,e),"out-in"===s&&l.type!==Rb)return r.isLeaving=!0,e.afterLeave=()=>{
r.isLeaving=!1,8&n.job.flags||n.update(),delete e.afterLeave,u=void 0},Ug(a)
;"in-out"===s&&l.type!==Rb?e.delayLeave=(e,t,n)=>{
Bg(r,u)[String(u.key)]=u,e[Pg]=()=>{
t(),e[Pg]=void 0,delete c.delayedLeave,u=void 0},c.delayedLeave=()=>{
n(),delete c.delayedLeave,u=void 0}}:u=void 0}else u&&(u=void 0);return a}}}
;function Bg(e,t){const{leavingVNodes:n}=e;let r=n.get(t.type)
;return r||(r=Object.create(null),n.set(t.type,r)),r}function jg(e,t,n,r,o){
const{appear:a,mode:i,persisted:s=!1,onBeforeEnter:l,onEnter:c,onAfterEnter:u,onEnterCancelled:d,onBeforeLeave:p,onLeave:h,onAfterLeave:f,onLeaveCancelled:m,onBeforeAppear:g,onAppear:v,onAfterAppear:b,onAppearCancelled:y}=t,O=String(e.key),w=Bg(n,e),x=(e,t)=>{
e&&Um(e,r,9,t)},k=(e,t)=>{const n=t[1]
;x(e,t),Jp(e)?e.every((e=>e.length<=1))&&n():e.length<=1&&n()},S={mode:i,
persisted:s,beforeEnter(t){let r=l;if(!n.isMounted){if(!a)return;r=g||l}
t[Pg]&&t[Pg](!0);const o=w[O];o&&qb(e,o)&&o.el[Pg]&&o.el[Pg](),x(r,[t])},
enter(e){let t=c,r=u,o=d;if(!n.isMounted){if(!a)return;t=v||c,r=b||u,o=y||d}
let i=!1;const s=e[Dg]=t=>{
i||(i=!0,x(t?o:r,[e]),S.delayedLeave&&S.delayedLeave(),e[Dg]=void 0)}
;t?k(t,[e,s]):s()},leave(t,r){const o=String(e.key)
;if(t[Dg]&&t[Dg](!0),n.isUnmounting)return r();x(p,[t]);let a=!1
;const i=t[Pg]=n=>{a||(a=!0,r(),x(n?m:f,[t]),t[Pg]=void 0,w[o]===e&&delete w[o])
};w[o]=e,h?k(h,[t,i]):i()},clone(e){const a=jg(e,t,n,r,o);return o&&o(a),a}}
;return S}function Ug(e){if(Kg(e))return(e=Jb(e)).children=null,e}
function zg(e){if(!Kg(e))return Og(e.type)&&e.children?Rg(e.children):e
;if(e.component)return e.component.subTree;const{shapeFlag:t,children:n}=e
;if(n){if(16&t)return n[0];if(32&t&&rh(n.default))return n.default()}}
function Fg(e,t){
6&e.shapeFlag&&e.component?(e.transition=t,Fg(e.component.subTree,t)):128&e.shapeFlag?(e.ssContent.transition=t.clone(e.ssContent),
e.ssFallback.transition=t.clone(e.ssFallback)):e.transition=t}
function Zg(e,t=!1,n){let r=[],o=0;for(let a=0;a<e.length;a++){let i=e[a]
;const s=null==n?i.key:String(n)+String(null!=i.key?i.key:a)
;i.type===Mb?(128&i.patchFlag&&o++,
r=r.concat(Zg(i.children,t,s))):(t||i.type!==Rb)&&r.push(null!=s?Jb(i,{key:s
}):i)}if(o>1)for(let a=0;a<r.length;a++)r[a].patchFlag=-2;return r}
function Qg(e,t){return rh(e)?(()=>Xp({name:e.name},t,{setup:e}))():e}
function Hg(){const e=dy()
;return e?(e.appContext.config.idPrefix||"v")+"-"+e.ids[0]+e.ids[1]++:""}
function Vg(e){e.ids=[e.ids[0]+e.ids[2]+++"-",0,0]}function qg(e){
const t=dy(),n=ym(null);if(t){const r=t.refs===Zp?t.refs={}:t.refs
;Object.defineProperty(r,e,{enumerable:!0,get:()=>n.value,set:e=>n.value=e})}
return n}const Wg=new WeakMap;function Xg(e,t,n,r,o=!1){
if(Jp(e))return void e.forEach(((e,a)=>Xg(e,t&&(Jp(t)?t[a]:t),n,r,o)))
;if(Yg(r)&&!o)return void(512&r.shapeFlag&&r.type.__asyncResolved&&r.component.subTree.component&&Xg(e,t,n,r.component.subTree))
;const a=4&r.shapeFlag?xy(r.component):r.el,i=o?null:a,{i:s,r:l}=e,c=t&&t.r,u=s.refs===Zp?s.refs={}:s.refs,d=s.setupState,p=hm(d),h=d===Zp?Vp:e=>Kp(p,e)
;if(null!=c&&c!==l)if(Gg(t),oh(c))u[c]=null,h(c)&&(d[c]=null);else if(vm(c)){
c.value=null;const e=t;e.k&&(u[e.k]=null)}if(rh(l))jm(l,s,12,[i,u]);else{
const t=oh(l),r=vm(l);if(t||r){const s=()=>{if(e.f){
const n=t?h(l)?d[l]:u[l]:l.value
;if(o)Jp(n)&&Gp(n,a);else if(Jp(n))n.includes(a)||n.push(a);else if(t)u[l]=[a],
h(l)&&(d[l]=u[l]);else{const t=[a];l.value=t,e.k&&(u[e.k]=t)}
}else t?(u[l]=i,h(l)&&(d[l]=i)):r&&(l.value=i,e.k&&(u[e.k]=i))};if(i){
const t=()=>{s(),Wg.delete(e)};t.id=-1,Wg.set(e,t),_b(t,n)}else Gg(e),s()}}}
function Gg(e){const t=Wg.get(e);t&&(t.flags|=8,Wg.delete(e))}
Eh().requestIdleCallback,Eh().cancelIdleCallback
;const Yg=e=>!!e.type.__asyncLoader,Kg=e=>e.type.__isKeepAlive;function Jg(e,t){
tv(e,"a",t)}function ev(e,t){tv(e,"da",t)}function tv(e,t,n=uy){
const r=e.__wdc||(e.__wdc=()=>{let t=n;for(;t;){if(t.isDeactivated)return
;t=t.parent}return e()});if(rv(t,r,n),n){let e=n.parent
;for(;e&&e.parent;)Kg(e.parent.vnode)&&nv(r,t,n,e),e=e.parent}}
function nv(e,t,n,r){const o=rv(t,e,r,!0);uv((()=>{Gp(r[t],o)}),n)}
function rv(e,t,n=uy,r=!1){if(n){
const o=n[e]||(n[e]=[]),a=t.__weh||(t.__weh=(...r)=>{hf()
;const o=fy(n),a=Um(t,n,e,r);return o(),ff(),a})
;return r?o.unshift(a):o.push(a),a}}const ov=e=>(t,n=uy)=>{
vy&&"sp"!==e||rv(e,((...e)=>t(...e)),n)
},av=ov("bm"),iv=ov("m"),sv=ov("bu"),lv=ov("u"),cv=ov("bum"),uv=ov("um"),dv=ov("sp"),pv=ov("rtg"),hv=ov("rtc")
;function fv(e,t=uy){rv("ec",e,t)}const mv="components";function gv(e,t){
return yv(mv,e,!0,t)||e}const vv=Symbol.for("v-ndc");function bv(e){
return oh(e)?yv(mv,e,!1)||e:e||vv}function yv(e,t,n=!0,r=!1){const o=rg||uy
;if(o){const n=o.type;{const e=ky(n,!1)
;if(e&&(e===t||e===gh(t)||e===yh(gh(t))))return n}
const a=Ov(o[e]||n[e],t)||Ov(o.appContext[e],t);return!a&&r?n:a}}
function Ov(e,t){return e&&(e[t]||e[gh(t)]||e[yh(gh(t))])}function wv(e,t,n,r){
let o;const a=n,i=Jp(e);if(i||oh(e)){let n=!1,r=!1
;i&&cm(e)&&(n=!dm(e),r=um(e),e=Ef(e)),o=new Array(e.length)
;for(let i=0,s=e.length;i<s;i++)o[i]=t(n?r?gm(mm(e[i])):mm(e[i]):e[i],i,void 0,a)
}else if("number"==typeof e){o=new Array(e)
;for(let n=0;n<e;n++)o[n]=t(n+1,n,void 0,a)
}else if(ih(e))if(e[Symbol.iterator])o=Array.from(e,((e,n)=>t(e,n,void 0,a)));else{
const n=Object.keys(e);o=new Array(n.length);for(let r=0,i=n.length;r<i;r++){
const i=n[r];o[r]=t(e[i],i,r,a)}}else o=[];return o}function xv(e,t){
for(let n=0;n<t.length;n++){const r=t[n]
;if(Jp(r))for(let t=0;t<r.length;t++)e[r[t].name]=r[t].fn;else r&&(e[r.name]=r.key?(...e)=>{
const t=r.fn(...e);return t&&(t.key=r.key),t}:r.fn)}return e}
function kv(e,t,n={},r,o){if(rg.ce||rg.parent&&Yg(rg.parent)&&rg.parent.ce){
const e=Object.keys(n).length>0
;return"default"!==t&&(n.name=t),Ub(),Hb(Mb,null,[Yb("slot",n,r&&r())],e?-2:64)}
let a=e[t];a&&a._c&&(a._d=!1),Ub()
;const i=a&&Sv(a(n)),s=n.key||i&&i.key,l=Hb(Mb,{
key:(s&&!ah(s)?s:`_${t}`)+(!i&&r?"_fb":"")},i||(r?r():[]),i&&1===e._?64:-2)
;return!o&&l.scopeId&&(l.slotScopeIds=[l.scopeId+"-s"]),a&&a._c&&(a._d=!0),l}
function Sv(e){
return e.some((e=>!Vb(e)||e.type!==Rb&&!(e.type===Mb&&!Sv(e.children))))?e:null}
function _v(e,t){const n={};for(const r in e)n[Oh(r)]=e[r];return n}
const Tv=e=>e?gy(e)?xy(e):Tv(e.parent):null,Ev=Xp(Object.create(null),{$:e=>e,
$el:e=>e.vnode.el,$data:e=>e.data,$props:e=>e.props,$attrs:e=>e.attrs,
$slots:e=>e.slots,$refs:e=>e.refs,$parent:e=>Tv(e.parent),$root:e=>Tv(e.root),
$host:e=>e.ce,$emit:e=>e.emit,$options:e=>Uv(e),$forceUpdate:e=>e.f||(e.f=()=>{
Gm(e.update)}),$nextTick:e=>e.n||(e.n=Xm.bind(e.proxy)),$watch:e=>vg.bind(e)
}),Av=(e,t)=>e!==Zp&&!e.__isScriptSetup&&Kp(e,t),Cv={get({_:e},t){
if("__v_skip"===t)return!0
;const{ctx:n,setupState:r,data:o,props:a,accessCache:i,type:s,appContext:l}=e
;if("$"!==t[0]){const e=i[t];if(void 0!==e)switch(e){case 1:return r[t];case 2:
return o[t];case 4:return n[t];case 3:return a[t]}else{if(Av(r,t))return i[t]=1,
r[t];if(o!==Zp&&Kp(o,t))return i[t]=2,o[t];if(Kp(a,t))return i[t]=3,a[t]
;if(n!==Zp&&Kp(n,t))return i[t]=4,n[t];Rv&&(i[t]=0)}}const c=Ev[t];let u,d
;return c?("$attrs"===t&&Sf(e.attrs,0,""),
c(e)):(u=s.__cssModules)&&(u=u[t])?u:n!==Zp&&Kp(n,t)?(i[t]=4,
n[t]):(d=l.config.globalProperties,Kp(d,t)?d[t]:void 0)},set({_:e},t,n){
const{data:r,setupState:o,ctx:a}=e
;return Av(o,t)?(o[t]=n,!0):r!==Zp&&Kp(r,t)?(r[t]=n,
!0):!Kp(e.props,t)&&(("$"!==t[0]||!(t.slice(1)in e))&&(a[t]=n,!0))},
has({_:{data:e,setupState:t,accessCache:n,ctx:r,appContext:o,props:a,type:i}},s){
let l
;return!!(n[s]||e!==Zp&&"$"!==s[0]&&Kp(e,s)||Av(t,s)||Kp(a,s)||Kp(r,s)||Kp(Ev,s)||Kp(o.config.globalProperties,s)||(l=i.__cssModules)&&l[s])
},defineProperty(e,t,n){
return null!=n.get?e._.accessCache[t]=0:Kp(n,"value")&&this.set(e,t,n.value,null),
Reflect.defineProperty(e,t,n)}};function $v(){return Dv().slots}function Pv(){
return Dv().attrs}function Dv(e){const t=dy()
;return t.setupContext||(t.setupContext=wy(t))}function Iv(e){
return Jp(e)?e.reduce(((e,t)=>(e[t]=null,e)),{}):e}function Mv(e,t){
const n=Iv(e);for(const r in t){if(r.startsWith("__skip"))continue;let e=n[r]
;e?Jp(e)||rh(e)?e=n[r]={type:e,default:t[r]}:e.default=t[r]:null===e&&(e=n[r]={
default:t[r]}),e&&t[`__skip_${r}`]&&(e.skipFactory=!0)}return n}
function Nv(e,t){return e&&t?Jp(e)&&Jp(t)?e.concat(t):Xp({},Iv(e),Iv(t)):e||t}
let Rv=!0;function Lv(e){const t=Uv(e),n=e.proxy,r=e.ctx
;Rv=!1,t.beforeCreate&&Bv(t.beforeCreate,e,"bc")
;const{data:o,computed:a,methods:i,watch:s,provide:l,inject:c,created:u,beforeMount:d,mounted:p,beforeUpdate:h,updated:f,activated:m,deactivated:g,beforeDestroy:v,beforeUnmount:b,destroyed:y,unmounted:O,render:w,renderTracked:x,renderTriggered:k,errorCaptured:S,serverPrefetch:_,expose:T,inheritAttrs:E,components:A,directives:C,filters:$}=t
;if(c&&function(e,t,n=Hp){Jp(e)&&(e=Qv(e));for(const r in e){const n=e[r];let o
;o=ih(n)?"default"in n?ug(n.from||r,n.default,!0):ug(n.from||r):ug(n),
vm(o)?Object.defineProperty(t,r,{enumerable:!0,configurable:!0,get:()=>o.value,
set:e=>o.value=e}):t[r]=o}}(c,r,null),i)for(const D in i){const e=i[D]
;rh(e)&&(r[D]=e.bind(n))}if(o){const t=o.call(n,n);ih(t)&&(e.data=am(t))}
if(Rv=!0,a)for(const D in a){
const e=a[D],t=rh(e)?e.bind(n,n):rh(e.get)?e.get.bind(n,n):Hp,o=!rh(e)&&rh(e.set)?e.set.bind(n):Hp,i=Sy({
get:t,set:o});Object.defineProperty(r,D,{enumerable:!0,configurable:!0,
get:()=>i.value,set:e=>i.value=e})}if(s)for(const D in s)jv(s[D],r,n,D);if(l){
const e=rh(l)?l.call(n):l;Reflect.ownKeys(e).forEach((t=>{cg(t,e[t])}))}
function P(e,t){Jp(t)?t.forEach((t=>e(t.bind(n)))):t&&e(t.bind(n))}
if(u&&Bv(u,e,"c"),
P(av,d),P(iv,p),P(sv,h),P(lv,f),P(Jg,m),P(ev,g),P(fv,S),P(hv,x),P(pv,k),P(cv,b),
P(uv,O),P(dv,_),Jp(T))if(T.length){const t=e.exposed||(e.exposed={})
;T.forEach((e=>{Object.defineProperty(t,e,{get:()=>n[e],set:t=>n[e]=t,
enumerable:!0})}))}else e.exposed||(e.exposed={})
;w&&e.render===Hp&&(e.render=w),null!=E&&(e.inheritAttrs=E),A&&(e.components=A),
C&&(e.directives=C),_&&Vg(e)}function Bv(e,t,n){
Um(Jp(e)?e.map((e=>e.bind(t.proxy))):e.bind(t.proxy),t,n)}function jv(e,t,n,r){
let o=r.includes(".")?bg(n,r):()=>n[r];if(oh(e)){const n=t[e];rh(n)&&mg(o,n)
}else if(rh(e))mg(o,e.bind(n));else if(ih(e))if(Jp(e))e.forEach((e=>jv(e,t,n,r)));else{
const r=rh(e.handler)?e.handler.bind(n):t[e.handler];rh(r)&&mg(o,r,e)}}
function Uv(e){
const t=e.type,{mixins:n,extends:r}=t,{mixins:o,optionsCache:a,config:{optionMergeStrategies:i}}=e.appContext,s=a.get(t)
;let l;return s?l=s:o.length||n||r?(l={},o.length&&o.forEach((e=>zv(l,e,i,!0))),
zv(l,t,i)):l=t,ih(t)&&a.set(t,l),l}function zv(e,t,n,r=!1){
const{mixins:o,extends:a}=t;a&&zv(e,a,n,!0),o&&o.forEach((t=>zv(e,t,n,!0)))
;for(const i in t)if(r&&"expose"===i);else{const r=Fv[i]||n&&n[i]
;e[i]=r?r(e[i],t[i]):t[i]}return e}const Fv={data:Zv,props:qv,emits:qv,
methods:Vv,computed:Vv,beforeCreate:Hv,created:Hv,beforeMount:Hv,mounted:Hv,
beforeUpdate:Hv,updated:Hv,beforeDestroy:Hv,beforeUnmount:Hv,destroyed:Hv,
unmounted:Hv,activated:Hv,deactivated:Hv,errorCaptured:Hv,serverPrefetch:Hv,
components:Vv,directives:Vv,watch:function(e,t){if(!e)return t;if(!t)return e
;const n=Xp(Object.create(null),e);for(const r in t)n[r]=Hv(e[r],t[r]);return n
},provide:Zv,inject:function(e,t){return Vv(Qv(e),Qv(t))}};function Zv(e,t){
return t?e?function(){
return Xp(rh(e)?e.call(this,this):e,rh(t)?t.call(this,this):t)}:t:e}
function Qv(e){if(Jp(e)){const t={};for(let n=0;n<e.length;n++)t[e[n]]=e[n]
;return t}return e}function Hv(e,t){return e?[...new Set([].concat(e,t))]:t}
function Vv(e,t){return e?Xp(Object.create(null),e,t):t}function qv(e,t){
return e?Jp(e)&&Jp(t)?[...new Set([...e,...t])]:Xp(Object.create(null),Iv(e),Iv(null!=t?t:{})):t
}function Wv(){return{app:null,config:{isNativeTag:Vp,performance:!1,
globalProperties:{},optionMergeStrategies:{},errorHandler:void 0,
warnHandler:void 0,compilerOptions:{}},mixins:[],components:{},directives:{},
provides:Object.create(null),optionsCache:new WeakMap,propsCache:new WeakMap,
emitsCache:new WeakMap}}let Xv=0;function Gv(e,t){return function(t,n=null){
rh(t)||(t=Xp({},t)),null==n||ih(n)||(n=null);const r=Wv(),o=new WeakSet,a=[]
;let i=!1;const s=r.app={_uid:Xv++,_component:t,_props:n,_container:null,
_context:r,_instance:null,version:Ty,get config(){return r.config},
set config(e){},
use:(e,...t)=>(o.has(e)||(e&&rh(e.install)?(o.add(e),e.install(s,...t)):rh(e)&&(o.add(e),
e(s,...t))),s),mixin:e=>(r.mixins.includes(e)||r.mixins.push(e),s),
component:(e,t)=>t?(r.components[e]=t,s):r.components[e],
directive:(e,t)=>t?(r.directives[e]=t,s):r.directives[e],mount(o,a,l){if(!i){
const a=s._ceVNode||Yb(t,n)
;return a.appContext=r,!0===l?l="svg":!1===l&&(l=void 0),
e(a,o,l),i=!0,s._container=o,o.__vue_app__=s,xy(a.component)}},onUnmount(e){
a.push(e)},unmount(){
i&&(Um(a,s._instance,16),e(null,s._container),delete s._container.__vue_app__)},
provide:(e,t)=>(r.provides[e]=t,s),runWithContext(e){const t=Yv;Yv=s;try{
return e()}finally{Yv=t}}};return s}}let Yv=null;function Kv(e,t,n=Zp){
const r=dy(),o=gh(t),a=bh(t),i=Jv(e,o),s=Em(((i,s)=>{let l,c,u=Zp
;return gg((()=>{const t=e[o];wh(l,t)&&(l=t,s())}),null,{flush:"sync"}),{
get:()=>(i(),n.get?n.get(l):l),set(e){const i=n.set?n.set(e):e
;if(!(wh(i,l)||u!==Zp&&wh(e,u)))return;const d=r.vnode.props
;d&&(t in d||o in d||a in d)&&(`onUpdate:${t}`in d||`onUpdate:${o}`in d||`onUpdate:${a}`in d)||(l=e,
s()),r.emit(`update:${t}`,i),wh(e,i)&&wh(e,u)&&!wh(i,c)&&s(),u=e,c=i}}}))
;return s[Symbol.iterator]=()=>{let e=0;return{next:()=>e<2?{value:e++?i||Zp:s,
done:!1}:{done:!0}}},s}
const Jv=(e,t)=>"modelValue"===t||"model-value"===t?e.modelModifiers:e[`${t}Modifiers`]||e[`${gh(t)}Modifiers`]||e[`${bh(t)}Modifiers`]
;function eb(e,t,...n){if(e.isUnmounted)return;const r=e.vnode.props||Zp;let o=n
;const a=t.startsWith("update:"),i=a&&Jv(r,t.slice(7));let s
;i&&(i.trim&&(o=n.map((e=>oh(e)?e.trim():e))),i.number&&(o=n.map(Sh)))
;let l=r[s=Oh(t)]||r[s=Oh(gh(t))];!l&&a&&(l=r[s=Oh(bh(t))]),l&&Um(l,e,6,o)
;const c=r[s+"Once"];if(c){if(e.emitted){if(e.emitted[s])return
}else e.emitted={};e.emitted[s]=!0,Um(c,e,6,o)}}const tb=new WeakMap
;function nb(e,t,n=!1){const r=n?tb:t.emitsCache,o=r.get(e)
;if(void 0!==o)return o;const a=e.emits;let i={},s=!1;if(!rh(e)){const r=e=>{
const n=nb(e,t,!0);n&&(s=!0,Xp(i,n))}
;!n&&t.mixins.length&&t.mixins.forEach(r),e.extends&&r(e.extends),
e.mixins&&e.mixins.forEach(r)}
return a||s?(Jp(a)?a.forEach((e=>i[e]=null)):Xp(i,a),
ih(e)&&r.set(e,i),i):(ih(e)&&r.set(e,null),null)}function rb(e,t){
return!(!e||!qp(t))&&(t=t.slice(2).replace(/Once$/,""),
Kp(e,t[0].toLowerCase()+t.slice(1))||Kp(e,bh(t))||Kp(e,t))}function ob(e){
const{type:t,vnode:n,proxy:r,withProxy:o,propsOptions:[a],slots:i,attrs:s,emit:l,render:c,renderCache:u,props:d,data:p,setupState:h,ctx:f,inheritAttrs:m}=e,g=ag(e)
;let v,b;try{if(4&n.shapeFlag){const e=o||r,t=e;v=ry(c.call(t,e,u,d,h,p,f)),b=s
}else{const e=t;0,v=ry(e.length>1?e(d,{attrs:s,slots:i,emit:l
}):e(d,null)),b=t.props?s:ab(s)}}catch(O){Bb.length=0,zm(O,e,1),v=Yb(Rb)}let y=v
;if(b&&!1!==m){const e=Object.keys(b),{shapeFlag:t}=y
;e.length&&7&t&&(a&&e.some(Wp)&&(b=ib(b,a)),y=Jb(y,b,!1,!0))}
return n.dirs&&(y=Jb(y,null,!1,!0),
y.dirs=y.dirs?y.dirs.concat(n.dirs):n.dirs),n.transition&&Fg(y,n.transition),
v=y,ag(g),v}const ab=e=>{let t
;for(const n in e)("class"===n||"style"===n||qp(n))&&((t||(t={}))[n]=e[n])
;return t},ib=(e,t)=>{const n={}
;for(const r in e)Wp(r)&&r.slice(9)in t||(n[r]=e[r]);return n}
;function sb(e,t,n){const r=Object.keys(t)
;if(r.length!==Object.keys(e).length)return!0;for(let o=0;o<r.length;o++){
const a=r[o];if(t[a]!==e[a]&&!rb(n,a))return!0}return!1}
const lb={},cb=()=>Object.create(lb),ub=e=>Object.getPrototypeOf(e)===lb
;function db(e,t,n,r=!1){const o={},a=cb()
;e.propsDefaults=Object.create(null),pb(e,t,o,a)
;for(const i in e.propsOptions[0])i in o||(o[i]=void 0)
;n?e.props=r?o:lm(o,!1,Qf,Kf,nm):e.type.props?e.props=o:e.props=a,e.attrs=a}
function pb(e,t,n,r){const[o,a]=e.propsOptions;let i,s=!1;if(t)for(let l in t){
if(hh(l))continue;const c=t[l];let u
;o&&Kp(o,u=gh(l))?a&&a.includes(u)?(i||(i={}))[u]=c:n[u]=c:rb(e.emitsOptions,l)||l in r&&c===r[l]||(r[l]=c,
s=!0)}if(a){const t=hm(n),r=i||Zp;for(let i=0;i<a.length;i++){const s=a[i]
;n[s]=hb(o,t,s,r[s],e,!Kp(r,s))}}return s}function hb(e,t,n,r,o,a){const i=e[n]
;if(null!=i){const e=Kp(i,"default");if(e&&void 0===r){const e=i.default
;if(i.type!==Function&&!i.skipFactory&&rh(e)){const{propsDefaults:a}=o
;if(n in a)r=a[n];else{const i=fy(o);r=a[n]=e.call(null,t),i()}}else r=e
;o.ce&&o.ce._setProp(n,r)}i[0]&&(a&&!e?r=!1:!i[1]||""!==r&&r!==bh(n)||(r=!0))}
return r}const fb=new WeakMap;function mb(e,t,n=!1){
const r=n?fb:t.propsCache,o=r.get(e);if(o)return o;const a=e.props,i={},s=[]
;let l=!1;if(!rh(e)){const r=e=>{l=!0;const[n,r]=mb(e,t,!0)
;Xp(i,n),r&&s.push(...r)}
;!n&&t.mixins.length&&t.mixins.forEach(r),e.extends&&r(e.extends),
e.mixins&&e.mixins.forEach(r)}if(!a&&!l)return ih(e)&&r.set(e,Qp),Qp
;if(Jp(a))for(let u=0;u<a.length;u++){const e=gh(a[u]);gb(e)&&(i[e]=Zp)
}else if(a)for(const u in a){const e=gh(u);if(gb(e)){
const t=a[u],n=i[e]=Jp(t)||rh(t)?{type:t}:Xp({},t),r=n.type;let o=!1,l=!0
;if(Jp(r))for(let e=0;e<r.length;++e){const t=r[e],n=rh(t)&&t.name
;if("Boolean"===n){o=!0;break}"String"===n&&(l=!1)
}else o=rh(r)&&"Boolean"===r.name;n[0]=o,n[1]=l,(o||Kp(n,"default"))&&s.push(e)}
}const c=[i,s];return ih(e)&&r.set(e,c),c}function gb(e){
return"$"!==e[0]&&!hh(e)}
const vb=e=>"_"===e||"_ctx"===e||"$stable"===e,bb=e=>Jp(e)?e.map(ry):[ry(e)],yb=(e,t,n)=>{
if(t._n)return t;const r=ig(((...e)=>bb(t(...e))),n);return r._c=!1,r
},Ob=(e,t,n)=>{const r=e._ctx;for(const o in e){if(vb(o))continue;const n=e[o]
;if(rh(n))t[o]=yb(0,n,r);else if(null!=n){const e=bb(n);t[o]=()=>e}}
},wb=(e,t)=>{const n=bb(t);e.slots.default=()=>n},xb=(e,t,n)=>{
for(const r in t)!n&&vb(r)||(e[r]=t[r])},kb=(e,t,n)=>{const r=e.slots=cb()
;if(32&e.vnode.shapeFlag){const e=t._;e?(xb(r,t,n),n&&kh(r,"_",e,!0)):Ob(t,r)
}else t&&wb(e,t)},Sb=(e,t,n)=>{const{vnode:r,slots:o}=e;let a=!0,i=Zp
;if(32&r.shapeFlag){const e=t._
;e?n&&1===e?a=!1:xb(o,t,n):(a=!t.$stable,Ob(t,o)),i=t}else t&&(wb(e,t),i={
default:1});if(a)for(const s in o)vb(s)||null!=i[s]||delete o[s]
},_b=function(e,t){
t&&t.pendingBranch?Jp(e)?t.effects.push(...e):t.effects.push(e):Km(e)}
;function Tb(e){return function(e,t){Eh().__VUE__=!0
;const{insert:n,remove:r,patchProp:o,createElement:a,createText:i,createComment:s,setText:l,setElementText:c,parentNode:u,nextSibling:d,setScopeId:p=Hp,insertStaticContent:h}=e,f=(e,t,n,r=null,o=null,a=null,i=void 0,s=null,l=!!t.dynamicChildren)=>{
if(e===t)return
;e&&!qb(e,t)&&(r=F(e),L(e,o,a,!0),e=null),-2===t.patchFlag&&(l=!1,
t.dynamicChildren=null);const{type:c,ref:u,shapeFlag:d}=t;switch(c){case Nb:
m(e,t,n,r);break;case Rb:g(e,t,n,r);break;case Lb:null==e&&v(t,n,r,i);break
;case Mb:E(e,t,n,r,o,a,i,s,l);break;default:
1&d?O(e,t,n,r,o,a,i,s,l):6&d?A(e,t,n,r,o,a,i,s,l):(64&d||128&d)&&c.process(e,t,n,r,o,a,i,s,l,H)
}
null!=u&&o?Xg(u,e&&e.ref,a,t||e,!t):null==u&&e&&null!=e.ref&&Xg(e.ref,null,a,e,!0)
},m=(e,t,r,o)=>{if(null==e)n(t.el=i(t.children),r,o);else{const n=t.el=e.el
;t.children!==e.children&&l(n,t.children)}},g=(e,t,r,o)=>{
null==e?n(t.el=s(t.children||""),r,o):t.el=e.el},v=(e,t,n,r)=>{
[e.el,e.anchor]=h(e.children,t,n,r,e.el,e.anchor)},b=({el:e,anchor:t},r,o)=>{
let a;for(;e&&e!==t;)a=d(e),n(e,r,o),e=a;n(t,r,o)},y=({el:e,anchor:t})=>{let n
;for(;e&&e!==t;)n=d(e),r(e),e=n;r(t)},O=(e,t,n,r,o,a,i,s,l)=>{
if("svg"===t.type?i="svg":"math"===t.type&&(i="mathml"),
null==e)w(t,n,r,o,a,i,s,l);else{const n=e.el&&e.el._isVueCE?e.el:null;try{
n&&n._beginPatch(),S(e,t,o,a,i,s,l)}finally{n&&n._endPatch()}}
},w=(e,t,r,i,s,l,u,d)=>{let p,h;const{props:f,shapeFlag:m,transition:g,dirs:v}=e
;if(p=e.el=a(e.type,l,f&&f.is,f),
8&m?c(p,e.children):16&m&&k(e.children,p,null,i,s,Eb(e,l),u,d),
v&&lg(e,null,i,"created"),x(p,e,e.scopeId,u,i),f){
for(const e in f)"value"===e||hh(e)||o(p,e,null,f[e],l,i)
;"value"in f&&o(p,"value",null,f.value,l),(h=f.onVnodeBeforeMount)&&sy(h,i,e)}
v&&lg(e,null,i,"beforeMount");const b=function(e,t){
return(!e||e&&!e.pendingBranch)&&t&&!t.persisted}(s,g)
;b&&g.beforeEnter(p),n(p,t,r),((h=f&&f.onVnodeMounted)||b||v)&&_b((()=>{
h&&sy(h,i,e),b&&g.enter(p),v&&lg(e,null,i,"mounted")}),s)},x=(e,t,n,r,o)=>{
if(n&&p(e,n),r)for(let a=0;a<r.length;a++)p(e,r[a]);if(o){let n=o.subTree
;if(t===n||Ib(n.type)&&(n.ssContent===t||n.ssFallback===t)){const t=o.vnode
;x(e,t,t.scopeId,t.slotScopeIds,o.parent)}}},k=(e,t,n,r,o,a,i,s,l=0)=>{
for(let c=l;c<e.length;c++){const l=e[c]=s?oy(e[c]):ry(e[c])
;f(null,l,t,n,r,o,a,i,s)}},S=(e,t,n,r,a,i,s)=>{const l=t.el=e.el
;let{patchFlag:u,dynamicChildren:d,dirs:p}=t;u|=16&e.patchFlag
;const h=e.props||Zp,f=t.props||Zp;let m
;if(n&&Ab(n,!1),(m=f.onVnodeBeforeUpdate)&&sy(m,n,t,e),
p&&lg(t,e,n,"beforeUpdate"),
n&&Ab(n,!0),(h.innerHTML&&null==f.innerHTML||h.textContent&&null==f.textContent)&&c(l,""),
d?_(e.dynamicChildren,d,l,n,r,Eb(t,a),i):s||I(e,t,l,null,n,r,Eb(t,a),i,!1),u>0){
if(16&u)T(l,h,f,n,a);else if(2&u&&h.class!==f.class&&o(l,"class",null,f.class,a),
4&u&&o(l,"style",h.style,f.style,a),8&u){const e=t.dynamicProps
;for(let t=0;t<e.length;t++){const r=e[t],i=h[r],s=f[r]
;s===i&&"value"!==r||o(l,r,i,s,a,n)}}
1&u&&e.children!==t.children&&c(l,t.children)}else s||null!=d||T(l,h,f,n,a)
;((m=f.onVnodeUpdated)||p)&&_b((()=>{m&&sy(m,n,t,e),p&&lg(t,e,n,"updated")}),r)
},_=(e,t,n,r,o,a,i)=>{for(let s=0;s<t.length;s++){
const l=e[s],c=t[s],d=l.el&&(l.type===Mb||!qb(l,c)||198&l.shapeFlag)?u(l.el):n
;f(l,c,d,null,r,o,a,i,!0)}},T=(e,t,n,r,a)=>{if(t!==n){
if(t!==Zp)for(const i in t)hh(i)||i in n||o(e,i,t[i],null,a,r)
;for(const i in n){if(hh(i))continue;const s=n[i],l=t[i]
;s!==l&&"value"!==i&&o(e,i,l,s,a,r)}"value"in n&&o(e,"value",t.value,n.value,a)}
},E=(e,t,r,o,a,s,l,c,u)=>{const d=t.el=e?e.el:i(""),p=t.anchor=e?e.anchor:i("")
;let{patchFlag:h,dynamicChildren:f,slotScopeIds:m}=t
;m&&(c=c?c.concat(m):m),null==e?(n(d,r,o),
n(p,r,o),k(t.children||[],r,p,a,s,l,c,u)):h>0&&64&h&&f&&e.dynamicChildren&&e.dynamicChildren.length===f.length?(_(e.dynamicChildren,f,r,a,s,l,c),
(null!=t.key||a&&t===a.subTree)&&Cb(e,t,!0)):I(e,t,r,p,a,s,l,c,u)
},A=(e,t,n,r,o,a,i,s,l)=>{
t.slotScopeIds=s,null==e?512&t.shapeFlag?o.ctx.activate(t,n,r,i,l):C(t,n,r,o,a,i,l):$(e,t,l)
},C=(e,t,n,r,o,a,i)=>{const s=e.component=function(e,t,n){
const r=e.type,o=(t?t.appContext:e.appContext)||ly,a={uid:cy++,vnode:e,type:r,
parent:t,appContext:o,root:null,next:null,subTree:null,effect:null,update:null,
job:null,scope:new Vh(!0),render:null,proxy:null,exposed:null,exposeProxy:null,
withProxy:null,provides:t?t.provides:Object.create(o.provides),
ids:t?t.ids:["",0,0],accessCache:null,renderCache:[],components:null,
directives:null,propsOptions:mb(r,o),emitsOptions:nb(r,o),emit:null,
emitted:null,propsDefaults:Zp,inheritAttrs:r.inheritAttrs,ctx:Zp,data:Zp,
props:Zp,attrs:Zp,slots:Zp,refs:Zp,setupState:Zp,setupContext:null,suspense:n,
suspenseId:n?n.pendingId:0,asyncDep:null,asyncResolved:!1,isMounted:!1,
isUnmounted:!1,isDeactivated:!1,bc:null,c:null,bm:null,m:null,bu:null,u:null,
um:null,bum:null,da:null,a:null,rtg:null,rtc:null,ec:null,sp:null};a.ctx={_:a
},a.root=t?t.root:a,a.emit=eb.bind(null,a),e.ce&&e.ce(a);return a}(e,r,o)
;if(Kg(e)&&(s.ctx.renderer=H),function(e,t=!1,n=!1){t&&hy(t)
;const{props:r,children:o}=e.vnode,a=gy(e);db(e,r,a,t),kb(e,o,n||t)
;const i=a?function(e,t){const n=e.type
;e.accessCache=Object.create(null),e.proxy=new Proxy(e.ctx,Cv);const{setup:r}=n
;if(r){hf()
;const n=e.setupContext=r.length>1?wy(e):null,o=fy(e),a=jm(r,e,0,[e.props,n]),i=sh(a)
;if(ff(),o(),!i&&!e.sp||Yg(e)||Vg(e),i){if(a.then(my,my),t)return a.then((t=>{
by(e,t)})).catch((t=>{zm(t,e,0)}));e.asyncDep=a}else by(e,a)}else yy(e)
}(e,t):void 0;t&&hy(!1)}(s,!1,i),s.asyncDep){if(o&&o.registerDep(s,P,i),!e.el){
const r=s.subTree=Yb(Rb);g(null,r,t,n),e.placeholder=r.el}}else P(s,e,t,n,o,a,i)
},$=(e,t,n)=>{const r=t.component=e.component;if(function(e,t,n){
const{props:r,children:o,component:a}=e,{props:i,children:s,patchFlag:l}=t,c=a.emitsOptions
;if(t.dirs||t.transition)return!0
;if(!(n&&l>=0))return!(!o&&!s||s&&s.$stable)||r!==i&&(r?!i||sb(r,i,c):!!i)
;if(1024&l)return!0;if(16&l)return r?sb(r,i,c):!!i;if(8&l){
const e=t.dynamicProps;for(let t=0;t<e.length;t++){const n=e[t]
;if(i[n]!==r[n]&&!rb(c,n))return!0}}return!1}(e,t,n)){
if(r.asyncDep&&!r.asyncResolved)return void D(r,t,n);r.next=t,r.update()
}else t.el=e.el,r.vnode=t},P=(e,t,n,r,o,a,i)=>{const s=()=>{if(e.isMounted){
let{next:t,bu:n,u:r,parent:l,vnode:c}=e;{const n=$b(e)
;if(n)return t&&(t.el=c.el,D(e,t,i)),void n.asyncDep.then((()=>{
e.isUnmounted||s()}))}let d,p=t
;Ab(e,!1),t?(t.el=c.el,D(e,t,i)):t=c,n&&xh(n),(d=t.props&&t.props.onVnodeBeforeUpdate)&&sy(d,l,t,c),
Ab(e,!0);const h=ob(e),m=e.subTree
;e.subTree=h,f(m,h,u(m.el),F(m),e,o,a),t.el=h.el,
null===p&&function({vnode:e,parent:t},n){for(;t;){const r=t.subTree
;if(r.suspense&&r.suspense.activeBranch===e&&(r.el=e.el),r!==e)break
;(e=t.vnode).el=n,t=t.parent}
}(e,h.el),r&&_b(r,o),(d=t.props&&t.props.onVnodeUpdated)&&_b((()=>sy(d,l,t,c)),o)
}else{let i;const{el:s,props:l}=t,{bm:c,m:u,parent:d,root:p,type:h}=e,m=Yg(t)
;Ab(e,!1),c&&xh(c),!m&&(i=l&&l.onVnodeBeforeMount)&&sy(i,d,t),Ab(e,!0);{
p.ce&&!1!==p.ce._def.shadowRoot&&p.ce._injectChildStyle(h)
;const i=e.subTree=ob(e);f(null,i,n,r,e,o,a),t.el=i.el}
if(u&&_b(u,o),!m&&(i=l&&l.onVnodeMounted)){const e=t;_b((()=>sy(i,d,e)),o)}
(256&t.shapeFlag||d&&Yg(d.vnode)&&256&d.vnode.shapeFlag)&&e.a&&_b(e.a,o),
e.isMounted=!0,t=n=r=null}};e.scope.on();const l=e.effect=new Yh(s)
;e.scope.off();const c=e.update=l.run.bind(l),d=e.job=l.runIfDirty.bind(l)
;d.i=e,d.id=e.uid,l.scheduler=()=>Gm(d),Ab(e,!0),c()},D=(e,t,n)=>{t.component=e
;const r=e.vnode.props;e.vnode=t,e.next=null,function(e,t,n,r){
const{props:o,attrs:a,vnode:{patchFlag:i}}=e,s=hm(o),[l]=e.propsOptions;let c=!1
;if(!(r||i>0)||16&i){let r;pb(e,t,o,a)&&(c=!0)
;for(const a in s)t&&(Kp(t,a)||(r=bh(a))!==a&&Kp(t,r))||(l?!n||void 0===n[a]&&void 0===n[r]||(o[a]=hb(l,s,a,void 0,e,!0)):delete o[a])
;if(a!==s)for(const e in a)t&&Kp(t,e)||(delete a[e],c=!0)}else if(8&i){
const n=e.vnode.dynamicProps;for(let r=0;r<n.length;r++){let i=n[r]
;if(rb(e.emitsOptions,i))continue;const u=t[i]
;if(l)if(Kp(a,i))u!==a[i]&&(a[i]=u,c=!0);else{const t=gh(i)
;o[t]=hb(l,s,t,u,e,!1)}else u!==a[i]&&(a[i]=u,c=!0)}}c&&_f(e.attrs,"set","")
}(e,t.props,r,n),Sb(e,t.children,n),hf(),Jm(e),ff()},I=(e,t,n,r,o,a,i,s,l=!1)=>{
const u=e&&e.children,d=e?e.shapeFlag:0,p=t.children,{patchFlag:h,shapeFlag:f}=t
;if(h>0){if(128&h)return void N(u,p,n,r,o,a,i,s,l)
;if(256&h)return void M(u,p,n,r,o,a,i,s,l)}
8&f?(16&d&&z(u,o,a),p!==u&&c(n,p)):16&d?16&f?N(u,p,n,r,o,a,i,s,l):z(u,o,a,!0):(8&d&&c(n,""),
16&f&&k(p,n,r,o,a,i,s,l))},M=(e,t,n,r,o,a,i,s,l)=>{t=t||Qp
;const c=(e=e||Qp).length,u=t.length,d=Math.min(c,u);let p;for(p=0;p<d;p++){
const r=t[p]=l?oy(t[p]):ry(t[p]);f(e[p],r,n,null,o,a,i,s,l)}
c>u?z(e,o,a,!0,!1,d):k(t,n,r,o,a,i,s,l,d)},N=(e,t,n,r,o,a,i,s,l)=>{let c=0
;const u=t.length;let d=e.length-1,p=u-1;for(;c<=d&&c<=p;){
const r=e[c],u=t[c]=l?oy(t[c]):ry(t[c]);if(!qb(r,u))break
;f(r,u,n,null,o,a,i,s,l),c++}for(;c<=d&&c<=p;){
const r=e[d],c=t[p]=l?oy(t[p]):ry(t[p]);if(!qb(r,c))break
;f(r,c,n,null,o,a,i,s,l),d--,p--}if(c>d){if(c<=p){const e=p+1,d=e<u?t[e].el:r
;for(;c<=p;)f(null,t[c]=l?oy(t[c]):ry(t[c]),n,d,o,a,i,s,l),c++}
}else if(c>p)for(;c<=d;)L(e[c],o,a,!0),c++;else{const h=c,m=c,g=new Map
;for(c=m;c<=p;c++){const e=t[c]=l?oy(t[c]):ry(t[c]);null!=e.key&&g.set(e.key,c)}
let v,b=0;const y=p-m+1;let O=!1,w=0;const x=new Array(y);for(c=0;c<y;c++)x[c]=0
;for(c=h;c<=d;c++){const r=e[c];if(b>=y){L(r,o,a,!0);continue}let u
;if(null!=r.key)u=g.get(r.key);else for(v=m;v<=p;v++)if(0===x[v-m]&&qb(r,t[v])){
u=v;break}
void 0===u?L(r,o,a,!0):(x[u-m]=c+1,u>=w?w=u:O=!0,f(r,t[u],n,null,o,a,i,s,l),b++)
}const k=O?function(e){const t=e.slice(),n=[0];let r,o,a,i,s;const l=e.length
;for(r=0;r<l;r++){const l=e[r];if(0!==l){if(o=n[n.length-1],e[o]<l){
t[r]=o,n.push(r);continue}for(a=0,i=n.length-1;a<i;)s=a+i>>1,e[n[s]]<l?a=s+1:i=s
;l<e[n[a]]&&(a>0&&(t[r]=n[a-1]),n[a]=r)}}a=n.length,i=n[a-1]
;for(;a-- >0;)n[a]=i,i=t[i];return n}(x):Qp;for(v=k.length-1,c=y-1;c>=0;c--){
const e=m+c,d=t[e],p=t[e+1],h=e+1<u?p.el||Db(p):r
;0===x[c]?f(null,d,n,h,o,a,i,s,l):O&&(v<0||c!==k[v]?R(d,n,h,2):v--)}}
},R=(e,t,o,a,i=null)=>{const{el:s,type:l,transition:c,children:u,shapeFlag:d}=e
;if(6&d)return void R(e.component.subTree,t,o,a)
;if(128&d)return void e.suspense.move(t,o,a);if(64&d)return void l.move(e,t,o,H)
;if(l===Mb){n(s,t,o);for(let e=0;e<u.length;e++)R(u[e],t,o,a)
;return void n(e.anchor,t,o)}if(l===Lb)return void b(e,t,o)
;if(2!==a&&1&d&&c)if(0===a)c.beforeEnter(s),
n(s,t,o),_b((()=>c.enter(s)),i);else{
const{leave:a,delayLeave:i,afterLeave:l}=c,u=()=>{
e.ctx.isUnmounted?r(s):n(s,t,o)},d=()=>{s._isLeaving&&s[Pg](!0),a(s,(()=>{
u(),l&&l()}))};i?i(s,u,d):d()}else n(s,t,o)},L=(e,t,n,r=!1,o=!1)=>{
const{type:a,props:i,ref:s,children:l,dynamicChildren:c,shapeFlag:u,patchFlag:d,dirs:p,cacheIndex:h}=e
;if(-2===d&&(o=!1),
null!=s&&(hf(),Xg(s,null,n,e,!0),ff()),null!=h&&(t.renderCache[h]=void 0),
256&u)return void t.ctx.deactivate(e);const f=1&u&&p,m=!Yg(e);let g
;if(m&&(g=i&&i.onVnodeBeforeUnmount)&&sy(g,t,e),6&u)U(e.component,n,r);else{
if(128&u)return void e.suspense.unmount(n,r)
;f&&lg(e,null,t,"beforeUnmount"),64&u?e.type.remove(e,t,n,H,r):c&&!c.hasOnce&&(a!==Mb||d>0&&64&d)?z(c,t,n,!1,!0):(a===Mb&&384&d||!o&&16&u)&&z(l,t,n),
r&&B(e)}(m&&(g=i&&i.onVnodeUnmounted)||f)&&_b((()=>{
g&&sy(g,t,e),f&&lg(e,null,t,"unmounted")}),n)},B=e=>{
const{type:t,el:n,anchor:o,transition:a}=e;if(t===Mb)return void j(n,o)
;if(t===Lb)return void y(e);const i=()=>{
r(n),a&&!a.persisted&&a.afterLeave&&a.afterLeave()}
;if(1&e.shapeFlag&&a&&!a.persisted){const{leave:t,delayLeave:r}=a,o=()=>t(n,i)
;r?r(e.el,i,o):o()}else i()},j=(e,t)=>{let n;for(;e!==t;)n=d(e),r(e),e=n;r(t)
},U=(e,t,n)=>{const{bum:r,scope:o,job:a,subTree:i,um:s,m:l,a:c}=e
;Pb(l),Pb(c),r&&xh(r),o.stop(),a&&(a.flags|=8,L(i,e,t,n)),s&&_b(s,t),_b((()=>{
e.isUnmounted=!0}),t)},z=(e,t,n,r=!1,o=!1,a=0)=>{
for(let i=a;i<e.length;i++)L(e[i],t,n,r,o)},F=e=>{
if(6&e.shapeFlag)return F(e.component.subTree)
;if(128&e.shapeFlag)return e.suspense.next()
;const t=d(e.anchor||e.el),n=t&&t[yg];return n?d(n):t};let Z=!1
;const Q=(e,t,n)=>{let r
;null==e?t._vnode&&(L(t._vnode,null,null,!0),r=t._vnode.component):f(t._vnode||null,e,t,null,null,null,n),
t._vnode=e,Z||(Z=!0,Jm(r),eg(),Z=!1)},H={p:f,um:L,m:R,r:B,mt:C,mc:k,pc:I,pbc:_,
n:F,o:e};let V;return{render:Q,hydrate:V,createApp:Gv(Q)}}(e)}
function Eb({type:e,props:t},n){
return"svg"===n&&"foreignObject"===e||"mathml"===n&&"annotation-xml"===e&&t&&t.encoding&&t.encoding.includes("html")?void 0:n
}function Ab({effect:e,job:t},n){
n?(e.flags|=32,t.flags|=4):(e.flags&=-33,t.flags&=-5)}function Cb(e,t,n=!1){
const r=e.children,o=t.children;if(Jp(r)&&Jp(o))for(let a=0;a<r.length;a++){
const t=r[a];let i=o[a]
;1&i.shapeFlag&&!i.dynamicChildren&&((i.patchFlag<=0||32===i.patchFlag)&&(i=o[a]=oy(o[a]),
i.el=t.el),
n||-2===i.patchFlag||Cb(t,i)),i.type===Nb&&(-1!==i.patchFlag?i.el=t.el:i.__elIndex=a+(e.type===Mb?1:0)),
i.type!==Rb||i.el||(i.el=t.el)}}function $b(e){const t=e.subTree.component
;if(t)return t.asyncDep&&!t.asyncResolved?t:$b(t)}function Pb(e){
if(e)for(let t=0;t<e.length;t++)e[t].flags|=8}function Db(e){
if(e.placeholder)return e.placeholder;const t=e.component
;return t?Db(t.subTree):null}const Ib=e=>e.__isSuspense
;const Mb=Symbol.for("v-fgt"),Nb=Symbol.for("v-txt"),Rb=Symbol.for("v-cmt"),Lb=Symbol.for("v-stc"),Bb=[]
;let jb=null;function Ub(e=!1){Bb.push(jb=e?null:[])}let zb=1
;function Fb(e,t=!1){zb+=e,e<0&&jb&&t&&(jb.hasOnce=!0)}function Zb(e){
return e.dynamicChildren=zb>0?jb||Qp:null,
Bb.pop(),jb=Bb[Bb.length-1]||null,zb>0&&jb&&jb.push(e),e}
function Qb(e,t,n,r,o,a){return Zb(Gb(e,t,n,r,o,a,!0))}function Hb(e,t,n,r,o){
return Zb(Yb(e,t,n,r,o,!0))}function Vb(e){return!!e&&!0===e.__v_isVNode}
function qb(e,t){return e.type===t.type&&e.key===t.key}
const Wb=({key:e})=>null!=e?e:null,Xb=({ref:e,ref_key:t,ref_for:n})=>("number"==typeof e&&(e=""+e),
null!=e?oh(e)||vm(e)||rh(e)?{i:rg,r:e,k:t,f:!!n}:e:null)
;function Gb(e,t=null,n=null,r=0,o=null,a=(e===Mb?0:1),i=!1,s=!1){const l={
__v_isVNode:!0,__v_skip:!0,type:e,props:t,key:t&&Wb(t),ref:t&&Xb(t),scopeId:og,
slotScopeIds:null,children:n,component:null,suspense:null,ssContent:null,
ssFallback:null,dirs:null,transition:null,el:null,anchor:null,target:null,
targetStart:null,targetAnchor:null,staticCount:0,shapeFlag:a,patchFlag:r,
dynamicProps:o,dynamicChildren:null,appContext:null,ctx:rg}
;return s?(ay(l,n),128&a&&e.normalize(l)):n&&(l.shapeFlag|=oh(n)?8:16),
zb>0&&!i&&jb&&(l.patchFlag>0||6&a)&&32!==l.patchFlag&&jb.push(l),l}
const Yb=function(e,t=null,n=null,r=0,o=null,a=!1){e&&e!==vv||(e=Rb);if(Vb(e)){
const r=Jb(e,t,!0)
;return n&&ay(r,n),zb>0&&!a&&jb&&(6&r.shapeFlag?jb[jb.indexOf(e)]=r:jb.push(r)),
r.patchFlag=-2,r}i=e,rh(i)&&"__vccOpts"in i&&(e=e.__vccOpts);var i;if(t){t=Kb(t)
;let{class:e,style:n}=t
;e&&!oh(e)&&(t.class=Ih(e)),ih(n)&&(pm(n)&&!Jp(n)&&(n=Xp({},n)),t.style=Ah(n))}
const s=oh(e)?1:Ib(e)?128:Og(e)?64:ih(e)?4:rh(e)?2:0;return Gb(e,t,n,r,o,s,a,!0)
};function Kb(e){return e?pm(e)||ub(e)?Xp({},e):e:null}
function Jb(e,t,n=!1,r=!1){
const{props:o,ref:a,patchFlag:i,children:s,transition:l}=e,c=t?iy(o||{},t):o,u={
__v_isVNode:!0,__v_skip:!0,type:e.type,props:c,key:c&&Wb(c),
ref:t&&t.ref?n&&a?Jp(a)?a.concat(Xb(t)):[a,Xb(t)]:Xb(t):a,scopeId:e.scopeId,
slotScopeIds:e.slotScopeIds,children:s,target:e.target,
targetStart:e.targetStart,targetAnchor:e.targetAnchor,staticCount:e.staticCount,
shapeFlag:e.shapeFlag,patchFlag:t&&e.type!==Mb?-1===i?16:16|i:i,
dynamicProps:e.dynamicProps,dynamicChildren:e.dynamicChildren,
appContext:e.appContext,dirs:e.dirs,transition:l,component:e.component,
suspense:e.suspense,ssContent:e.ssContent&&Jb(e.ssContent),
ssFallback:e.ssFallback&&Jb(e.ssFallback),placeholder:e.placeholder,el:e.el,
anchor:e.anchor,ctx:e.ctx,ce:e.ce};return l&&r&&Fg(u,l.clone(u)),u}
function ey(e=" ",t=0){return Yb(Nb,null,e,t)}function ty(e,t){
const n=Yb(Lb,null,e);return n.staticCount=t,n}function ny(e="",t=!1){
return t?(Ub(),Hb(Rb,null,e)):Yb(Rb,null,e)}function ry(e){
return null==e||"boolean"==typeof e?Yb(Rb):Jp(e)?Yb(Mb,null,e.slice()):Vb(e)?oy(e):Yb(Nb,null,String(e))
}function oy(e){return null===e.el&&-1!==e.patchFlag||e.memo?e:Jb(e)}
function ay(e,t){let n=0;const{shapeFlag:r}=e
;if(null==t)t=null;else if(Jp(t))n=16;else if("object"==typeof t){if(65&r){
const n=t.default;return void(n&&(n._c&&(n._d=!1),ay(e,n()),n._c&&(n._d=!0)))}{
n=32;const r=t._
;r||ub(t)?3===r&&rg&&(1===rg.slots._?t._=1:(t._=2,e.patchFlag|=1024)):t._ctx=rg}
}else rh(t)?(t={default:t,_ctx:rg},n=32):(t=String(t),64&r?(n=16,t=[ey(t)]):n=8)
;e.children=t,e.shapeFlag|=n}function iy(...e){const t={}
;for(let n=0;n<e.length;n++){const r=e[n]
;for(const e in r)if("class"===e)t.class!==r.class&&(t.class=Ih([t.class,r.class]));else if("style"===e)t.style=Ah([t.style,r.style]);else if(qp(e)){
const n=t[e],o=r[e];!o||n===o||Jp(n)&&n.includes(o)||(t[e]=n?[].concat(n,o):o)
}else""!==e&&(t[e]=r[e])}return t}function sy(e,t,n,r=null){Um(e,t,7,[n,r])}
const ly=Wv();let cy=0;let uy=null;const dy=()=>uy||rg;let py,hy;{
const e=Eh(),t=(t,n)=>{let r;return(r=e[t])||(r=e[t]=[]),r.push(n),e=>{
r.length>1?r.forEach((t=>t(e))):r[0](e)}}
;py=t("__VUE_INSTANCE_SETTERS__",(e=>uy=e)),
hy=t("__VUE_SSR_SETTERS__",(e=>vy=e))}const fy=e=>{const t=uy
;return py(e),e.scope.on(),()=>{e.scope.off(),py(t)}},my=()=>{
uy&&uy.scope.off(),py(null)};function gy(e){return 4&e.vnode.shapeFlag}let vy=!1
;function by(e,t,n){
rh(t)?e.type.__ssrInlineRender?e.ssrRender=t:e.render=t:ih(t)&&(e.setupState=_m(t)),
yy(e)}function yy(e,t,n){const r=e.type;e.render||(e.render=r.render||Hp);{
const t=fy(e);hf();try{Lv(e)}finally{ff(),t()}}}const Oy={
get:(e,t)=>(Sf(e,0,""),e[t])};function wy(e){const t=t=>{e.exposed=t||{}}
;return{attrs:new Proxy(e.attrs,Oy),slots:e.slots,emit:e.emit,expose:t}}
function xy(e){
return e.exposed?e.exposeProxy||(e.exposeProxy=new Proxy(_m(fm(e.exposed)),{
get:(t,n)=>n in t?t[n]:n in Ev?Ev[n](e):void 0,has:(e,t)=>t in e||t in Ev
})):e.proxy}function ky(e,t=!0){
return rh(e)?e.displayName||e.name:e.name||t&&e.__name}const Sy=(e,t)=>{
const n=function(e,t,n=!1){let r,o
;return rh(e)?r=e:(r=e.get,o=e.set),new Im(r,o,n)}(e,0,vy);return n}
;function _y(e,t,n){try{Fb(-1);const r=arguments.length
;return 2===r?ih(t)&&!Jp(t)?Vb(t)?Yb(e,null,[t]):Yb(e,t):Yb(e,null,t):(r>3?n=Array.prototype.slice.call(arguments,2):3===r&&Vb(n)&&(n=[n]),
Yb(e,t,n))}finally{Fb(1)}}const Ty="3.5.26";let Ey
;const Ay="undefined"!=typeof window&&window.trustedTypes;if(Ay)try{
Ey=Ay.createPolicy("vue",{createHTML:e=>e})}catch(Bw){}
const Cy=Ey?e=>Ey.createHTML(e):e=>e,$y="undefined"!=typeof document?document:null,Py=$y&&$y.createElement("template"),Dy={
insert:(e,t,n)=>{t.insertBefore(e,n||null)},remove:e=>{const t=e.parentNode
;t&&t.removeChild(e)},createElement:(e,t,n,r)=>{
const o="svg"===t?$y.createElementNS("http://www.w3.org/2000/svg",e):"mathml"===t?$y.createElementNS("http://www.w3.org/1998/Math/MathML",e):n?$y.createElement(e,{
is:n}):$y.createElement(e)
;return"select"===e&&r&&null!=r.multiple&&o.setAttribute("multiple",r.multiple),
o},createText:e=>$y.createTextNode(e),createComment:e=>$y.createComment(e),
setText:(e,t)=>{e.nodeValue=t},setElementText:(e,t)=>{e.textContent=t},
parentNode:e=>e.parentNode,nextSibling:e=>e.nextSibling,
querySelector:e=>$y.querySelector(e),setScopeId(e,t){e.setAttribute(t,"")},
insertStaticContent(e,t,n,r,o,a){const i=n?n.previousSibling:t.lastChild
;if(o&&(o===a||o.nextSibling))for(;t.insertBefore(o.cloneNode(!0),n),
o!==a&&(o=o.nextSibling););else{
Py.innerHTML=Cy("svg"===r?`<svg>${e}</svg>`:"mathml"===r?`<math>${e}</math>`:e)
;const o=Py.content;if("svg"===r||"mathml"===r){const e=o.firstChild
;for(;e.firstChild;)o.appendChild(e.firstChild);o.removeChild(e)}
t.insertBefore(o,n)}
return[i?i.nextSibling:t.firstChild,n?n.previousSibling:t.lastChild]}
},Iy="transition",My="animation",Ny=Symbol("_vtc"),Ry={name:String,type:String,
css:{type:Boolean,default:!0},duration:[String,Number,Object],
enterFromClass:String,enterActiveClass:String,enterToClass:String,
appearFromClass:String,appearActiveClass:String,appearToClass:String,
leaveFromClass:String,leaveActiveClass:String,leaveToClass:String
},Ly=Xp({},Mg,Ry),By=e=>(e.displayName="Transition",
e.props=Ly,e),jy=By(((e,{slots:t})=>_y(Lg,function(e){const t={}
;for(const A in e)A in Ry||(t[A]=e[A]);if(!1===e.css)return t
;const{name:n="v",type:r,duration:o,enterFromClass:a=`${n}-enter-from`,enterActiveClass:i=`${n}-enter-active`,enterToClass:s=`${n}-enter-to`,appearFromClass:l=a,appearActiveClass:c=i,appearToClass:u=s,leaveFromClass:d=`${n}-leave-from`,leaveActiveClass:p=`${n}-leave-active`,leaveToClass:h=`${n}-leave-to`}=e,f=function(e){
if(null==e)return null;if(ih(e))return[Fy(e.enter),Fy(e.leave)];{const t=Fy(e)
;return[t,t]}
}(o),m=f&&f[0],g=f&&f[1],{onBeforeEnter:v,onEnter:b,onEnterCancelled:y,onLeave:O,onLeaveCancelled:w,onBeforeAppear:x=v,onAppear:k=b,onAppearCancelled:S=y}=t,_=(e,t,n,r)=>{
e._enterCancelled=r,Qy(e,t?u:s),Qy(e,t?c:i),n&&n()},T=(e,t)=>{
e._isLeaving=!1,Qy(e,d),Qy(e,h),Qy(e,p),t&&t()},E=e=>(t,n)=>{
const o=e?k:b,i=()=>_(t,e,n);Uy(o,[t,i]),Hy((()=>{
Qy(t,e?l:a),Zy(t,e?u:s),zy(o)||qy(t,r,m,i)}))};return Xp(t,{onBeforeEnter(e){
Uy(v,[e]),Zy(e,a),Zy(e,i)},onBeforeAppear(e){Uy(x,[e]),Zy(e,l),Zy(e,c)},
onEnter:E(!1),onAppear:E(!0),onLeave(e,t){e._isLeaving=!0;const n=()=>T(e,t)
;Zy(e,d),e._enterCancelled?(Zy(e,p),Gy(e)):(Gy(e),Zy(e,p)),Hy((()=>{
e._isLeaving&&(Qy(e,d),Zy(e,h),zy(O)||qy(e,r,g,n))})),Uy(O,[e,n])},
onEnterCancelled(e){_(e,!1,void 0,!0),Uy(y,[e])},onAppearCancelled(e){
_(e,!0,void 0,!0),Uy(S,[e])},onLeaveCancelled(e){T(e),Uy(w,[e])}})
}(e),t))),Uy=(e,t=[])=>{Jp(e)?e.forEach((e=>e(...t))):e&&e(...t)
},zy=e=>!!e&&(Jp(e)?e.some((e=>e.length>1)):e.length>1);function Fy(e){
return _h(e)}function Zy(e,t){
t.split(/\s+/).forEach((t=>t&&e.classList.add(t))),
(e[Ny]||(e[Ny]=new Set)).add(t)}function Qy(e,t){
t.split(/\s+/).forEach((t=>t&&e.classList.remove(t)));const n=e[Ny]
;n&&(n.delete(t),n.size||(e[Ny]=void 0))}function Hy(e){
requestAnimationFrame((()=>{requestAnimationFrame(e)}))}let Vy=0
;function qy(e,t,n,r){const o=e._endId=++Vy,a=()=>{o===e._endId&&r()}
;if(null!=n)return setTimeout(a,n)
;const{type:i,timeout:s,propCount:l}=function(e,t){
const n=window.getComputedStyle(e),r=e=>(n[e]||"").split(", "),o=r(`${Iy}Delay`),a=r(`${Iy}Duration`),i=Wy(o,a),s=r(`${My}Delay`),l=r(`${My}Duration`),c=Wy(s,l)
;let u=null,d=0,p=0
;t===Iy?i>0&&(u=Iy,d=i,p=a.length):t===My?c>0&&(u=My,d=c,p=l.length):(d=Math.max(i,c),
u=d>0?i>c?Iy:My:null,p=u?u===Iy?a.length:l.length:0)
;const h=u===Iy&&/\b(?:transform|all)(?:,|$)/.test(r(`${Iy}Property`).toString())
;return{type:u,timeout:d,propCount:p,hasTransform:h}}(e,t);if(!i)return r()
;const c=i+"end";let u=0;const d=()=>{e.removeEventListener(c,p),a()},p=t=>{
t.target===e&&++u>=l&&d()};setTimeout((()=>{u<l&&d()
}),s+1),e.addEventListener(c,p)}function Wy(e,t){
for(;e.length<t.length;)e=e.concat(e)
;return Math.max(...t.map(((t,n)=>Xy(t)+Xy(e[n]))))}function Xy(e){
return"auto"===e?0:1e3*Number(e.slice(0,-1).replace(",","."))}function Gy(e){
return(e?e.ownerDocument:document).body.offsetHeight}
const Yy=Symbol("_vod"),Ky=Symbol("_vsh"),Jy={name:"show",
beforeMount(e,{value:t},{transition:n}){
e[Yy]="none"===e.style.display?"":e.style.display,n&&t?n.beforeEnter(e):eO(e,t)
},mounted(e,{value:t},{transition:n}){n&&t&&n.enter(e)},
updated(e,{value:t,oldValue:n},{transition:r}){
!t!=!n&&(r?t?(r.beforeEnter(e),eO(e,!0),r.enter(e)):r.leave(e,(()=>{eO(e,!1)
})):eO(e,t))},beforeUnmount(e,{value:t}){eO(e,t)}};function eO(e,t){
e.style.display=t?e[Yy]:"none",e[Ky]=!t}const tO=Symbol("");function nO(e){
const t=dy();if(!t)return;const n=t.ut=(n=e(t.proxy))=>{
Array.from(document.querySelectorAll(`[data-v-owner="${t.uid}"]`)).forEach((e=>oO(e,n)))
},r=()=>{const r=e(t.proxy);t.ce?oO(t.ce,r):rO(t.subTree,r),n(r)};sv((()=>{Km(r)
})),iv((()=>{mg(r,Hp,{flush:"post"});const e=new MutationObserver(r)
;e.observe(t.subTree.el.parentNode,{childList:!0}),uv((()=>e.disconnect()))}))}
function rO(e,t){if(128&e.shapeFlag){const n=e.suspense
;e=n.activeBranch,n.pendingBranch&&!n.isHydrating&&n.effects.push((()=>{
rO(n.activeBranch,t)}))}for(;e.component;)e=e.component.subTree
;if(1&e.shapeFlag&&e.el)oO(e.el,t);else if(e.type===Mb)e.children.forEach((e=>rO(e,t)));else if(e.type===Lb){
let{el:n,anchor:r}=e;for(;n&&(oO(n,t),n!==r);)n=n.nextSibling}}function oO(e,t){
if(1===e.nodeType){const n=e.style;let r="";for(const e in t){const o=Zh(t[e])
;n.setProperty(`--${e}`,o),r+=`--${e}: ${o};`}n[tO]=r}}
const aO=/(?:^|;)\s*display\s*:/;const iO=/\s*!important$/;function sO(e,t,n){
if(Jp(n))n.forEach((n=>sO(e,t,n)));else if(null==n&&(n=""),
t.startsWith("--"))e.setProperty(t,n);else{const r=function(e,t){const n=cO[t]
;if(n)return n;let r=gh(t);if("filter"!==r&&r in e)return cO[t]=r;r=yh(r)
;for(let o=0;o<lO.length;o++){const n=lO[o]+r;if(n in e)return cO[t]=n}return t
}(e,t);iO.test(n)?e.setProperty(bh(r),n.replace(iO,""),"important"):e[r]=n}}
const lO=["Webkit","Moz","ms"],cO={};const uO="http://www.w3.org/1999/xlink"
;function dO(e,t,n,r,o,a=Nh(t)){
r&&t.startsWith("xlink:")?null==n?e.removeAttributeNS(uO,t.slice(6,t.length)):e.setAttributeNS(uO,t,n):null==n||a&&!Rh(n)?e.removeAttribute(t):e.setAttribute(t,a?"":ah(n)?String(n):n)
}function pO(e,t,n,r,o){
if("innerHTML"===t||"textContent"===t)return void(null!=n&&(e[t]="innerHTML"===t?Cy(n):n))
;const a=e.tagName;if("value"===t&&"PROGRESS"!==a&&!a.includes("-")){
const r="OPTION"===a?e.getAttribute("value")||"":e.value,o=null==n?"checkbox"===e.type?"on":"":String(n)
;return r===o&&"_value"in e||(e.value=o),
null==n&&e.removeAttribute(t),void(e._value=n)}let i=!1;if(""===n||null==n){
const r=typeof e[t]
;"boolean"===r?n=Rh(n):null==n&&"string"===r?(n="",i=!0):"number"===r&&(n=0,
i=!0)}try{e[t]=n}catch(Bw){}i&&e.removeAttribute(o||t)}function hO(e,t,n,r){
e.addEventListener(t,n,r)}const fO=Symbol("_vei");function mO(e,t,n,r,o=null){
const a=e[fO]||(e[fO]={}),i=a[t];if(r&&i)i.value=r;else{const[n,s]=function(e){
let t;if(gO.test(e)){let n
;for(t={};n=e.match(gO);)e=e.slice(0,e.length-n[0].length),
t[n[0].toLowerCase()]=!0}const n=":"===e[2]?e.slice(3):bh(e.slice(2))
;return[n,t]}(t);if(r){const i=a[t]=function(e,t){const n=e=>{if(e._vts){
if(e._vts<=n.attached)return}else e._vts=Date.now();Um(function(e,t){if(Jp(t)){
const n=e.stopImmediatePropagation;return e.stopImmediatePropagation=()=>{
n.call(e),e._stopped=!0},t.map((e=>t=>!t._stopped&&e&&e(t)))}return t
}(e,n.value),t,5,[e])};return n.value=e,n.attached=yO(),n}(r,o);hO(e,n,i,s)
}else i&&(!function(e,t,n,r){e.removeEventListener(t,n,r)}(e,n,i,s),a[t]=void 0)
}}const gO=/(?:Once|Passive|Capture)$/;let vO=0
;const bO=Promise.resolve(),yO=()=>vO||(bO.then((()=>vO=0)),vO=Date.now())
;const OO=e=>111===e.charCodeAt(0)&&110===e.charCodeAt(1)&&e.charCodeAt(2)>96&&e.charCodeAt(2)<123
;const wO=e=>{const t=e.props["onUpdate:modelValue"]||!1
;return Jp(t)?e=>xh(t,e):t};function xO(e){e.target.composing=!0}function kO(e){
const t=e.target
;t.composing&&(t.composing=!1,t.dispatchEvent(new Event("input")))}
const SO=Symbol("_assign");function _O(e,t,n){
return t&&(e=e.trim()),n&&(e=Sh(e)),e}const TO={
created(e,{modifiers:{lazy:t,trim:n,number:r}},o){e[SO]=wO(o)
;const a=r||o.props&&"number"===o.props.type;hO(e,t?"change":"input",(t=>{
t.target.composing||e[SO](_O(e.value,n,a))})),(n||a)&&hO(e,"change",(()=>{
e.value=_O(e.value,n,a)
})),t||(hO(e,"compositionstart",xO),hO(e,"compositionend",kO),hO(e,"change",kO))
},mounted(e,{value:t}){e.value=null==t?"":t},
beforeUpdate(e,{value:t,oldValue:n,modifiers:{lazy:r,trim:o,number:a}},i){
if(e[SO]=wO(i),e.composing)return;const s=null==t?"":t
;if((!a&&"number"!==e.type||/^0\d/.test(e.value)?e.value:Sh(e.value))!==s){
if(document.activeElement===e&&"range"!==e.type){if(r&&t===n)return
;if(o&&e.value.trim()===s)return}e.value=s}}},EO={deep:!0,created(e,t,n){
e[SO]=wO(n),hO(e,"change",(()=>{
const t=e._modelValue,n=DO(e),r=e.checked,o=e[SO];if(Jp(t)){
const e=Bh(t,n),a=-1!==e;if(r&&!a)o(t.concat(n));else if(!r&&a){const n=[...t]
;n.splice(e,1),o(n)}}else if(th(t)){const e=new Set(t)
;r?e.add(n):e.delete(n),o(e)}else o(IO(e,r))}))},mounted:AO,beforeUpdate(e,t,n){
e[SO]=wO(n),AO(e,t,n)}};function AO(e,{value:t,oldValue:n},r){let o
;if(e._modelValue=t,
Jp(t))o=Bh(t,r.props.value)>-1;else if(th(t))o=t.has(r.props.value);else{
if(t===n)return;o=Lh(t,IO(e,!0))}e.checked!==o&&(e.checked=o)}const CO={
created(e,{value:t},n){
e.checked=Lh(t,n.props.value),e[SO]=wO(n),hO(e,"change",(()=>{e[SO](DO(e))}))},
beforeUpdate(e,{value:t,oldValue:n},r){
e[SO]=wO(r),t!==n&&(e.checked=Lh(t,r.props.value))}},$O={deep:!0,
created(e,{value:t,modifiers:{number:n}},r){const o=th(t);hO(e,"change",(()=>{
const t=Array.prototype.filter.call(e.options,(e=>e.selected)).map((e=>n?Sh(DO(e)):DO(e)))
;e[SO](e.multiple?o?new Set(t):t:t[0]),e._assigning=!0,Xm((()=>{e._assigning=!1
}))})),e[SO]=wO(r)},mounted(e,{value:t}){PO(e,t)},beforeUpdate(e,t,n){
e[SO]=wO(n)},updated(e,{value:t}){e._assigning||PO(e,t)}};function PO(e,t){
const n=e.multiple,r=Jp(t);if(!n||r||th(t)){
for(let o=0,a=e.options.length;o<a;o++){const a=e.options[o],i=DO(a);if(n)if(r){
const e=typeof i
;a.selected="string"===e||"number"===e?t.some((e=>String(e)===String(i))):Bh(t,i)>-1
}else a.selected=t.has(i);else if(Lh(DO(a),t))return void(e.selectedIndex!==o&&(e.selectedIndex=o))
}n||-1===e.selectedIndex||(e.selectedIndex=-1)}}function DO(e){
return"_value"in e?e._value:e.value}function IO(e,t){
const n=t?"_trueValue":"_falseValue";return n in e?e[n]:t}const MO={
created(e,t,n){NO(e,t,n,null,"created")},mounted(e,t,n){NO(e,t,n,null,"mounted")
},beforeUpdate(e,t,n,r){NO(e,t,n,r,"beforeUpdate")},updated(e,t,n,r){
NO(e,t,n,r,"updated")}};function NO(e,t,n,r,o){const a=function(e,t){switch(e){
case"SELECT":return $O;case"TEXTAREA":return TO;default:switch(t){
case"checkbox":return EO;case"radio":return CO;default:return TO}}
}(e.tagName,n.props&&n.props.type)[o];a&&a(e,t,n,r)}
const RO=["ctrl","shift","alt","meta"],LO={stop:e=>e.stopPropagation(),
prevent:e=>e.preventDefault(),self:e=>e.target!==e.currentTarget,
ctrl:e=>!e.ctrlKey,shift:e=>!e.shiftKey,alt:e=>!e.altKey,meta:e=>!e.metaKey,
left:e=>"button"in e&&0!==e.button,middle:e=>"button"in e&&1!==e.button,
right:e=>"button"in e&&2!==e.button,
exact:(e,t)=>RO.some((n=>e[`${n}Key`]&&!t.includes(n)))},BO=(e,t)=>{
const n=e._withMods||(e._withMods={}),r=t.join(".")
;return n[r]||(n[r]=(n,...r)=>{for(let e=0;e<t.length;e++){const r=LO[t[e]]
;if(r&&r(n,t))return}return e(n,...r)})},jO={esc:"escape",space:" ",
up:"arrow-up",left:"arrow-left",right:"arrow-right",down:"arrow-down",
delete:"backspace"},UO=(e,t)=>{
const n=e._withKeys||(e._withKeys={}),r=t.join(".");return n[r]||(n[r]=n=>{
if(!("key"in n))return;const r=bh(n.key)
;return t.some((e=>e===r||jO[e]===r))?e(n):void 0})},zO=Xp({
patchProp:(e,t,n,r,o,a)=>{const i="svg"===o;"class"===t?function(e,t,n){
const r=e[Ny]
;r&&(t=(t?[t,...r]:[...r]).join(" ")),null==t?e.removeAttribute("class"):n?e.setAttribute("class",t):e.className=t
}(e,r,i):"style"===t?function(e,t,n){const r=e.style,o=oh(n);let a=!1;if(n&&!o){
if(t)if(oh(t))for(const e of t.split(";")){
const t=e.slice(0,e.indexOf(":")).trim();null==n[t]&&sO(r,t,"")
}else for(const e in t)null==n[e]&&sO(r,e,"")
;for(const e in n)"display"===e&&(a=!0),sO(r,e,n[e])}else if(o){if(t!==n){
const e=r[tO];e&&(n+=";"+e),r.cssText=n,a=aO.test(n)}
}else t&&e.removeAttribute("style")
;Yy in e&&(e[Yy]=a?r.display:"",e[Ky]&&(r.display="none"))
}(e,n,r):qp(t)?Wp(t)||mO(e,t,0,r,a):("."===t[0]?(t=t.slice(1),
1):"^"===t[0]?(t=t.slice(1),0):function(e,t,n,r){
if(r)return"innerHTML"===t||"textContent"===t||!!(t in e&&OO(t)&&rh(n))
;if("spellcheck"===t||"draggable"===t||"translate"===t||"autocorrect"===t)return!1
;if("sandbox"===t&&"IFRAME"===e.tagName)return!1;if("form"===t)return!1
;if("list"===t&&"INPUT"===e.tagName)return!1
;if("type"===t&&"TEXTAREA"===e.tagName)return!1;if("width"===t||"height"===t){
const t=e.tagName;if("IMG"===t||"VIDEO"===t||"CANVAS"===t||"SOURCE"===t)return!1
}if(OO(t)&&oh(n))return!1;return t in e
}(e,t,r,i))?(pO(e,t,r),e.tagName.includes("-")||"value"!==t&&"checked"!==t&&"selected"!==t||dO(e,t,r,i,0,"value"!==t)):!e._isVueCE||!/[A-Z]/.test(t)&&oh(r)?("true-value"===t?e._trueValue=r:"false-value"===t&&(e._falseValue=r),
dO(e,t,r,i)):pO(e,gh(t),r,0,t)}},Dy);let FO;function ZO(){return FO||(FO=Tb(zO))
}const QO=(...e)=>{ZO().render(...e)},HO=(...e)=>{
const t=ZO().createApp(...e),{mount:n}=t;return t.mount=e=>{const r=function(e){
if(oh(e)){return document.querySelector(e)}return e}(e);if(!r)return
;const o=t._component
;rh(o)||o.render||o.template||(o.template=r.innerHTML),1===r.nodeType&&(r.textContent="")
;const a=n(r,!1,function(e){if(e instanceof SVGElement)return"svg"
;if("function"==typeof MathMLElement&&e instanceof MathMLElement)return"mathml"
}(r))
;return r instanceof Element&&(r.removeAttribute("v-cloak"),r.setAttribute("data-v-app","")),
a},t};const VO="3"===Ty[0];function qO(e){
if(e instanceof Promise||e instanceof Date||e instanceof RegExp)return e
;const t="function"==typeof(n=e)?n():xm(n);var n;if(!e||!t)return t
;if(Array.isArray(t))return t.map((e=>qO(e)));if("object"==typeof t){const e={}
;for(const n in t)Object.prototype.hasOwnProperty.call(t,n)&&("titleTemplate"===n||"o"===n[0]&&"n"===n[1]?e[n]=xm(t[n]):e[n]=qO(t[n]))
;return e}return t}const WO={hooks:{"entries:resolve":e=>{
for(const t of e.entries)t.resolvedInput=qO(t.input)}}},XO="usehead"
;function GO(e={}){
e.domDelayFn=e.domDelayFn||(e=>Xm((()=>setTimeout((()=>e()),0))));const t=Up(e)
;return t.use(WO),t.install=function(e){return{install(t){
VO&&(t.config.globalProperties.$unhead=e,
t.config.globalProperties.$head=e,t.provide(XO,e))}}.install}(t),t}
const YO="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof self?self:{},KO="__unhead_injection_handler__"
;function JO(){if(KO in YO)return YO[KO]();return ug(XO)||jp}
function ew(e,t={}){const n=t.head||JO()
;if(n)return n.ssr?n.push(e,t):function(e,t,n={}){const r=bm(!1),o=bm({})
;fg((()=>{o.value=r.value?{}:qO(t)}));const a=e.push(o.value,n);mg(o,(e=>{
a.patch(e)}));dy()&&(cv((()=>{a.dispose()})),ev((()=>{r.value=!0})),Jg((()=>{
r.value=!1})));return a}(n,e,t)}function tw(e){
"function"==typeof queueMicrotask?queueMicrotask(e):Promise.resolve().then(e).catch((e=>setTimeout((()=>{
throw e}))))}function nw(){let e=[],t={
addEventListener:(e,n,r,o)=>(e.addEventListener(n,r,o),
t.add((()=>e.removeEventListener(n,r,o)))),requestAnimationFrame(...e){
let n=requestAnimationFrame(...e);t.add((()=>cancelAnimationFrame(n)))},
nextFrame(...e){t.requestAnimationFrame((()=>{t.requestAnimationFrame(...e)}))},
setTimeout(...e){let n=setTimeout(...e);t.add((()=>clearTimeout(n)))},
microTask(...e){let n={current:!0};return tw((()=>{n.current&&e[0]()
})),t.add((()=>{n.current=!1}))},style(e,t,n){let r=e.style.getPropertyValue(t)
;return Object.assign(e.style,{[t]:n}),this.add((()=>{Object.assign(e.style,{
[t]:r})}))},group(e){let t=nw();return e(t),this.add((()=>t.dispose()))},
add:t=>(e.push(t),()=>{let n=e.indexOf(t);if(n>=0)for(let t of e.splice(n,1))t()
}),dispose(){for(let t of e.splice(0))t()}};return t}var rw
;let ow=Symbol("headlessui.useid"),aw=0;const iw=null!=(rw=Hg)?rw:function(){
return ug(ow,(()=>""+ ++aw))()};function sw(e){var t
;if(null==e||null==e.value)return null;let n=null!=(t=e.value.$el)?t:e.value
;return n instanceof Node?n:null}function lw(e,t,...n){if(e in t){let r=t[e]
;return"function"==typeof r?r(...n):r}
let r=new Error(`Tried to handle "${e}" but there is no handler defined. Only defined handlers are: ${Object.keys(t).map((e=>`"${e}"`)).join(", ")}.`)
;throw Error.captureStackTrace&&Error.captureStackTrace(r,lw),r}
var cw=Object.defineProperty,uw=(e,t,n)=>(((e,t,n)=>{t in e?cw(e,t,{
enumerable:!0,configurable:!0,writable:!0,value:n}):e[t]=n
})(e,"symbol"!=typeof t?t+"":t,n),n);let dw=new class{constructor(){
uw(this,"current",this.detect()),uw(this,"currentId",0)}set(e){
this.current!==e&&(this.currentId=0,this.current=e)}reset(){
this.set(this.detect())}nextId(){return++this.currentId}get isServer(){
return"server"===this.current}get isClient(){return"client"===this.current}
detect(){
return"undefined"==typeof window||"undefined"==typeof document?"server":"client"
}};function pw(e){if(dw.isServer)return null
;if(e instanceof Node)return e.ownerDocument
;if(null!=e&&e.hasOwnProperty("value")){let t=sw(e);if(t)return t.ownerDocument}
return document}
let hw=["[contentEditable=true]","[tabindex]","a[href]","area[href]","button:not([disabled])","iframe","input:not([disabled])","select:not([disabled])","textarea:not([disabled])"].map((e=>`${e}:not([tabindex='-1'])`)).join(",")
;var fw,mw,gw,vw=((gw=vw||{})[gw.First=1]="First",
gw[gw.Previous=2]="Previous",gw[gw.Next=4]="Next",
gw[gw.Last=8]="Last",gw[gw.WrapAround=16]="WrapAround",
gw[gw.NoScroll=32]="NoScroll",
gw),bw=((mw=bw||{})[mw.Error=0]="Error",mw[mw.Overflow=1]="Overflow",
mw[mw.Success=2]="Success",
mw[mw.Underflow=3]="Underflow",mw),yw=((fw=yw||{})[fw.Previous=-1]="Previous",
fw[fw.Next=1]="Next",fw);function Ow(e=document.body){
return null==e?[]:Array.from(e.querySelectorAll(hw)).sort(((e,t)=>Math.sign((e.tabIndex||Number.MAX_SAFE_INTEGER)-(t.tabIndex||Number.MAX_SAFE_INTEGER))))
}var ww=(e=>(e[e.Strict=0]="Strict",e[e.Loose=1]="Loose",e))(ww||{})
;function xw(e,t=0){var n;return e!==(null==(n=pw(e))?void 0:n.body)&&lw(t,{
0:()=>e.matches(hw),1(){let t=e;for(;null!==t;){if(t.matches(hw))return!0
;t=t.parentElement}return!1}})}function kw(e){let t=pw(e);Xm((()=>{
t&&!xw(t.activeElement,0)&&_w(e)}))}
var Sw=(e=>(e[e.Keyboard=0]="Keyboard",e[e.Mouse=1]="Mouse",e))(Sw||{})
;function _w(e){null==e||e.focus({preventScroll:!0})}
"undefined"!=typeof window&&"undefined"!=typeof document&&(document.addEventListener("keydown",(e=>{
e.metaKey||e.altKey||e.ctrlKey||(document.documentElement.dataset.headlessuiFocusVisible="")
}),!0),document.addEventListener("click",(e=>{
1===e.detail?delete document.documentElement.dataset.headlessuiFocusVisible:0===e.detail&&(document.documentElement.dataset.headlessuiFocusVisible="")
}),!0));let Tw=["textarea","input"].join(",");function Ew(e,t=e=>e){
return e.slice().sort(((e,n)=>{let r=t(e),o=t(n);if(null===r||null===o)return 0
;let a=r.compareDocumentPosition(o)
;return a&Node.DOCUMENT_POSITION_FOLLOWING?-1:a&Node.DOCUMENT_POSITION_PRECEDING?1:0
}))}function Aw(e,t,{sorted:n=!0,relativeTo:r=null,skipElements:o=[]}={}){var a
;let i=null!=(a=Array.isArray(e)?e.length>0?e[0].ownerDocument:document:null==e?void 0:e.ownerDocument)?a:document,s=Array.isArray(e)?n?Ew(e):e:Ow(e)
;o.length>0&&s.length>1&&(s=s.filter((e=>!o.includes(e)))),
r=null!=r?r:i.activeElement;let l,c=(()=>{if(5&t)return 1;if(10&t)return-1
;throw new Error("Missing Focus.First, Focus.Previous, Focus.Next or Focus.Last")
})(),u=(()=>{if(1&t)return 0;if(2&t)return Math.max(0,s.indexOf(r))-1
;if(4&t)return Math.max(0,s.indexOf(r))+1;if(8&t)return s.length-1
;throw new Error("Missing Focus.First, Focus.Previous, Focus.Next or Focus.Last")
})(),d=32&t?{preventScroll:!0}:{},p=0,h=s.length;do{if(p>=h||p+h<=0)return 0
;let e=u+p;if(16&t)e=(e+h)%h;else{if(e<0)return 3;if(e>=h)return 1}
l=s[e],null==l||l.focus(d),p+=c}while(l!==i.activeElement)
;return 6&t&&function(e){var t,n
;return null!=(n=null==(t=null==e?void 0:e.matches)?void 0:t.call(e,Tw))&&n
}(l)&&l.select(),2}function Cw(){
return/iPhone/gi.test(window.navigator.platform)||/Mac/gi.test(window.navigator.platform)&&window.navigator.maxTouchPoints>0
}function $w(){return Cw()||/Android/gi.test(window.navigator.userAgent)}
function Pw(e,t,n){dw.isServer||fg((r=>{
document.addEventListener(e,t,n),r((()=>document.removeEventListener(e,t,n)))}))
}function Dw(e,t,n){dw.isServer||fg((r=>{
window.addEventListener(e,t,n),r((()=>window.removeEventListener(e,t,n)))}))}
function Iw(e,t,n=Sy((()=>!0))){function r(r,o){
if(!n.value||r.defaultPrevented)return;let a=o(r)
;if(null===a||!a.getRootNode().contains(a))return;let i=function e(t){
return"function"==typeof t?e(t()):Array.isArray(t)||t instanceof Set?t:[t]}(e)
;for(let e of i){if(null===e)continue;let t=e instanceof HTMLElement?e:sw(e)
;if(null!=t&&t.contains(a)||r.composed&&r.composedPath().includes(t))return}
return!xw(a,ww.Loose)&&-1!==a.tabIndex&&r.preventDefault(),t(r,a)}let o=bm(null)
;Pw("pointerdown",(e=>{var t,r
;n.value&&(o.value=(null==(r=null==(t=e.composedPath)?void 0:t.call(e))?void 0:r[0])||e.target)
}),!0),Pw("mousedown",(e=>{var t,r
;n.value&&(o.value=(null==(r=null==(t=e.composedPath)?void 0:t.call(e))?void 0:r[0])||e.target)
}),!0),Pw("click",(e=>{$w()||o.value&&(r(e,(()=>o.value)),o.value=null)
}),!0),Pw("touchend",(e=>r(e,(()=>e.target instanceof HTMLElement?e.target:null))),!0),
Dw("blur",(e=>r(e,(()=>window.document.activeElement instanceof HTMLIFrameElement?window.document.activeElement:null))),!0)
}function Mw(e,t){if(e)return e;let n=null!=t?t:"button"
;return"string"==typeof n&&"button"===n.toLowerCase()?"button":void 0}
function Nw(e,t){let n=bm(Mw(e.value.type,e.value.as));return iv((()=>{
n.value=Mw(e.value.type,e.value.as)})),fg((()=>{var e
;n.value||sw(t)&&sw(t)instanceof HTMLButtonElement&&(null==(e=sw(t))||!e.hasAttribute("type"))&&(n.value="button")
})),n}function Rw(e){return[e.screenX,e.screenY]}function Lw(){let e=bm([-1,-1])
;return{wasMoved(t){let n=Rw(t)
;return(e.value[0]!==n[0]||e.value[1]!==n[1])&&(e.value=n,!0)},update(t){
e.value=Rw(t)}}}
var Bw,jw=(e=>(e[e.None=0]="None",e[e.RenderStrategy=1]="RenderStrategy",
e[e.Static=2]="Static",
e))(jw||{}),Uw=((Bw=Uw||{})[Bw.Unmount=0]="Unmount",Bw[Bw.Hidden=1]="Hidden",Bw)
;function zw({visible:e=!0,features:t=0,ourProps:n,theirProps:r,...o}){var a
;let i=Qw(r,n),s=Object.assign(o,{props:i});if(e||2&t&&i.static)return Fw(s)
;if(1&t){return lw(null==(a=i.unmount)||a?0:1,{0:()=>null,1:()=>Fw({...o,props:{
...i,hidden:!0,style:{display:"none"}}})})}return Fw(s)}
function Fw({props:e,attrs:t,slots:n,slot:r,name:o}){var a,i
;let{as:s,...l}=Hw(e,["unmount","static"]),c=null==(a=n.default)?void 0:a.call(n,r),u={}
;if(r){let e=!1,t=[]
;for(let[n,o]of Object.entries(r))"boolean"==typeof o&&(e=!0),!0===o&&t.push(n)
;e&&(u["data-headlessui-state"]=t.join(" "))}if("template"===s){
if(c=Zw(null!=c?c:[]),Object.keys(l).length>0||Object.keys(t).length>0){
let[e,...n]=null!=c?c:[];if(!function(e){
return null!=e&&("string"==typeof e.type||"object"==typeof e.type||"function"==typeof e.type)
}(e)||n.length>0)throw new Error(['Passing props on "template"!',"",`The current component <${o} /> is rendering a "template".`,"However we need to passthrough the following props:",Object.keys(l).concat(Object.keys(t)).map((e=>e.trim())).filter(((e,t,n)=>n.indexOf(e)===t)).sort(((e,t)=>e.localeCompare(t))).map((e=>`  - ${e}`)).join("\n"),"","You can apply a few solutions:",['Add an `as="..."` prop, to ensure that we render an actual element instead of a "template".',"Render a single element as the child so that we can forward the props onto that element."].map((e=>`  - ${e}`)).join("\n")].join("\n"))
;let r=Qw(null!=(i=e.props)?i:{},l,u),a=Jb(e,r,!0)
;for(let t in r)t.startsWith("on")&&(a.props||(a.props={}),a.props[t]=r[t])
;return a}return Array.isArray(c)&&1===c.length?c[0]:c}
return _y(s,Object.assign({},l,u),{default:()=>c})}function Zw(e){
return e.flatMap((e=>e.type===Mb?Zw(e.children):[e]))}function Qw(...e){
if(0===e.length)return{};if(1===e.length)return e[0];let t={},n={}
;for(let r of e)for(let e in r)e.startsWith("on")&&"function"==typeof r[e]?(null!=n[e]||(n[e]=[]),
n[e].push(r[e])):t[e]=r[e]
;if(t.disabled||t["aria-disabled"])return Object.assign(t,Object.fromEntries(Object.keys(n).map((e=>[e,void 0]))))
;for(let r in n)Object.assign(t,{[r](e,...t){let o=n[r];for(let n of o){
if(e instanceof Event&&e.defaultPrevented)return;n(e,...t)}}});return t}
function Hw(e,t=[]){let n=Object.assign({},e);for(let r of t)r in n&&delete n[r]
;return n}
var Vw=(e=>(e[e.None=1]="None",e[e.Focusable=2]="Focusable",e[e.Hidden=4]="Hidden",
e))(Vw||{});let qw=Qg({name:"Hidden",props:{as:{type:[Object,String],
default:"div"},features:{type:Number,default:1}},
setup:(e,{slots:t,attrs:n})=>()=>{var r;let{features:o,...a}=e;return zw({
ourProps:{"aria-hidden":!(2&~o)||(null!=(r=a["aria-hidden"])?r:void 0),
hidden:!(4&~o)||void 0,style:{position:"fixed",top:1,left:1,width:1,height:0,
padding:0,margin:-1,overflow:"hidden",clip:"rect(0, 0, 0, 0)",
whiteSpace:"nowrap",borderWidth:"0",...!(4&~o)&&!!(2&~o)&&{display:"none"}}},
theirProps:a,slot:{},attrs:n,slots:t,name:"Hidden"})}}),Ww=Symbol("Context")
;var Xw=(e=>(e[e.Open=1]="Open",e[e.Closed=2]="Closed",e[e.Closing=4]="Closing",
e[e.Opening=8]="Opening",e))(Xw||{});function Gw(){return ug(Ww,null)}
function Yw(e){cg(Ww,e)}
var Kw,Jw=((Kw=Jw||{}).Space=" ",Kw.Enter="Enter",Kw.Escape="Escape",
Kw.Backspace="Backspace",
Kw.Delete="Delete",Kw.ArrowLeft="ArrowLeft",Kw.ArrowUp="ArrowUp",
Kw.ArrowRight="ArrowRight",Kw.ArrowDown="ArrowDown",Kw.Home="Home",Kw.End="End",
Kw.PageUp="PageUp",Kw.PageDown="PageDown",Kw.Tab="Tab",Kw);let ex=[]
;!function(e){function t(){
"loading"!==document.readyState&&(e(),document.removeEventListener("DOMContentLoaded",t))
}
"undefined"!=typeof window&&"undefined"!=typeof document&&(document.addEventListener("DOMContentLoaded",t),
t())}((()=>{function e(e){
e.target instanceof HTMLElement&&e.target!==document.body&&ex[0]!==e.target&&(ex.unshift(e.target),
ex=ex.filter((e=>null!=e&&e.isConnected)),ex.splice(10))}
window.addEventListener("click",e,{capture:!0
}),window.addEventListener("mousedown",e,{capture:!0
}),window.addEventListener("focus",e,{capture:!0
}),document.body.addEventListener("click",e,{capture:!0
}),document.body.addEventListener("mousedown",e,{capture:!0
}),document.body.addEventListener("focus",e,{capture:!0})}))
;var tx,nx=((tx=nx||{})[tx.First=0]="First",
tx[tx.Previous=1]="Previous",tx[tx.Next=2]="Next",
tx[tx.Last=3]="Last",tx[tx.Specific=4]="Specific",tx[tx.Nothing=5]="Nothing",tx)
;function rx(e,t){let n=t.resolveItems();if(n.length<=0)return null
;let r=t.resolveActiveIndex(),o=null!=r?r:-1;switch(e.focus){case 0:
for(let e=0;e<n.length;++e)if(!t.resolveDisabled(n[e],e,n))return e;return r
;case 1:-1===o&&(o=n.length)
;for(let e=o-1;e>=0;--e)if(!t.resolveDisabled(n[e],e,n))return e;return r
;case 2:for(let e=o+1;e<n.length;++e)if(!t.resolveDisabled(n[e],e,n))return e
;return r;case 3:
for(let e=n.length-1;e>=0;--e)if(!t.resolveDisabled(n[e],e,n))return e;return r
;case 4:for(let r=0;r<n.length;++r)if(t.resolveId(n[r],r,n)===e.id)return r
;return r;case 5:return null;default:!function(e){
throw new Error("Unexpected object: "+e)}(e)}}function ox(e={},t=null,n=[]){
for(let[r,o]of Object.entries(e))ix(n,ax(t,r),o);return n}function ax(e,t){
return e?e+"["+t+"]":t}function ix(e,t,n){
if(Array.isArray(n))for(let[r,o]of n.entries())ix(e,ax(t,r.toString()),o);else n instanceof Date?e.push([t,n.toISOString()]):"boolean"==typeof n?e.push([t,n?"1":"0"]):"string"==typeof n?e.push([t,n]):"number"==typeof n?e.push([t,`${n}`]):null==n?e.push([t,""]):ox(n,t,e)
}function sx(e,t,n,r){dw.isServer||fg((o=>{
(e=null!=e?e:window).addEventListener(t,n,r),
o((()=>e.removeEventListener(t,n,r)))}))}var lx=(e=>(e[e.Forwards=0]="Forwards",
e[e.Backwards=1]="Backwards",e))(lx||{});function cx(){let e=bm(0)
;return Dw("keydown",(t=>{"Tab"===t.key&&(e.value=t.shiftKey?1:0)})),e}
function ux(e){if(!e)return new Set;if("function"==typeof e)return new Set(e())
;let t=new Set;for(let n of e.value){let e=sw(n)
;e instanceof HTMLElement&&t.add(e)}return t}
var dx=(e=>(e[e.None=1]="None",e[e.InitialFocus=2]="InitialFocus",
e[e.TabLock=4]="TabLock",
e[e.FocusLock=8]="FocusLock",e[e.RestoreFocus=16]="RestoreFocus",
e[e.All=30]="All",e))(dx||{});let px=Object.assign(Qg({name:"FocusTrap",props:{
as:{type:[Object,String],default:"div"},initialFocus:{type:Object,default:null},
features:{type:Number,default:30},containers:{type:[Object,Function],
default:bm(new Set)}},inheritAttrs:!1,setup(e,{attrs:t,slots:n,expose:r}){
let o=bm(null);r({el:o,$el:o});let a=Sy((()=>pw(o))),i=bm(!1)
;iv((()=>i.value=!0)),uv((()=>i.value=!1)),function({ownerDocument:e},t){
let n=function(e){let t=bm(ex.slice());return mg([e],(([e],[n])=>{
!0===n&&!1===e?tw((()=>{t.value.splice(0)
})):!1===n&&!0===e&&(t.value=ex.slice())}),{flush:"post"}),()=>{var e
;return null!=(e=t.value.find((e=>null!=e&&e.isConnected)))?e:null}}(t)
;iv((()=>{fg((()=>{var r,o
;t.value||(null==(r=e.value)?void 0:r.activeElement)===(null==(o=e.value)?void 0:o.body)&&_w(n())
}),{flush:"post"})})),uv((()=>{t.value&&_w(n())}))}({ownerDocument:a
},Sy((()=>i.value&&Boolean(16&e.features))))
;let s=function({ownerDocument:e,container:t,initialFocus:n},r){
let o=bm(null),a=bm(!1)
;return iv((()=>a.value=!0)),uv((()=>a.value=!1)),iv((()=>{mg([t,n,r],((i,s)=>{
if(i.every(((e,t)=>(null==s?void 0:s[t])===e))||!r.value)return;let l=sw(t)
;l&&tw((()=>{var t,r;if(!a.value)return
;let i=sw(n),s=null==(t=e.value)?void 0:t.activeElement;if(i){
if(i===s)return void(o.value=s)}else if(l.contains(s))return void(o.value=s)
;i?_w(i):Aw(l,vw.First|vw.NoScroll)===bw.Error&&console.warn("There are no focusable elements inside the <FocusTrap />"),
o.value=null==(r=e.value)?void 0:r.activeElement}))}),{immediate:!0,flush:"post"
})})),o}({ownerDocument:a,container:o,initialFocus:Sy((()=>e.initialFocus))
},Sy((()=>i.value&&Boolean(2&e.features))))
;!function({ownerDocument:e,container:t,containers:n,previousActiveElement:r},o){
var a;sx(null==(a=e.value)?void 0:a.defaultView,"focus",(e=>{if(!o.value)return
;let a=ux(n);sw(t)instanceof HTMLElement&&a.add(sw(t));let i=r.value
;if(!i)return;let s=e.target
;s&&s instanceof HTMLElement?hx(a,s)?(r.value=s,_w(s)):(e.preventDefault(),
e.stopPropagation(),_w(i)):_w(r.value)}),!0)}({ownerDocument:a,container:o,
containers:e.containers,previousActiveElement:s
},Sy((()=>i.value&&Boolean(8&e.features))));let l=cx();function c(e){let t=sw(o)
;t&&lw(l.value,{[lx.Forwards]:()=>{Aw(t,vw.First,{skipElements:[e.relatedTarget]
})},[lx.Backwards]:()=>{Aw(t,vw.Last,{skipElements:[e.relatedTarget]})}})}
let u=bm(!1);function d(e){
"Tab"===e.key&&(u.value=!0,requestAnimationFrame((()=>{u.value=!1})))}
function p(t){if(!i.value)return;let n=ux(e.containers)
;sw(o)instanceof HTMLElement&&n.add(sw(o));let r=t.relatedTarget
;r instanceof HTMLElement&&"true"!==r.dataset.headlessuiFocusGuard&&(hx(n,r)||(u.value?Aw(sw(o),lw(l.value,{
[lx.Forwards]:()=>vw.Next,[lx.Backwards]:()=>vw.Previous})|vw.WrapAround,{
relativeTo:t.target}):t.target instanceof HTMLElement&&_w(t.target)))}
return()=>{let r={ref:o,onKeydown:d,onFocusout:p
},{features:a,initialFocus:i,containers:s,...l}=e
;return _y(Mb,[Boolean(4&a)&&_y(qw,{as:"button",type:"button",
"data-headlessui-focus-guard":!0,onFocus:c,features:Vw.Focusable}),zw({
ourProps:r,theirProps:{...t,...l},slot:{},attrs:t,slots:n,name:"FocusTrap"
}),Boolean(4&a)&&_y(qw,{as:"button",type:"button",
"data-headlessui-focus-guard":!0,onFocus:c,features:Vw.Focusable})])}}}),{
features:dx});function hx(e,t){for(let n of e)if(n.contains(t))return!0;return!1
}function fx(){let e;return{before({doc:t}){var n;let r=t.documentElement
;e=(null!=(n=t.defaultView)?n:window).innerWidth-r.clientWidth},
after({doc:t,d:n}){let r=t.documentElement,o=r.clientWidth-r.offsetWidth,a=e-o
;n.style(r,"paddingRight",`${a}px`)}}}function mx(e){let t={}
;for(let n of e)Object.assign(t,n(t));return t}let gx=function(e,t){
let n=e(),r=new Set;return{getSnapshot:()=>n,
subscribe:e=>(r.add(e),()=>r.delete(e)),dispatch(e,...o){let a=t[e].call(n,...o)
;a&&(n=a,r.forEach((e=>e())))}}}((()=>new Map),{PUSH(e,t){var n
;let r=null!=(n=this.get(e))?n:{doc:e,count:0,d:nw(),meta:new Set}
;return r.count++,r.meta.add(t),this.set(e,r),this},POP(e,t){let n=this.get(e)
;return n&&(n.count--,n.meta.delete(t)),this},
SCROLL_PREVENT({doc:e,d:t,meta:n}){let r={doc:e,d:t,meta:mx(n)},o=[Cw()?{
before({doc:e,d:t,meta:n}){function r(e){
return n.containers.flatMap((e=>e())).some((t=>t.contains(e)))}
t.microTask((()=>{var n
;if("auto"!==window.getComputedStyle(e.documentElement).scrollBehavior){
let n=nw()
;n.style(e.documentElement,"scrollBehavior","auto"),t.add((()=>t.microTask((()=>n.dispose()))))
}let o=null!=(n=window.scrollY)?n:window.pageYOffset,a=null
;t.addEventListener(e,"click",(t=>{if(t.target instanceof HTMLElement)try{
let n=t.target.closest("a");if(!n)return
;let{hash:o}=new URL(n.href),i=e.querySelector(o);i&&!r(i)&&(a=i)}catch{}}),!0),
t.addEventListener(e,"touchstart",(e=>{
if(e.target instanceof HTMLElement)if(r(e.target)){let n=e.target
;for(;n.parentElement&&r(n.parentElement);)n=n.parentElement
;t.style(n,"overscrollBehavior","contain")
}else t.style(e.target,"touchAction","none")
})),t.addEventListener(e,"touchmove",(e=>{if(e.target instanceof HTMLElement){
if("INPUT"===e.target.tagName)return;if(r(e.target)){let t=e.target
;for(;t.parentElement&&""!==t.dataset.headlessuiPortal&&!(t.scrollHeight>t.clientHeight||t.scrollWidth>t.clientWidth);)t=t.parentElement
;""===t.dataset.headlessuiPortal&&e.preventDefault()}else e.preventDefault()}
}),{passive:!1}),t.add((()=>{var e
;let t=null!=(e=window.scrollY)?e:window.pageYOffset
;o!==t&&window.scrollTo(0,o),a&&a.isConnected&&(a.scrollIntoView({
block:"nearest"}),a=null)}))}))}}:{},fx(),{before({doc:e,d:t}){
t.style(e.documentElement,"overflow","hidden")}}]
;o.forEach((({before:e})=>null==e?void 0:e(r))),
o.forEach((({after:e})=>null==e?void 0:e(r)))},SCROLL_ALLOW({d:e}){e.dispose()},
TEARDOWN({doc:e}){this.delete(e)}});function vx(e,t,n){let r=function(e){
let t=ym(e.getSnapshot());return uv(e.subscribe((()=>{t.value=e.getSnapshot()
}))),t}(gx),o=Sy((()=>{let t=e.value?r.value.get(e.value):void 0
;return!!t&&t.count>0}));return mg([e,t],(([e,t],[r],o)=>{if(!e||!t)return
;gx.dispatch("PUSH",e,n);let a=!1;o((()=>{
a||(gx.dispatch("POP",null!=r?r:e,n),a=!0)}))}),{immediate:!0}),o}
gx.subscribe((()=>{let e=gx.getSnapshot(),t=new Map
;for(let[n]of e)t.set(n,n.documentElement.style.overflow)
;for(let n of e.values()){let e="hidden"===t.get(n.doc),r=0!==n.count
;(r&&!e||!r&&e)&&gx.dispatch(n.count>0?"SCROLL_PREVENT":"SCROLL_ALLOW",n),
0===n.count&&gx.dispatch("TEARDOWN",n)}}));let bx=new Map,yx=new Map
;function Ox(e,t=bm(!0)){fg((n=>{var r;if(!t.value)return;let o=sw(e)
;if(!o)return;n((function(){var e;if(!o)return;let t=null!=(e=yx.get(o))?e:1
;if(1===t?yx.delete(o):yx.set(o,t-1),1!==t)return;let n=bx.get(o)
;n&&(null===n["aria-hidden"]?o.removeAttribute("aria-hidden"):o.setAttribute("aria-hidden",n["aria-hidden"]),
o.inert=n.inert,bx.delete(o))}));let a=null!=(r=yx.get(o))?r:0
;yx.set(o,a+1),0===a&&(bx.set(o,{"aria-hidden":o.getAttribute("aria-hidden"),
inert:o.inert}),o.setAttribute("aria-hidden","true"),o.inert=!0)}))}
function wx({defaultContainers:e=[],portals:t,mainTreeNodeRef:n}={}){
let r=bm(null),o=pw(r);function a(){var n,a,i;let s=[]
;for(let t of e)null!==t&&(t instanceof HTMLElement?s.push(t):"value"in t&&t.value instanceof HTMLElement&&s.push(t.value))
;if(null!=t&&t.value)for(let e of t.value)s.push(e)
;for(let e of null!=(n=null==o?void 0:o.querySelectorAll("html > *, body > *"))?n:[])e!==document.body&&e!==document.head&&e instanceof HTMLElement&&"headlessui-portal-root"!==e.id&&(e.contains(sw(r))||e.contains(null==(i=null==(a=sw(r))?void 0:a.getRootNode())?void 0:i.host)||s.some((t=>e.contains(t)))||s.push(e))
;return s}return{resolveContainers:a,contains:e=>a().some((t=>t.contains(e))),
mainTreeNodeRef:r,MainTreeNode:()=>null!=n?null:_y(qw,{features:Vw.Hidden,ref:r
})}}let xx=Symbol("ForcePortalRootContext");let kx=Qg({name:"ForcePortalRoot",
props:{as:{type:[Object,String],default:"template"},force:{type:Boolean,
default:!1}},setup:(e,{slots:t,attrs:n})=>(cg(xx,e.force),()=>{
let{force:r,...o}=e;return zw({theirProps:o,ourProps:{},slot:{},slots:t,attrs:n,
name:"ForcePortalRoot"})})}),Sx=Symbol("StackContext")
;var _x=(e=>(e[e.Add=0]="Add",e[e.Remove=1]="Remove",e))(_x||{})
;function Tx({type:e,enabled:t,element:n,onUpdate:r}){let o=ug(Sx,(()=>{}))
;function a(...e){null==r||r(...e),o(...e)}iv((()=>{mg(t,((t,r)=>{
t?a(0,e,n):!0===r&&a(1,e,n)}),{immediate:!0,flush:"sync"})})),uv((()=>{
t.value&&a(1,e,n)})),cg(Sx,a)}let Ex=Symbol("DescriptionContext")
;const Ax=new WeakMap;function Cx(e,t){let n=t(function(e){var t
;return null!=(t=Ax.get(e))?t:0}(e));return n<=0?Ax.delete(e):Ax.set(e,n),n}
let $x=Qg({name:"Portal",props:{as:{type:[Object,String],default:"div"}},
setup(e,{slots:t,attrs:n}){
let r=bm(null),o=Sy((()=>pw(r))),a=ug(xx,!1),i=ug(Ix,null),s=bm(!0===a||null==i?function(e){
let t=pw(e);if(!t){if(null===e)return null
;throw new Error(`[Headless UI]: Cannot find ownerDocument for contextElement: ${e}`)
}let n=t.getElementById("headlessui-portal-root");if(n)return n
;let r=t.createElement("div")
;return r.setAttribute("id","headlessui-portal-root"),t.body.appendChild(r)
}(r.value):i.resolveTarget());s.value&&Cx(s.value,(e=>e+1));let l=bm(!1)
;iv((()=>{l.value=!0})),fg((()=>{a||null!=i&&(s.value=i.resolveTarget())}))
;let c=ug(Px,null),u=!1,d=dy();return mg(r,(()=>{if(u||!c)return;let e=sw(r)
;e&&(uv(c.register(e),d),u=!0)})),uv((()=>{var e,t
;let n=null==(e=o.value)?void 0:e.getElementById("headlessui-portal-root")
;!n||s.value!==n||Cx(s.value,(e=>e-1))||s.value.children.length>0||null==(t=s.value.parentElement)||t.removeChild(s.value)
})),()=>{if(!l.value||null===s.value)return null;let o={ref:r,
"data-headlessui-portal":""};return _y(Ag,{to:s.value},zw({ourProps:o,
theirProps:e,slot:{},attrs:n,slots:t,name:"Portal"}))}}
}),Px=Symbol("PortalParentContext");function Dx(){let e=ug(Px,null),t=bm([])
;function n(n){let r=t.value.indexOf(n)
;-1!==r&&t.value.splice(r,1),e&&e.unregister(n)}let r={register:function(r){
return t.value.push(r),e&&e.register(r),()=>n(r)},unregister:n,portals:t}
;return[t,Qg({name:"PortalWrapper",setup:(e,{slots:t})=>(cg(Px,r),()=>{var e
;return null==(e=t.default)?void 0:e.call(t)})})]}
let Ix=Symbol("PortalGroupContext"),Mx=Qg({name:"PortalGroup",props:{as:{
type:[Object,String],default:"template"},target:{type:Object,default:null}},
setup(e,{attrs:t,slots:n}){let r=am({resolveTarget:()=>e.target})
;return cg(Ix,r),()=>{let{target:r,...o}=e;return zw({theirProps:o,ourProps:{},
slot:{},attrs:t,slots:n,name:"PortalGroup"})}}})
;var Nx,Rx=((Nx=Rx||{})[Nx.Open=0]="Open",Nx[Nx.Closed=1]="Closed",Nx)
;let Lx=Symbol("DialogContext");function Bx(e){let t=ug(Lx,null);if(null===t){
let t=new Error(`<${e} /> is missing a parent <Dialog /> component.`)
;throw Error.captureStackTrace&&Error.captureStackTrace(t,Bx),t}return t}
let jx="DC8F892D-2EBD-447C-A4C8-A03058436FF4",Ux=Qg({name:"Dialog",
inheritAttrs:!1,props:{as:{type:[Object,String],default:"div"},static:{
type:Boolean,default:!1},unmount:{type:Boolean,default:!0},open:{
type:[Boolean,String],default:jx},initialFocus:{type:Object,default:null},id:{
type:String,default:null},role:{type:String,default:"dialog"}},emits:{
close:e=>!0},setup(e,{emit:t,attrs:n,slots:r,expose:o}){var a,i
;let s=null!=(a=e.id)?a:`headlessui-dialog-${iw()}`,l=bm(!1);iv((()=>{l.value=!0
}))
;let c=!1,u=Sy((()=>"dialog"===e.role||"alertdialog"===e.role?e.role:(c||(c=!0,
console.warn(`Invalid role [${u}] passed to <Dialog />. Only \`dialog\` and and \`alertdialog\` are supported. Using \`dialog\` instead.`)),
"dialog"))),d=bm(0),p=Gw(),h=Sy((()=>e.open===jx&&null!==p?(p.value&Xw.Open)===Xw.Open:e.open)),f=bm(null),m=Sy((()=>pw(f)))
;if(o({el:f,$el:f
}),e.open===jx&&null===p)throw new Error("You forgot to provide an `open` prop to the `Dialog`.")
;if("boolean"!=typeof h.value)throw new Error(`You provided an \`open\` prop to the \`Dialog\`, but the value is not a boolean. Received: ${h.value===jx?void 0:e.open}`)
;let g=Sy((()=>l.value&&h.value?0:1)),v=Sy((()=>0===g.value)),b=Sy((()=>d.value>1)),y=null!==ug(Lx,null),[O,w]=Dx(),{resolveContainers:x,mainTreeNodeRef:k,MainTreeNode:S}=wx({
portals:O,defaultContainers:[Sy((()=>{var e
;return null!=(e=I.panelRef.value)?e:f.value}))]
}),_=Sy((()=>b.value?"parent":"leaf")),T=Sy((()=>null!==p&&(p.value&Xw.Closing)===Xw.Closing)),E=Sy((()=>!y&&!T.value&&v.value)),A=Sy((()=>{
var e,t,n
;return null!=(n=Array.from(null!=(t=null==(e=m.value)?void 0:e.querySelectorAll("body > *"))?t:[]).find((e=>"headlessui-portal-root"!==e.id&&(e.contains(sw(k))&&e instanceof HTMLElement))))?n:null
}));Ox(A,E);let C=Sy((()=>!!b.value||v.value)),$=Sy((()=>{var e,t,n
;return null!=(n=Array.from(null!=(t=null==(e=m.value)?void 0:e.querySelectorAll("[data-headlessui-portal]"))?t:[]).find((e=>e.contains(sw(k))&&e instanceof HTMLElement)))?n:null
}));Ox($,C),Tx({type:"Dialog",enabled:Sy((()=>0===g.value)),element:f,
onUpdate:(e,t)=>{if("Dialog"===t)return lw(e,{[_x.Add]:()=>d.value+=1,
[_x.Remove]:()=>d.value-=1})}})
;let P=function({slot:e=bm({}),name:t="Description",props:n={}}={}){let r=bm([])
;return cg(Ex,{register:function(e){return r.value.push(e),()=>{
let t=r.value.indexOf(e);-1!==t&&r.value.splice(t,1)}},slot:e,name:t,props:n
}),Sy((()=>r.value.length>0?r.value.join(" "):void 0))}({
name:"DialogDescription",slot:Sy((()=>({open:h.value})))}),D=bm(null),I={
titleId:D,panelRef:bm(null),dialogState:g,setTitleId(e){D.value!==e&&(D.value=e)
},close(){t("close",!1)}};cg(Lx,I);let M=Sy((()=>!(!v.value||b.value)))
;Iw(x,((e,t)=>{e.preventDefault(),I.close(),Xm((()=>null==t?void 0:t.focus()))
}),M);let N=Sy((()=>!(b.value||0!==g.value)))
;sx(null==(i=m.value)?void 0:i.defaultView,"keydown",(e=>{
N.value&&(e.defaultPrevented||e.key===Jw.Escape&&(e.preventDefault(),
e.stopPropagation(),I.close()))}));let R=Sy((()=>!(T.value||0!==g.value||y)))
;return vx(m,R,(e=>{var t;return{containers:[...null!=(t=e.containers)?t:[],x]}
})),fg((e=>{if(0!==g.value)return;let t=sw(f);if(!t)return
;let n=new ResizeObserver((e=>{for(let t of e){
let e=t.target.getBoundingClientRect()
;0===e.x&&0===e.y&&0===e.width&&0===e.height&&I.close()}}))
;n.observe(t),e((()=>n.disconnect()))})),()=>{
let{open:t,initialFocus:o,...a}=e,i={...n,ref:f,id:s,role:u.value,
"aria-modal":0===g.value||void 0,"aria-labelledby":D.value,
"aria-describedby":P.value},l={open:0===g.value};return _y(kx,{force:!0
},(()=>[_y($x,(()=>_y(Mx,{target:f.value},(()=>_y(kx,{force:!1},(()=>_y(px,{
initialFocus:o,containers:x,features:v.value?lw(_.value,{
parent:px.features.RestoreFocus,leaf:px.features.All&~px.features.FocusLock
}):px.features.None},(()=>_y(w,{},(()=>zw({ourProps:i,theirProps:{...a,...n},
slot:l,attrs:n,slots:r,visible:0===g.value,features:jw.RenderStrategy|jw.Static,
name:"Dialog"}))))))))))),_y(S)]))}}}),zx=Qg({name:"DialogPanel",props:{as:{
type:[Object,String],default:"div"},id:{type:String,default:null}},
setup(e,{attrs:t,slots:n,expose:r}){var o
;let a=null!=(o=e.id)?o:`headlessui-dialog-panel-${iw()}`,i=Bx("DialogPanel")
;function s(e){e.stopPropagation()}return r({el:i.panelRef,$el:i.panelRef
}),()=>{let{...r}=e;return zw({ourProps:{id:a,ref:i.panelRef,onClick:s},
theirProps:r,slot:{open:0===i.dialogState.value},attrs:t,slots:n,
name:"DialogPanel"})}}}),Fx=Qg({name:"DialogTitle",props:{as:{
type:[Object,String],default:"h2"},id:{type:String,default:null}},
setup(e,{attrs:t,slots:n}){var r
;let o=null!=(r=e.id)?r:`headlessui-dialog-title-${iw()}`,a=Bx("DialogTitle")
;return iv((()=>{a.setTitleId(o),uv((()=>a.setTitleId(null)))})),()=>{
let{...r}=e;return zw({ourProps:{id:o},theirProps:r,slot:{
open:0===a.dialogState.value},attrs:t,slots:n,name:"DialogTitle"})}}})
;var Zx=(e=>(e[e.Open=0]="Open",e[e.Closed=1]="Closed",e))(Zx||{})
;let Qx=Symbol("DisclosureContext");function Hx(e){let t=ug(Qx,null)
;if(null===t){
let t=new Error(`<${e} /> is missing a parent <Disclosure /> component.`)
;throw Error.captureStackTrace&&Error.captureStackTrace(t,Hx),t}return t}
let Vx=Symbol("DisclosurePanelContext");let qx=Qg({name:"Disclosure",props:{as:{
type:[Object,String],default:"template"},defaultOpen:{type:[Boolean],default:!1}
},setup(e,{slots:t,attrs:n}){
let r=bm(e.defaultOpen?0:1),o=bm(null),a=bm(null),i={
buttonId:bm(`headlessui-disclosure-button-${iw()}`),
panelId:bm(`headlessui-disclosure-panel-${iw()}`),disclosureState:r,panel:o,
button:a,toggleDisclosure(){r.value=lw(r.value,{0:1,1:0})},closeDisclosure(){
1!==r.value&&(r.value=1)},close(e){i.closeDisclosure()
;let t=e?e instanceof HTMLElement?e:e.value instanceof HTMLElement?sw(e):sw(i.button):sw(i.button)
;null==t||t.focus()}};return cg(Qx,i),Yw(Sy((()=>lw(r.value,{0:Xw.Open,
1:Xw.Closed})))),()=>{let{defaultOpen:o,...a}=e;return zw({theirProps:a,
ourProps:{},slot:{open:0===r.value,close:i.close},slots:t,attrs:n,
name:"Disclosure"})}}}),Wx=Qg({name:"DisclosureButton",props:{as:{
type:[Object,String],default:"button"},disabled:{type:[Boolean],default:!1},id:{
type:String,default:null}},setup(e,{attrs:t,slots:n,expose:r}){
let o=Hx("DisclosureButton"),a=ug(Vx,null),i=Sy((()=>null!==a&&a.value===o.panelId.value))
;iv((()=>{i.value||null!==e.id&&(o.buttonId.value=e.id)})),uv((()=>{
i.value||(o.buttonId.value=null)}));let s=bm(null);r({el:s,$el:s
}),i.value||fg((()=>{o.button.value=s.value}));let l=Nw(Sy((()=>({as:e.as,
type:t.type}))),s);function c(){var t
;e.disabled||(i.value?(o.toggleDisclosure(),
null==(t=sw(o.button))||t.focus()):o.toggleDisclosure())}function u(t){var n
;if(!e.disabled)if(i.value)switch(t.key){case Jw.Space:case Jw.Enter:
t.preventDefault(),
t.stopPropagation(),o.toggleDisclosure(),null==(n=sw(o.button))||n.focus()
}else switch(t.key){case Jw.Space:case Jw.Enter:
t.preventDefault(),t.stopPropagation(),o.toggleDisclosure()}}function d(e){
if(e.key===Jw.Space)e.preventDefault()}return()=>{var r;let a={
open:0===o.disclosureState.value},{id:p,...h}=e;return zw({ourProps:i.value?{
ref:s,type:l.value,onClick:c,onKeydown:u}:{id:null!=(r=o.buttonId.value)?r:p,
ref:s,type:l.value,"aria-expanded":0===o.disclosureState.value,
"aria-controls":0===o.disclosureState.value||sw(o.panel)?o.panelId.value:void 0,
disabled:!!e.disabled||void 0,onClick:c,onKeydown:u,onKeyup:d},theirProps:h,
slot:a,attrs:t,slots:n,name:"DisclosureButton"})}}}),Xx=Qg({
name:"DisclosurePanel",props:{as:{type:[Object,String],default:"div"},static:{
type:Boolean,default:!1},unmount:{type:Boolean,default:!0},id:{type:String,
default:null}},setup(e,{attrs:t,slots:n,expose:r}){let o=Hx("DisclosurePanel")
;iv((()=>{null!==e.id&&(o.panelId.value=e.id)})),uv((()=>{o.panelId.value=null
})),r({el:o.panel,$el:o.panel}),cg(Vx,o.panelId)
;let a=Gw(),i=Sy((()=>null!==a?(a.value&Xw.Open)===Xw.Open:0===o.disclosureState.value))
;return()=>{var r;let a={open:0===o.disclosureState.value,close:o.close
},{id:s,...l}=e;return zw({ourProps:{id:null!=(r=o.panelId.value)?r:s,
ref:o.panel},theirProps:l,slot:a,attrs:t,slots:n,
features:jw.RenderStrategy|jw.Static,visible:i.value,name:"DisclosurePanel"})}}
}),Gx=/([\u2700-\u27BF]|[\uE000-\uF8FF]|\uD83C[\uDC00-\uDFFF]|\uD83D[\uDC00-\uDFFF]|[\u2011-\u26FF]|\uD83E[\uDD10-\uDDFF])/g
;function Yx(e){var t,n;let r=null!=(t=e.innerText)?t:"",o=e.cloneNode(!0)
;if(!(o instanceof HTMLElement))return r;let a=!1
;for(let s of o.querySelectorAll('[hidden],[aria-hidden],[role="img"]'))s.remove(),
a=!0;let i=a?null!=(n=o.innerText)?n:"":r
;return Gx.test(i)&&(i=i.replace(Gx,"")),i}function Kx(e){let t=bm(""),n=bm("")
;return()=>{let r=sw(e);if(!r)return"";let o=r.innerText
;if(t.value===o)return n.value;let a=function(e){
let t=e.getAttribute("aria-label");if("string"==typeof t)return t.trim()
;let n=e.getAttribute("aria-labelledby");if(n){let e=n.split(" ").map((e=>{
let t=document.getElementById(e);if(t){let e=t.getAttribute("aria-label")
;return"string"==typeof e?e.trim():Yx(t).trim()}return null})).filter(Boolean)
;if(e.length>0)return e.join(", ")}return Yx(e).trim()}(r).trim().toLowerCase()
;return t.value=o,n.value=a,a}}function Jx(e,t){return e===t}
var ek=(e=>(e[e.Open=0]="Open",
e[e.Closed=1]="Closed",e))(ek||{}),tk=(e=>(e[e.Single=0]="Single",
e[e.Multi=1]="Multi",
e))(tk||{}),nk=(e=>(e[e.Pointer=0]="Pointer",e[e.Other=1]="Other",e))(nk||{})
;let rk=Symbol("ListboxContext");function ok(e){let t=ug(rk,null);if(null===t){
let t=new Error(`<${e} /> is missing a parent <Listbox /> component.`)
;throw Error.captureStackTrace&&Error.captureStackTrace(t,ok),t}return t}
let ak=Qg({name:"Listbox",emits:{"update:modelValue":e=>!0},props:{as:{
type:[Object,String],default:"template"},disabled:{type:[Boolean],default:!1},
by:{type:[String,Function],default:()=>Jx},horizontal:{type:[Boolean],default:!1
},modelValue:{type:[Object,String,Number,Boolean],default:void 0},defaultValue:{
type:[Object,String,Number,Boolean],default:void 0},form:{type:String,
optional:!0},name:{type:String,optional:!0},multiple:{type:[Boolean],default:!1}
},inheritAttrs:!1,setup(e,{slots:t,attrs:n,emit:r}){
let o=bm(1),a=bm(null),i=bm(null),s=bm(null),l=bm([]),c=bm(""),u=bm(null),d=bm(1)
;function p(e=e=>e){
let t=null!==u.value?l.value[u.value]:null,n=Ew(e(l.value.slice()),(e=>sw(e.dataRef.domRef))),r=t?n.indexOf(t):null
;return-1===r&&(r=null),{options:n,activeOptionIndex:r}}
let h=Sy((()=>e.multiple?1:0)),[f,m]=function(e,t,n){
let r=bm(null==n?void 0:n.value),o=Sy((()=>void 0!==e.value))
;return[Sy((()=>o.value?e.value:r.value)),function(e){
return o.value||(r.value=e),null==t?void 0:t(e)}]
}(Sy((()=>e.modelValue)),(e=>r("update:modelValue",e)),Sy((()=>e.defaultValue))),g=Sy((()=>void 0===f.value?lw(h.value,{
1:[],0:void 0}):f.value)),v={listboxState:o,value:g,mode:h,compare(t,n){
if("string"==typeof e.by){let r=e.by
;return(null==t?void 0:t[r])===(null==n?void 0:n[r])}return e.by(t,n)},
orientation:Sy((()=>e.horizontal?"horizontal":"vertical")),labelRef:a,
buttonRef:i,optionsRef:s,disabled:Sy((()=>e.disabled)),options:l,searchQuery:c,
activeOptionIndex:u,activationTrigger:d,closeListbox(){
e.disabled||1!==o.value&&(o.value=1,u.value=null)},openListbox(){
e.disabled||0!==o.value&&(o.value=0)},goToOption(t,n,r){
if(e.disabled||1===o.value)return;let a=p(),i=rx(t===nx.Specific?{
focus:nx.Specific,id:n}:{focus:t},{resolveItems:()=>a.options,
resolveActiveIndex:()=>a.activeOptionIndex,resolveId:e=>e.id,
resolveDisabled:e=>e.dataRef.disabled})
;c.value="",u.value=i,d.value=null!=r?r:1,l.value=a.options},search(t){
if(e.disabled||1===o.value)return;let n=""!==c.value?0:1
;c.value+=t.toLowerCase()
;let r=(null!==u.value?l.value.slice(u.value+n).concat(l.value.slice(0,u.value+n)):l.value).find((e=>e.dataRef.textValue.startsWith(c.value)&&!e.dataRef.disabled)),a=r?l.value.indexOf(r):-1
;-1===a||a===u.value||(u.value=a,d.value=1)},clearSearch(){
e.disabled||1!==o.value&&""!==c.value&&(c.value="")},registerOption(e,t){
let n=p((n=>[...n,{id:e,dataRef:t}]))
;l.value=n.options,u.value=n.activeOptionIndex},unregisterOption(e){
let t=p((t=>{let n=t.findIndex((t=>t.id===e));return-1!==n&&t.splice(n,1),t}))
;l.value=t.options,u.value=t.activeOptionIndex,d.value=1},theirOnChange(t){
e.disabled||m(t)},select(t){e.disabled||m(lw(h.value,{0:()=>t,1:()=>{
let e=hm(v.value.value).slice(),n=hm(t),r=e.findIndex((e=>v.compare(n,hm(e))))
;return-1===r?e.push(n):e.splice(r,1),e}}))}};Iw([i,s],((e,t)=>{var n
;v.closeListbox(),
xw(t,ww.Loose)||(e.preventDefault(),null==(n=sw(i))||n.focus())
}),Sy((()=>0===o.value))),cg(rk,v),Yw(Sy((()=>lw(o.value,{0:Xw.Open,1:Xw.Closed
}))));let b=Sy((()=>{var e;return null==(e=sw(i))?void 0:e.closest("form")}))
;return iv((()=>{mg([b],(()=>{
if(b.value&&void 0!==e.defaultValue)return b.value.addEventListener("reset",t),
()=>{var e;null==(e=b.value)||e.removeEventListener("reset",t)};function t(){
v.theirOnChange(e.defaultValue)}}),{immediate:!0})})),()=>{
let{name:r,modelValue:a,disabled:i,form:s,...l}=e,c={open:0===o.value,
disabled:i,value:g.value};return _y(Mb,[...null!=r&&null!=g.value?ox({
[r]:g.value}).map((([e,t])=>_y(qw,function(e){let t=Object.assign({},e)
;for(let n in t)void 0===t[n]&&delete t[n];return t}({features:Vw.Hidden,key:e,
as:"input",type:"hidden",hidden:!0,readOnly:!0,form:s,disabled:i,name:e,value:t
})))):[],zw({ourProps:{},theirProps:{...n,
...Hw(l,["defaultValue","onUpdate:modelValue","horizontal","multiple","by"])},
slot:c,slots:t,attrs:n,name:"Listbox"})])}}}),ik=Qg({name:"ListboxLabel",props:{
as:{type:[Object,String],default:"label"},id:{type:String,default:null}},
setup(e,{attrs:t,slots:n}){var r
;let o=null!=(r=e.id)?r:`headlessui-listbox-label-${iw()}`,a=ok("ListboxLabel")
;function i(){var e;null==(e=sw(a.buttonRef))||e.focus({preventScroll:!0})}
return()=>{let r={open:0===a.listboxState.value,disabled:a.disabled.value
},{...s}=e;return zw({ourProps:{id:o,ref:a.labelRef,onClick:i},theirProps:s,
slot:r,attrs:t,slots:n,name:"ListboxLabel"})}}}),sk=Qg({name:"ListboxButton",
props:{as:{type:[Object,String],default:"button"},id:{type:String,default:null}
},setup(e,{attrs:t,slots:n,expose:r}){var o
;let a=null!=(o=e.id)?o:`headlessui-listbox-button-${iw()}`,i=ok("ListboxButton")
;function s(e){switch(e.key){case Jw.Space:case Jw.Enter:case Jw.ArrowDown:
e.preventDefault(),i.openListbox(),Xm((()=>{var e
;null==(e=sw(i.optionsRef))||e.focus({preventScroll:!0
}),i.value.value||i.goToOption(nx.First)}));break;case Jw.ArrowUp:
e.preventDefault(),i.openListbox(),Xm((()=>{var e
;null==(e=sw(i.optionsRef))||e.focus({preventScroll:!0
}),i.value.value||i.goToOption(nx.Last)}))}}function l(e){
if(e.key===Jw.Space)e.preventDefault()}function c(e){
i.disabled.value||(0===i.listboxState.value?(i.closeListbox(),Xm((()=>{var e
;return null==(e=sw(i.buttonRef))?void 0:e.focus({preventScroll:!0})
}))):(e.preventDefault(),i.openListbox(),function(e){
requestAnimationFrame((()=>requestAnimationFrame(e)))}((()=>{var e
;return null==(e=sw(i.optionsRef))?void 0:e.focus({preventScroll:!0})}))))}r({
el:i.buttonRef,$el:i.buttonRef});let u=Nw(Sy((()=>({as:e.as,type:t.type
}))),i.buttonRef);return()=>{var r,o;let d={open:0===i.listboxState.value,
disabled:i.disabled.value,value:i.value.value},{...p}=e;return zw({ourProps:{
ref:i.buttonRef,id:a,type:u.value,"aria-haspopup":"listbox",
"aria-controls":null==(r=sw(i.optionsRef))?void 0:r.id,
"aria-expanded":0===i.listboxState.value,
"aria-labelledby":i.labelRef.value?[null==(o=sw(i.labelRef))?void 0:o.id,a].join(" "):void 0,
disabled:!0===i.disabled.value||void 0,onKeydown:s,onKeyup:l,onClick:c},
theirProps:p,slot:d,attrs:t,slots:n,name:"ListboxButton"})}}}),lk=Qg({
name:"ListboxOptions",props:{as:{type:[Object,String],default:"ul"},static:{
type:Boolean,default:!1},unmount:{type:Boolean,default:!0},id:{type:String,
default:null}},setup(e,{attrs:t,slots:n,expose:r}){var o
;let a=null!=(o=e.id)?o:`headlessui-listbox-options-${iw()}`,i=ok("ListboxOptions"),s=bm(null)
;function l(e){switch(s.value&&clearTimeout(s.value),e.key){case Jw.Space:
if(""!==i.searchQuery.value)return e.preventDefault(),
e.stopPropagation(),i.search(e.key);case Jw.Enter:
if(e.preventDefault(),e.stopPropagation(),null!==i.activeOptionIndex.value){
let e=i.options.value[i.activeOptionIndex.value];i.select(e.dataRef.value)}
0===i.mode.value&&(i.closeListbox(),Xm((()=>{var e
;return null==(e=sw(i.buttonRef))?void 0:e.focus({preventScroll:!0})})));break
;case lw(i.orientation.value,{vertical:Jw.ArrowDown,horizontal:Jw.ArrowRight}):
return e.preventDefault(),e.stopPropagation(),i.goToOption(nx.Next)
;case lw(i.orientation.value,{vertical:Jw.ArrowUp,horizontal:Jw.ArrowLeft}):
return e.preventDefault(),e.stopPropagation(),i.goToOption(nx.Previous)
;case Jw.Home:case Jw.PageUp:
return e.preventDefault(),e.stopPropagation(),i.goToOption(nx.First)
;case Jw.End:case Jw.PageDown:
return e.preventDefault(),e.stopPropagation(),i.goToOption(nx.Last)
;case Jw.Escape:
e.preventDefault(),e.stopPropagation(),i.closeListbox(),Xm((()=>{var e
;return null==(e=sw(i.buttonRef))?void 0:e.focus({preventScroll:!0})}));break
;case Jw.Tab:e.preventDefault(),e.stopPropagation();break;default:
1===e.key.length&&(i.search(e.key),
s.value=setTimeout((()=>i.clearSearch()),350))}}r({el:i.optionsRef,
$el:i.optionsRef})
;let c=Gw(),u=Sy((()=>null!==c?(c.value&Xw.Open)===Xw.Open:0===i.listboxState.value))
;return()=>{var r,o;let s={open:0===i.listboxState.value},{...c}=e;return zw({
ourProps:{
"aria-activedescendant":null===i.activeOptionIndex.value||null==(r=i.options.value[i.activeOptionIndex.value])?void 0:r.id,
"aria-multiselectable":1===i.mode.value||void 0,
"aria-labelledby":null==(o=sw(i.buttonRef))?void 0:o.id,
"aria-orientation":i.orientation.value,id:a,onKeydown:l,role:"listbox",
tabIndex:0,ref:i.optionsRef},theirProps:c,slot:s,attrs:t,slots:n,
features:jw.RenderStrategy|jw.Static,visible:u.value,name:"ListboxOptions"})}}
}),ck=Qg({name:"ListboxOption",props:{as:{type:[Object,String],default:"li"},
value:{type:[Object,String,Number,Boolean]},disabled:{type:Boolean,default:!1},
id:{type:String,default:null}},setup(e,{slots:t,attrs:n,expose:r}){var o
;let a=null!=(o=e.id)?o:`headlessui-listbox-option-${iw()}`,i=ok("ListboxOption"),s=bm(null)
;r({el:s,$el:s})
;let l=Sy((()=>null!==i.activeOptionIndex.value&&i.options.value[i.activeOptionIndex.value].id===a)),c=Sy((()=>lw(i.mode.value,{
0:()=>i.compare(hm(i.value.value),hm(e.value)),
1:()=>hm(i.value.value).some((t=>i.compare(hm(t),hm(e.value))))
}))),u=Sy((()=>lw(i.mode.value,{1:()=>{var e;let t=hm(i.value.value)
;return(null==(e=i.options.value.find((e=>t.some((t=>i.compare(hm(t),hm(e.dataRef.value)))))))?void 0:e.id)===a
},0:()=>c.value}))),d=Kx(s),p=Sy((()=>({disabled:e.disabled,value:e.value,
get textValue(){return d()},domRef:s})));function h(t){
if(e.disabled)return t.preventDefault()
;i.select(e.value),0===i.mode.value&&(i.closeListbox(),Xm((()=>{var e
;return null==(e=sw(i.buttonRef))?void 0:e.focus({preventScroll:!0})})))}
function f(){if(e.disabled)return i.goToOption(nx.Nothing)
;i.goToOption(nx.Specific,a)}
iv((()=>i.registerOption(a,p))),uv((()=>i.unregisterOption(a))),iv((()=>{
mg([i.listboxState,c],(()=>{0===i.listboxState.value&&c.value&&lw(i.mode.value,{
1:()=>{u.value&&i.goToOption(nx.Specific,a)},0:()=>{i.goToOption(nx.Specific,a)}
})}),{immediate:!0})})),fg((()=>{
0===i.listboxState.value&&l.value&&0!==i.activationTrigger.value&&Xm((()=>{
var e,t
;return null==(t=null==(e=sw(s))?void 0:e.scrollIntoView)?void 0:t.call(e,{
block:"nearest"})}))}));let m=Lw();function g(e){m.update(e)}function v(t){
m.wasMoved(t)&&(e.disabled||l.value||i.goToOption(nx.Specific,a,0))}
function b(t){m.wasMoved(t)&&(e.disabled||l.value&&i.goToOption(nx.Nothing))}
return()=>{let{disabled:r}=e,o={active:l.value,selected:c.value,disabled:r
},{value:i,disabled:u,...d}=e;return zw({ourProps:{id:a,ref:s,role:"option",
tabIndex:!0===r?void 0:-1,"aria-disabled":!0===r||void 0,
"aria-selected":c.value,disabled:void 0,onClick:h,onFocus:f,onPointerenter:g,
onMouseenter:g,onPointermove:v,onMousemove:v,onPointerleave:b,onMouseleave:b},
theirProps:d,slot:o,attrs:n,slots:t,name:"ListboxOption"})}}})
;var uk=(e=>(e[e.Open=0]="Open",
e[e.Closed=1]="Closed",e))(uk||{}),dk=(e=>(e[e.Pointer=0]="Pointer",
e[e.Other=1]="Other",e))(dk||{});let pk=Symbol("MenuContext");function hk(e){
let t=ug(pk,null);if(null===t){
let t=new Error(`<${e} /> is missing a parent <Menu /> component.`)
;throw Error.captureStackTrace&&Error.captureStackTrace(t,hk),t}return t}
let fk=Qg({name:"Menu",props:{as:{type:[Object,String],default:"template"}},
setup(e,{slots:t,attrs:n}){
let r=bm(1),o=bm(null),a=bm(null),i=bm([]),s=bm(""),l=bm(null),c=bm(1)
;function u(e=e=>e){
let t=null!==l.value?i.value[l.value]:null,n=Ew(e(i.value.slice()),(e=>sw(e.dataRef.domRef))),r=t?n.indexOf(t):null
;return-1===r&&(r=null),{items:n,activeItemIndex:r}}let d={menuState:r,
buttonRef:o,itemsRef:a,items:i,searchQuery:s,activeItemIndex:l,
activationTrigger:c,closeMenu:()=>{r.value=1,l.value=null},
openMenu:()=>r.value=0,goToItem(e,t,n){let r=u(),o=rx(e===nx.Specific?{
focus:nx.Specific,id:t}:{focus:e},{resolveItems:()=>r.items,
resolveActiveIndex:()=>r.activeItemIndex,resolveId:e=>e.id,
resolveDisabled:e=>e.dataRef.disabled})
;s.value="",l.value=o,c.value=null!=n?n:1,i.value=r.items},search(e){
let t=""!==s.value?0:1;s.value+=e.toLowerCase()
;let n=(null!==l.value?i.value.slice(l.value+t).concat(i.value.slice(0,l.value+t)):i.value).find((e=>e.dataRef.textValue.startsWith(s.value)&&!e.dataRef.disabled)),r=n?i.value.indexOf(n):-1
;-1===r||r===l.value||(l.value=r,c.value=1)},clearSearch(){s.value=""},
registerItem(e,t){let n=u((n=>[...n,{id:e,dataRef:t}]))
;i.value=n.items,l.value=n.activeItemIndex,c.value=1},unregisterItem(e){
let t=u((t=>{let n=t.findIndex((t=>t.id===e));return-1!==n&&t.splice(n,1),t}))
;i.value=t.items,l.value=t.activeItemIndex,c.value=1}};return Iw([o,a],((e,t)=>{
var n
;d.closeMenu(),xw(t,ww.Loose)||(e.preventDefault(),null==(n=sw(o))||n.focus())
}),Sy((()=>0===r.value))),cg(pk,d),Yw(Sy((()=>lw(r.value,{0:Xw.Open,1:Xw.Closed
})))),()=>{let o={open:0===r.value,close:d.closeMenu};return zw({ourProps:{},
theirProps:e,slot:o,slots:t,attrs:n,name:"Menu"})}}}),mk=Qg({name:"MenuButton",
props:{disabled:{type:Boolean,default:!1},as:{type:[Object,String],
default:"button"},id:{type:String,default:null}},
setup(e,{attrs:t,slots:n,expose:r}){var o
;let a=null!=(o=e.id)?o:`headlessui-menu-button-${iw()}`,i=hk("MenuButton")
;function s(e){switch(e.key){case Jw.Space:case Jw.Enter:case Jw.ArrowDown:
e.preventDefault(),e.stopPropagation(),i.openMenu(),Xm((()=>{var e
;null==(e=sw(i.itemsRef))||e.focus({preventScroll:!0}),i.goToItem(nx.First)}))
;break;case Jw.ArrowUp:
e.preventDefault(),e.stopPropagation(),i.openMenu(),Xm((()=>{var e
;null==(e=sw(i.itemsRef))||e.focus({preventScroll:!0}),i.goToItem(nx.Last)}))}}
function l(e){if(e.key===Jw.Space)e.preventDefault()}function c(t){
e.disabled||(0===i.menuState.value?(i.closeMenu(),Xm((()=>{var e
;return null==(e=sw(i.buttonRef))?void 0:e.focus({preventScroll:!0})
}))):(t.preventDefault(),i.openMenu(),function(e){
requestAnimationFrame((()=>requestAnimationFrame(e)))}((()=>{var e
;return null==(e=sw(i.itemsRef))?void 0:e.focus({preventScroll:!0})}))))}r({
el:i.buttonRef,$el:i.buttonRef});let u=Nw(Sy((()=>({as:e.as,type:t.type
}))),i.buttonRef);return()=>{var r;let o={open:0===i.menuState.value},{...d}=e
;return zw({ourProps:{ref:i.buttonRef,id:a,type:u.value,"aria-haspopup":"menu",
"aria-controls":null==(r=sw(i.itemsRef))?void 0:r.id,
"aria-expanded":0===i.menuState.value,onKeydown:s,onKeyup:l,onClick:c},
theirProps:d,slot:o,attrs:t,slots:n,name:"MenuButton"})}}}),gk=Qg({
name:"MenuItems",props:{as:{type:[Object,String],default:"div"},static:{
type:Boolean,default:!1},unmount:{type:Boolean,default:!0},id:{type:String,
default:null}},setup(e,{attrs:t,slots:n,expose:r}){var o
;let a=null!=(o=e.id)?o:`headlessui-menu-items-${iw()}`,i=hk("MenuItems"),s=bm(null)
;function l(e){var t;switch(s.value&&clearTimeout(s.value),e.key){case Jw.Space:
if(""!==i.searchQuery.value)return e.preventDefault(),
e.stopPropagation(),i.search(e.key);case Jw.Enter:
if(e.preventDefault(),e.stopPropagation(),null!==i.activeItemIndex.value){
null==(t=sw(i.items.value[i.activeItemIndex.value].dataRef.domRef))||t.click()}
i.closeMenu(),kw(sw(i.buttonRef));break;case Jw.ArrowDown:
return e.preventDefault(),e.stopPropagation(),i.goToItem(nx.Next)
;case Jw.ArrowUp:
return e.preventDefault(),e.stopPropagation(),i.goToItem(nx.Previous)
;case Jw.Home:case Jw.PageUp:
return e.preventDefault(),e.stopPropagation(),i.goToItem(nx.First);case Jw.End:
case Jw.PageDown:
return e.preventDefault(),e.stopPropagation(),i.goToItem(nx.Last)
;case Jw.Escape:e.preventDefault(),e.stopPropagation(),i.closeMenu(),Xm((()=>{
var e;return null==(e=sw(i.buttonRef))?void 0:e.focus({preventScroll:!0})}))
;break;case Jw.Tab:
e.preventDefault(),e.stopPropagation(),i.closeMenu(),Xm((()=>function(e,t){
return Aw(Ow(),t,{relativeTo:e})
}(sw(i.buttonRef),e.shiftKey?vw.Previous:vw.Next)));break;default:
1===e.key.length&&(i.search(e.key),
s.value=setTimeout((()=>i.clearSearch()),350))}}function c(e){
if(e.key===Jw.Space)e.preventDefault()}r({el:i.itemsRef,$el:i.itemsRef
}),function({container:e,accept:t,walk:n,enabled:r}){fg((()=>{let o=e.value
;if(!o||void 0!==r&&!r.value)return;let a=pw(e);if(!a)return
;let i=Object.assign((e=>t(e)),{acceptNode:t
}),s=a.createTreeWalker(o,NodeFilter.SHOW_ELEMENT,i,!1)
;for(;s.nextNode();)n(s.currentNode)}))}({container:Sy((()=>sw(i.itemsRef))),
enabled:Sy((()=>0===i.menuState.value)),
accept:e=>"menuitem"===e.getAttribute("role")?NodeFilter.FILTER_REJECT:e.hasAttribute("role")?NodeFilter.FILTER_SKIP:NodeFilter.FILTER_ACCEPT,
walk(e){e.setAttribute("role","none")}})
;let u=Gw(),d=Sy((()=>null!==u?(u.value&Xw.Open)===Xw.Open:0===i.menuState.value))
;return()=>{var r,o;let s={open:0===i.menuState.value},{...u}=e;return zw({
ourProps:{
"aria-activedescendant":null===i.activeItemIndex.value||null==(r=i.items.value[i.activeItemIndex.value])?void 0:r.id,
"aria-labelledby":null==(o=sw(i.buttonRef))?void 0:o.id,id:a,onKeydown:l,
onKeyup:c,role:"menu",tabIndex:0,ref:i.itemsRef},theirProps:u,slot:s,attrs:t,
slots:n,features:jw.RenderStrategy|jw.Static,visible:d.value,name:"MenuItems"})}
}}),vk=Qg({name:"MenuItem",inheritAttrs:!1,props:{as:{type:[Object,String],
default:"template"},disabled:{type:Boolean,default:!1},id:{type:String,
default:null}},setup(e,{slots:t,attrs:n,expose:r}){var o
;let a=null!=(o=e.id)?o:`headlessui-menu-item-${iw()}`,i=hk("MenuItem"),s=bm(null)
;r({el:s,$el:s})
;let l=Sy((()=>null!==i.activeItemIndex.value&&i.items.value[i.activeItemIndex.value].id===a)),c=Kx(s),u=Sy((()=>({
disabled:e.disabled,get textValue(){return c()},domRef:s})));function d(t){
if(e.disabled)return t.preventDefault();i.closeMenu(),kw(sw(i.buttonRef))}
function p(){if(e.disabled)return i.goToItem(nx.Nothing)
;i.goToItem(nx.Specific,a)}
iv((()=>i.registerItem(a,u))),uv((()=>i.unregisterItem(a))),fg((()=>{
0===i.menuState.value&&l.value&&0!==i.activationTrigger.value&&Xm((()=>{var e,t
;return null==(t=null==(e=sw(s))?void 0:e.scrollIntoView)?void 0:t.call(e,{
block:"nearest"})}))}));let h=Lw();function f(e){h.update(e)}function m(t){
h.wasMoved(t)&&(e.disabled||l.value||i.goToItem(nx.Specific,a,0))}function g(t){
h.wasMoved(t)&&(e.disabled||l.value&&i.goToItem(nx.Nothing))}return()=>{
let{disabled:r,...o}=e,c={active:l.value,disabled:r,close:i.closeMenu}
;return zw({ourProps:{id:a,ref:s,role:"menuitem",tabIndex:!0===r?void 0:-1,
"aria-disabled":!0===r||void 0,onClick:d,onFocus:p,onPointerenter:f,
onMouseenter:f,onPointermove:m,onMousemove:m,onPointerleave:g,onMouseleave:g},
theirProps:{...n,...o},slot:c,attrs:n,slots:t,name:"MenuItem"})}}})
;var bk,yk=((bk=yk||{})[bk.Open=0]="Open",bk[bk.Closed=1]="Closed",bk)
;let Ok=Symbol("PopoverContext");function wk(e){let t=ug(Ok,null);if(null===t){
let t=new Error(`<${e} /> is missing a parent <${_k.name} /> component.`)
;throw Error.captureStackTrace&&Error.captureStackTrace(t,wk),t}return t}
let xk=Symbol("PopoverGroupContext");function kk(){return ug(xk,null)}
let Sk=Symbol("PopoverPanelContext");let _k=Qg({name:"Popover",inheritAttrs:!1,
props:{as:{type:[Object,String],default:"div"}},
setup(e,{slots:t,attrs:n,expose:r}){var o;let a=bm(null);r({el:a,$el:a})
;let i=bm(1),s=bm(null),l=bm(null),c=bm(null),u=bm(null),d=Sy((()=>pw(a))),p=Sy((()=>{
var e,t;if(!sw(s)||!sw(u))return!1
;for(let c of document.querySelectorAll("body > *"))if(Number(null==c?void 0:c.contains(sw(s)))^Number(null==c?void 0:c.contains(sw(u))))return!0
;let n=Ow(),r=n.indexOf(sw(s)),o=(r+n.length-1)%n.length,a=(r+1)%n.length,i=n[o],l=n[a]
;return!(null!=(e=sw(u))&&e.contains(i)||null!=(t=sw(u))&&t.contains(l))})),h={
popoverState:i,buttonId:bm(null),panelId:bm(null),panel:u,button:s,
isPortalled:p,beforePanelSentinel:l,afterPanelSentinel:c,togglePopover(){
i.value=lw(i.value,{0:1,1:0})},closePopover(){1!==i.value&&(i.value=1)},
close(e){h.closePopover()
;let t=e?e instanceof HTMLElement?e:e.value instanceof HTMLElement?sw(e):sw(h.button):sw(h.button)
;null==t||t.focus()}};cg(Ok,h),Yw(Sy((()=>lw(i.value,{0:Xw.Open,1:Xw.Closed}))))
;let f={buttonId:h.buttonId,panelId:h.panelId,close(){h.closePopover()}
},m=kk(),g=null==m?void 0:m.registerPopover,[v,b]=Dx(),y=wx({
mainTreeNodeRef:null==m?void 0:m.mainTreeNodeRef,portals:v,
defaultContainers:[s,u]})
;return fg((()=>null==g?void 0:g(f))),sx(null==(o=d.value)?void 0:o.defaultView,"focus",(e=>{
var t,n
;e.target!==window&&e.target instanceof HTMLElement&&0===i.value&&(function(){
var e,t,n,r
;return null!=(r=null==m?void 0:m.isFocusWithinPopoverGroup())?r:(null==(e=d.value)?void 0:e.activeElement)&&((null==(t=sw(s))?void 0:t.contains(d.value.activeElement))||(null==(n=sw(u))?void 0:n.contains(d.value.activeElement)))
}()||s&&u&&(y.contains(e.target)||null!=(t=sw(h.beforePanelSentinel))&&t.contains(e.target)||null!=(n=sw(h.afterPanelSentinel))&&n.contains(e.target)||h.closePopover()))
}),!0),Iw(y.resolveContainers,((e,t)=>{var n
;h.closePopover(),xw(t,ww.Loose)||(e.preventDefault(),
null==(n=sw(s))||n.focus())}),Sy((()=>0===i.value))),()=>{let r={
open:0===i.value,close:h.close};return _y(Mb,[_y(b,{},(()=>zw({theirProps:{...e,
...n},ourProps:{ref:a},slot:r,slots:t,attrs:n,name:"Popover"
}))),_y(y.MainTreeNode)])}}}),Tk=Qg({name:"PopoverButton",props:{as:{
type:[Object,String],default:"button"},disabled:{type:[Boolean],default:!1},id:{
type:String,default:null}},inheritAttrs:!1,setup(e,{attrs:t,slots:n,expose:r}){
var o
;let a=null!=(o=e.id)?o:`headlessui-popover-button-${iw()}`,i=wk("PopoverButton"),s=Sy((()=>pw(i.button)))
;r({el:i.button,$el:i.button}),iv((()=>{i.buttonId.value=a})),uv((()=>{
i.buttonId.value=null}))
;let l=kk(),c=null==l?void 0:l.closeOthers,u=ug(Sk,null),d=Sy((()=>null!==u&&u.value===i.panelId.value)),p=bm(null),h=`headlessui-focus-sentinel-${iw()}`
;d.value||fg((()=>{i.button.value=sw(p)}));let f=Nw(Sy((()=>({as:e.as,
type:t.type}))),p);function m(e){var t,n,r,o,a;if(d.value){
if(1===i.popoverState.value)return;switch(e.key){case Jw.Space:case Jw.Enter:
e.preventDefault(),
null==(n=(t=e.target).click)||n.call(t),i.closePopover(),null==(r=sw(i.button))||r.focus()
}}else switch(e.key){case Jw.Space:case Jw.Enter:
e.preventDefault(),e.stopPropagation(),
1===i.popoverState.value&&(null==c||c(i.buttonId.value)),i.togglePopover();break
;case Jw.Escape:
if(0!==i.popoverState.value)return null==c?void 0:c(i.buttonId.value)
;if(!sw(i.button)||null!=(o=s.value)&&o.activeElement&&(null==(a=sw(i.button))||!a.contains(s.value.activeElement)))return
;e.preventDefault(),e.stopPropagation(),i.closePopover()}}function g(e){
d.value||e.key===Jw.Space&&e.preventDefault()}function v(t){var n,r
;e.disabled||(d.value?(i.closePopover(),
null==(n=sw(i.button))||n.focus()):(t.preventDefault(),
t.stopPropagation(),1===i.popoverState.value&&(null==c||c(i.buttonId.value)),
i.togglePopover(),null==(r=sw(i.button))||r.focus()))}function b(e){
e.preventDefault(),e.stopPropagation()}let y=cx();function O(){let e=sw(i.panel)
;e&&lw(y.value,{[lx.Forwards]:()=>Aw(e,vw.First),
[lx.Backwards]:()=>Aw(e,vw.Last)
})===bw.Error&&Aw(Ow().filter((e=>"true"!==e.dataset.headlessuiFocusGuard)),lw(y.value,{
[lx.Forwards]:vw.Next,[lx.Backwards]:vw.Previous}),{relativeTo:sw(i.button)})}
return()=>{let r=0===i.popoverState.value,o={open:r},{...s}=e,l=d.value?{ref:p,
type:f.value,onKeydown:m,onClick:v}:{ref:p,id:a,type:f.value,
"aria-expanded":0===i.popoverState.value,
"aria-controls":sw(i.panel)?i.panelId.value:void 0,
disabled:!!e.disabled||void 0,onKeydown:m,onKeyup:g,onClick:v,onMousedown:b}
;return _y(Mb,[zw({ourProps:l,theirProps:{...t,...s},slot:o,attrs:t,slots:n,
name:"PopoverButton"}),r&&!d.value&&i.isPortalled.value&&_y(qw,{id:h,
features:Vw.Focusable,"data-headlessui-focus-guard":!0,as:"button",
type:"button",onFocus:O})])}}}),Ek=Qg({name:"PopoverPanel",props:{as:{
type:[Object,String],default:"div"},static:{type:Boolean,default:!1},unmount:{
type:Boolean,default:!0},focus:{type:Boolean,default:!1},id:{type:String,
default:null}},inheritAttrs:!1,setup(e,{attrs:t,slots:n,expose:r}){var o
;let a=null!=(o=e.id)?o:`headlessui-popover-panel-${iw()}`,{focus:i}=e,s=wk("PopoverPanel"),l=Sy((()=>pw(s.panel))),c=`headlessui-focus-sentinel-before-${iw()}`,u=`headlessui-focus-sentinel-after-${iw()}`
;r({el:s.panel,$el:s.panel}),iv((()=>{s.panelId.value=a})),uv((()=>{
s.panelId.value=null})),cg(Sk,s.panelId),fg((()=>{var e,t
;if(!i||0!==s.popoverState.value||!s.panel)return
;let n=null==(e=l.value)?void 0:e.activeElement
;null!=(t=sw(s.panel))&&t.contains(n)||Aw(sw(s.panel),vw.First)}))
;let d=Gw(),p=Sy((()=>null!==d?(d.value&Xw.Open)===Xw.Open:0===s.popoverState.value))
;function h(e){var t,n;if(e.key===Jw.Escape){
if(0!==s.popoverState.value||!sw(s.panel)||l.value&&(null==(t=sw(s.panel))||!t.contains(l.value.activeElement)))return
;e.preventDefault(),
e.stopPropagation(),s.closePopover(),null==(n=sw(s.button))||n.focus()}}
function f(e){var t,n,r,o,a;let i=e.relatedTarget
;i&&sw(s.panel)&&(null!=(t=sw(s.panel))&&t.contains(i)||(s.closePopover(),
(null!=(r=null==(n=sw(s.beforePanelSentinel))?void 0:n.contains)&&r.call(n,i)||null!=(a=null==(o=sw(s.afterPanelSentinel))?void 0:o.contains)&&a.call(o,i))&&i.focus({
preventScroll:!0})))}let m=cx();function g(){let e=sw(s.panel);e&&lw(m.value,{
[lx.Forwards]:()=>{var t
;Aw(e,vw.First)===bw.Error&&(null==(t=sw(s.afterPanelSentinel))||t.focus())},
[lx.Backwards]:()=>{var e;null==(e=sw(s.button))||e.focus({preventScroll:!0})}})
}function v(){let e=sw(s.panel);e&&lw(m.value,{[lx.Forwards]:()=>{
let e=sw(s.button),t=sw(s.panel);if(!e)return
;let n=Ow(),r=n.indexOf(e),o=n.slice(0,r+1),a=[...n.slice(r+1),...o]
;for(let i of a.slice())if("true"===i.dataset.headlessuiFocusGuard||null!=t&&t.contains(i)){
let e=a.indexOf(i);-1!==e&&a.splice(e,1)}Aw(a,vw.First,{sorted:!1})},
[lx.Backwards]:()=>{var t
;Aw(e,vw.Previous)===bw.Error&&(null==(t=sw(s.button))||t.focus())}})}
return()=>{let r={open:0===s.popoverState.value,close:s.close},{focus:o,...l}=e
;return zw({ourProps:{ref:s.panel,id:a,onKeydown:h,
onFocusout:i&&0===s.popoverState.value?f:void 0,tabIndex:-1},theirProps:{...t,
...l},attrs:t,slot:r,slots:{...n,default:(...e)=>{var t
;return[_y(Mb,[p.value&&s.isPortalled.value&&_y(qw,{id:c,
ref:s.beforePanelSentinel,features:Vw.Focusable,
"data-headlessui-focus-guard":!0,as:"button",type:"button",onFocus:g
}),null==(t=n.default)?void 0:t.call(n,...e),p.value&&s.isPortalled.value&&_y(qw,{
id:u,ref:s.afterPanelSentinel,features:Vw.Focusable,
"data-headlessui-focus-guard":!0,as:"button",type:"button",onFocus:v})])]}},
features:jw.RenderStrategy|jw.Static,visible:p.value,name:"PopoverPanel"})}}
}),Ak=Qg({props:{onFocus:{type:Function,required:!0}},setup(e){let t=bm(!0)
;return()=>t.value?_y(qw,{as:"button",type:"button",features:Vw.Focusable,
onFocus(n){n.preventDefault();let r,o=50;r=requestAnimationFrame((function n(){
var a
;if(!(o--<=0))return null!=(a=e.onFocus)&&a.call(e)?(t.value=!1,void cancelAnimationFrame(r)):void(r=requestAnimationFrame(n))
;r&&cancelAnimationFrame(r)}))}}):null}})
;var Ck,$k=(e=>(e[e.Forwards=0]="Forwards",
e[e.Backwards=1]="Backwards",e))($k||{}),Pk=((Ck=Pk||{})[Ck.Less=-1]="Less",
Ck[Ck.Equal=0]="Equal",Ck[Ck.Greater=1]="Greater",Ck)
;let Dk=Symbol("TabsContext");function Ik(e){let t=ug(Dk,null);if(null===t){
let t=new Error(`<${e} /> is missing a parent <TabGroup /> component.`)
;throw Error.captureStackTrace&&Error.captureStackTrace(t,Ik),t}return t}
let Mk=Symbol("TabsSSRContext"),Nk=Qg({name:"TabGroup",emits:{change:e=>!0},
props:{as:{type:[Object,String],default:"template"},selectedIndex:{
type:[Number],default:null},defaultIndex:{type:[Number],default:0},vertical:{
type:[Boolean],default:!1},manual:{type:[Boolean],default:!1}},inheritAttrs:!1,
setup(e,{slots:t,attrs:n,emit:r}){var o
;let a=bm(null!=(o=e.selectedIndex)?o:e.defaultIndex),i=bm([]),s=bm([]),l=Sy((()=>null!==e.selectedIndex)),c=Sy((()=>l.value?e.selectedIndex:a.value))
;function u(e){var t
;let n=Ew(d.tabs.value,sw),r=Ew(d.panels.value,sw),o=n.filter((e=>{var t
;return!(null!=(t=sw(e))&&t.hasAttribute("disabled"))}));if(e<0||e>n.length-1){
let t=lw(null===a.value?0:Math.sign(e-a.value),{[-1]:()=>1,
0:()=>lw(Math.sign(e),{[-1]:()=>0,0:()=>0,1:()=>1}),1:()=>0}),i=lw(t,{
0:()=>n.indexOf(o[0]),1:()=>n.indexOf(o[o.length-1])})
;-1!==i&&(a.value=i),d.tabs.value=n,d.panels.value=r}else{
let i=n.slice(0,e),s=[...n.slice(e),...i].find((e=>o.includes(e)));if(!s)return
;let l=null!=(t=n.indexOf(s))?t:d.selectedIndex.value
;-1===l&&(l=d.selectedIndex.value),a.value=l,d.tabs.value=n,d.panels.value=r}}
let d={selectedIndex:Sy((()=>{var t,n
;return null!=(n=null!=(t=a.value)?t:e.defaultIndex)?n:null})),
orientation:Sy((()=>e.vertical?"vertical":"horizontal")),
activation:Sy((()=>e.manual?"manual":"auto")),tabs:i,panels:s,
setSelectedIndex(e){c.value!==e&&r("change",e),l.value||u(e)},registerTab(e){
var t;if(i.value.includes(e))return;let n=i.value[a.value]
;if(i.value.push(e),i.value=Ew(i.value,sw),!l.value){
let e=null!=(t=i.value.indexOf(n))?t:a.value;-1!==e&&(a.value=e)}},
unregisterTab(e){let t=i.value.indexOf(e);-1!==t&&i.value.splice(t,1)},
registerPanel(e){s.value.includes(e)||(s.value.push(e),s.value=Ew(s.value,sw))},
unregisterPanel(e){let t=s.value.indexOf(e);-1!==t&&s.value.splice(t,1)}}
;cg(Dk,d);let p=bm({tabs:[],panels:[]}),h=bm(!1);iv((()=>{h.value=!0
})),cg(Mk,Sy((()=>h.value?null:p.value)));let f=Sy((()=>e.selectedIndex))
;return iv((()=>{mg([f],(()=>{var t
;return u(null!=(t=e.selectedIndex)?t:e.defaultIndex)}),{immediate:!0})
})),fg((()=>{if(!l.value||null==c.value||d.tabs.value.length<=0)return
;let e=Ew(d.tabs.value,sw)
;e.some(((e,t)=>sw(d.tabs.value[t])!==sw(e)))&&d.setSelectedIndex(e.findIndex((e=>sw(e)===sw(d.tabs.value[c.value]))))
})),()=>{let r={selectedIndex:a.value};return _y(Mb,[i.value.length<=0&&_y(Ak,{
onFocus:()=>{for(let e of i.value){let t=sw(e)
;if(0===(null==t?void 0:t.tabIndex))return t.focus(),!0}return!1}}),zw({
theirProps:{...n,
...Hw(e,["selectedIndex","defaultIndex","manual","vertical","onChange"])},
ourProps:{},slot:r,slots:t,attrs:n,name:"TabGroup"})])}}}),Rk=Qg({
name:"TabList",props:{as:{type:[Object,String],default:"div"}},
setup(e,{attrs:t,slots:n}){let r=Ik("TabList");return()=>{let o={
selectedIndex:r.selectedIndex.value};return zw({ourProps:{role:"tablist",
"aria-orientation":r.orientation.value},theirProps:e,slot:o,attrs:t,slots:n,
name:"TabList"})}}}),Lk=Qg({name:"Tab",props:{as:{type:[Object,String],
default:"button"},disabled:{type:[Boolean],default:!1},id:{type:String,
default:null}},setup(e,{attrs:t,slots:n,expose:r}){var o
;let a=null!=(o=e.id)?o:`headlessui-tabs-tab-${iw()}`,i=Ik("Tab"),s=bm(null);r({
el:s,$el:s}),iv((()=>i.registerTab(s))),uv((()=>i.unregisterTab(s)))
;let l=ug(Mk),c=Sy((()=>{if(l.value){let e=l.value.tabs.indexOf(a)
;return-1===e?l.value.tabs.push(a)-1:e}return-1})),u=Sy((()=>{
let e=i.tabs.value.indexOf(s);return-1===e?c.value:e
})),d=Sy((()=>u.value===i.selectedIndex.value));function p(e){var t;let n=e()
;if(n===bw.Success&&"auto"===i.activation.value){
let e=null==(t=pw(s))?void 0:t.activeElement,n=i.tabs.value.findIndex((t=>sw(t)===e))
;-1!==n&&i.setSelectedIndex(n)}return n}function h(e){
let t=i.tabs.value.map((e=>sw(e))).filter(Boolean)
;if(e.key===Jw.Space||e.key===Jw.Enter)return e.preventDefault(),
e.stopPropagation(),void i.setSelectedIndex(u.value);switch(e.key){case Jw.Home:
case Jw.PageUp:
return e.preventDefault(),e.stopPropagation(),p((()=>Aw(t,vw.First)))
;case Jw.End:case Jw.PageDown:
return e.preventDefault(),e.stopPropagation(),p((()=>Aw(t,vw.Last)))}
return p((()=>lw(i.orientation.value,{
vertical:()=>e.key===Jw.ArrowUp?Aw(t,vw.Previous|vw.WrapAround):e.key===Jw.ArrowDown?Aw(t,vw.Next|vw.WrapAround):bw.Error,
horizontal:()=>e.key===Jw.ArrowLeft?Aw(t,vw.Previous|vw.WrapAround):e.key===Jw.ArrowRight?Aw(t,vw.Next|vw.WrapAround):bw.Error
})))===bw.Success?e.preventDefault():void 0}let f=bm(!1);function m(){var t
;f.value||(f.value=!0,!e.disabled&&(null==(t=sw(s))||t.focus({preventScroll:!0
}),i.setSelectedIndex(u.value),tw((()=>{f.value=!1}))))}function g(e){
e.preventDefault()}let v=Nw(Sy((()=>({as:e.as,type:t.type}))),s);return()=>{
var r,o;let l={selected:d.value,disabled:null!=(r=e.disabled)&&r},{...c}=e
;return zw({ourProps:{ref:s,onKeydown:h,onMousedown:g,onClick:m,id:a,role:"tab",
type:v.value,"aria-controls":null==(o=sw(i.panels.value[u.value]))?void 0:o.id,
"aria-selected":d.value,tabIndex:d.value?0:-1,disabled:!!e.disabled||void 0},
theirProps:c,slot:l,attrs:t,slots:n,name:"Tab"})}}}),Bk=Qg({name:"TabPanels",
props:{as:{type:[Object,String],default:"div"}},setup(e,{slots:t,attrs:n}){
let r=Ik("TabPanels");return()=>{let o={selectedIndex:r.selectedIndex.value}
;return zw({theirProps:e,ourProps:{},slot:o,attrs:n,slots:t,name:"TabPanels"})}}
}),jk=Qg({name:"TabPanel",props:{as:{type:[Object,String],default:"div"},
static:{type:Boolean,default:!1},unmount:{type:Boolean,default:!0},id:{
type:String,default:null},tabIndex:{type:Number,default:0}},
setup(e,{attrs:t,slots:n,expose:r}){var o
;let a=null!=(o=e.id)?o:`headlessui-tabs-panel-${iw()}`,i=Ik("TabPanel"),s=bm(null)
;r({el:s,$el:s}),iv((()=>i.registerPanel(s))),uv((()=>i.unregisterPanel(s)))
;let l=ug(Mk),c=Sy((()=>{if(l.value){let e=l.value.panels.indexOf(a)
;return-1===e?l.value.panels.push(a)-1:e}return-1})),u=Sy((()=>{
let e=i.panels.value.indexOf(s);return-1===e?c.value:e
})),d=Sy((()=>u.value===i.selectedIndex.value));return()=>{var r;let o={
selected:d.value},{tabIndex:l,...c}=e,p={ref:s,id:a,role:"tabpanel",
"aria-labelledby":null==(r=sw(i.tabs.value[u.value]))?void 0:r.id,
tabIndex:d.value?l:-1};return d.value||!e.unmount||e.static?zw({ourProps:p,
theirProps:c,slot:o,attrs:t,slots:n,features:jw.Static|jw.RenderStrategy,
visible:d.value,name:"TabPanel"}):_y(qw,{as:"span","aria-hidden":!0,...p})}}})
;function Uk(e){var t,n,r=""
;if("string"==typeof e||"number"==typeof e)r+=e;else if("object"==typeof e)if(Array.isArray(e)){
var o=e.length;for(t=0;t<o;t++)e[t]&&(n=Uk(e[t]))&&(r&&(r+=" "),r+=n)
}else for(n in e)e[n]&&(r&&(r+=" "),r+=n);return r}function zk(){
for(var e,t,n=0,r="",o=arguments.length;n<o;n++)(e=arguments[n])&&(t=Uk(e))&&(r&&(r+=" "),
r+=t);return r}const Fk=e=>"boolean"==typeof e?`${e}`:0===e?"0":e,Zk=e=>{
const t=qk(e),{conflictingClassGroups:n,conflictingClassGroupModifiers:r}=e
;return{getClassGroupId:e=>{const n=e.split("-")
;return""===n[0]&&1!==n.length&&n.shift(),Qk(n,t)||Vk(e)},
getConflictingClassGroupIds:(e,t)=>{const o=n[e]||[]
;return t&&r[e]?[...o,...r[e]]:o}}},Qk=(e,t)=>{
if(0===e.length)return t.classGroupId
;const n=e[0],r=t.nextPart.get(n),o=r?Qk(e.slice(1),r):void 0;if(o)return o
;if(0===t.validators.length)return;const a=e.join("-")
;return t.validators.find((({validator:e})=>e(a)))?.classGroupId
},Hk=/^\[(.+)\]$/,Vk=e=>{if(Hk.test(e)){
const t=Hk.exec(e)[1],n=t?.substring(0,t.indexOf(":"))
;if(n)return"arbitrary.."+n}},qk=e=>{const{theme:t,prefix:n}=e,r={
nextPart:new Map,validators:[]}
;return Yk(Object.entries(e.classGroups),n).forEach((([e,n])=>{Wk(n,r,e,t)})),r
},Wk=(e,t,n,r)=>{e.forEach((e=>{if("string"!=typeof e){
if("function"==typeof e)return Gk(e)?void Wk(e(r),t,n,r):void t.validators.push({
validator:e,classGroupId:n});Object.entries(e).forEach((([e,o])=>{
Wk(o,Xk(t,e),n,r)}))}else{(""===e?t:Xk(t,e)).classGroupId=n}}))},Xk=(e,t)=>{
let n=e;return t.split("-").forEach((e=>{n.nextPart.has(e)||n.nextPart.set(e,{
nextPart:new Map,validators:[]}),n=n.nextPart.get(e)})),n
},Gk=e=>e.isThemeGetter,Yk=(e,t)=>t?e.map((([e,n])=>[e,n.map((e=>"string"==typeof e?t+e:"object"==typeof e?Object.fromEntries(Object.entries(e).map((([e,n])=>[t+e,n]))):e))])):e,Kk=e=>{
if(e<1)return{get:()=>{},set:()=>{}};let t=0,n=new Map,r=new Map
;const o=(o,a)=>{n.set(o,a),t++,t>e&&(t=0,r=n,n=new Map)};return{get(e){
let t=n.get(e);return void 0!==t?t:void 0!==(t=r.get(e))?(o(e,t),t):void 0},
set(e,t){n.has(e)?n.set(e,t):o(e,t)}}},Jk=e=>{
const{separator:t,experimentalParseClassName:n}=e,r=1===t.length,o=t[0],a=t.length,i=e=>{
const n=[];let i,s=0,l=0;for(let d=0;d<e.length;d++){let c=e[d];if(0===s){
if(c===o&&(r||e.slice(d,d+a)===t)){n.push(e.slice(l,d)),l=d+a;continue}
if("/"===c){i=d;continue}}"["===c?s++:"]"===c&&s--}
const c=0===n.length?e:e.substring(l),u=c.startsWith("!");return{modifiers:n,
hasImportantModifier:u,baseClassName:u?c.substring(1):c,
maybePostfixModifierPosition:i&&i>l?i-l:void 0}};return n?e=>n({className:e,
parseClassName:i}):i},eS=e=>{if(e.length<=1)return e;const t=[];let n=[]
;return e.forEach((e=>{"["===e[0]?(t.push(...n.sort(),e),n=[]):n.push(e)
})),t.push(...n.sort()),t},tS=/\s+/;function nS(){let e,t,n=0,r=""
;for(;n<arguments.length;)(e=arguments[n++])&&(t=rS(e))&&(r&&(r+=" "),r+=t)
;return r}const rS=e=>{if("string"==typeof e)return e;let t,n=""
;for(let r=0;r<e.length;r++)e[r]&&(t=rS(e[r]))&&(n&&(n+=" "),n+=t);return n}
;function oS(e,...t){let n,r,o,a=function(s){const l=t.reduce(((e,t)=>t(e)),e())
;return n=(e=>({cache:Kk(e.cacheSize),parseClassName:Jk(e),...Zk(e)
}))(l),r=n.cache.get,o=n.cache.set,a=i,i(s)};function i(e){const t=r(e)
;if(t)return t;const a=((e,t)=>{
const{parseClassName:n,getClassGroupId:r,getConflictingClassGroupIds:o}=t,a=[],i=e.trim().split(tS)
;let s="";for(let l=i.length-1;l>=0;l-=1){
const e=i[l],{modifiers:t,hasImportantModifier:c,baseClassName:u,maybePostfixModifierPosition:d}=n(e)
;let p=Boolean(d),h=r(p?u.substring(0,d):u);if(!h){if(!p){
s=e+(s.length>0?" "+s:s);continue}if(h=r(u),!h){s=e+(s.length>0?" "+s:s)
;continue}p=!1}const f=eS(t).join(":"),m=c?f+"!":f,g=m+h
;if(a.includes(g))continue;a.push(g);const v=o(h,p);for(let n=0;n<v.length;++n){
const e=v[n];a.push(m+e)}s=e+(s.length>0?" "+s:s)}return s})(e,n);return o(e,a),
a}return function(){return a(nS.apply(null,arguments))}}const aS=e=>{
const t=t=>t[e]||[];return t.isThemeGetter=!0,t
},iS=/^\[(?:([a-z-]+):)?(.+)\]$/i,sS=/^\d+\/\d+$/,lS=new Set(["px","full","screen"]),cS=/^(\d+(\.\d+)?)?(xs|sm|md|lg|xl)$/,uS=/\d+(%|px|r?em|[sdl]?v([hwib]|min|max)|pt|pc|in|cm|mm|cap|ch|ex|r?lh|cq(w|h|i|b|min|max))|\b(calc|min|max|clamp)\(.+\)|^0$/,dS=/^(rgba?|hsla?|hwb|(ok)?(lab|lch))\(.+\)$/,pS=/^(inset_)?-?((\d+)?\.?(\d+)[a-z]+|0)_-?((\d+)?\.?(\d+)[a-z]+|0)/,hS=/^(url|image|image-set|cross-fade|element|(repeating-)?(linear|radial|conic)-gradient)\(.+\)$/,fS=e=>gS(e)||lS.has(e)||sS.test(e),mS=e=>CS(e,"length",$S),gS=e=>Boolean(e)&&!Number.isNaN(Number(e)),vS=e=>CS(e,"number",gS),bS=e=>Boolean(e)&&Number.isInteger(Number(e)),yS=e=>e.endsWith("%")&&gS(e.slice(0,-1)),OS=e=>iS.test(e),wS=e=>cS.test(e),xS=new Set(["length","size","percentage"]),kS=e=>CS(e,xS,PS),SS=e=>CS(e,"position",PS),_S=new Set(["image","url"]),TS=e=>CS(e,_S,IS),ES=e=>CS(e,"",DS),AS=()=>!0,CS=(e,t,n)=>{
const r=iS.exec(e)
;return!!r&&(r[1]?"string"==typeof t?r[1]===t:t.has(r[1]):n(r[2]))
},$S=e=>uS.test(e)&&!dS.test(e),PS=()=>!1,DS=e=>pS.test(e),IS=e=>hS.test(e),MS=()=>{
const e=aS("colors"),t=aS("spacing"),n=aS("blur"),r=aS("brightness"),o=aS("borderColor"),a=aS("borderRadius"),i=aS("borderSpacing"),s=aS("borderWidth"),l=aS("contrast"),c=aS("grayscale"),u=aS("hueRotate"),d=aS("invert"),p=aS("gap"),h=aS("gradientColorStops"),f=aS("gradientColorStopPositions"),m=aS("inset"),g=aS("margin"),v=aS("opacity"),b=aS("padding"),y=aS("saturate"),O=aS("scale"),w=aS("sepia"),x=aS("skew"),k=aS("space"),S=aS("translate"),_=()=>["auto",OS,t],T=()=>[OS,t],E=()=>["",fS,mS],A=()=>["auto",gS,OS],C=()=>["","0",OS],$=()=>[gS,OS]
;return{cacheSize:500,separator:":",theme:{colors:[AS],spacing:[fS,mS],
blur:["none","",wS,OS],brightness:$(),borderColor:[e],
borderRadius:["none","","full",wS,OS],borderSpacing:T(),borderWidth:E(),
contrast:$(),grayscale:C(),hueRotate:$(),invert:C(),gap:T(),
gradientColorStops:[e],gradientColorStopPositions:[yS,mS],inset:_(),margin:_(),
opacity:$(),padding:T(),saturate:$(),scale:$(),sepia:C(),skew:$(),space:T(),
translate:T()},classGroups:{aspect:[{aspect:["auto","square","video",OS]}],
container:["container"],columns:[{columns:[wS]}],"break-after":[{
"break-after":["auto","avoid","all","avoid-page","page","left","right","column"]
}],"break-before":[{
"break-before":["auto","avoid","all","avoid-page","page","left","right","column"]
}],"break-inside":[{"break-inside":["auto","avoid","avoid-page","avoid-column"]
}],"box-decoration":[{"box-decoration":["slice","clone"]}],box:[{
box:["border","content"]}],
display:["block","inline-block","inline","flex","inline-flex","table","inline-table","table-caption","table-cell","table-column","table-column-group","table-footer-group","table-header-group","table-row-group","table-row","flow-root","grid","inline-grid","contents","list-item","hidden"],
float:[{float:["right","left","none","start","end"]}],clear:[{
clear:["left","right","both","none","start","end"]}],
isolation:["isolate","isolation-auto"],"object-fit":[{
object:["contain","cover","fill","none","scale-down"]}],"object-position":[{
object:["bottom","center","left","left-bottom","left-top","right","right-bottom","right-top","top",OS]
}],overflow:[{overflow:["auto","hidden","clip","visible","scroll"]}],
"overflow-x":[{"overflow-x":["auto","hidden","clip","visible","scroll"]}],
"overflow-y":[{"overflow-y":["auto","hidden","clip","visible","scroll"]}],
overscroll:[{overscroll:["auto","contain","none"]}],"overscroll-x":[{
"overscroll-x":["auto","contain","none"]}],"overscroll-y":[{
"overscroll-y":["auto","contain","none"]}],
position:["static","fixed","absolute","relative","sticky"],inset:[{inset:[m]}],
"inset-x":[{"inset-x":[m]}],"inset-y":[{"inset-y":[m]}],start:[{start:[m]}],
end:[{end:[m]}],top:[{top:[m]}],right:[{right:[m]}],bottom:[{bottom:[m]}],
left:[{left:[m]}],visibility:["visible","invisible","collapse"],z:[{
z:["auto",bS,OS]}],basis:[{basis:_()}],"flex-direction":[{
flex:["row","row-reverse","col","col-reverse"]}],"flex-wrap":[{
flex:["wrap","wrap-reverse","nowrap"]}],flex:[{
flex:["1","auto","initial","none",OS]}],grow:[{grow:C()}],shrink:[{shrink:C()}],
order:[{order:["first","last","none",bS,OS]}],"grid-cols":[{"grid-cols":[AS]}],
"col-start-end":[{col:["auto",{span:["full",bS,OS]},OS]}],"col-start":[{
"col-start":A()}],"col-end":[{"col-end":A()}],"grid-rows":[{"grid-rows":[AS]}],
"row-start-end":[{row:["auto",{span:[bS,OS]},OS]}],"row-start":[{"row-start":A()
}],"row-end":[{"row-end":A()}],"grid-flow":[{
"grid-flow":["row","col","dense","row-dense","col-dense"]}],"auto-cols":[{
"auto-cols":["auto","min","max","fr",OS]}],"auto-rows":[{
"auto-rows":["auto","min","max","fr",OS]}],gap:[{gap:[p]}],"gap-x":[{"gap-x":[p]
}],"gap-y":[{"gap-y":[p]}],"justify-content":[{
justify:["normal","start","end","center","between","around","evenly","stretch"]
}],"justify-items":[{"justify-items":["start","end","center","stretch"]}],
"justify-self":[{"justify-self":["auto","start","end","center","stretch"]}],
"align-content":[{
content:["normal","start","end","center","between","around","evenly","stretch","baseline"]
}],"align-items":[{items:["start","end","center","baseline","stretch"]}],
"align-self":[{self:["auto","start","end","center","stretch","baseline"]}],
"place-content":[{
"place-content":["start","end","center","between","around","evenly","stretch","baseline"]
}],"place-items":[{"place-items":["start","end","center","baseline","stretch"]
}],"place-self":[{"place-self":["auto","start","end","center","stretch"]}],p:[{
p:[b]}],px:[{px:[b]}],py:[{py:[b]}],ps:[{ps:[b]}],pe:[{pe:[b]}],pt:[{pt:[b]}],
pr:[{pr:[b]}],pb:[{pb:[b]}],pl:[{pl:[b]}],m:[{m:[g]}],mx:[{mx:[g]}],my:[{my:[g]
}],ms:[{ms:[g]}],me:[{me:[g]}],mt:[{mt:[g]}],mr:[{mr:[g]}],mb:[{mb:[g]}],ml:[{
ml:[g]}],"space-x":[{"space-x":[k]}],"space-x-reverse":["space-x-reverse"],
"space-y":[{"space-y":[k]}],"space-y-reverse":["space-y-reverse"],w:[{
w:["auto","min","max","fit","svw","lvw","dvw",OS,t]}],"min-w":[{
"min-w":[OS,t,"min","max","fit"]}],"max-w":[{
"max-w":[OS,t,"none","full","min","max","fit","prose",{screen:[wS]},wS]}],h:[{
h:[OS,t,"auto","min","max","fit","svh","lvh","dvh"]}],"min-h":[{
"min-h":[OS,t,"min","max","fit","svh","lvh","dvh"]}],"max-h":[{
"max-h":[OS,t,"min","max","fit","svh","lvh","dvh"]}],size:[{
size:[OS,t,"auto","min","max","fit"]}],"font-size":[{text:["base",wS,mS]}],
"font-smoothing":["antialiased","subpixel-antialiased"],
"font-style":["italic","not-italic"],"font-weight":[{
font:["thin","extralight","light","normal","medium","semibold","bold","extrabold","black",vS]
}],"font-family":[{font:[AS]}],"fvn-normal":["normal-nums"],
"fvn-ordinal":["ordinal"],"fvn-slashed-zero":["slashed-zero"],
"fvn-figure":["lining-nums","oldstyle-nums"],
"fvn-spacing":["proportional-nums","tabular-nums"],
"fvn-fraction":["diagonal-fractions","stacked-fractions"],tracking:[{
tracking:["tighter","tight","normal","wide","wider","widest",OS]}],
"line-clamp":[{"line-clamp":["none",gS,vS]}],leading:[{
leading:["none","tight","snug","normal","relaxed","loose",fS,OS]}],
"list-image":[{"list-image":["none",OS]}],"list-style-type":[{
list:["none","disc","decimal",OS]}],"list-style-position":[{
list:["inside","outside"]}],"placeholder-color":[{placeholder:[e]}],
"placeholder-opacity":[{"placeholder-opacity":[v]}],"text-alignment":[{
text:["left","center","right","justify","start","end"]}],"text-color":[{text:[e]
}],"text-opacity":[{"text-opacity":[v]}],
"text-decoration":["underline","overline","line-through","no-underline"],
"text-decoration-style":[{
decoration:["solid","dashed","dotted","double","none","wavy"]}],
"text-decoration-thickness":[{decoration:["auto","from-font",fS,mS]}],
"underline-offset":[{"underline-offset":["auto",fS,OS]}],
"text-decoration-color":[{decoration:[e]}],
"text-transform":["uppercase","lowercase","capitalize","normal-case"],
"text-overflow":["truncate","text-ellipsis","text-clip"],"text-wrap":[{
text:["wrap","nowrap","balance","pretty"]}],indent:[{indent:T()}],
"vertical-align":[{
align:["baseline","top","middle","bottom","text-top","text-bottom","sub","super",OS]
}],whitespace:[{
whitespace:["normal","nowrap","pre","pre-line","pre-wrap","break-spaces"]}],
break:[{break:["normal","words","all","keep"]}],hyphens:[{
hyphens:["none","manual","auto"]}],content:[{content:["none",OS]}],
"bg-attachment":[{bg:["fixed","local","scroll"]}],"bg-clip":[{
"bg-clip":["border","padding","content","text"]}],"bg-opacity":[{
"bg-opacity":[v]}],"bg-origin":[{"bg-origin":["border","padding","content"]}],
"bg-position":[{
bg:["bottom","center","left","left-bottom","left-top","right","right-bottom","right-top","top",SS]
}],"bg-repeat":[{bg:["no-repeat",{repeat:["","x","y","round","space"]}]}],
"bg-size":[{bg:["auto","cover","contain",kS]}],"bg-image":[{bg:["none",{
"gradient-to":["t","tr","r","br","b","bl","l","tl"]},TS]}],"bg-color":[{bg:[e]
}],"gradient-from-pos":[{from:[f]}],"gradient-via-pos":[{via:[f]}],
"gradient-to-pos":[{to:[f]}],"gradient-from":[{from:[h]}],"gradient-via":[{
via:[h]}],"gradient-to":[{to:[h]}],rounded:[{rounded:[a]}],"rounded-s":[{
"rounded-s":[a]}],"rounded-e":[{"rounded-e":[a]}],"rounded-t":[{"rounded-t":[a]
}],"rounded-r":[{"rounded-r":[a]}],"rounded-b":[{"rounded-b":[a]}],
"rounded-l":[{"rounded-l":[a]}],"rounded-ss":[{"rounded-ss":[a]}],
"rounded-se":[{"rounded-se":[a]}],"rounded-ee":[{"rounded-ee":[a]}],
"rounded-es":[{"rounded-es":[a]}],"rounded-tl":[{"rounded-tl":[a]}],
"rounded-tr":[{"rounded-tr":[a]}],"rounded-br":[{"rounded-br":[a]}],
"rounded-bl":[{"rounded-bl":[a]}],"border-w":[{border:[s]}],"border-w-x":[{
"border-x":[s]}],"border-w-y":[{"border-y":[s]}],"border-w-s":[{"border-s":[s]
}],"border-w-e":[{"border-e":[s]}],"border-w-t":[{"border-t":[s]}],
"border-w-r":[{"border-r":[s]}],"border-w-b":[{"border-b":[s]}],"border-w-l":[{
"border-l":[s]}],"border-opacity":[{"border-opacity":[v]}],"border-style":[{
border:["solid","dashed","dotted","double","none","hidden"]}],"divide-x":[{
"divide-x":[s]}],"divide-x-reverse":["divide-x-reverse"],"divide-y":[{
"divide-y":[s]}],"divide-y-reverse":["divide-y-reverse"],"divide-opacity":[{
"divide-opacity":[v]}],"divide-style":[{
divide:["solid","dashed","dotted","double","none"]}],"border-color":[{border:[o]
}],"border-color-x":[{"border-x":[o]}],"border-color-y":[{"border-y":[o]}],
"border-color-s":[{"border-s":[o]}],"border-color-e":[{"border-e":[o]}],
"border-color-t":[{"border-t":[o]}],"border-color-r":[{"border-r":[o]}],
"border-color-b":[{"border-b":[o]}],"border-color-l":[{"border-l":[o]}],
"divide-color":[{divide:[o]}],"outline-style":[{
outline:["","solid","dashed","dotted","double","none"]}],"outline-offset":[{
"outline-offset":[fS,OS]}],"outline-w":[{outline:[fS,mS]}],"outline-color":[{
outline:[e]}],"ring-w":[{ring:E()}],"ring-w-inset":["ring-inset"],
"ring-color":[{ring:[e]}],"ring-opacity":[{"ring-opacity":[v]}],
"ring-offset-w":[{"ring-offset":[fS,mS]}],"ring-offset-color":[{
"ring-offset":[e]}],shadow:[{shadow:["","inner","none",wS,ES]}],
"shadow-color":[{shadow:[AS]}],opacity:[{opacity:[v]}],"mix-blend":[{
"mix-blend":["normal","multiply","screen","overlay","darken","lighten","color-dodge","color-burn","hard-light","soft-light","difference","exclusion","hue","saturation","color","luminosity","plus-lighter","plus-darker"]
}],"bg-blend":[{
"bg-blend":["normal","multiply","screen","overlay","darken","lighten","color-dodge","color-burn","hard-light","soft-light","difference","exclusion","hue","saturation","color","luminosity"]
}],filter:[{filter:["","none"]}],blur:[{blur:[n]}],brightness:[{brightness:[r]
}],contrast:[{contrast:[l]}],"drop-shadow":[{"drop-shadow":["","none",wS,OS]}],
grayscale:[{grayscale:[c]}],"hue-rotate":[{"hue-rotate":[u]}],invert:[{
invert:[d]}],saturate:[{saturate:[y]}],sepia:[{sepia:[w]}],"backdrop-filter":[{
"backdrop-filter":["","none"]}],"backdrop-blur":[{"backdrop-blur":[n]}],
"backdrop-brightness":[{"backdrop-brightness":[r]}],"backdrop-contrast":[{
"backdrop-contrast":[l]}],"backdrop-grayscale":[{"backdrop-grayscale":[c]}],
"backdrop-hue-rotate":[{"backdrop-hue-rotate":[u]}],"backdrop-invert":[{
"backdrop-invert":[d]}],"backdrop-opacity":[{"backdrop-opacity":[v]}],
"backdrop-saturate":[{"backdrop-saturate":[y]}],"backdrop-sepia":[{
"backdrop-sepia":[w]}],"border-collapse":[{border:["collapse","separate"]}],
"border-spacing":[{"border-spacing":[i]}],"border-spacing-x":[{
"border-spacing-x":[i]}],"border-spacing-y":[{"border-spacing-y":[i]}],
"table-layout":[{table:["auto","fixed"]}],caption:[{caption:["top","bottom"]}],
transition:[{
transition:["none","all","","colors","opacity","shadow","transform",OS]}],
duration:[{duration:$()}],ease:[{ease:["linear","in","out","in-out",OS]}],
delay:[{delay:$()}],animate:[{animate:["none","spin","ping","pulse","bounce",OS]
}],transform:[{transform:["","gpu","none"]}],scale:[{scale:[O]}],"scale-x":[{
"scale-x":[O]}],"scale-y":[{"scale-y":[O]}],rotate:[{rotate:[bS,OS]}],
"translate-x":[{"translate-x":[S]}],"translate-y":[{"translate-y":[S]}],
"skew-x":[{"skew-x":[x]}],"skew-y":[{"skew-y":[x]}],"transform-origin":[{
origin:["center","top","top-right","right","bottom-right","bottom","bottom-left","left","top-left",OS]
}],accent:[{accent:["auto",e]}],appearance:[{appearance:["none","auto"]}],
cursor:[{
cursor:["auto","default","pointer","wait","text","move","help","not-allowed","none","context-menu","progress","cell","crosshair","vertical-text","alias","copy","no-drop","grab","grabbing","all-scroll","col-resize","row-resize","n-resize","e-resize","s-resize","w-resize","ne-resize","nw-resize","se-resize","sw-resize","ew-resize","ns-resize","nesw-resize","nwse-resize","zoom-in","zoom-out",OS]
}],"caret-color":[{caret:[e]}],"pointer-events":[{
"pointer-events":["none","auto"]}],resize:[{resize:["none","y","x",""]}],
"scroll-behavior":[{scroll:["auto","smooth"]}],"scroll-m":[{"scroll-m":T()}],
"scroll-mx":[{"scroll-mx":T()}],"scroll-my":[{"scroll-my":T()}],"scroll-ms":[{
"scroll-ms":T()}],"scroll-me":[{"scroll-me":T()}],"scroll-mt":[{"scroll-mt":T()
}],"scroll-mr":[{"scroll-mr":T()}],"scroll-mb":[{"scroll-mb":T()}],
"scroll-ml":[{"scroll-ml":T()}],"scroll-p":[{"scroll-p":T()}],"scroll-px":[{
"scroll-px":T()}],"scroll-py":[{"scroll-py":T()}],"scroll-ps":[{"scroll-ps":T()
}],"scroll-pe":[{"scroll-pe":T()}],"scroll-pt":[{"scroll-pt":T()}],
"scroll-pr":[{"scroll-pr":T()}],"scroll-pb":[{"scroll-pb":T()}],"scroll-pl":[{
"scroll-pl":T()}],"snap-align":[{snap:["start","end","center","align-none"]}],
"snap-stop":[{snap:["normal","always"]}],"snap-type":[{
snap:["none","x","y","both"]}],"snap-strictness":[{
snap:["mandatory","proximity"]}],touch:[{touch:["auto","none","manipulation"]}],
"touch-x":[{"touch-pan":["x","left","right"]}],"touch-y":[{
"touch-pan":["y","up","down"]}],"touch-pz":["touch-pinch-zoom"],select:[{
select:["none","text","all","auto"]}],"will-change":[{
"will-change":["auto","scroll","contents","transform",OS]}],fill:[{
fill:[e,"none"]}],"stroke-w":[{stroke:[fS,mS,vS]}],stroke:[{stroke:[e,"none"]}],
sr:["sr-only","not-sr-only"],"forced-color-adjust":[{
"forced-color-adjust":["auto","none"]}]},conflictingClassGroups:{
overflow:["overflow-x","overflow-y"],overscroll:["overscroll-x","overscroll-y"],
inset:["inset-x","inset-y","start","end","top","right","bottom","left"],
"inset-x":["right","left"],"inset-y":["top","bottom"],
flex:["basis","grow","shrink"],gap:["gap-x","gap-y"],
p:["px","py","ps","pe","pt","pr","pb","pl"],px:["pr","pl"],py:["pt","pb"],
m:["mx","my","ms","me","mt","mr","mb","ml"],mx:["mr","ml"],my:["mt","mb"],
size:["w","h"],"font-size":["leading"],
"fvn-normal":["fvn-ordinal","fvn-slashed-zero","fvn-figure","fvn-spacing","fvn-fraction"],
"fvn-ordinal":["fvn-normal"],"fvn-slashed-zero":["fvn-normal"],
"fvn-figure":["fvn-normal"],"fvn-spacing":["fvn-normal"],
"fvn-fraction":["fvn-normal"],"line-clamp":["display","overflow"],
rounded:["rounded-s","rounded-e","rounded-t","rounded-r","rounded-b","rounded-l","rounded-ss","rounded-se","rounded-ee","rounded-es","rounded-tl","rounded-tr","rounded-br","rounded-bl"],
"rounded-s":["rounded-ss","rounded-es"],"rounded-e":["rounded-se","rounded-ee"],
"rounded-t":["rounded-tl","rounded-tr"],"rounded-r":["rounded-tr","rounded-br"],
"rounded-b":["rounded-br","rounded-bl"],"rounded-l":["rounded-tl","rounded-bl"],
"border-spacing":["border-spacing-x","border-spacing-y"],
"border-w":["border-w-s","border-w-e","border-w-t","border-w-r","border-w-b","border-w-l"],
"border-w-x":["border-w-r","border-w-l"],
"border-w-y":["border-w-t","border-w-b"],
"border-color":["border-color-s","border-color-e","border-color-t","border-color-r","border-color-b","border-color-l"],
"border-color-x":["border-color-r","border-color-l"],
"border-color-y":["border-color-t","border-color-b"],
"scroll-m":["scroll-mx","scroll-my","scroll-ms","scroll-me","scroll-mt","scroll-mr","scroll-mb","scroll-ml"],
"scroll-mx":["scroll-mr","scroll-ml"],"scroll-my":["scroll-mt","scroll-mb"],
"scroll-p":["scroll-px","scroll-py","scroll-ps","scroll-pe","scroll-pt","scroll-pr","scroll-pb","scroll-pl"],
"scroll-px":["scroll-pr","scroll-pl"],"scroll-py":["scroll-pt","scroll-pb"],
touch:["touch-x","touch-y","touch-pz"],"touch-x":["touch"],"touch-y":["touch"],
"touch-pz":["touch"]},conflictingClassGroupModifiers:{"font-size":["leading"]}}
},NS=(e,t,n)=>{void 0!==n&&(e[t]=n)},RS=(e,t)=>{
if(t)for(const n in t)NS(e,n,t[n])},LS=(e,t)=>{if(t)for(const n in t){
const r=t[n];void 0!==r&&(e[n]=(e[n]||[]).concat(r))}
},BS=((e,...t)=>"function"==typeof e?oS(MS,e,...t):oS((()=>((e,{cacheSize:t,prefix:n,separator:r,experimentalParseClassName:o,extend:a={},override:i={}})=>{
NS(e,"cacheSize",t),
NS(e,"prefix",n),NS(e,"separator",r),NS(e,"experimentalParseClassName",o)
;for(const s in i)RS(e[s],i[s]);for(const s in a)LS(e[s],a[s]);return e
})(MS(),e)),...t))({extend:{classGroups:{"font-size":["text-3xs","text-xxs"],
"font-weight":["font-sidebar","font-sidebar-active"]}}}),{cva:jS,cx:US}=(e=>{
const t=function(){
for(var t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];var o,a
;return void 0!==(null==e||null===(o=e.hooks)||void 0===o?void 0:o["cx:done"])?null==e?void 0:e.hooks["cx:done"](zk(n)):void 0!==(null==e||null===(a=e.hooks)||void 0===a?void 0:a.onComplete)?null==e?void 0:e.hooks.onComplete(zk(n)):zk(n)
};return{compose:function(){
for(var e=arguments.length,n=new Array(e),r=0;r<e;r++)n[r]=arguments[r]
;return e=>{const r=Object.fromEntries(Object.entries(e||{}).filter((e=>{
let[t]=e;return!["class","className"].includes(t)})))
;return t(n.map((e=>e(r))),null==e?void 0:e.class,null==e?void 0:e.className)}},
cva:e=>n=>{var r
;if(null==(null==e?void 0:e.variants))return t(null==e?void 0:e.base,null==n?void 0:n.class,null==n?void 0:n.className)
;const{variants:o,defaultVariants:a}=e,i=Object.keys(o).map((e=>{
const t=null==n?void 0:n[e],r=null==a?void 0:a[e],i=Fk(t)||Fk(r);return o[e][i]
})),s={...a,...n&&Object.entries(n).reduce(((e,t)=>{let[n,r]=t
;return void 0===r?e:{...e,[n]:r}}),{})
},l=null==e||null===(r=e.compoundVariants)||void 0===r?void 0:r.reduce(((e,t)=>{
let{class:n,className:r,...o}=t;return Object.entries(o).every((e=>{let[t,n]=e
;const r=s[t];return Array.isArray(n)?n.includes(r):r===n}))?[...e,n,r]:e}),[])
;return t(null==e?void 0:e.base,i,l,null==n?void 0:n.class,null==n?void 0:n.className)
},cx:t}})({hooks:{onComplete:e=>BS(e)}});function zS(){const e=Pv(),t=Sy((()=>{
const{class:t,style:n,...r}=e;return{class:t||"",style:n,rest:r}}));return{
cx:function(...e){return{class:US(...e,t.value.class),style:t.value.style,
...t.value.rest}},stylingAttrsCx:function(...e){return{
class:US(...e,t.value.class),style:t.value.style}},
otherAttrs:Sy((()=>t.value.rest))}}const FS={
solid:["scalar-button-solid","bg-b-btn text-c-btn focus-visible:border-c-btn active:bg-b-btn hover:bg-h-btn outline-offset-1"],
outlined:["scalar-button-outlined","active:bg-btn-1 border border-solid border-border bg-b-1 text-c-1 hover:bg-b-2"],
ghost:["scalar-button-ghost","bg-transparent text-c-3 active:text-c-1 hover:text-c-1"],
gradient:["scalar-button-gradient","border bg-b-1.5 bg-linear-to-b from-b-1 to-b-2 hover:bg-linear-to-t","dark:bg-linear-to-t dark:hover:bg-linear-to-b"],
danger:["scalar-button-danger","bg-c-danger text-white active:brightness-90 hover:brightness-90"]
},ZS={class:"circular-loader"},QS=Qg({inheritAttrs:!1,__name:"ScalarLoading",
props:{loader:{},size:{}},setup(e){const{cx:t}=zS(),n=jS({variants:{size:{
xs:"size-3",sm:"size-3.5",md:"size-4",lg:"size-5",xl:"size-6","2xl":"size-8",
"3xl":"size-10",full:"size-full"}},defaultVariants:{size:"full"}})
;return(r,o)=>e.loader?(Ub(),Qb("div",Mh(iy({key:0
},xm(t)("loader-wrapper",xm(n)({size:e.size})))),[(Ub(),Qb("svg",{
class:Ih(["svg-loader",{"icon-is-valid":e.loader.isValid,
"icon-is-invalid":e.loader.isInvalid}]),viewBox:"0 0 100 100",
xmlns:"http://www.w3.org/2000/svg","xmlns:xlink":"http://www.w3.org/1999/xlink"
},[o[0]||(o[0]=ty('<path class="svg-path svg-check-mark" d="m 0 60 l 30 30 l 70 -80" data-v-27df5cd8></path><path class="svg-path svg-x-mark" d="m 50 50 l 40 -40" data-v-27df5cd8></path><path class="svg-path svg-x-mark" d="m 50 50 l 40 40" data-v-27df5cd8></path><path class="svg-path svg-x-mark" d="m 50 50 l -40 -40" data-v-27df5cd8></path><path class="svg-path svg-x-mark" d="m 50 50 l -40 40" data-v-27df5cd8></path>',5)),Gb("g",ZS,[Gb("circle",{
class:Ih(["loader-path",{"loader-path-off":!e.loader.isLoading}]),cx:"50",
cy:"50",fill:"none",r:"20","stroke-width":"3"},null,2)])],2))],16)):ny("",!0)}
}),HS=(e,t)=>{const n=e.__vccOpts||e;for(const[r,o]of t)n[r]=o;return n
},VS=HS(QS,[["__scopeId","data-v-27df5cd8"]]),qS={key:3,class:"centered"
},WS=Qg({inheritAttrs:!1,__name:"ScalarButton",props:{is:{default:"button"},
variant:{default:"solid"},size:{default:"md"},disabled:{type:Boolean},icon:{
type:[Object,Function]},loader:{}},setup(e){const t=jS({
base:"scalar-button flex cursor-pointer items-center justify-center rounded font-medium -outline-offset-1",
variants:{disabled:{true:"bg-b-2 text-color-3 shadow-none"},size:{
xs:"px-2 py-1 text-xs leading-5",sm:"px-3.5 py-2 text-sm leading-5",
md:"px-5 py-3 text-sm leading-5"},variant:FS},compoundVariants:[{disabled:!0,
variant:["solid","outlined","ghost","gradient","danger"],
class:"bg-b-2 text-c-3 shadow-none hover:bg-b-[_] cursor-not-allowed active:bg-b-[_] hover:text-c-[_] active:text-c-[_]"
},{disabled:!0,variant:["gradient"],
class:"to-b-1.5 bg-linear-to-b hover:bg-linear-to-b dark:hover:bg-linear-to-t"}]
}),n=jS({base:"shrink-0",variants:{size:{xs:"size-2.75 -ml-0.25 mr-1",
sm:"size-3.25 -ml-0.5 mr-1.5",md:"size-3.5 -ml-0.5 mr-1.5"}}}),r=jS({variants:{
size:{xs:"size-4",sm:"size-5",md:"size-6"}}}),{cx:o}=zS()
;return(a,i)=>(Ub(),Hb(bv(e.is),iy({"aria-disabled":e.disabled||void 0,
type:"button"===e.is?"button":void 0},xm(o)(xm(t)({disabled:e.disabled,
size:e.size,variant:e.variant}),{relative:e.loader?.isActive})),{
default:ig((()=>[a.$slots.icon||e.icon?(Ub(),Qb("div",{key:0,class:Ih([xm(n)({
size:e.size}),{invisible:e.loader?.isActive}])
},[kv(a.$slots,"icon",{},(()=>[(Ub(),Hb(bv(e.icon),{class:"size-full"
}))]))],2)):ny("",!0),e.loader?(Ub(),Qb("span",{key:1,class:Ih({
invisible:e.loader?.isActive})
},[kv(a.$slots,"default")],2)):kv(a.$slots,"default",{key:2
}),e.loader?.isActive?(Ub(),Qb("div",qS,[Yb(xm(VS),{class:Ih(xm(r)({size:e.size
})),loader:e.loader},null,8,["class","loader"])])):ny("",!0)])),_:3
},16,["aria-disabled","type"]))}}),XS=Symbol(),GS=Qg({inheritAttrs:!1,
__name:"ScalarCard",props:{label:{}},setup(e){const{id:t}=(()=>{const e=bm()
;return cg(XS,e),{id:e}})(),n=Sy((()=>e.label?{"aria-label":e.label}:t.value?{
"aria-labelledby":t.value}:{})),{cx:r}=zS();return(e,t)=>(Ub(),Qb("div",iy({
role:"group"},{...n.value,
...xm(r)("scalar-card bg-b-2 flex flex-col divide-y rounded-lg border *:first:rounded-t-[inherit] *:last:rounded-b-[inherit]")
}),[kv(e.$slots,"default")],16))}}),YS=Qg({inheritAttrs:!1,
__name:"ScalarCardSection",setup(e){const{cx:t}=zS()
;return(e,n)=>(Ub(),Qb("div",Mh(Kb(xm(t)("scalar-card-content flex overflow-auto"))),[kv(e.$slots,"default")],16))
}}),KS=Qg({inheritAttrs:!1,__name:"ScalarCardFooter",setup(e){const{cx:t}=zS()
;return(e,n)=>(Ub(),Hb(YS,Mh(Kb(xm(t)("scalar-card-footer"))),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}}),JS=["id"],e_={key:0,
class:"flex"},t_=Qg({inheritAttrs:!1,__name:"ScalarCardHeader",setup(e){
const{cx:t}=zS(),n=Hg();return(e=>{const t=ug(XS,void 0);t&&(t.value=e)
})(n),(e,r)=>(Ub(),
Hb(YS,Mh(Kb(xm(t)("scalar-card-header leading-[22px] font-medium py-[6.75px] px-3 shrink-0"))),{
default:ig((()=>[Gb("div",{id:xm(n),
class:"scalar-card-header-title min-w-0 flex-1 truncate"
},[kv(e.$slots,"default")],8,JS),e.$slots.actions?(Ub(),
Qb("div",e_,[kv(e.$slots,"actions")])):ny("",!0)])),_:3},16))}})
;function n_(e={}){const t=Sy((()=>e.label?{"aria-label":e.label}:{
"aria-hidden":!0,role:"presentation"}));return{bind:Sy((()=>({width:"1em",
height:"1em",...t.value}))),weight:Sy((()=>e.weight??"regular"))}}const r_={
key:0},o_={key:1},a_={key:2},i_={key:3},s_={key:4},l_={key:5},c_=Qg({
name:"ScalarIconArrowUpRight",props:{label:{},weight:{}},setup(e){
const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",r_,[...t[0]||(t[0]=[Gb("path",{
d:"M204,64V168a12,12,0,0,1-24,0V93L72.49,200.49a12,12,0,0,1-17-17L163,76H88a12,12,0,0,1,0-24H192A12,12,0,0,1,204,64Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",o_,[...t[1]||(t[1]=[Gb("path",{
d:"M192,64V168L88,64Z",opacity:"0.2"},null,-1),Gb("path",{
d:"M192,56H88a8,8,0,0,0-5.66,13.66L128.69,116,58.34,186.34a8,8,0,0,0,11.32,11.32L140,127.31l46.34,46.35A8,8,0,0,0,200,168V64A8,8,0,0,0,192,56Zm-8,92.69-38.34-38.34h0L107.31,72H184Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",a_,[...t[2]||(t[2]=[Gb("path",{
d:"M200,64V168a8,8,0,0,1-13.66,5.66L140,127.31,69.66,197.66a8,8,0,0,1-11.32-11.32L128.69,116,82.34,69.66A8,8,0,0,1,88,56H192A8,8,0,0,1,200,64Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",i_,[...t[3]||(t[3]=[Gb("path",{
d:"M198,64V168a6,6,0,0,1-12,0V78.48L68.24,196.24a6,6,0,0,1-8.48-8.48L177.52,70H88a6,6,0,0,1,0-12H192A6,6,0,0,1,198,64Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",s_,[...t[4]||(t[4]=[Gb("path",{
d:"M200,64V168a8,8,0,0,1-16,0V83.31L69.66,197.66a8,8,0,0,1-11.32-11.32L172.69,72H88a8,8,0,0,1,0-16H192A8,8,0,0,1,200,64Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",l_,[...t[5]||(t[5]=[Gb("path",{
d:"M196,64V168a4,4,0,0,1-8,0V73.66L66.83,194.83a4,4,0,0,1-5.66-5.66L182.34,68H88a4,4,0,0,1,0-8H192A4,4,0,0,1,196,64Z"
},null,-1)])])):ny("",!0)],16))}}),u_={key:0},d_={key:1},p_={key:2},h_={key:3
},f_={key:4},m_={key:5},g_=Qg({name:"ScalarIconBook",props:{label:{},weight:{}},
setup(e){const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",u_,[...t[0]||(t[0]=[Gb("path",{
d:"M208,20H72A36,36,0,0,0,36,56V224a12,12,0,0,0,12,12H192a12,12,0,0,0,0-24H60v-4a12,12,0,0,1,12-12H208a12,12,0,0,0,12-12V32A12,12,0,0,0,208,20ZM196,172H72a35.59,35.59,0,0,0-12,2.06V56A12,12,0,0,1,72,44H196Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",d_,[...t[1]||(t[1]=[Gb("path",{
d:"M208,32V192H72a24,24,0,0,0-24,24V56A24,24,0,0,1,72,32Z",opacity:"0.2"
},null,-1),Gb("path",{
d:"M208,24H72A32,32,0,0,0,40,56V224a8,8,0,0,0,8,8H192a8,8,0,0,0,0-16H56a16,16,0,0,1,16-16H208a8,8,0,0,0,8-8V32A8,8,0,0,0,208,24Zm-8,160H72a31.82,31.82,0,0,0-16,4.29V56A16,16,0,0,1,72,40H200Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",p_,[...t[2]||(t[2]=[Gb("path",{
d:"M216,32V192a8,8,0,0,1-8,8H72a16,16,0,0,0-16,16H192a8,8,0,0,1,0,16H48a8,8,0,0,1-8-8V56A32,32,0,0,1,72,24H208A8,8,0,0,1,216,32Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",h_,[...t[3]||(t[3]=[Gb("path",{
d:"M208,26H72A30,30,0,0,0,42,56V224a6,6,0,0,0,6,6H192a6,6,0,0,0,0-12H54v-2a18,18,0,0,1,18-18H208a6,6,0,0,0,6-6V32A6,6,0,0,0,208,26Zm-6,160H72a29.87,29.87,0,0,0-18,6V56A18,18,0,0,1,72,38H202Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",f_,[...t[4]||(t[4]=[Gb("path",{
d:"M208,24H72A32,32,0,0,0,40,56V224a8,8,0,0,0,8,8H192a8,8,0,0,0,0-16H56a16,16,0,0,1,16-16H208a8,8,0,0,0,8-8V32A8,8,0,0,0,208,24Zm-8,160H72a31.82,31.82,0,0,0-16,4.29V56A16,16,0,0,1,72,40H200Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",m_,[...t[5]||(t[5]=[Gb("path",{
d:"M208,28H72A28,28,0,0,0,44,56V224a4,4,0,0,0,4,4H192a4,4,0,0,0,0-8H52v-4a20,20,0,0,1,20-20H208a4,4,0,0,0,4-4V32A4,4,0,0,0,208,28Zm-4,160H72a27.94,27.94,0,0,0-20,8.42V56A20,20,0,0,1,72,36H204Z"
},null,-1)])])):ny("",!0)],16))}}),v_={key:0},b_={key:1},y_={key:2},O_={key:3
},w_={key:4},x_={key:5},k_=Qg({name:"ScalarIconBookOpenText",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",v_,[...t[0]||(t[0]=[Gb("path",{
d:"M232,44H160a43.86,43.86,0,0,0-32,13.85A43.86,43.86,0,0,0,96,44H24A12,12,0,0,0,12,56V200a12,12,0,0,0,12,12H96a20,20,0,0,1,20,20,12,12,0,0,0,24,0,20,20,0,0,1,20-20h72a12,12,0,0,0,12-12V56A12,12,0,0,0,232,44ZM96,188H36V68H96a20,20,0,0,1,20,20V192.81A43.79,43.79,0,0,0,96,188Zm124,0H160a43.71,43.71,0,0,0-20,4.83V88a20,20,0,0,1,20-20h60ZM164,96h32a12,12,0,0,1,0,24H164a12,12,0,0,1,0-24Zm44,52a12,12,0,0,1-12,12H164a12,12,0,0,1,0-24h32A12,12,0,0,1,208,148Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",b_,[...t[1]||(t[1]=[Gb("path",{
d:"M232,56V200H160a32,32,0,0,0-32,32V88a32,32,0,0,1,32-32Z",opacity:"0.2"
},null,-1),Gb("path",{
d:"M232,48H160a40,40,0,0,0-32,16A40,40,0,0,0,96,48H24a8,8,0,0,0-8,8V200a8,8,0,0,0,8,8H96a24,24,0,0,1,24,24,8,8,0,0,0,16,0,24,24,0,0,1,24-24h72a8,8,0,0,0,8-8V56A8,8,0,0,0,232,48ZM96,192H32V64H96a24,24,0,0,1,24,24V200A39.81,39.81,0,0,0,96,192Zm128,0H160a39.81,39.81,0,0,0-24,8V88a24,24,0,0,1,24-24h64ZM160,88h40a8,8,0,0,1,0,16H160a8,8,0,0,1,0-16Zm48,40a8,8,0,0,1-8,8H160a8,8,0,0,1,0-16h40A8,8,0,0,1,208,128Zm0,32a8,8,0,0,1-8,8H160a8,8,0,0,1,0-16h40A8,8,0,0,1,208,160Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",y_,[...t[2]||(t[2]=[Gb("path",{
d:"M232,48H168a32,32,0,0,0-32,32v87.73a8.17,8.17,0,0,1-7.47,8.25,8,8,0,0,1-8.53-8V80A32,32,0,0,0,88,48H24a8,8,0,0,0-8,8V200a8,8,0,0,0,8,8H96a24,24,0,0,1,24,23.94,7.9,7.9,0,0,0,5.12,7.55A8,8,0,0,0,136,232a24,24,0,0,1,24-24h72a8,8,0,0,0,8-8V56A8,8,0,0,0,232,48ZM208,168H168.27a8.17,8.17,0,0,1-8.25-7.47,8,8,0,0,1,8-8.53h39.73a8.17,8.17,0,0,1,8.25,7.47A8,8,0,0,1,208,168Zm0-32H168.27a8.17,8.17,0,0,1-8.25-7.47,8,8,0,0,1,8-8.53h39.73a8.17,8.17,0,0,1,8.25,7.47A8,8,0,0,1,208,136Zm0-32H168.27A8.17,8.17,0,0,1,160,96.53,8,8,0,0,1,168,88h39.73A8.17,8.17,0,0,1,216,95.47,8,8,0,0,1,208,104Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",O_,[...t[3]||(t[3]=[Gb("path",{
d:"M232,50H160a38,38,0,0,0-32,17.55A38,38,0,0,0,96,50H24a6,6,0,0,0-6,6V200a6,6,0,0,0,6,6H96a26,26,0,0,1,26,26,6,6,0,0,0,12,0,26,26,0,0,1,26-26h72a6,6,0,0,0,6-6V56A6,6,0,0,0,232,50ZM96,194H30V62H96a26,26,0,0,1,26,26V204.31A37.86,37.86,0,0,0,96,194Zm130,0H160a37.87,37.87,0,0,0-26,10.32V88a26,26,0,0,1,26-26h66ZM160,90h40a6,6,0,0,1,0,12H160a6,6,0,0,1,0-12Zm46,38a6,6,0,0,1-6,6H160a6,6,0,0,1,0-12h40A6,6,0,0,1,206,128Zm0,32a6,6,0,0,1-6,6H160a6,6,0,0,1,0-12h40A6,6,0,0,1,206,160Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",w_,[...t[4]||(t[4]=[Gb("path",{
d:"M232,48H160a40,40,0,0,0-32,16A40,40,0,0,0,96,48H24a8,8,0,0,0-8,8V200a8,8,0,0,0,8,8H96a24,24,0,0,1,24,24,8,8,0,0,0,16,0,24,24,0,0,1,24-24h72a8,8,0,0,0,8-8V56A8,8,0,0,0,232,48ZM96,192H32V64H96a24,24,0,0,1,24,24V200A39.81,39.81,0,0,0,96,192Zm128,0H160a39.81,39.81,0,0,0-24,8V88a24,24,0,0,1,24-24h64ZM160,88h40a8,8,0,0,1,0,16H160a8,8,0,0,1,0-16Zm48,40a8,8,0,0,1-8,8H160a8,8,0,0,1,0-16h40A8,8,0,0,1,208,128Zm0,32a8,8,0,0,1-8,8H160a8,8,0,0,1,0-16h40A8,8,0,0,1,208,160Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",x_,[...t[5]||(t[5]=[Gb("path",{
d:"M232,52H160a36,36,0,0,0-32,19.54A36,36,0,0,0,96,52H24a4,4,0,0,0-4,4V200a4,4,0,0,0,4,4H96a28,28,0,0,1,28,28,4,4,0,0,0,8,0,28,28,0,0,1,28-28h72a4,4,0,0,0,4-4V56A4,4,0,0,0,232,52ZM96,196H28V60H96a28,28,0,0,1,28,28V209.4A35.94,35.94,0,0,0,96,196Zm132,0H160a35.94,35.94,0,0,0-28,13.41V88a28,28,0,0,1,28-28h68ZM160,92h40a4,4,0,0,1,0,8H160a4,4,0,0,1,0-8Zm44,36a4,4,0,0,1-4,4H160a4,4,0,0,1,0-8h40A4,4,0,0,1,204,128Zm0,32a4,4,0,0,1-4,4H160a4,4,0,0,1,0-8h40A4,4,0,0,1,204,160Z"
},null,-1)])])):ny("",!0)],16))}}),S_={key:0},__={key:1},T_={key:2},E_={key:3
},A_={key:4},C_={key:5},$_=Qg({name:"ScalarIconBracketsCurly",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",S_,[...t[0]||(t[0]=[Gb("path",{
d:"M54.8,119.49A35.06,35.06,0,0,1,49.05,128a35.06,35.06,0,0,1,5.75,8.51C60,147.24,60,159.83,60,172c0,25.94,1.84,32,20,32a12,12,0,0,1,0,24c-19.14,0-32.2-6.9-38.8-20.51C36,196.76,36,184.17,36,172c0-25.94-1.84-32-20-32a12,12,0,0,1,0-24c18.16,0,20-6.06,20-32,0-12.17,0-24.76,5.2-35.49C47.8,34.9,60.86,28,80,28a12,12,0,0,1,0,24c-18.16,0-20,6.06-20,32C60,96.17,60,108.76,54.8,119.49ZM240,116c-18.16,0-20-6.06-20-32,0-12.17,0-24.76-5.2-35.49C208.2,34.9,195.14,28,176,28a12,12,0,0,0,0,24c18.16,0,20,6.06,20,32,0,12.17,0,24.76,5.2,35.49A35.06,35.06,0,0,0,207,128a35.06,35.06,0,0,0-5.75,8.51C196,147.24,196,159.83,196,172c0,25.94-1.84,32-20,32a12,12,0,0,0,0,24c19.14,0,32.2-6.9,38.8-20.51C220,196.76,220,184.17,220,172c0-25.94,1.84-32,20-32a12,12,0,0,0,0-24Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",__,[...t[1]||(t[1]=[Gb("path",{
d:"M240,128c-64,0,0,88-64,88H80c-64,0,0-88-64-88,64,0,0-88,64-88h96C240,40,176,128,240,128Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M43.18,128a29.78,29.78,0,0,1,8,10.26c4.8,9.9,4.8,22,4.8,33.74,0,24.31,1,36,24,36a8,8,0,0,1,0,16c-17.48,0-29.32-6.14-35.2-18.26-4.8-9.9-4.8-22-4.8-33.74,0-24.31-1-36-24-36a8,8,0,0,1,0-16c23,0,24-11.69,24-36,0-11.72,0-23.84,4.8-33.74C50.68,38.14,62.52,32,80,32a8,8,0,0,1,0,16C57,48,56,59.69,56,84c0,11.72,0,23.84-4.8,33.74A29.78,29.78,0,0,1,43.18,128ZM240,120c-23,0-24-11.69-24-36,0-11.72,0-23.84-4.8-33.74C205.32,38.14,193.48,32,176,32a8,8,0,0,0,0,16c23,0,24,11.69,24,36,0,11.72,0,23.84,4.8,33.74a29.78,29.78,0,0,0,8,10.26,29.78,29.78,0,0,0-8,10.26c-4.8,9.9-4.8,22-4.8,33.74,0,24.31-1,36-24,36a8,8,0,0,0,0,16c17.48,0,29.32-6.14,35.2-18.26,4.8-9.9,4.8-22,4.8-33.74,0-24.31,1-36,24-36a8,8,0,0,0,0-16Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",T_,[...t[2]||(t[2]=[Gb("path",{
d:"M216,40H40A16,16,0,0,0,24,56V200a16,16,0,0,0,16,16H216a16,16,0,0,0,16-16V56A16,16,0,0,0,216,40ZM88,155.84c.29,14.26.41,20.16,16,20.16a8,8,0,0,1,0,16c-31.27,0-31.72-22.43-32-35.84C71.71,141.9,71.59,136,56,136a8,8,0,0,1,0-16c15.59,0,15.71-5.9,16-20.16C72.28,86.43,72.73,64,104,64a8,8,0,0,1,0,16c-15.59,0-15.71,5.9-16,20.16-.17,8.31-.41,20.09-8,27.84C87.59,135.75,87.83,147.53,88,155.84ZM200,136c-15.59,0-15.71,5.9-16,20.16-.28,13.41-.73,35.84-32,35.84a8,8,0,0,1,0-16c15.59,0,15.71-5.9,16-20.16.17-8.31.41-20.09,8-27.84-7.6-7.75-7.84-19.53-8-27.84C167.71,85.9,167.59,80,152,80a8,8,0,0,1,0-16c31.27,0,31.72,22.43,32,35.84.29,14.26.41,20.16,16,20.16a8,8,0,0,1,0,16Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",E_,[...t[3]||(t[3]=[Gb("path",{
d:"M39.91,128a27.68,27.68,0,0,1,9.49,11.13C54,148.62,54,160.51,54,172c0,24.27,1.21,38,26,38a6,6,0,0,1,0,12c-16.88,0-27.81-5.6-33.4-17.13C42,195.38,42,183.49,42,172c0-24.27-1.21-38-26-38a6,6,0,0,1,0-12c24.79,0,26-13.73,26-38,0-11.49,0-23.38,4.6-32.87C52.19,39.6,63.12,34,80,34a6,6,0,0,1,0,12C55.21,46,54,59.73,54,84c0,11.49,0,23.38-4.6,32.87A27.68,27.68,0,0,1,39.91,128ZM240,122c-24.79,0-26-13.73-26-38,0-11.49,0-23.38-4.6-32.87C203.81,39.6,192.88,34,176,34a6,6,0,0,0,0,12c24.79,0,26,13.73,26,38,0,11.49,0,23.38,4.6,32.87A27.68,27.68,0,0,0,216.09,128a27.68,27.68,0,0,0-9.49,11.13C202,148.62,202,160.51,202,172c0,24.27-1.21,38-26,38a6,6,0,0,0,0,12c16.88,0,27.81-5.6,33.4-17.13,4.6-9.49,4.6-21.38,4.6-32.87,0-24.27,1.21-38,26-38a6,6,0,0,0,0-12Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",A_,[...t[4]||(t[4]=[Gb("path",{
d:"M43.18,128a29.78,29.78,0,0,1,8,10.26c4.8,9.9,4.8,22,4.8,33.74,0,24.31,1,36,24,36a8,8,0,0,1,0,16c-17.48,0-29.32-6.14-35.2-18.26-4.8-9.9-4.8-22-4.8-33.74,0-24.31-1-36-24-36a8,8,0,0,1,0-16c23,0,24-11.69,24-36,0-11.72,0-23.84,4.8-33.74C50.68,38.14,62.52,32,80,32a8,8,0,0,1,0,16C57,48,56,59.69,56,84c0,11.72,0,23.84-4.8,33.74A29.78,29.78,0,0,1,43.18,128ZM240,120c-23,0-24-11.69-24-36,0-11.72,0-23.84-4.8-33.74C205.32,38.14,193.48,32,176,32a8,8,0,0,0,0,16c23,0,24,11.69,24,36,0,11.72,0,23.84,4.8,33.74a29.78,29.78,0,0,0,8,10.26,29.78,29.78,0,0,0-8,10.26c-4.8,9.9-4.8,22-4.8,33.74,0,24.31-1,36-24,36a8,8,0,0,0,0,16c17.48,0,29.32-6.14,35.2-18.26,4.8-9.9,4.8-22,4.8-33.74,0-24.31,1-36,24-36a8,8,0,0,0,0-16Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",C_,[...t[5]||(t[5]=[Gb("path",{
d:"M35.89,128C52,136.23,52,155.64,52,172c0,24.8,1.35,40,28,40a4,4,0,0,1,0,8c-36,0-36-26.61-36-48,0-24.8-1.35-40-28-40a4,4,0,0,1,0-8c26.65,0,28-15.2,28-40,0-21.39,0-48,36-48a4,4,0,0,1,0,8C53.35,44,52,59.2,52,84,52,100.36,52,119.77,35.89,128ZM240,124c-26.65,0-28-15.2-28-40,0-21.39,0-48-36-48a4,4,0,0,0,0,8c26.65,0,28,15.2,28,40,0,16.36,0,35.77,16.11,44C204,136.23,204,155.64,204,172c0,24.8-1.35,40-28,40a4,4,0,0,0,0,8c36,0,36-26.61,36-48,0-24.8,1.35-40,28-40a4,4,0,0,0,0-8Z"
},null,-1)])])):ny("",!0)],16))}}),P_={key:0},D_={key:1},I_={key:2},M_={key:3
},N_={key:4},R_={key:5},L_=Qg({name:"ScalarIconCaretDown",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",P_,[...t[0]||(t[0]=[Gb("path",{
d:"M216.49,104.49l-80,80a12,12,0,0,1-17,0l-80-80a12,12,0,0,1,17-17L128,159l71.51-71.52a12,12,0,0,1,17,17Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",D_,[...t[1]||(t[1]=[Gb("path",{
d:"M208,96l-80,80L48,96Z",opacity:"0.2"},null,-1),Gb("path",{
d:"M215.39,92.94A8,8,0,0,0,208,88H48a8,8,0,0,0-5.66,13.66l80,80a8,8,0,0,0,11.32,0l80-80A8,8,0,0,0,215.39,92.94ZM128,164.69,67.31,104H188.69Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",I_,[...t[2]||(t[2]=[Gb("path",{
d:"M213.66,101.66l-80,80a8,8,0,0,1-11.32,0l-80-80A8,8,0,0,1,48,88H208a8,8,0,0,1,5.66,13.66Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",M_,[...t[3]||(t[3]=[Gb("path",{
d:"M212.24,100.24l-80,80a6,6,0,0,1-8.48,0l-80-80a6,6,0,0,1,8.48-8.48L128,167.51l75.76-75.75a6,6,0,0,1,8.48,8.48Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",N_,[...t[4]||(t[4]=[Gb("path",{
d:"M213.66,101.66l-80,80a8,8,0,0,1-11.32,0l-80-80A8,8,0,0,1,53.66,90.34L128,164.69l74.34-74.35a8,8,0,0,1,11.32,11.32Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",R_,[...t[5]||(t[5]=[Gb("path",{
d:"M210.83,98.83l-80,80a4,4,0,0,1-5.66,0l-80-80a4,4,0,0,1,5.66-5.66L128,170.34l77.17-77.17a4,4,0,1,1,5.66,5.66Z"
},null,-1)])])):ny("",!0)],16))}}),B_={key:0},j_={key:1},U_={key:2},z_={key:3
},F_={key:4},Z_={key:5},Q_=Qg({name:"ScalarIconCaretRight",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",B_,[...t[0]||(t[0]=[Gb("path",{
d:"M184.49,136.49l-80,80a12,12,0,0,1-17-17L159,128,87.51,56.49a12,12,0,1,1,17-17l80,80A12,12,0,0,1,184.49,136.49Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",j_,[...t[1]||(t[1]=[Gb("path",{
d:"M176,128,96,208V48Z",opacity:"0.2"},null,-1),Gb("path",{
d:"M181.66,122.34l-80-80A8,8,0,0,0,88,48V208a8,8,0,0,0,13.66,5.66l80-80A8,8,0,0,0,181.66,122.34ZM104,188.69V67.31L164.69,128Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",U_,[...t[2]||(t[2]=[Gb("path",{
d:"M181.66,133.66l-80,80A8,8,0,0,1,88,208V48a8,8,0,0,1,13.66-5.66l80,80A8,8,0,0,1,181.66,133.66Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",z_,[...t[3]||(t[3]=[Gb("path",{
d:"M180.24,132.24l-80,80a6,6,0,0,1-8.48-8.48L167.51,128,91.76,52.24a6,6,0,0,1,8.48-8.48l80,80A6,6,0,0,1,180.24,132.24Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",F_,[...t[4]||(t[4]=[Gb("path",{
d:"M181.66,133.66l-80,80a8,8,0,0,1-11.32-11.32L164.69,128,90.34,53.66a8,8,0,0,1,11.32-11.32l80,80A8,8,0,0,1,181.66,133.66Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",Z_,[...t[5]||(t[5]=[Gb("path",{
d:"M178.83,130.83l-80,80a4,4,0,0,1-5.66-5.66L170.34,128,93.17,50.83a4,4,0,0,1,5.66-5.66l80,80A4,4,0,0,1,178.83,130.83Z"
},null,-1)])])):ny("",!0)],16))}}),H_={key:0},V_={key:1},q_={key:2},W_={key:3
},X_={key:4},G_={key:5},Y_=Qg({name:"ScalarIconCaretUpDown",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",H_,[...t[0]||(t[0]=[Gb("path",{
d:"M184.49,167.51a12,12,0,0,1,0,17l-48,48a12,12,0,0,1-17,0l-48-48a12,12,0,0,1,17-17L128,207l39.51-39.52A12,12,0,0,1,184.49,167.51Zm-96-79L128,49l39.51,39.52a12,12,0,0,0,17-17l-48-48a12,12,0,0,0-17,0l-48,48a12,12,0,0,0,17,17Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",V_,[...t[1]||(t[1]=[Gb("path",{
d:"M80,176h96l-48,48ZM128,32,80,80h96Z",opacity:"0.2"},null,-1),Gb("path",{
d:"M176,168H80a8,8,0,0,0-5.66,13.66l48,48a8,8,0,0,0,11.32,0l48-48A8,8,0,0,0,176,168Zm-48,44.69L99.31,184h57.38ZM80,88h96a8,8,0,0,0,5.66-13.66l-48-48a8,8,0,0,0-11.32,0l-48,48A8,8,0,0,0,80,88Zm48-44.69L156.69,72H99.31Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",q_,[...t[2]||(t[2]=[Gb("path",{
d:"M72.61,83.06a8,8,0,0,1,1.73-8.72l48-48a8,8,0,0,1,11.32,0l48,48A8,8,0,0,1,176,88H80A8,8,0,0,1,72.61,83.06ZM176,168H80a8,8,0,0,0-5.66,13.66l48,48a8,8,0,0,0,11.32,0l48-48A8,8,0,0,0,176,168Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",W_,[...t[3]||(t[3]=[Gb("path",{
d:"M180.24,171.76a6,6,0,0,1,0,8.48l-48,48a6,6,0,0,1-8.48,0l-48-48a6,6,0,0,1,8.48-8.48L128,215.51l43.76-43.75A6,6,0,0,1,180.24,171.76Zm-96-87.52L128,40.49l43.76,43.75a6,6,0,0,0,8.48-8.48l-48-48a6,6,0,0,0-8.48,0l-48,48a6,6,0,0,0,8.48,8.48Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",X_,[...t[4]||(t[4]=[Gb("path",{
d:"M181.66,170.34a8,8,0,0,1,0,11.32l-48,48a8,8,0,0,1-11.32,0l-48-48a8,8,0,0,1,11.32-11.32L128,212.69l42.34-42.35A8,8,0,0,1,181.66,170.34Zm-96-84.68L128,43.31l42.34,42.35a8,8,0,0,0,11.32-11.32l-48-48a8,8,0,0,0-11.32,0l-48,48A8,8,0,0,0,85.66,85.66Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",G_,[...t[5]||(t[5]=[Gb("path",{
d:"M178.83,173.17a4,4,0,0,1,0,5.66l-48,48a4,4,0,0,1-5.66,0l-48-48a4,4,0,0,1,5.66-5.66L128,218.34l45.17-45.17A4,4,0,0,1,178.83,173.17Zm-96-90.34L128,37.66l45.17,45.17a4,4,0,1,0,5.66-5.66l-48-48a4,4,0,0,0-5.66,0l-48,48a4,4,0,0,0,5.66,5.66Z"
},null,-1)])])):ny("",!0)],16))}}),K_={key:0},J_={key:1},eT={key:2},tT={key:3
},nT={key:4},rT={key:5},oT=Qg({name:"ScalarIconCheck",props:{label:{},weight:{}
},setup(e){const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",K_,[...t[0]||(t[0]=[Gb("path",{
d:"M232.49,80.49l-128,128a12,12,0,0,1-17,0l-56-56a12,12,0,1,1,17-17L96,183,215.51,63.51a12,12,0,0,1,17,17Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",J_,[...t[1]||(t[1]=[Gb("path",{
d:"M232,56V200a16,16,0,0,1-16,16H40a16,16,0,0,1-16-16V56A16,16,0,0,1,40,40H216A16,16,0,0,1,232,56Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M205.66,85.66l-96,96a8,8,0,0,1-11.32,0l-40-40a8,8,0,0,1,11.32-11.32L104,164.69l90.34-90.35a8,8,0,0,1,11.32,11.32Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",eT,[...t[2]||(t[2]=[Gb("path",{
d:"M216,40H40A16,16,0,0,0,24,56V200a16,16,0,0,0,16,16H216a16,16,0,0,0,16-16V56A16,16,0,0,0,216,40ZM205.66,85.66l-96,96a8,8,0,0,1-11.32,0l-40-40a8,8,0,0,1,11.32-11.32L104,164.69l90.34-90.35a8,8,0,0,1,11.32,11.32Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",tT,[...t[3]||(t[3]=[Gb("path",{
d:"M228.24,76.24l-128,128a6,6,0,0,1-8.48,0l-56-56a6,6,0,0,1,8.48-8.48L96,191.51,219.76,67.76a6,6,0,0,1,8.48,8.48Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",nT,[...t[4]||(t[4]=[Gb("path",{
d:"M229.66,77.66l-128,128a8,8,0,0,1-11.32,0l-56-56a8,8,0,0,1,11.32-11.32L96,188.69,218.34,66.34a8,8,0,0,1,11.32,11.32Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",rT,[...t[5]||(t[5]=[Gb("path",{
d:"M226.83,74.83l-128,128a4,4,0,0,1-5.66,0l-56-56a4,4,0,0,1,5.66-5.66L96,194.34,221.17,69.17a4,4,0,1,1,5.66,5.66Z"
},null,-1)])])):ny("",!0)],16))}}),aT={key:0},iT={key:1},sT={key:2},lT={key:3
},cT={key:4},uT={key:5},dT=Qg({name:"ScalarIconCopy",props:{label:{},weight:{}},
setup(e){const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",aT,[...t[0]||(t[0]=[Gb("path",{
d:"M216,28H88A12,12,0,0,0,76,40V76H40A12,12,0,0,0,28,88V216a12,12,0,0,0,12,12H168a12,12,0,0,0,12-12V180h36a12,12,0,0,0,12-12V40A12,12,0,0,0,216,28ZM156,204H52V100H156Zm48-48H180V88a12,12,0,0,0-12-12H100V52H204Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",iT,[...t[1]||(t[1]=[Gb("path",{
d:"M216,40V168H168V88H88V40Z",opacity:"0.2"},null,-1),Gb("path",{
d:"M216,32H88a8,8,0,0,0-8,8V80H40a8,8,0,0,0-8,8V216a8,8,0,0,0,8,8H168a8,8,0,0,0,8-8V176h40a8,8,0,0,0,8-8V40A8,8,0,0,0,216,32ZM160,208H48V96H160Zm48-48H176V88a8,8,0,0,0-8-8H96V48H208Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",sT,[...t[2]||(t[2]=[Gb("path",{
d:"M216,32H88a8,8,0,0,0-8,8V80H40a8,8,0,0,0-8,8V216a8,8,0,0,0,8,8H168a8,8,0,0,0,8-8V176h40a8,8,0,0,0,8-8V40A8,8,0,0,0,216,32Zm-8,128H176V88a8,8,0,0,0-8-8H96V48H208Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",lT,[...t[3]||(t[3]=[Gb("path",{
d:"M216,34H88a6,6,0,0,0-6,6V82H40a6,6,0,0,0-6,6V216a6,6,0,0,0,6,6H168a6,6,0,0,0,6-6V174h42a6,6,0,0,0,6-6V40A6,6,0,0,0,216,34ZM162,210H46V94H162Zm48-48H174V88a6,6,0,0,0-6-6H94V46H210Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",cT,[...t[4]||(t[4]=[Gb("path",{
d:"M216,32H88a8,8,0,0,0-8,8V80H40a8,8,0,0,0-8,8V216a8,8,0,0,0,8,8H168a8,8,0,0,0,8-8V176h40a8,8,0,0,0,8-8V40A8,8,0,0,0,216,32ZM160,208H48V96H160Zm48-48H176V88a8,8,0,0,0-8-8H96V48H208Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",uT,[...t[5]||(t[5]=[Gb("path",{
d:"M216,36H88a4,4,0,0,0-4,4V84H40a4,4,0,0,0-4,4V216a4,4,0,0,0,4,4H168a4,4,0,0,0,4-4V172h44a4,4,0,0,0,4-4V40A4,4,0,0,0,216,36ZM164,212H44V92H164Zm48-48H172V88a4,4,0,0,0-4-4H92V44H212Z"
},null,-1)])])):ny("",!0)],16))}}),pT={key:0},hT={key:1},fT={key:2},mT={key:3
},gT={key:4},vT={key:5},bT=Qg({name:"ScalarIconDiscordLogo",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",pT,[...t[0]||(t[0]=[Gb("path",{
d:"M108,136a16,16,0,1,1-16-16A16,16,0,0,1,108,136Zm56-16a16,16,0,1,0,16,16A16,16,0,0,0,164,120Zm76.07,76.56-67,29.71A20.15,20.15,0,0,1,146,214.9l-8.54-23.13c-3.13.14-6.27.24-9.45.24s-6.32-.1-9.45-.24L110,214.9a20.19,20.19,0,0,1-27.08,11.37l-67-29.71A19.93,19.93,0,0,1,4.62,173.41L34.15,57A20,20,0,0,1,50.37,42.19l36.06-5.93A20.26,20.26,0,0,1,109.22,51.1l4.41,17.41c4.74-.33,9.52-.51,14.37-.51s9.63.18,14.37.51l4.41-17.41a20.25,20.25,0,0,1,22.79-14.84l36.06,5.93A20,20,0,0,1,221.85,57l29.53,116.38A19.93,19.93,0,0,1,240.07,196.56ZM227.28,176,199.23,65.46l-30.07-4.94-2.84,11.17c2.9.58,5.78,1.2,8.61,1.92a12,12,0,1,1-5.86,23.27A168.43,168.43,0,0,0,128,92a168.43,168.43,0,0,0-41.07,4.88,12,12,0,0,1-5.86-23.27c2.83-.72,5.71-1.34,8.61-1.92L86.85,60.52,56.77,65.46,28.72,176l60.22,26.7,5-13.57c-4.37-.76-8.67-1.65-12.88-2.71a12,12,0,0,1,5.86-23.28A168.43,168.43,0,0,0,128,168a168.43,168.43,0,0,0,41.07-4.88,12,12,0,0,1,5.86,23.28c-4.21,1.06-8.51,1.95-12.88,2.71l5,13.57Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",hT,[...t[1]||(t[1]=[Gb("path",{
d:"M235.21,185.59l-67,29.7a8.15,8.15,0,0,1-11-4.56L147,183.06a190.5,190.5,0,0,1-19,.94,190.5,190.5,0,0,1-19-.94L98.75,210.73a8.15,8.15,0,0,1-11,4.56l-67-29.7a8,8,0,0,1-4.55-9.24L45.77,60A8.08,8.08,0,0,1,52.31,54l36.06-5.92a8.1,8.1,0,0,1,9.21,6l5,19.63a192.32,192.32,0,0,1,50.88,0l5-19.63a8.1,8.1,0,0,1,9.21-6L203.69,54A8.08,8.08,0,0,1,210.23,60l29.53,116.37A8,8,0,0,1,235.21,185.59Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M104,140a12,12,0,1,1-12-12A12,12,0,0,1,104,140Zm60-12a12,12,0,1,0,12,12A12,12,0,0,0,164,128Zm74.45,64.9-67,29.71a16.17,16.17,0,0,1-21.71-9.1l-8.11-22q-6.72.45-13.63.46t-13.63-.46l-8.11,22a16.18,16.18,0,0,1-21.71,9.1l-67-29.71a15.94,15.94,0,0,1-9.06-18.51L38,58A16.08,16.08,0,0,1,51,46.13l36.06-5.92a16.21,16.21,0,0,1,18.26,11.88l3.26,12.83Q118.11,64,128,64t19.4.92l3.26-12.83a16.22,16.22,0,0,1,18.26-11.88L205,46.13A16.08,16.08,0,0,1,218,58l29.53,116.38A15.94,15.94,0,0,1,238.45,192.9ZM232,178.28,202.47,62s0,0-.08,0L166.33,56a.17.17,0,0,0-.17,0l-2.83,11.14c5,.94,10,2.06,14.83,3.42A8,8,0,0,1,176,86.31a8.09,8.09,0,0,1-2.16-.3A172.25,172.25,0,0,0,128,80a172.25,172.25,0,0,0-45.84,6,8,8,0,1,1-4.32-15.4c4.82-1.36,9.78-2.48,14.82-3.42L89.83,56a.21.21,0,0,0-.12,0h0L53.61,61.92a.24.24,0,0,0-.09,0L24,178.33,91,208a.21.21,0,0,0,.22,0L98,189.72a173.2,173.2,0,0,1-20.14-4.32A8,8,0,0,1,82.16,170,171.85,171.85,0,0,0,128,176a171.85,171.85,0,0,0,45.84-6,8,8,0,0,1,4.32,15.41A173.2,173.2,0,0,1,158,189.72L164.75,208a.22.22,0,0,0,.21,0Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",fT,[...t[2]||(t[2]=[Gb("path",{
d:"M247.51,174.39,218,58a16.08,16.08,0,0,0-13-11.88l-36.06-5.92a16.22,16.22,0,0,0-18.26,11.88l-.21.85a4,4,0,0,0,3.27,4.93,155.62,155.62,0,0,1,24.41,5.62,8.2,8.2,0,0,1,5.62,9.7,8,8,0,0,1-10.19,5.64,155.4,155.4,0,0,0-90.8-.1,8.22,8.22,0,0,1-10.28-4.81,8,8,0,0,1,5.08-10.33,156.85,156.85,0,0,1,24.72-5.72,4,4,0,0,0,3.27-4.93l-.21-.85A16.21,16.21,0,0,0,87.08,40.21L51,46.13A16.08,16.08,0,0,0,38,58L8.49,174.39a15.94,15.94,0,0,0,9.06,18.51l67,29.71a16.17,16.17,0,0,0,21.71-9.1l3.49-9.45a4,4,0,0,0-3.27-5.35,158.13,158.13,0,0,1-28.63-6.2,8.2,8.2,0,0,1-5.61-9.67,8,8,0,0,1,10.2-5.66,155.59,155.59,0,0,0,91.12,0,8,8,0,0,1,10.19,5.65,8.19,8.19,0,0,1-5.61,9.68,157.84,157.84,0,0,1-28.62,6.2,4,4,0,0,0-3.27,5.35l3.49,9.45a16.18,16.18,0,0,0,21.71,9.1l67-29.71A15.94,15.94,0,0,0,247.51,174.39ZM92,152a12,12,0,1,1,12-12A12,12,0,0,1,92,152Zm72,0a12,12,0,1,1,12-12A12,12,0,0,1,164,152Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",mT,[...t[3]||(t[3]=[Gb("path",{
d:"M102,140a10,10,0,1,1-10-10A10,10,0,0,1,102,140Zm62-10a10,10,0,1,0,10,10A10,10,0,0,0,164,130Zm73.64,61.08-67,29.71a14.43,14.43,0,0,1-5.77,1.21,14.13,14.13,0,0,1-13.25-9.18L143,189.43c-4.93.37-9.92.58-15,.58s-10.06-.21-15-.58l-8.63,23.39A14.13,14.13,0,0,1,91.13,222a14.43,14.43,0,0,1-5.77-1.21l-67-29.71a14,14,0,0,1-7.93-16.2L40,58.5A14.07,14.07,0,0,1,51.34,48.11L87.4,42.19a14.19,14.19,0,0,1,16,10.39l3.69,14.53a197.5,197.5,0,0,1,41.82,0l3.69-14.53a14.19,14.19,0,0,1,16-10.39l36.06,5.92A14.07,14.07,0,0,1,216,58.5l29.53,116.38A14,14,0,0,1,237.64,191.08Zm-3.7-13.25L204.41,61.45a2.08,2.08,0,0,0-1.7-1.5L166.65,54a2.13,2.13,0,0,0-2.42,1.5l-3.36,13.24a169.28,169.28,0,0,1,16.75,3.76A6,6,0,0,1,176,84.31a5.71,5.71,0,0,1-1.62-.23A174.26,174.26,0,0,0,128,78a174.26,174.26,0,0,0-46.38,6.08,6,6,0,1,1-3.24-11.55,169.28,169.28,0,0,1,16.75-3.76L91.77,55.53A2.12,2.12,0,0,0,89.35,54L53.29,60a2.08,2.08,0,0,0-1.7,1.5L22.06,177.83a2,2,0,0,0,1.16,2.28l67,29.7a2.19,2.19,0,0,0,1.76,0,2.07,2.07,0,0,0,1.14-1.17l7.58-20.55a171.46,171.46,0,0,1-22.33-4.64,6,6,0,1,1,3.24-11.55A174.26,174.26,0,0,0,128,178a174.26,174.26,0,0,0,46.38-6.08,6,6,0,1,1,3.24,11.55,171.46,171.46,0,0,1-22.33,4.64l7.58,20.55a2.07,2.07,0,0,0,1.14,1.17,2.19,2.19,0,0,0,1.76,0l67-29.7A2,2,0,0,0,233.94,177.83Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",gT,[...t[4]||(t[4]=[Gb("path",{
d:"M104,140a12,12,0,1,1-12-12A12,12,0,0,1,104,140Zm60-12a12,12,0,1,0,12,12A12,12,0,0,0,164,128Zm74.45,64.9-67,29.71a16.17,16.17,0,0,1-21.71-9.1l-8.11-22q-6.72.45-13.63.46t-13.63-.46l-8.11,22a16.18,16.18,0,0,1-21.71,9.1l-67-29.71a15.93,15.93,0,0,1-9.06-18.51L38,58A16.07,16.07,0,0,1,51,46.14l36.06-5.93a16.22,16.22,0,0,1,18.26,11.88l3.26,12.84Q118.11,64,128,64t19.4.93l3.26-12.84a16.21,16.21,0,0,1,18.26-11.88L205,46.14A16.07,16.07,0,0,1,218,58l29.53,116.38A15.93,15.93,0,0,1,238.45,192.9ZM232,178.28,202.47,62s0,0-.08,0L166.33,56a.17.17,0,0,0-.17,0l-2.83,11.14c5,.94,10,2.06,14.83,3.42A8,8,0,0,1,176,86.31a8.09,8.09,0,0,1-2.16-.3A172.25,172.25,0,0,0,128,80a172.25,172.25,0,0,0-45.84,6,8,8,0,1,1-4.32-15.4c4.82-1.36,9.78-2.48,14.82-3.42L89.83,56s0,0-.12,0h0L53.61,61.93a.17.17,0,0,0-.09,0L24,178.33,91,208a.23.23,0,0,0,.22,0L98,189.72a173.2,173.2,0,0,1-20.14-4.32A8,8,0,0,1,82.16,170,171.85,171.85,0,0,0,128,176a171.85,171.85,0,0,0,45.84-6,8,8,0,0,1,4.32,15.41A173.2,173.2,0,0,1,158,189.72L164.75,208a.22.22,0,0,0,.21,0Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",vT,[...t[5]||(t[5]=[Gb("path",{
d:"M100,140a8,8,0,1,1-8-8A8,8,0,0,1,100,140Zm64-8a8,8,0,1,0,8,8A8,8,0,0,0,164,132Zm72.83,57.25-67,29.71a12.36,12.36,0,0,1-5,1,12.13,12.13,0,0,1-11.38-7.88l-9.15-24.81c-5.36.45-10.81.69-16.34.69s-11-.24-16.34-.69l-9.15,24.81A12.13,12.13,0,0,1,91.13,220a12.36,12.36,0,0,1-5-1l-67-29.71a12,12,0,0,1-6.8-13.88L41.9,59a12.06,12.06,0,0,1,9.77-8.91l36.06-5.92a12.18,12.18,0,0,1,13.73,8.91l4.12,16.22a195.47,195.47,0,0,1,44.84,0l4.12-16.22a12.18,12.18,0,0,1,13.73-8.91l36.06,5.92A12.06,12.06,0,0,1,214.1,59l29.53,116.38A12,12,0,0,1,236.83,189.25Zm-1-11.91L206.35,61A4.07,4.07,0,0,0,203,58L167,52.05a4.15,4.15,0,0,0-4.69,3L158.4,70.38a166.74,166.74,0,0,1,18.68,4.08,4,4,0,1,1-2.16,7.7A176.21,176.21,0,0,0,128,76a176.21,176.21,0,0,0-46.92,6.16,4,4,0,1,1-2.16-7.7A166.74,166.74,0,0,1,97.6,70.38L93.71,55a4.15,4.15,0,0,0-4.69-3L53,58a4.07,4.07,0,0,0-3.31,3L20.12,177.34a4,4,0,0,0,2.29,4.59l67,29.71a4.16,4.16,0,0,0,3.35,0A4,4,0,0,0,95,209.35l8.45-22.88a171.49,171.49,0,0,1-24.53-4.92,4,4,0,0,1,2.16-7.71A176.21,176.21,0,0,0,128,180a176.21,176.21,0,0,0,46.92-6.16,4,4,0,0,1,2.16,7.71,171.49,171.49,0,0,1-24.53,4.92L161,209.35a4,4,0,0,0,2.23,2.32,4.16,4.16,0,0,0,3.35,0l67-29.71A4,4,0,0,0,235.88,177.34Z"
},null,-1)])])):ny("",!0)],16))}}),yT={key:0},OT={key:1},wT={key:2},xT={key:3
},kT={key:4},ST={key:5},_T=Qg({name:"ScalarIconEnvelopeSimple",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",yT,[...t[0]||(t[0]=[Gb("path",{
d:"M224,44H32A12,12,0,0,0,20,56V192a20,20,0,0,0,20,20H216a20,20,0,0,0,20-20V56A12,12,0,0,0,224,44ZM193.15,68,128,127.72,62.85,68ZM44,188V83.28l75.89,69.57a12,12,0,0,0,16.22,0L212,83.28V188Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",OT,[...t[1]||(t[1]=[Gb("path",{
d:"M224,56l-96,88L32,56Z",opacity:"0.2"},null,-1),Gb("path",{
d:"M224,48H32a8,8,0,0,0-8,8V192a16,16,0,0,0,16,16H216a16,16,0,0,0,16-16V56A8,8,0,0,0,224,48ZM203.43,64,128,133.15,52.57,64ZM216,192H40V74.19l82.59,75.71a8,8,0,0,0,10.82,0L216,74.19V192Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",wT,[...t[2]||(t[2]=[Gb("path",{
d:"M224,48H32a8,8,0,0,0-8,8V192a16,16,0,0,0,16,16H216a16,16,0,0,0,16-16V56A8,8,0,0,0,224,48Zm-8,144H40V74.19l82.59,75.71a8,8,0,0,0,10.82,0L216,74.19V192Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",xT,[...t[3]||(t[3]=[Gb("path",{
d:"M224,50H32a6,6,0,0,0-6,6V192a14,14,0,0,0,14,14H216a14,14,0,0,0,14-14V56A6,6,0,0,0,224,50ZM208.58,62,128,135.86,47.42,62ZM216,194H40a2,2,0,0,1-2-2V69.64l86,78.78a6,6,0,0,0,8.1,0L218,69.64V192A2,2,0,0,1,216,194Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",kT,[...t[4]||(t[4]=[Gb("path",{
d:"M224,48H32a8,8,0,0,0-8,8V192a16,16,0,0,0,16,16H216a16,16,0,0,0,16-16V56A8,8,0,0,0,224,48ZM203.43,64,128,133.15,52.57,64ZM216,192H40V74.19l82.59,75.71a8,8,0,0,0,10.82,0L216,74.19V192Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",ST,[...t[5]||(t[5]=[Gb("path",{
d:"M224,52H32a4,4,0,0,0-4,4V192a12,12,0,0,0,12,12H216a12,12,0,0,0,12-12V56A4,4,0,0,0,224,52Zm-10.28,8L128,138.57,42.28,60ZM216,196H40a4,4,0,0,1-4-4V65.09L125.3,147a4,4,0,0,0,5.4,0L220,65.09V192A4,4,0,0,1,216,196Z"
},null,-1)])])):ny("",!0)],16))}}),TT={key:0},ET={key:1},AT={key:2},CT={key:3
},$T={key:4},PT={key:5},DT=Qg({name:"ScalarIconEye",props:{label:{},weight:{}},
setup(e){const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",TT,[...t[0]||(t[0]=[Gb("path",{
d:"M251,123.13c-.37-.81-9.13-20.26-28.48-39.61C196.63,57.67,164,44,128,44S59.37,57.67,33.51,83.52C14.16,102.87,5.4,122.32,5,123.13a12.08,12.08,0,0,0,0,9.75c.37.82,9.13,20.26,28.49,39.61C59.37,198.34,92,212,128,212s68.63-13.66,94.48-39.51c19.36-19.35,28.12-38.79,28.49-39.61A12.08,12.08,0,0,0,251,123.13Zm-46.06,33C183.47,177.27,157.59,188,128,188s-55.47-10.73-76.91-31.88A130.36,130.36,0,0,1,29.52,128,130.45,130.45,0,0,1,51.09,99.89C72.54,78.73,98.41,68,128,68s55.46,10.73,76.91,31.89A130.36,130.36,0,0,1,226.48,128,130.45,130.45,0,0,1,204.91,156.12ZM128,84a44,44,0,1,0,44,44A44.05,44.05,0,0,0,128,84Zm0,64a20,20,0,1,1,20-20A20,20,0,0,1,128,148Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",ET,[...t[1]||(t[1]=[Gb("path",{
d:"M128,56C48,56,16,128,16,128s32,72,112,72,112-72,112-72S208,56,128,56Zm0,112a40,40,0,1,1,40-40A40,40,0,0,1,128,168Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M247.31,124.76c-.35-.79-8.82-19.58-27.65-38.41C194.57,61.26,162.88,48,128,48S61.43,61.26,36.34,86.35C17.51,105.18,9,124,8.69,124.76a8,8,0,0,0,0,6.5c.35.79,8.82,19.57,27.65,38.4C61.43,194.74,93.12,208,128,208s66.57-13.26,91.66-38.34c18.83-18.83,27.3-37.61,27.65-38.4A8,8,0,0,0,247.31,124.76ZM128,192c-30.78,0-57.67-11.19-79.93-33.25A133.47,133.47,0,0,1,25,128,133.33,133.33,0,0,1,48.07,97.25C70.33,75.19,97.22,64,128,64s57.67,11.19,79.93,33.25A133.46,133.46,0,0,1,231.05,128C223.84,141.46,192.43,192,128,192Zm0-112a48,48,0,1,0,48,48A48.05,48.05,0,0,0,128,80Zm0,80a32,32,0,1,1,32-32A32,32,0,0,1,128,160Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",AT,[...t[2]||(t[2]=[Gb("path",{
d:"M247.31,124.76c-.35-.79-8.82-19.58-27.65-38.41C194.57,61.26,162.88,48,128,48S61.43,61.26,36.34,86.35C17.51,105.18,9,124,8.69,124.76a8,8,0,0,0,0,6.5c.35.79,8.82,19.57,27.65,38.4C61.43,194.74,93.12,208,128,208s66.57-13.26,91.66-38.34c18.83-18.83,27.3-37.61,27.65-38.4A8,8,0,0,0,247.31,124.76ZM128,168a40,40,0,1,1,40-40A40,40,0,0,1,128,168Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",CT,[...t[3]||(t[3]=[Gb("path",{
d:"M245.48,125.57c-.34-.78-8.66-19.23-27.24-37.81C201,70.54,171.38,50,128,50S55,70.54,37.76,87.76c-18.58,18.58-26.9,37-27.24,37.81a6,6,0,0,0,0,4.88c.34.77,8.66,19.22,27.24,37.8C55,185.47,84.62,206,128,206s73-20.53,90.24-37.75c18.58-18.58,26.9-37,27.24-37.8A6,6,0,0,0,245.48,125.57ZM128,194c-31.38,0-58.78-11.42-81.45-33.93A134.77,134.77,0,0,1,22.69,128,134.56,134.56,0,0,1,46.55,95.94C69.22,73.42,96.62,62,128,62s58.78,11.42,81.45,33.94A134.56,134.56,0,0,1,233.31,128C226.94,140.21,195,194,128,194Zm0-112a46,46,0,1,0,46,46A46.06,46.06,0,0,0,128,82Zm0,80a34,34,0,1,1,34-34A34,34,0,0,1,128,162Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",$T,[...t[4]||(t[4]=[Gb("path",{
d:"M247.31,124.76c-.35-.79-8.82-19.58-27.65-38.41C194.57,61.26,162.88,48,128,48S61.43,61.26,36.34,86.35C17.51,105.18,9,124,8.69,124.76a8,8,0,0,0,0,6.5c.35.79,8.82,19.57,27.65,38.4C61.43,194.74,93.12,208,128,208s66.57-13.26,91.66-38.34c18.83-18.83,27.3-37.61,27.65-38.4A8,8,0,0,0,247.31,124.76ZM128,192c-30.78,0-57.67-11.19-79.93-33.25A133.47,133.47,0,0,1,25,128,133.33,133.33,0,0,1,48.07,97.25C70.33,75.19,97.22,64,128,64s57.67,11.19,79.93,33.25A133.46,133.46,0,0,1,231.05,128C223.84,141.46,192.43,192,128,192Zm0-112a48,48,0,1,0,48,48A48.05,48.05,0,0,0,128,80Zm0,80a32,32,0,1,1,32-32A32,32,0,0,1,128,160Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",PT,[...t[5]||(t[5]=[Gb("path",{
d:"M243.66,126.38c-.34-.76-8.52-18.89-26.83-37.2C199.87,72.22,170.7,52,128,52S56.13,72.22,39.17,89.18c-18.31,18.31-26.49,36.44-26.83,37.2a4.08,4.08,0,0,0,0,3.25c.34.77,8.52,18.89,26.83,37.2,17,17,46.14,37.17,88.83,37.17s71.87-20.21,88.83-37.17c18.31-18.31,26.49-36.43,26.83-37.2A4.08,4.08,0,0,0,243.66,126.38Zm-32.7,35c-23.07,23-51,34.62-83,34.62s-59.89-11.65-83-34.62A135.71,135.71,0,0,1,20.44,128,135.69,135.69,0,0,1,45,94.62C68.11,71.65,96,60,128,60s59.89,11.65,83,34.62A135.79,135.79,0,0,1,235.56,128,135.71,135.71,0,0,1,211,161.38ZM128,84a44,44,0,1,0,44,44A44.05,44.05,0,0,0,128,84Zm0,80a36,36,0,1,1,36-36A36,36,0,0,1,128,164Z"
},null,-1)])])):ny("",!0)],16))}}),IT={key:0},MT={key:1},NT={key:2},RT={key:3
},LT={key:4},BT={key:5},jT=Qg({name:"ScalarIconEyeSlash",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",IT,[...t[0]||(t[0]=[Gb("path",{
d:"M56.88,31.93A12,12,0,1,0,39.12,48.07l16,17.65C20.67,88.66,5.72,121.58,5,123.13a12.08,12.08,0,0,0,0,9.75c.37.82,9.13,20.26,28.49,39.61C59.37,198.34,92,212,128,212a131.34,131.34,0,0,0,51-10l20.09,22.1a12,12,0,0,0,17.76-16.14ZM128,188c-29.59,0-55.47-10.73-76.91-31.88A130.69,130.69,0,0,1,29.52,128c5.27-9.31,18.79-29.9,42-44.29l90.09,99.11A109.33,109.33,0,0,1,128,188Zm123-55.12c-.36.81-9,20-28,39.16a12,12,0,1,1-17-16.9A130.48,130.48,0,0,0,226.48,128a130.36,130.36,0,0,0-21.57-28.12C183.46,78.73,157.59,68,128,68c-3.35,0-6.7.14-10,.42a12,12,0,1,1-2-23.91c3.93-.34,8-.51,12-.51,36,0,68.63,13.67,94.49,39.52,19.35,19.35,28.11,38.8,28.48,39.61A12.08,12.08,0,0,1,251,132.88Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",MT,[...t[1]||(t[1]=[Gb("path",{
d:"M128,56C48,56,16,128,16,128s32,72,112,72,112-72,112-72S208,56,128,56Zm0,112a40,40,0,1,1,40-40A40,40,0,0,1,128,168Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M53.92,34.62A8,8,0,1,0,42.08,45.38L61.32,66.55C25,88.84,9.38,123.2,8.69,124.76a8,8,0,0,0,0,6.5c.35.79,8.82,19.57,27.65,38.4C61.43,194.74,93.12,208,128,208a127.11,127.11,0,0,0,52.07-10.83l22,24.21a8,8,0,1,0,11.84-10.76Zm47.33,75.84,41.67,45.85a32,32,0,0,1-41.67-45.85ZM128,192c-30.78,0-57.67-11.19-79.93-33.25A133.16,133.16,0,0,1,25,128c4.69-8.79,19.66-33.39,47.35-49.38l18,19.75a48,48,0,0,0,63.66,70l14.73,16.2A112,112,0,0,1,128,192Zm6-95.43a8,8,0,0,1,3-15.72,48.16,48.16,0,0,1,38.77,42.64,8,8,0,0,1-7.22,8.71,6.39,6.39,0,0,1-.75,0,8,8,0,0,1-8-7.26A32.09,32.09,0,0,0,134,96.57Zm113.28,34.69c-.42.94-10.55,23.37-33.36,43.8a8,8,0,1,1-10.67-11.92A132.77,132.77,0,0,0,231.05,128a133.15,133.15,0,0,0-23.12-30.77C185.67,75.19,158.78,64,128,64a118.37,118.37,0,0,0-19.36,1.57A8,8,0,1,1,106,49.79,134,134,0,0,1,128,48c34.88,0,66.57,13.26,91.66,38.35,18.83,18.83,27.3,37.62,27.65,38.41A8,8,0,0,1,247.31,131.26Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",NT,[...t[2]||(t[2]=[Gb("path",{
d:"M96.68,57.87a4,4,0,0,1,2.08-6.6A130.13,130.13,0,0,1,128,48c34.88,0,66.57,13.26,91.66,38.35,18.83,18.83,27.3,37.62,27.65,38.41a8,8,0,0,1,0,6.5c-.35.79-8.82,19.57-27.65,38.4q-4.28,4.26-8.79,8.07a4,4,0,0,1-5.55-.36ZM213.92,210.62a8,8,0,1,1-11.84,10.76L180,197.13A127.21,127.21,0,0,1,128,208c-34.88,0-66.57-13.26-91.66-38.34C17.51,150.83,9,132.05,8.69,131.26a8,8,0,0,1,0-6.5C9,124,17.51,105.18,36.34,86.35a135,135,0,0,1,25-19.78L42.08,45.38A8,8,0,1,1,53.92,34.62Zm-65.49-48.25-52.69-58a40,40,0,0,0,52.69,58Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",RT,[...t[3]||(t[3]=[Gb("path",{
d:"M52.44,36A6,6,0,0,0,43.56,44L64.44,67c-37.28,21.9-53.23,57-53.92,58.57a6,6,0,0,0,0,4.88c.34.77,8.66,19.22,27.24,37.8C55,185.47,84.62,206,128,206a124.91,124.91,0,0,0,52.57-11.25l23,25.29a6,6,0,0,0,8.88-8.08Zm48.62,71.32,45,49.52a34,34,0,0,1-45-49.52ZM128,194c-31.38,0-58.78-11.42-81.45-33.93A134.57,134.57,0,0,1,22.69,128c4.29-8.2,20.1-35.18,50-51.91L92.89,98.3a46,46,0,0,0,61.35,67.48l17.81,19.6A113.47,113.47,0,0,1,128,194Zm6.4-99.4a6,6,0,0,1,2.25-11.79,46.17,46.17,0,0,1,37.15,40.87,6,6,0,0,1-5.42,6.53l-.56,0a6,6,0,0,1-6-5.45A34.1,34.1,0,0,0,134.4,94.6Zm111.08,35.85c-.41.92-10.37,23-32.86,43.12a6,6,0,1,1-8-8.94A134.07,134.07,0,0,0,233.31,128a134.67,134.67,0,0,0-23.86-32.07C186.78,73.42,159.38,62,128,62a120.19,120.19,0,0,0-19.69,1.6,6,6,0,1,1-2-11.83A131.12,131.12,0,0,1,128,50c43.38,0,73,20.54,90.24,37.76,18.58,18.58,26.9,37,27.24,37.81A6,6,0,0,1,245.48,130.45Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",LT,[...t[4]||(t[4]=[Gb("path",{
d:"M53.92,34.62A8,8,0,1,0,42.08,45.38L61.32,66.55C25,88.84,9.38,123.2,8.69,124.76a8,8,0,0,0,0,6.5c.35.79,8.82,19.57,27.65,38.4C61.43,194.74,93.12,208,128,208a127.11,127.11,0,0,0,52.07-10.83l22,24.21a8,8,0,1,0,11.84-10.76Zm47.33,75.84,41.67,45.85a32,32,0,0,1-41.67-45.85ZM128,192c-30.78,0-57.67-11.19-79.93-33.25A133.16,133.16,0,0,1,25,128c4.69-8.79,19.66-33.39,47.35-49.38l18,19.75a48,48,0,0,0,63.66,70l14.73,16.2A112,112,0,0,1,128,192Zm6-95.43a8,8,0,0,1,3-15.72,48.16,48.16,0,0,1,38.77,42.64,8,8,0,0,1-7.22,8.71,6.39,6.39,0,0,1-.75,0,8,8,0,0,1-8-7.26A32.09,32.09,0,0,0,134,96.57Zm113.28,34.69c-.42.94-10.55,23.37-33.36,43.8a8,8,0,1,1-10.67-11.92A132.77,132.77,0,0,0,231.05,128a133.15,133.15,0,0,0-23.12-30.77C185.67,75.19,158.78,64,128,64a118.37,118.37,0,0,0-19.36,1.57A8,8,0,1,1,106,49.79,134,134,0,0,1,128,48c34.88,0,66.57,13.26,91.66,38.35,18.83,18.83,27.3,37.62,27.65,38.41A8,8,0,0,1,247.31,131.26Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",BT,[...t[5]||(t[5]=[Gb("path",{
d:"M51,37.31A4,4,0,0,0,45,42.69L67.59,67.5C29.34,89,13,124.81,12.34,126.38a4.08,4.08,0,0,0,0,3.25c.34.77,8.52,18.89,26.83,37.2,17,17,46.14,37.17,88.83,37.17a122.59,122.59,0,0,0,53.06-11.69l24,26.38a4,4,0,1,0,5.92-5.38ZM149.1,157.16A36,36,0,0,1,101,104.22ZM128,196c-32,0-59.89-11.65-83-34.62A135.81,135.81,0,0,1,20.44,128c3.65-7.23,20.09-36.81,52.68-54.43l22.45,24.7a44,44,0,0,0,59,64.83l20.89,23A114.94,114.94,0,0,1,128,196Zm6.78-103.36a4,4,0,0,1,1.49-7.86,44.15,44.15,0,0,1,35.54,39.09,4,4,0,0,1-3.61,4.35l-.38,0a4,4,0,0,1-4-3.63A36.1,36.1,0,0,0,134.78,92.64Zm108.88,37c-.41.91-10.2,22.58-32.38,42.45a4,4,0,0,1-2.67,1,4,4,0,0,1-2.67-7A136.71,136.71,0,0,0,235.56,128,136.07,136.07,0,0,0,211,94.62C187.89,71.65,160,60,128,60a122,122,0,0,0-20,1.63,4,4,0,0,1-1.32-7.89A129.3,129.3,0,0,1,128,52c42.7,0,71.87,20.22,88.83,37.18,18.31,18.31,26.49,36.44,26.83,37.2A4.08,4.08,0,0,1,243.66,129.63Z"
},null,-1)])])):ny("",!0)],16))}}),UT={key:0},zT={key:1},FT={key:2},ZT={key:3
},QT={key:4},HT={key:5},VT=Qg({name:"ScalarIconFileDashed",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",UT,[...t[0]||(t[0]=[Gb("path",{
d:"M84,224a12,12,0,0,1-12,12H56a20,20,0,0,1-20-20V184a12,12,0,0,1,24,0v28H72A12,12,0,0,1,84,224ZM220,88v48a12,12,0,0,1-24,0V104H148a12,12,0,0,1-12-12V44H120a12,12,0,0,1,0-24h32a12,12,0,0,1,8.49,3.51l56,56A12,12,0,0,1,220,88Zm-60-8h23L160,57ZM80,20H56A20,20,0,0,0,36,40V64a12,12,0,0,0,24,0V44H80a12,12,0,0,0,0-24ZM208,164a12,12,0,0,0-12,12v36h-4a12,12,0,0,0,0,24h8a20,20,0,0,0,20-20V176A12,12,0,0,0,208,164ZM48,156a12,12,0,0,0,12-12V104a12,12,0,0,0-24,0v40A12,12,0,0,0,48,156Zm104,56H112a12,12,0,0,0,0,24h40a12,12,0,0,0,0-24Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",zT,[...t[1]||(t[1]=[Gb("path",{
d:"M208,88H152V32Z",opacity:"0.2"},null,-1),Gb("path",{
d:"M80,224a8,8,0,0,1-8,8H56a16,16,0,0,1-16-16V184a8,8,0,0,1,16,0v32H72A8,8,0,0,1,80,224ZM216,88v48a8,8,0,0,1-16,0V96H152a8,8,0,0,1-8-8V40H120a8,8,0,0,1,0-16h32a8,8,0,0,1,5.66,2.34l56,56A8,8,0,0,1,216,88Zm-56-8h28.69L160,51.31ZM80,24H56A16,16,0,0,0,40,40V64a8,8,0,0,0,16,0V40H80a8,8,0,0,0,0-16ZM208,168a8,8,0,0,0-8,8v40h-8a8,8,0,0,0,0,16h8a16,16,0,0,0,16-16V176A8,8,0,0,0,208,168ZM48,152a8,8,0,0,0,8-8V104a8,8,0,0,0-16,0v40A8,8,0,0,0,48,152Zm104,64H112a8,8,0,0,0,0,16h40a8,8,0,0,0,0-16Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",FT,[...t[2]||(t[2]=[Gb("path",{
d:"M80,224a8,8,0,0,1-8,8H56a16,16,0,0,1-16-16V184a8,8,0,0,1,16,0v32H72A8,8,0,0,1,80,224ZM213.66,82.34l-56-56A8,8,0,0,0,152,24H120a8,8,0,0,0,0,16h24V88a8,8,0,0,0,8,8h48v40a8,8,0,0,0,16,0V88A8,8,0,0,0,213.66,82.34ZM80,24H56A16,16,0,0,0,40,40V64a8,8,0,0,0,16,0V40H80a8,8,0,0,0,0-16ZM208,168a8,8,0,0,0-8,8v40h-8a8,8,0,0,0,0,16h8a16,16,0,0,0,16-16V176A8,8,0,0,0,208,168ZM48,152a8,8,0,0,0,8-8V104a8,8,0,0,0-16,0v40A8,8,0,0,0,48,152Zm104,64H112a8,8,0,0,0,0,16h40a8,8,0,0,0,0-16Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",ZT,[...t[3]||(t[3]=[Gb("path",{
d:"M78,224a6,6,0,0,1-6,6H56a14,14,0,0,1-14-14V184a6,6,0,0,1,12,0v32a2,2,0,0,0,2,2H72A6,6,0,0,1,78,224ZM214,88v48a6,6,0,0,1-12,0V94H152a6,6,0,0,1-6-6V38H120a6,6,0,0,1,0-12h32a6,6,0,0,1,4.24,1.76l56,56A6,6,0,0,1,214,88Zm-56-6h35.51L158,46.49ZM80,26H56A14,14,0,0,0,42,40V64a6,6,0,0,0,12,0V40a2,2,0,0,1,2-2H80a6,6,0,0,0,0-12ZM208,170a6,6,0,0,0-6,6v40a2,2,0,0,1-2,2h-8a6,6,0,0,0,0,12h8a14,14,0,0,0,14-14V176A6,6,0,0,0,208,170ZM48,150a6,6,0,0,0,6-6V104a6,6,0,0,0-12,0v40A6,6,0,0,0,48,150Zm104,68H112a6,6,0,0,0,0,12h40a6,6,0,0,0,0-12Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",QT,[...t[4]||(t[4]=[Gb("path",{
d:"M80,224a8,8,0,0,1-8,8H56a16,16,0,0,1-16-16V184a8,8,0,0,1,16,0v32H72A8,8,0,0,1,80,224ZM216,88v48a8,8,0,0,1-16,0V96H152a8,8,0,0,1-8-8V40H120a8,8,0,0,1,0-16h32a8,8,0,0,1,5.66,2.34l56,56A8,8,0,0,1,216,88Zm-56-8h28.69L160,51.31ZM80,24H56A16,16,0,0,0,40,40V64a8,8,0,0,0,16,0V40H80a8,8,0,0,0,0-16ZM208,168a8,8,0,0,0-8,8v40h-8a8,8,0,0,0,0,16h8a16,16,0,0,0,16-16V176A8,8,0,0,0,208,168ZM48,152a8,8,0,0,0,8-8V104a8,8,0,0,0-16,0v40A8,8,0,0,0,48,152Zm104,64H112a8,8,0,0,0,0,16h40a8,8,0,0,0,0-16Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",HT,[...t[5]||(t[5]=[Gb("path",{
d:"M76,224a4,4,0,0,1-4,4H56a12,12,0,0,1-12-12V184a4,4,0,0,1,8,0v32a4,4,0,0,0,4,4H72A4,4,0,0,1,76,224ZM212,88v48a4,4,0,0,1-8,0V92H152a4,4,0,0,1-4-4V36H120a4,4,0,0,1,0-8h32a4,4,0,0,1,2.83,1.17l56,56A4,4,0,0,1,212,88Zm-56-4h42.34L156,41.66ZM80,28H56A12,12,0,0,0,44,40V64a4,4,0,0,0,8,0V40a4,4,0,0,1,4-4H80a4,4,0,0,0,0-8ZM208,172a4,4,0,0,0-4,4v40a4,4,0,0,1-4,4h-8a4,4,0,0,0,0,8h8a12,12,0,0,0,12-12V176A4,4,0,0,0,208,172ZM48,148a4,4,0,0,0,4-4V104a4,4,0,0,0-8,0v40A4,4,0,0,0,48,148Zm104,72H112a4,4,0,0,0,0,8h40a4,4,0,0,0,0-8Z"
},null,-1)])])):ny("",!0)],16))}}),qT={key:0},WT={key:1},XT={key:2},GT={key:3
},YT={key:4},KT={key:5},JT=Qg({name:"ScalarIconFileMd",props:{label:{},weight:{}
},setup(e){const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",qT,[...t[0]||(t[0]=[Gb("path",{
d:"M100,152v56a12,12,0,0,1-24,0V190.07l-6.17,8.81a12,12,0,0,1-19.66,0L44,190.07V208a12,12,0,0,1-24,0V152a12,12,0,0,1,21.83-6.88L60,171.07l18.17-25.95A12,12,0,0,1,100,152Zm84,28a40,40,0,0,1-40,40H128a12,12,0,0,1-12-12V152a12,12,0,0,1,12-12h16A40,40,0,0,1,184,180Zm-24,0a16,16,0,0,0-16-16h-4v32h4A16,16,0,0,0,160,180Zm60-92V224a12,12,0,0,1-24,0V104H148a12,12,0,0,1-12-12V44H60v64a12,12,0,0,1-24,0V40A20,20,0,0,1,56,20h96a12,12,0,0,1,8.49,3.52l56,56A12,12,0,0,1,220,88Zm-60-8h23L160,57Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",WT,[...t[1]||(t[1]=[Gb("path",{
d:"M208,88H152V32Z",opacity:"0.2"},null,-1),Gb("path",{
d:"M213.66,82.34l-56-56A8,8,0,0,0,152,24H56A16,16,0,0,0,40,40v72a8,8,0,0,0,16,0V40h88V88a8,8,0,0,0,8,8h48V224a8,8,0,0,0,16,0V88A8,8,0,0,0,213.66,82.34ZM160,51.31,188.69,80H160ZM144,144H128a8,8,0,0,0-8,8v56a8,8,0,0,0,8,8h16a36,36,0,0,0,0-72Zm0,56h-8V160h8a20,20,0,0,1,0,40Zm-40-48v56a8,8,0,0,1-16,0V177.38L74.55,196.59a8,8,0,0,1-13.1,0L48,177.38V208a8,8,0,0,1-16,0V152a8,8,0,0,1,14.55-4.59L68,178.05l21.45-30.64A8,8,0,0,1,104,152Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",XT,[...t[2]||(t[2]=[Gb("path",{
d:"M213.66,82.34l-56-56A8,8,0,0,0,152,24H56A16,16,0,0,0,40,40v76a4,4,0,0,0,4,4H196a4,4,0,0,1,4,4V224a8,8,0,0,0,9.19,7.91,8.15,8.15,0,0,0,6.81-8.16V88A8,8,0,0,0,213.66,82.34ZM152,88V44l44,44Zm-8,56H128a8,8,0,0,0-8,8v56a8,8,0,0,0,8,8h15.32c19.66,0,36.21-15.48,36.67-35.13A36,36,0,0,0,144,144Zm-.49,56H136V160h8a20,20,0,0,1,20,20.77C163.58,191.59,154.34,200,143.51,200ZM104,152v55.73A8.17,8.17,0,0,1,96.53,216,8,8,0,0,1,88,208V177.38l-13.32,19a8.3,8.3,0,0,1-4.2,3.2,8,8,0,0,1-9-3L48,177.38v30.35A8.17,8.17,0,0,1,40.53,216,8,8,0,0,1,32,208V152.31a8.27,8.27,0,0,1,4.56-7.53,8,8,0,0,1,10,2.63L68,178.05l21.27-30.39a8.28,8.28,0,0,1,8.06-3.55A8,8,0,0,1,104,152Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",GT,[...t[3]||(t[3]=[Gb("path",{
d:"M212.24,83.76l-56-56A6,6,0,0,0,152,26H56A14,14,0,0,0,42,40v72a6,6,0,0,0,12,0V40a2,2,0,0,1,2-2h90V88a6,6,0,0,0,6,6h50V224a6,6,0,0,0,12,0V88A6,6,0,0,0,212.24,83.76ZM158,46.48,193.52,82H158ZM144,146H128a6,6,0,0,0-6,6v56a6,6,0,0,0,6,6h16a34,34,0,0,0,0-68Zm0,56H134V158h10a22,22,0,0,1,0,44Zm-42-50v56a6,6,0,0,1-12,0V171L72.92,195.44a6,6,0,0,1-9.84,0L46,171v37a6,6,0,0,1-12,0V152a6,6,0,0,1,10.92-3.44l23.08,33,23.08-33A6,6,0,0,1,102,152Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",YT,[...t[4]||(t[4]=[Gb("path",{
d:"M213.66,82.34l-56-56A8,8,0,0,0,152,24H56A16,16,0,0,0,40,40v72a8,8,0,0,0,16,0V40h88V88a8,8,0,0,0,8,8h48V224a8,8,0,0,0,16,0V88A8,8,0,0,0,213.66,82.34ZM160,51.31,188.69,80H160ZM144,144H128a8,8,0,0,0-8,8v56a8,8,0,0,0,8,8h16a36,36,0,0,0,0-72Zm0,56h-8V160h8a20,20,0,0,1,0,40Zm-40-48v56a8,8,0,0,1-16,0V177.38L74.55,196.59a8,8,0,0,1-13.1,0L48,177.38V208a8,8,0,0,1-16,0V152a8,8,0,0,1,14.55-4.59L68,178.05l21.45-30.64A8,8,0,0,1,104,152Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",KT,[...t[5]||(t[5]=[Gb("path",{
d:"M210.83,85.17l-56-56A4,4,0,0,0,152,28H56A12,12,0,0,0,44,40v72a4,4,0,0,0,8,0V40a4,4,0,0,1,4-4h92V88a4,4,0,0,0,4,4h52V224a4,4,0,0,0,8,0V88A4,4,0,0,0,210.83,85.17ZM156,41.65,198.34,84H156ZM144,148H128a4,4,0,0,0-4,4v56a4,4,0,0,0,4,4h16a32,32,0,0,0,0-64Zm0,56H132V156h12a24,24,0,0,1,0,48Zm-44-52v56a4,4,0,0,1-8,0V164.69l-20.72,29.6a4,4,0,0,1-6.56,0L44,164.69V208a4,4,0,0,1-8,0V152a4,4,0,0,1,7.28-2.29L68,185l24.72-35.31A4,4,0,0,1,100,152Z"
},null,-1)])])):ny("",!0)],16))}}),eE={key:0},tE={key:1},nE={key:2},rE={key:3
},oE={key:4},aE={key:5},iE=Qg({name:"ScalarIconFileText",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",eE,[...t[0]||(t[0]=[Gb("path",{
d:"M216.49,79.52l-56-56A12,12,0,0,0,152,20H56A20,20,0,0,0,36,40V216a20,20,0,0,0,20,20H200a20,20,0,0,0,20-20V88A12,12,0,0,0,216.49,79.52ZM160,57l23,23H160ZM60,212V44h76V92a12,12,0,0,0,12,12h48V212Zm112-80a12,12,0,0,1-12,12H96a12,12,0,0,1,0-24h64A12,12,0,0,1,172,132Zm0,40a12,12,0,0,1-12,12H96a12,12,0,0,1,0-24h64A12,12,0,0,1,172,172Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",tE,[...t[1]||(t[1]=[Gb("path",{
d:"M208,88H152V32Z",opacity:"0.2"},null,-1),Gb("path",{
d:"M213.66,82.34l-56-56A8,8,0,0,0,152,24H56A16,16,0,0,0,40,40V216a16,16,0,0,0,16,16H200a16,16,0,0,0,16-16V88A8,8,0,0,0,213.66,82.34ZM160,51.31,188.69,80H160ZM200,216H56V40h88V88a8,8,0,0,0,8,8h48V216Zm-32-80a8,8,0,0,1-8,8H96a8,8,0,0,1,0-16h64A8,8,0,0,1,168,136Zm0,32a8,8,0,0,1-8,8H96a8,8,0,0,1,0-16h64A8,8,0,0,1,168,168Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",nE,[...t[2]||(t[2]=[Gb("path",{
d:"M213.66,82.34l-56-56A8,8,0,0,0,152,24H56A16,16,0,0,0,40,40V216a16,16,0,0,0,16,16H200a16,16,0,0,0,16-16V88A8,8,0,0,0,213.66,82.34ZM160,176H96a8,8,0,0,1,0-16h64a8,8,0,0,1,0,16Zm0-32H96a8,8,0,0,1,0-16h64a8,8,0,0,1,0,16Zm-8-56V44l44,44Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",rE,[...t[3]||(t[3]=[Gb("path",{
d:"M212.24,83.76l-56-56A6,6,0,0,0,152,26H56A14,14,0,0,0,42,40V216a14,14,0,0,0,14,14H200a14,14,0,0,0,14-14V88A6,6,0,0,0,212.24,83.76ZM158,46.48,193.52,82H158ZM200,218H56a2,2,0,0,1-2-2V40a2,2,0,0,1,2-2h90V88a6,6,0,0,0,6,6h50V216A2,2,0,0,1,200,218Zm-34-82a6,6,0,0,1-6,6H96a6,6,0,0,1,0-12h64A6,6,0,0,1,166,136Zm0,32a6,6,0,0,1-6,6H96a6,6,0,0,1,0-12h64A6,6,0,0,1,166,168Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",oE,[...t[4]||(t[4]=[Gb("path",{
d:"M213.66,82.34l-56-56A8,8,0,0,0,152,24H56A16,16,0,0,0,40,40V216a16,16,0,0,0,16,16H200a16,16,0,0,0,16-16V88A8,8,0,0,0,213.66,82.34ZM160,51.31,188.69,80H160ZM200,216H56V40h88V88a8,8,0,0,0,8,8h48V216Zm-32-80a8,8,0,0,1-8,8H96a8,8,0,0,1,0-16h64A8,8,0,0,1,168,136Zm0,32a8,8,0,0,1-8,8H96a8,8,0,0,1,0-16h64A8,8,0,0,1,168,168Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",aE,[...t[5]||(t[5]=[Gb("path",{
d:"M210.83,85.17l-56-56A4,4,0,0,0,152,28H56A12,12,0,0,0,44,40V216a12,12,0,0,0,12,12H200a12,12,0,0,0,12-12V88A4,4,0,0,0,210.83,85.17ZM156,41.65,198.34,84H156ZM200,220H56a4,4,0,0,1-4-4V40a4,4,0,0,1,4-4h92V88a4,4,0,0,0,4,4h52V216A4,4,0,0,1,200,220Zm-36-84a4,4,0,0,1-4,4H96a4,4,0,0,1,0-8h64A4,4,0,0,1,164,136Zm0,32a4,4,0,0,1-4,4H96a4,4,0,0,1,0-8h64A4,4,0,0,1,164,168Z"
},null,-1)])])):ny("",!0)],16))}}),sE={key:0},lE={key:1},cE={key:2},uE={key:3
},dE={key:4},pE={key:5},hE=Qg({name:"ScalarIconGavel",props:{label:{},weight:{}
},setup(e){const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",sE,[...t[0]||(t[0]=[Gb("path",{
d:"M246.14,113.86l-16-16a20,20,0,0,0-23.06-3.75l-45.2-45.2a20,20,0,0,0-3.74-23.06l-16-16a20,20,0,0,0-28.28,0l-64,64a20,20,0,0,0,0,28.28l16,16a20,20,0,0,0,23,3.79L29.36,181.38a32,32,0,0,0,45.26,45.26L134,167.21a20,20,0,0,0,3.81,22.94l16,16a20,20,0,0,0,28.29,0l64-64a20,20,0,0,0,0-28.29ZM80,98.34,69.64,88,128,29.65,138.34,40ZM57.64,209.67a8,8,0,0,1-11.31-11.32l59.52-59.52,11.31,11.32Zm92.7-60.29-43.72-43.72,39-39,43.72,43.72Zm17.65,37L157.65,176,216,117.66,226.34,128Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",lE,[...t[1]||(t[1]=[Gb("path",{
d:"M149.66,45.66l-64,64a8,8,0,0,1-11.32,0l-16-16a8,8,0,0,1,0-11.32l64-64a8,8,0,0,1,11.32,0l16,16A8,8,0,0,1,149.66,45.66Zm88,76.68-16-16a8,8,0,0,0-11.32,0l-64,64a8,8,0,0,0,0,11.32l16,16a8,8,0,0,0,11.32,0l64-64A8,8,0,0,0,237.66,122.34Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M243.32,116.69l-16-16a16,16,0,0,0-20.84-1.53L156.84,49.52a16,16,0,0,0-1.52-20.84l-16-16a16,16,0,0,0-22.63,0l-64,64a16,16,0,0,0,0,22.63l16,16a16,16,0,0,0,20.83,1.52L96.69,124,31.31,189.38A25,25,0,0,0,66.63,224.7L132,159.32l7.17,7.16a16,16,0,0,0,1.52,20.84l16,16a16,16,0,0,0,22.63,0l64-64A16,16,0,0,0,243.32,116.69ZM80,104,64,88l64-64,16,16ZM55.32,213.38a9,9,0,0,1-12.69,0,9,9,0,0,1,0-12.68L108,135.32,120.69,148ZM101,105.66,145.66,61,195,110.34,150.35,155ZM168,192l-16-16,4-4h0l56-56h0l4-4,16,16Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",cE,[...t[2]||(t[2]=[Gb("path",{
d:"M52.69,99.31a16,16,0,0,1,0-22.63l64-64a16,16,0,0,1,22.63,22.63l-64,64a16,16,0,0,1-22.63,0Zm190.63,17.37a16,16,0,0,0-22.63,0l-64,64a16,16,0,0,0,0,22.63h0a16,16,0,0,0,22.63,0l64-64A16,16,0,0,0,243.32,116.68Zm-35.11-15.8L155.12,47.79a4,4,0,0,0-5.66,0L87.8,109.45a4,4,0,0,0,0,5.66L103,130.34,28.69,204.69a16,16,0,0,0,22.62,22.62L125.66,153l15.23,15.23a4,4,0,0,0,5.66,0l61.66-61.66A4,4,0,0,0,208.21,100.88Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",uE,[...t[3]||(t[3]=[Gb("path",{
d:"M241.91,118.1l-16-16a14,14,0,0,0-19.55-.23L154.13,49.64a14,14,0,0,0-.23-19.55l-16-16a14,14,0,0,0-19.8,0l-64,64a14,14,0,0,0,0,19.8l16,16a14,14,0,0,0,19.55.23L99.52,124,32.73,190.79a23,23,0,0,0,32.48,32.49L132,156.49l9.87,9.87a14,14,0,0,0,.23,19.55l16,16a14,14,0,0,0,19.8,0l64-64A14,14,0,0,0,241.91,118.1Zm-91.56,39.76-52.21-52.2,47.52-47.52,52.2,52.2ZM78.59,105.41l-16-16a2,2,0,0,1,0-2.83l64-64a2,2,0,0,1,2.83,0l16,16a2,2,0,0,1,0,2.83l-64,64A2,2,0,0,1,78.59,105.41ZM56.73,214.8a11,11,0,0,1-15.52-15.52L108,132.49,123.52,148Zm176.69-85.38-64,64a2,2,0,0,1-2.83,0l-16-16a2,2,0,0,1,0-2.83l64-64a2,2,0,0,1,2.83,0l16,16A2,2,0,0,1,233.42,129.42Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",dE,[...t[4]||(t[4]=[Gb("path",{
d:"M243.32,116.69l-16-16a16,16,0,0,0-20.84-1.53L156.84,49.52a16,16,0,0,0-1.52-20.84l-16-16a16,16,0,0,0-22.63,0l-64,64a16,16,0,0,0,0,22.63l16,16a16,16,0,0,0,20.83,1.52L96.69,124,31.31,189.38A25,25,0,0,0,66.63,224.7L132,159.32l7.17,7.16a16,16,0,0,0,1.52,20.84l16,16a16,16,0,0,0,22.63,0l64-64A16,16,0,0,0,243.32,116.69ZM80,104,64,88l64-64,16,16ZM55.32,213.38a9,9,0,0,1-12.69,0,9,9,0,0,1,0-12.68L108,135.32,120.69,148ZM101,105.66,145.66,61,195,110.34,150.35,155ZM168,192l-16-16,4-4h0l56-56h0l4-4,16,16Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",pE,[...t[5]||(t[5]=[Gb("path",{
d:"M240.49,119.52l-16-16a12,12,0,0,0-17,0l-1.17,1.17-55-55,1.18-1.17a12,12,0,0,0,0-17l-16-16a12,12,0,0,0-17,0l-64,64a12,12,0,0,0,0,17l16,16a12,12,0,0,0,17,0l1.17-1.18L102.34,124l-68.2,68.21A21,21,0,0,0,63.8,221.87L132,153.66l12.69,12.69-1.18,1.17a12,12,0,0,0,0,17l16,16a12,12,0,0,0,17,0l64-64a12,12,0,0,0,0-17ZM77.17,106.83l-16-16a4,4,0,0,1,0-5.66l64-64a4,4,0,0,1,5.66,0l16,16a4,4,0,0,1,0,5.65l-64,64A4,4,0,0,1,77.17,106.83Zm-19,109.38A13,13,0,1,1,39.8,197.87L108,129.66,126.34,148ZM95.31,105.66l50.35-50.35,55,55-50.35,50.35Zm139.52,25.17-64,64a4,4,0,0,1-5.66,0l-16-16a4,4,0,0,1,0-5.65l64-64a4,4,0,0,1,5.66,0l16,16a4,4,0,0,1,0,5.66Z"
},null,-1)])])):ny("",!0)],16))}}),fE={key:0},mE={key:1},gE={key:2},vE={key:3
},bE={key:4},yE={key:5},OE=Qg({name:"ScalarIconGear",props:{label:{},weight:{}},
setup(e){const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",fE,[...t[0]||(t[0]=[Gb("path",{
d:"M128,76a52,52,0,1,0,52,52A52.06,52.06,0,0,0,128,76Zm0,80a28,28,0,1,1,28-28A28,28,0,0,1,128,156Zm92-27.21v-1.58l14-17.51a12,12,0,0,0,2.23-10.59A111.75,111.75,0,0,0,225,71.89,12,12,0,0,0,215.89,66L193.61,63.5l-1.11-1.11L190,40.1A12,12,0,0,0,184.11,31a111.67,111.67,0,0,0-27.23-11.27A12,12,0,0,0,146.3,22L128.79,36h-1.58L109.7,22a12,12,0,0,0-10.59-2.23A111.75,111.75,0,0,0,71.89,31.05,12,12,0,0,0,66,40.11L63.5,62.39,62.39,63.5,40.1,66A12,12,0,0,0,31,71.89,111.67,111.67,0,0,0,19.77,99.12,12,12,0,0,0,22,109.7l14,17.51v1.58L22,146.3a12,12,0,0,0-2.23,10.59,111.75,111.75,0,0,0,11.29,27.22A12,12,0,0,0,40.11,190l22.28,2.48,1.11,1.11L66,215.9A12,12,0,0,0,71.89,225a111.67,111.67,0,0,0,27.23,11.27A12,12,0,0,0,109.7,234l17.51-14h1.58l17.51,14a12,12,0,0,0,10.59,2.23A111.75,111.75,0,0,0,184.11,225a12,12,0,0,0,5.91-9.06l2.48-22.28,1.11-1.11L215.9,190a12,12,0,0,0,9.06-5.91,111.67,111.67,0,0,0,11.27-27.23A12,12,0,0,0,234,146.3Zm-24.12-4.89a70.1,70.1,0,0,1,0,8.2,12,12,0,0,0,2.61,8.22l12.84,16.05A86.47,86.47,0,0,1,207,166.86l-20.43,2.27a12,12,0,0,0-7.65,4,69,69,0,0,1-5.8,5.8,12,12,0,0,0-4,7.65L166.86,207a86.47,86.47,0,0,1-10.49,4.35l-16.05-12.85a12,12,0,0,0-7.5-2.62c-.24,0-.48,0-.72,0a70.1,70.1,0,0,1-8.2,0,12.06,12.06,0,0,0-8.22,2.6L99.63,211.33A86.47,86.47,0,0,1,89.14,207l-2.27-20.43a12,12,0,0,0-4-7.65,69,69,0,0,1-5.8-5.8,12,12,0,0,0-7.65-4L49,166.86a86.47,86.47,0,0,1-4.35-10.49l12.84-16.05a12,12,0,0,0,2.61-8.22,70.1,70.1,0,0,1,0-8.2,12,12,0,0,0-2.61-8.22L44.67,99.63A86.47,86.47,0,0,1,49,89.14l20.43-2.27a12,12,0,0,0,7.65-4,69,69,0,0,1,5.8-5.8,12,12,0,0,0,4-7.65L89.14,49a86.47,86.47,0,0,1,10.49-4.35l16.05,12.85a12.06,12.06,0,0,0,8.22,2.6,70.1,70.1,0,0,1,8.2,0,12,12,0,0,0,8.22-2.6l16.05-12.85A86.47,86.47,0,0,1,166.86,49l2.27,20.43a12,12,0,0,0,4,7.65,69,69,0,0,1,5.8,5.8,12,12,0,0,0,7.65,4L207,89.14a86.47,86.47,0,0,1,4.35,10.49l-12.84,16.05A12,12,0,0,0,195.88,123.9Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",mE,[...t[1]||(t[1]=[Gb("path",{
d:"M207.86,123.18l16.78-21a99.14,99.14,0,0,0-10.07-24.29l-26.7-3a81,81,0,0,0-6.81-6.81l-3-26.71a99.43,99.43,0,0,0-24.3-10l-21,16.77a81.59,81.59,0,0,0-9.64,0l-21-16.78A99.14,99.14,0,0,0,77.91,41.43l-3,26.7a81,81,0,0,0-6.81,6.81l-26.71,3a99.43,99.43,0,0,0-10,24.3l16.77,21a81.59,81.59,0,0,0,0,9.64l-16.78,21a99.14,99.14,0,0,0,10.07,24.29l26.7,3a81,81,0,0,0,6.81,6.81l3,26.71a99.43,99.43,0,0,0,24.3,10l21-16.77a81.59,81.59,0,0,0,9.64,0l21,16.78a99.14,99.14,0,0,0,24.29-10.07l3-26.7a81,81,0,0,0,6.81-6.81l26.71-3a99.43,99.43,0,0,0,10-24.3l-16.77-21A81.59,81.59,0,0,0,207.86,123.18ZM128,168a40,40,0,1,1,40-40A40,40,0,0,1,128,168Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M128,80a48,48,0,1,0,48,48A48.05,48.05,0,0,0,128,80Zm0,80a32,32,0,1,1,32-32A32,32,0,0,1,128,160Zm88-29.84q.06-2.16,0-4.32l14.92-18.64a8,8,0,0,0,1.48-7.06,107.6,107.6,0,0,0-10.88-26.25,8,8,0,0,0-6-3.93l-23.72-2.64q-1.48-1.56-3-3L186,40.54a8,8,0,0,0-3.94-6,107.29,107.29,0,0,0-26.25-10.86,8,8,0,0,0-7.06,1.48L130.16,40Q128,40,125.84,40L107.2,25.11a8,8,0,0,0-7.06-1.48A107.6,107.6,0,0,0,73.89,34.51a8,8,0,0,0-3.93,6L67.32,64.27q-1.56,1.49-3,3L40.54,70a8,8,0,0,0-6,3.94,107.71,107.71,0,0,0-10.87,26.25,8,8,0,0,0,1.49,7.06L40,125.84Q40,128,40,130.16L25.11,148.8a8,8,0,0,0-1.48,7.06,107.6,107.6,0,0,0,10.88,26.25,8,8,0,0,0,6,3.93l23.72,2.64q1.49,1.56,3,3L70,215.46a8,8,0,0,0,3.94,6,107.71,107.71,0,0,0,26.25,10.87,8,8,0,0,0,7.06-1.49L125.84,216q2.16.06,4.32,0l18.64,14.92a8,8,0,0,0,7.06,1.48,107.21,107.21,0,0,0,26.25-10.88,8,8,0,0,0,3.93-6l2.64-23.72q1.56-1.48,3-3L215.46,186a8,8,0,0,0,6-3.94,107.71,107.71,0,0,0,10.87-26.25,8,8,0,0,0-1.49-7.06Zm-16.1-6.5a73.93,73.93,0,0,1,0,8.68,8,8,0,0,0,1.74,5.48l14.19,17.73a91.57,91.57,0,0,1-6.23,15L187,173.11a8,8,0,0,0-5.1,2.64,74.11,74.11,0,0,1-6.14,6.14,8,8,0,0,0-2.64,5.1l-2.51,22.58a91.32,91.32,0,0,1-15,6.23l-17.74-14.19a8,8,0,0,0-5-1.75h-.48a73.93,73.93,0,0,1-8.68,0,8.06,8.06,0,0,0-5.48,1.74L100.45,215.8a91.57,91.57,0,0,1-15-6.23L82.89,187a8,8,0,0,0-2.64-5.1,74.11,74.11,0,0,1-6.14-6.14,8,8,0,0,0-5.1-2.64L46.43,170.6a91.32,91.32,0,0,1-6.23-15l14.19-17.74a8,8,0,0,0,1.74-5.48,73.93,73.93,0,0,1,0-8.68,8,8,0,0,0-1.74-5.48L40.2,100.45a91.57,91.57,0,0,1,6.23-15L69,82.89a8,8,0,0,0,5.1-2.64,74.11,74.11,0,0,1,6.14-6.14A8,8,0,0,0,82.89,69L85.4,46.43a91.32,91.32,0,0,1,15-6.23l17.74,14.19a8,8,0,0,0,5.48,1.74,73.93,73.93,0,0,1,8.68,0,8.06,8.06,0,0,0,5.48-1.74L155.55,40.2a91.57,91.57,0,0,1,15,6.23L173.11,69a8,8,0,0,0,2.64,5.1,74.11,74.11,0,0,1,6.14,6.14,8,8,0,0,0,5.1,2.64l22.58,2.51a91.32,91.32,0,0,1,6.23,15l-14.19,17.74A8,8,0,0,0,199.87,123.66Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",gE,[...t[2]||(t[2]=[Gb("path",{
d:"M216,130.16q.06-2.16,0-4.32l14.92-18.64a8,8,0,0,0,1.48-7.06,107.6,107.6,0,0,0-10.88-26.25,8,8,0,0,0-6-3.93l-23.72-2.64q-1.48-1.56-3-3L186,40.54a8,8,0,0,0-3.94-6,107.29,107.29,0,0,0-26.25-10.86,8,8,0,0,0-7.06,1.48L130.16,40Q128,40,125.84,40L107.2,25.11a8,8,0,0,0-7.06-1.48A107.6,107.6,0,0,0,73.89,34.51a8,8,0,0,0-3.93,6L67.32,64.27q-1.56,1.49-3,3L40.54,70a8,8,0,0,0-6,3.94,107.71,107.71,0,0,0-10.87,26.25,8,8,0,0,0,1.49,7.06L40,125.84Q40,128,40,130.16L25.11,148.8a8,8,0,0,0-1.48,7.06,107.6,107.6,0,0,0,10.88,26.25,8,8,0,0,0,6,3.93l23.72,2.64q1.49,1.56,3,3L70,215.46a8,8,0,0,0,3.94,6,107.71,107.71,0,0,0,26.25,10.87,8,8,0,0,0,7.06-1.49L125.84,216q2.16.06,4.32,0l18.64,14.92a8,8,0,0,0,7.06,1.48,107.21,107.21,0,0,0,26.25-10.88,8,8,0,0,0,3.93-6l2.64-23.72q1.56-1.48,3-3L215.46,186a8,8,0,0,0,6-3.94,107.71,107.71,0,0,0,10.87-26.25,8,8,0,0,0-1.49-7.06ZM128,168a40,40,0,1,1,40-40A40,40,0,0,1,128,168Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",vE,[...t[3]||(t[3]=[Gb("path",{
d:"M128,82a46,46,0,1,0,46,46A46.06,46.06,0,0,0,128,82Zm0,80a34,34,0,1,1,34-34A34,34,0,0,1,128,162ZM214,130.84c.06-1.89.06-3.79,0-5.68L229.33,106a6,6,0,0,0,1.11-5.29A105.34,105.34,0,0,0,219.76,74.9a6,6,0,0,0-4.53-3l-24.45-2.71q-1.93-2.07-4-4l-2.72-24.46a6,6,0,0,0-3-4.53,105.65,105.65,0,0,0-25.77-10.66A6,6,0,0,0,150,26.68l-19.2,15.37c-1.89-.06-3.79-.06-5.68,0L106,26.67a6,6,0,0,0-5.29-1.11A105.34,105.34,0,0,0,74.9,36.24a6,6,0,0,0-3,4.53L69.23,65.22q-2.07,1.94-4,4L40.76,72a6,6,0,0,0-4.53,3,105.65,105.65,0,0,0-10.66,25.77A6,6,0,0,0,26.68,106l15.37,19.2c-.06,1.89-.06,3.79,0,5.68L26.67,150.05a6,6,0,0,0-1.11,5.29A105.34,105.34,0,0,0,36.24,181.1a6,6,0,0,0,4.53,3l24.45,2.71q1.94,2.07,4,4L72,215.24a6,6,0,0,0,3,4.53,105.65,105.65,0,0,0,25.77,10.66,6,6,0,0,0,5.29-1.11L125.16,214c1.89.06,3.79.06,5.68,0l19.21,15.38a6,6,0,0,0,3.75,1.31,6.2,6.2,0,0,0,1.54-.2,105.34,105.34,0,0,0,25.76-10.68,6,6,0,0,0,3-4.53l2.71-24.45q2.07-1.93,4-4l24.46-2.72a6,6,0,0,0,4.53-3,105.49,105.49,0,0,0,10.66-25.77,6,6,0,0,0-1.11-5.29Zm-3.1,41.63-23.64,2.63a6,6,0,0,0-3.82,2,75.14,75.14,0,0,1-6.31,6.31,6,6,0,0,0-2,3.82l-2.63,23.63A94.28,94.28,0,0,1,155.14,218l-18.57-14.86a6,6,0,0,0-3.75-1.31h-.36a78.07,78.07,0,0,1-8.92,0,6,6,0,0,0-4.11,1.3L100.87,218a94.13,94.13,0,0,1-17.34-7.17L80.9,187.21a6,6,0,0,0-2-3.82,75.14,75.14,0,0,1-6.31-6.31,6,6,0,0,0-3.82-2l-23.63-2.63A94.28,94.28,0,0,1,38,155.14l14.86-18.57a6,6,0,0,0,1.3-4.11,78.07,78.07,0,0,1,0-8.92,6,6,0,0,0-1.3-4.11L38,100.87a94.13,94.13,0,0,1,7.17-17.34L68.79,80.9a6,6,0,0,0,3.82-2,75.14,75.14,0,0,1,6.31-6.31,6,6,0,0,0,2-3.82l2.63-23.63A94.28,94.28,0,0,1,100.86,38l18.57,14.86a6,6,0,0,0,4.11,1.3,78.07,78.07,0,0,1,8.92,0,6,6,0,0,0,4.11-1.3L155.13,38a94.13,94.13,0,0,1,17.34,7.17l2.63,23.64a6,6,0,0,0,2,3.82,75.14,75.14,0,0,1,6.31,6.31,6,6,0,0,0,3.82,2l23.63,2.63A94.28,94.28,0,0,1,218,100.86l-14.86,18.57a6,6,0,0,0-1.3,4.11,78.07,78.07,0,0,1,0,8.92,6,6,0,0,0,1.3,4.11L218,155.13A94.13,94.13,0,0,1,210.85,172.47Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",bE,[...t[4]||(t[4]=[Gb("path",{
d:"M128,80a48,48,0,1,0,48,48A48.05,48.05,0,0,0,128,80Zm0,80a32,32,0,1,1,32-32A32,32,0,0,1,128,160Zm88-29.84q.06-2.16,0-4.32l14.92-18.64a8,8,0,0,0,1.48-7.06,107.21,107.21,0,0,0-10.88-26.25,8,8,0,0,0-6-3.93l-23.72-2.64q-1.48-1.56-3-3L186,40.54a8,8,0,0,0-3.94-6,107.71,107.71,0,0,0-26.25-10.87,8,8,0,0,0-7.06,1.49L130.16,40Q128,40,125.84,40L107.2,25.11a8,8,0,0,0-7.06-1.48A107.6,107.6,0,0,0,73.89,34.51a8,8,0,0,0-3.93,6L67.32,64.27q-1.56,1.49-3,3L40.54,70a8,8,0,0,0-6,3.94,107.71,107.71,0,0,0-10.87,26.25,8,8,0,0,0,1.49,7.06L40,125.84Q40,128,40,130.16L25.11,148.8a8,8,0,0,0-1.48,7.06,107.21,107.21,0,0,0,10.88,26.25,8,8,0,0,0,6,3.93l23.72,2.64q1.49,1.56,3,3L70,215.46a8,8,0,0,0,3.94,6,107.71,107.71,0,0,0,26.25,10.87,8,8,0,0,0,7.06-1.49L125.84,216q2.16.06,4.32,0l18.64,14.92a8,8,0,0,0,7.06,1.48,107.21,107.21,0,0,0,26.25-10.88,8,8,0,0,0,3.93-6l2.64-23.72q1.56-1.48,3-3L215.46,186a8,8,0,0,0,6-3.94,107.71,107.71,0,0,0,10.87-26.25,8,8,0,0,0-1.49-7.06Zm-16.1-6.5a73.93,73.93,0,0,1,0,8.68,8,8,0,0,0,1.74,5.48l14.19,17.73a91.57,91.57,0,0,1-6.23,15L187,173.11a8,8,0,0,0-5.1,2.64,74.11,74.11,0,0,1-6.14,6.14,8,8,0,0,0-2.64,5.1l-2.51,22.58a91.32,91.32,0,0,1-15,6.23l-17.74-14.19a8,8,0,0,0-5-1.75h-.48a73.93,73.93,0,0,1-8.68,0,8,8,0,0,0-5.48,1.74L100.45,215.8a91.57,91.57,0,0,1-15-6.23L82.89,187a8,8,0,0,0-2.64-5.1,74.11,74.11,0,0,1-6.14-6.14,8,8,0,0,0-5.1-2.64L46.43,170.6a91.32,91.32,0,0,1-6.23-15l14.19-17.74a8,8,0,0,0,1.74-5.48,73.93,73.93,0,0,1,0-8.68,8,8,0,0,0-1.74-5.48L40.2,100.45a91.57,91.57,0,0,1,6.23-15L69,82.89a8,8,0,0,0,5.1-2.64,74.11,74.11,0,0,1,6.14-6.14A8,8,0,0,0,82.89,69L85.4,46.43a91.32,91.32,0,0,1,15-6.23l17.74,14.19a8,8,0,0,0,5.48,1.74,73.93,73.93,0,0,1,8.68,0,8,8,0,0,0,5.48-1.74L155.55,40.2a91.57,91.57,0,0,1,15,6.23L173.11,69a8,8,0,0,0,2.64,5.1,74.11,74.11,0,0,1,6.14,6.14,8,8,0,0,0,5.1,2.64l22.58,2.51a91.32,91.32,0,0,1,6.23,15l-14.19,17.74A8,8,0,0,0,199.87,123.66Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",yE,[...t[5]||(t[5]=[Gb("path",{
d:"M128,84a44,44,0,1,0,44,44A44.05,44.05,0,0,0,128,84Zm0,80a36,36,0,1,1,36-36A36,36,0,0,1,128,164Zm83.93-32.49q.13-3.51,0-7l15.83-19.79a4,4,0,0,0,.75-3.53A103.64,103.64,0,0,0,218,75.9a4,4,0,0,0-3-2l-25.19-2.8c-1.58-1.71-3.24-3.37-4.95-4.95L182.07,41a4,4,0,0,0-2-3A104,104,0,0,0,154.82,27.5a4,4,0,0,0-3.53.74L131.51,44.07q-3.51-.14-7,0L104.7,28.24a4,4,0,0,0-3.53-.75A103.64,103.64,0,0,0,75.9,38a4,4,0,0,0-2,3l-2.8,25.19c-1.71,1.58-3.37,3.24-4.95,4.95L41,73.93a4,4,0,0,0-3,2A104,104,0,0,0,27.5,101.18a4,4,0,0,0,.74,3.53l15.83,19.78q-.14,3.51,0,7L28.24,151.3a4,4,0,0,0-.75,3.53A103.64,103.64,0,0,0,38,180.1a4,4,0,0,0,3,2l25.19,2.8c1.58,1.71,3.24,3.37,4.95,4.95l2.8,25.2a4,4,0,0,0,2,3,104,104,0,0,0,25.28,10.46,4,4,0,0,0,3.53-.74l19.78-15.83q3.51.13,7,0l19.79,15.83a4,4,0,0,0,2.5.88,4,4,0,0,0,1-.13A103.64,103.64,0,0,0,180.1,218a4,4,0,0,0,2-3l2.8-25.19c1.71-1.58,3.37-3.24,4.95-4.95l25.2-2.8a4,4,0,0,0,3-2,104,104,0,0,0,10.46-25.28,4,4,0,0,0-.74-3.53Zm.17,42.83-24.67,2.74a4,4,0,0,0-2.55,1.32,76.2,76.2,0,0,1-6.48,6.48,4,4,0,0,0-1.32,2.55l-2.74,24.66a95.45,95.45,0,0,1-19.64,8.15l-19.38-15.51a4,4,0,0,0-2.5-.87h-.24a73.67,73.67,0,0,1-9.16,0,4,4,0,0,0-2.74.87l-19.37,15.5a95.33,95.33,0,0,1-19.65-8.13l-2.74-24.67a4,4,0,0,0-1.32-2.55,76.2,76.2,0,0,1-6.48-6.48,4,4,0,0,0-2.55-1.32l-24.66-2.74a95.45,95.45,0,0,1-8.15-19.64l15.51-19.38a4,4,0,0,0,.87-2.74,77.76,77.76,0,0,1,0-9.16,4,4,0,0,0-.87-2.74l-15.5-19.37A95.33,95.33,0,0,1,43.9,81.66l24.67-2.74a4,4,0,0,0,2.55-1.32,76.2,76.2,0,0,1,6.48-6.48,4,4,0,0,0,1.32-2.55l2.74-24.66a95.45,95.45,0,0,1,19.64-8.15l19.38,15.51a4,4,0,0,0,2.74.87,73.67,73.67,0,0,1,9.16,0,4,4,0,0,0,2.74-.87l19.37-15.5a95.33,95.33,0,0,1,19.65,8.13l2.74,24.67a4,4,0,0,0,1.32,2.55,76.2,76.2,0,0,1,6.48,6.48,4,4,0,0,0,2.55,1.32l24.66,2.74a95.45,95.45,0,0,1,8.15,19.64l-15.51,19.38a4,4,0,0,0-.87,2.74,77.76,77.76,0,0,1,0,9.16,4,4,0,0,0,.87,2.74l15.5,19.37A95.33,95.33,0,0,1,212.1,174.34Z"
},null,-1)])])):ny("",!0)],16))}}),wE={key:0},xE={key:1},kE={key:2},SE={key:3
},_E={key:4},TE={key:5},EE=Qg({name:"ScalarIconGitBranch",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",wE,[...t[0]||(t[0]=[Gb("path",{
d:"M236,64a36,36,0,1,0-48,33.94V112a4,4,0,0,1-4,4H96a27.8,27.8,0,0,0-4,.29V97.94a36,36,0,1,0-24,0v60.12a36,36,0,1,0,24,0V144a4,4,0,0,1,4-4h88a28,28,0,0,0,28-28V97.94A36.07,36.07,0,0,0,236,64ZM80,52A12,12,0,1,1,68,64,12,12,0,0,1,80,52Zm0,152a12,12,0,1,1,12-12A12,12,0,0,1,80,204ZM200,76a12,12,0,1,1,12-12A12,12,0,0,1,200,76Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",xE,[...t[1]||(t[1]=[Gb("path",{
d:"M224,64a24,24,0,1,1-24-24A24,24,0,0,1,224,64Z",opacity:"0.2"
},null,-1),Gb("path",{
d:"M232,64a32,32,0,1,0-40,31v17a8,8,0,0,1-8,8H96a23.84,23.84,0,0,0-8,1.38V95a32,32,0,1,0-16,0v66a32,32,0,1,0,16,0V144a8,8,0,0,1,8-8h88a24,24,0,0,0,24-24V95A32.06,32.06,0,0,0,232,64ZM64,64A16,16,0,1,1,80,80,16,16,0,0,1,64,64ZM96,192a16,16,0,1,1-16-16A16,16,0,0,1,96,192ZM200,80a16,16,0,1,1,16-16A16,16,0,0,1,200,80Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",kE,[...t[2]||(t[2]=[Gb("path",{
d:"M232,64a32,32,0,1,0-40,31v17a8,8,0,0,1-8,8H96a23.84,23.84,0,0,0-8,1.38V95a32,32,0,1,0-16,0v66a32,32,0,1,0,16,0V144a8,8,0,0,1,8-8h88a24,24,0,0,0,24-24V95A32.06,32.06,0,0,0,232,64ZM64,64A16,16,0,1,1,80,80,16,16,0,0,1,64,64ZM96,192a16,16,0,1,1-16-16A16,16,0,0,1,96,192Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",SE,[...t[3]||(t[3]=[Gb("path",{
d:"M230,64a30,30,0,1,0-36,29.4V112a10,10,0,0,1-10,10H96a21.84,21.84,0,0,0-10,2.42v-31a30,30,0,1,0-12,0v69.2a30,30,0,1,0,12,0V144a10,10,0,0,1,10-10h88a22,22,0,0,0,22-22V93.4A30.05,30.05,0,0,0,230,64ZM62,64A18,18,0,1,1,80,82,18,18,0,0,1,62,64ZM98,192a18,18,0,1,1-18-18A18,18,0,0,1,98,192ZM200,82a18,18,0,1,1,18-18A18,18,0,0,1,200,82Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",_E,[...t[4]||(t[4]=[Gb("path",{
d:"M232,64a32,32,0,1,0-40,31v17a8,8,0,0,1-8,8H96a23.84,23.84,0,0,0-8,1.38V95a32,32,0,1,0-16,0v66a32,32,0,1,0,16,0V144a8,8,0,0,1,8-8h88a24,24,0,0,0,24-24V95A32.06,32.06,0,0,0,232,64ZM64,64A16,16,0,1,1,80,80,16,16,0,0,1,64,64ZM96,192a16,16,0,1,1-16-16A16,16,0,0,1,96,192ZM200,80a16,16,0,1,1,16-16A16,16,0,0,1,200,80Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",TE,[...t[5]||(t[5]=[Gb("path",{
d:"M228,64a28,28,0,1,0-32,27.71V112a12,12,0,0,1-12,12H96a19.91,19.91,0,0,0-12,4V91.71a28,28,0,1,0-8,0v72.58a28,28,0,1,0,8,0V144a12,12,0,0,1,12-12h88a20,20,0,0,0,20-20V91.71A28,28,0,0,0,228,64ZM60,64A20,20,0,1,1,80,84,20,20,0,0,1,60,64Zm40,128a20,20,0,1,1-20-20A20,20,0,0,1,100,192ZM200,84a20,20,0,1,1,20-20A20,20,0,0,1,200,84Z"
},null,-1)])])):ny("",!0)],16))}}),AE={key:0},CE={key:1},$E={key:2},PE={key:3
},DE={key:4},IE={key:5},ME=Qg({name:"ScalarIconGithubLogo",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",AE,[...t[0]||(t[0]=[Gb("path",{
d:"M212.62,75.17A63.7,63.7,0,0,0,206.39,26,12,12,0,0,0,196,20a63.71,63.71,0,0,0-50,24H126A63.71,63.71,0,0,0,76,20a12,12,0,0,0-10.39,6,63.7,63.7,0,0,0-6.23,49.17A61.5,61.5,0,0,0,52,104v8a60.1,60.1,0,0,0,45.76,58.28A43.66,43.66,0,0,0,92,192v4H76a20,20,0,0,1-20-20,44.05,44.05,0,0,0-44-44,12,12,0,0,0,0,24,20,20,0,0,1,20,20,44.05,44.05,0,0,0,44,44H92v12a12,12,0,0,0,24,0V192a20,20,0,0,1,40,0v40a12,12,0,0,0,24,0V192a43.66,43.66,0,0,0-5.76-21.72A60.1,60.1,0,0,0,220,112v-8A61.5,61.5,0,0,0,212.62,75.17ZM196,112a36,36,0,0,1-36,36H112a36,36,0,0,1-36-36v-8a37.87,37.87,0,0,1,6.13-20.12,11.65,11.65,0,0,0,1.58-11.49,39.9,39.9,0,0,1-.4-27.72,39.87,39.87,0,0,1,26.41,17.8A12,12,0,0,0,119.82,68h32.35a12,12,0,0,0,10.11-5.53,39.84,39.84,0,0,1,26.41-17.8,39.9,39.9,0,0,1-.4,27.72,12,12,0,0,0,1.61,11.53A37.85,37.85,0,0,1,196,104Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",CE,[...t[1]||(t[1]=[Gb("path",{
d:"M208,104v8a48,48,0,0,1-48,48H136a32,32,0,0,1,32,32v40H104V192a32,32,0,0,1,32-32H112a48,48,0,0,1-48-48v-8a49.28,49.28,0,0,1,8.51-27.3A51.92,51.92,0,0,1,76,32a52,52,0,0,1,43.83,24h32.34A52,52,0,0,1,196,32a51.92,51.92,0,0,1,3.49,44.7A49.28,49.28,0,0,1,208,104Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M208.3,75.68A59.74,59.74,0,0,0,202.93,28,8,8,0,0,0,196,24a59.75,59.75,0,0,0-48,24H124A59.75,59.75,0,0,0,76,24a8,8,0,0,0-6.93,4,59.78,59.78,0,0,0-5.38,47.68A58.14,58.14,0,0,0,56,104v8a56.06,56.06,0,0,0,48.44,55.47A39.8,39.8,0,0,0,96,192v8H72a24,24,0,0,1-24-24A40,40,0,0,0,8,136a8,8,0,0,0,0,16,24,24,0,0,1,24,24,40,40,0,0,0,40,40H96v16a8,8,0,0,0,16,0V192a24,24,0,0,1,48,0v40a8,8,0,0,0,16,0V192a39.8,39.8,0,0,0-8.44-24.53A56.06,56.06,0,0,0,216,112v-8A58,58,0,0,0,208.3,75.68ZM200,112a40,40,0,0,1-40,40H112a40,40,0,0,1-40-40v-8a41.74,41.74,0,0,1,6.9-22.48A8,8,0,0,0,80,73.83a43.81,43.81,0,0,1,.79-33.58,43.88,43.88,0,0,1,32.32,20.06A8,8,0,0,0,119.82,64h32.35a8,8,0,0,0,6.74-3.69,43.87,43.87,0,0,1,32.32-20.06A43.81,43.81,0,0,1,192,73.83a8.09,8.09,0,0,0,1,7.65A41.76,41.76,0,0,1,200,104Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",$E,[...t[2]||(t[2]=[Gb("path",{
d:"M216,104v8a56.06,56.06,0,0,1-48.44,55.47A39.8,39.8,0,0,1,176,192v40a8,8,0,0,1-8,8H104a8,8,0,0,1-8-8V216H72a40,40,0,0,1-40-40A24,24,0,0,0,8,152a8,8,0,0,1,0-16,40,40,0,0,1,40,40,24,24,0,0,0,24,24H96v-8a39.8,39.8,0,0,1,8.44-24.53A56.06,56.06,0,0,1,56,112v-8a58.14,58.14,0,0,1,7.69-28.32A59.78,59.78,0,0,1,69.07,28,8,8,0,0,1,76,24a59.75,59.75,0,0,1,48,24h24a59.75,59.75,0,0,1,48-24,8,8,0,0,1,6.93,4,59.74,59.74,0,0,1,5.37,47.68A58,58,0,0,1,216,104Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",PE,[...t[3]||(t[3]=[Gb("path",{
d:"M206.13,75.92A57.79,57.79,0,0,0,201.2,29a6,6,0,0,0-5.2-3,57.77,57.77,0,0,0-47,24H123A57.77,57.77,0,0,0,76,26a6,6,0,0,0-5.2,3,57.79,57.79,0,0,0-4.93,46.92A55.88,55.88,0,0,0,58,104v8a54.06,54.06,0,0,0,50.45,53.87A37.85,37.85,0,0,0,98,192v10H72a26,26,0,0,1-26-26A38,38,0,0,0,8,138a6,6,0,0,0,0,12,26,26,0,0,1,26,26,38,38,0,0,0,38,38H98v18a6,6,0,0,0,12,0V192a26,26,0,0,1,52,0v40a6,6,0,0,0,12,0V192a37.85,37.85,0,0,0-10.45-26.13A54.06,54.06,0,0,0,214,112v-8A55.88,55.88,0,0,0,206.13,75.92ZM202,112a42,42,0,0,1-42,42H112a42,42,0,0,1-42-42v-8a43.86,43.86,0,0,1,7.3-23.69,6,6,0,0,0,.81-5.76,45.85,45.85,0,0,1,1.43-36.42,45.85,45.85,0,0,1,35.23,21.1A6,6,0,0,0,119.83,62h32.34a6,6,0,0,0,5.06-2.76,45.83,45.83,0,0,1,35.23-21.11,45.85,45.85,0,0,1,1.43,36.42,6,6,0,0,0,.79,5.74A43.78,43.78,0,0,1,202,104Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",DE,[...t[4]||(t[4]=[Gb("path",{
d:"M208.31,75.68A59.78,59.78,0,0,0,202.93,28,8,8,0,0,0,196,24a59.75,59.75,0,0,0-48,24H124A59.75,59.75,0,0,0,76,24a8,8,0,0,0-6.93,4,59.78,59.78,0,0,0-5.38,47.68A58.14,58.14,0,0,0,56,104v8a56.06,56.06,0,0,0,48.44,55.47A39.8,39.8,0,0,0,96,192v8H72a24,24,0,0,1-24-24A40,40,0,0,0,8,136a8,8,0,0,0,0,16,24,24,0,0,1,24,24,40,40,0,0,0,40,40H96v16a8,8,0,0,0,16,0V192a24,24,0,0,1,48,0v40a8,8,0,0,0,16,0V192a39.8,39.8,0,0,0-8.44-24.53A56.06,56.06,0,0,0,216,112v-8A58.14,58.14,0,0,0,208.31,75.68ZM200,112a40,40,0,0,1-40,40H112a40,40,0,0,1-40-40v-8a41.74,41.74,0,0,1,6.9-22.48A8,8,0,0,0,80,73.83a43.81,43.81,0,0,1,.79-33.58,43.88,43.88,0,0,1,32.32,20.06A8,8,0,0,0,119.82,64h32.35a8,8,0,0,0,6.74-3.69,43.87,43.87,0,0,1,32.32-20.06A43.81,43.81,0,0,1,192,73.83a8.09,8.09,0,0,0,1,7.65A41.72,41.72,0,0,1,200,104Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",IE,[...t[5]||(t[5]=[Gb("path",{
d:"M203.94,76.16A55.73,55.73,0,0,0,199.46,30,4,4,0,0,0,196,28a55.78,55.78,0,0,0-46,24H122A55.78,55.78,0,0,0,76,28a4,4,0,0,0-3.46,2,55.73,55.73,0,0,0-4.48,46.16A53.78,53.78,0,0,0,60,104v8a52.06,52.06,0,0,0,52,52h1.41A36,36,0,0,0,100,192v12H72a28,28,0,0,1-28-28A36,36,0,0,0,8,140a4,4,0,0,0,0,8,28,28,0,0,1,28,28,36,36,0,0,0,36,36h28v20a4,4,0,0,0,8,0V192a28,28,0,0,1,56,0v40a4,4,0,0,0,8,0V192a36,36,0,0,0-13.41-28H160a52.06,52.06,0,0,0,52-52v-8A53.78,53.78,0,0,0,203.94,76.16ZM204,112a44.05,44.05,0,0,1-44,44H112a44.05,44.05,0,0,1-44-44v-8a45.76,45.76,0,0,1,7.71-24.89,4,4,0,0,0,.53-3.84,47.82,47.82,0,0,1,2.1-39.21,47.8,47.8,0,0,1,38.12,22.1A4,4,0,0,0,119.83,60h32.34a4,4,0,0,0,3.37-1.84,47.8,47.8,0,0,1,38.12-22.1,47.82,47.82,0,0,1,2.1,39.21,4,4,0,0,0,.53,3.83A45.85,45.85,0,0,1,204,104Z"
},null,-1)])])):ny("",!0)],16))}}),NE={key:0},RE={key:1},LE={key:2},BE={key:3
},jE={key:4},UE={key:5},zE=Qg({name:"ScalarIconGlobe",props:{label:{},weight:{}
},setup(e){const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",NE,[...t[0]||(t[0]=[Gb("path",{
d:"M128,20A108,108,0,1,0,236,128,108.12,108.12,0,0,0,128,20Zm0,187a113.4,113.4,0,0,1-20.39-35h40.82a116.94,116.94,0,0,1-10,20.77A108.61,108.61,0,0,1,128,207Zm-26.49-59a135.42,135.42,0,0,1,0-40h53a135.42,135.42,0,0,1,0,40ZM44,128a83.49,83.49,0,0,1,2.43-20H77.25a160.63,160.63,0,0,0,0,40H46.43A83.49,83.49,0,0,1,44,128Zm84-79a113.4,113.4,0,0,1,20.39,35H107.59a116.94,116.94,0,0,1,10-20.77A108.61,108.61,0,0,1,128,49Zm50.73,59h30.82a83.52,83.52,0,0,1,0,40H178.75a160.63,160.63,0,0,0,0-40Zm20.77-24H173.71a140.82,140.82,0,0,0-15.5-34.36A84.51,84.51,0,0,1,199.52,84ZM97.79,49.64A140.82,140.82,0,0,0,82.29,84H56.48A84.51,84.51,0,0,1,97.79,49.64ZM56.48,172H82.29a140.82,140.82,0,0,0,15.5,34.36A84.51,84.51,0,0,1,56.48,172Zm101.73,34.36A140.82,140.82,0,0,0,173.71,172h25.81A84.51,84.51,0,0,1,158.21,206.36Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",RE,[...t[1]||(t[1]=[Gb("path",{
d:"M224,128a96,96,0,1,1-96-96A96,96,0,0,1,224,128Z",opacity:"0.2"
},null,-1),Gb("path",{
d:"M128,24h0A104,104,0,1,0,232,128,104.12,104.12,0,0,0,128,24Zm88,104a87.61,87.61,0,0,1-3.33,24H174.16a157.44,157.44,0,0,0,0-48h38.51A87.61,87.61,0,0,1,216,128ZM102,168H154a115.11,115.11,0,0,1-26,45A115.27,115.27,0,0,1,102,168Zm-3.9-16a140.84,140.84,0,0,1,0-48h59.88a140.84,140.84,0,0,1,0,48ZM40,128a87.61,87.61,0,0,1,3.33-24H81.84a157.44,157.44,0,0,0,0,48H43.33A87.61,87.61,0,0,1,40,128ZM154,88H102a115.11,115.11,0,0,1,26-45A115.27,115.27,0,0,1,154,88Zm52.33,0H170.71a135.28,135.28,0,0,0-22.3-45.6A88.29,88.29,0,0,1,206.37,88ZM107.59,42.4A135.28,135.28,0,0,0,85.29,88H49.63A88.29,88.29,0,0,1,107.59,42.4ZM49.63,168H85.29a135.28,135.28,0,0,0,22.3,45.6A88.29,88.29,0,0,1,49.63,168Zm98.78,45.6a135.28,135.28,0,0,0,22.3-45.6h35.66A88.29,88.29,0,0,1,148.41,213.6Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",LE,[...t[2]||(t[2]=[Gb("path",{
d:"M128,24h0A104,104,0,1,0,232,128,104.12,104.12,0,0,0,128,24Zm78.36,64H170.71a135.28,135.28,0,0,0-22.3-45.6A88.29,88.29,0,0,1,206.37,88ZM216,128a87.61,87.61,0,0,1-3.33,24H174.16a157.44,157.44,0,0,0,0-48h38.51A87.61,87.61,0,0,1,216,128ZM128,43a115.27,115.27,0,0,1,26,45H102A115.11,115.11,0,0,1,128,43ZM102,168H154a115.11,115.11,0,0,1-26,45A115.27,115.27,0,0,1,102,168Zm-3.9-16a140.84,140.84,0,0,1,0-48h59.88a140.84,140.84,0,0,1,0,48Zm50.35,61.6a135.28,135.28,0,0,0,22.3-45.6h35.66A88.29,88.29,0,0,1,148.41,213.6Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",BE,[...t[3]||(t[3]=[Gb("path",{
d:"M128,26A102,102,0,1,0,230,128,102.12,102.12,0,0,0,128,26Zm81.57,64H169.19a132.58,132.58,0,0,0-25.73-50.67A90.29,90.29,0,0,1,209.57,90ZM218,128a89.7,89.7,0,0,1-3.83,26H171.81a155.43,155.43,0,0,0,0-52h42.36A89.7,89.7,0,0,1,218,128Zm-90,87.83a110,110,0,0,1-15.19-19.45A124.24,124.24,0,0,1,99.35,166h57.3a124.24,124.24,0,0,1-13.46,30.38A110,110,0,0,1,128,215.83ZM96.45,154a139.18,139.18,0,0,1,0-52h63.1a139.18,139.18,0,0,1,0,52ZM38,128a89.7,89.7,0,0,1,3.83-26H84.19a155.43,155.43,0,0,0,0,52H41.83A89.7,89.7,0,0,1,38,128Zm90-87.83a110,110,0,0,1,15.19,19.45A124.24,124.24,0,0,1,156.65,90H99.35a124.24,124.24,0,0,1,13.46-30.38A110,110,0,0,1,128,40.17Zm-15.46-.84A132.58,132.58,0,0,0,86.81,90H46.43A90.29,90.29,0,0,1,112.54,39.33ZM46.43,166H86.81a132.58,132.58,0,0,0,25.73,50.67A90.29,90.29,0,0,1,46.43,166Zm97,50.67A132.58,132.58,0,0,0,169.19,166h40.38A90.29,90.29,0,0,1,143.46,216.67Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",jE,[...t[4]||(t[4]=[Gb("path",{
d:"M128,24h0A104,104,0,1,0,232,128,104.12,104.12,0,0,0,128,24Zm88,104a87.61,87.61,0,0,1-3.33,24H174.16a157.44,157.44,0,0,0,0-48h38.51A87.61,87.61,0,0,1,216,128ZM102,168H154a115.11,115.11,0,0,1-26,45A115.27,115.27,0,0,1,102,168Zm-3.9-16a140.84,140.84,0,0,1,0-48h59.88a140.84,140.84,0,0,1,0,48ZM40,128a87.61,87.61,0,0,1,3.33-24H81.84a157.44,157.44,0,0,0,0,48H43.33A87.61,87.61,0,0,1,40,128ZM154,88H102a115.11,115.11,0,0,1,26-45A115.27,115.27,0,0,1,154,88Zm52.33,0H170.71a135.28,135.28,0,0,0-22.3-45.6A88.29,88.29,0,0,1,206.37,88ZM107.59,42.4A135.28,135.28,0,0,0,85.29,88H49.63A88.29,88.29,0,0,1,107.59,42.4ZM49.63,168H85.29a135.28,135.28,0,0,0,22.3,45.6A88.29,88.29,0,0,1,49.63,168Zm98.78,45.6a135.28,135.28,0,0,0,22.3-45.6h35.66A88.29,88.29,0,0,1,148.41,213.6Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",UE,[...t[5]||(t[5]=[Gb("path",{
d:"M128,28h0A100,100,0,1,0,228,128,100.11,100.11,0,0,0,128,28Zm0,190.61c-6.33-6.09-23-24.41-31.27-54.61h62.54C151,194.2,134.33,212.52,128,218.61ZM94.82,156a140.42,140.42,0,0,1,0-56h66.36a140.42,140.42,0,0,1,0,56ZM128,37.39c6.33,6.09,23,24.41,31.27,54.61H96.73C105,61.8,121.67,43.48,128,37.39ZM169.41,100h46.23a92.09,92.09,0,0,1,0,56H169.41a152.65,152.65,0,0,0,0-56Zm43.25-8h-45a129.39,129.39,0,0,0-29.19-55.4A92.25,92.25,0,0,1,212.66,92ZM117.54,36.6A129.39,129.39,0,0,0,88.35,92h-45A92.25,92.25,0,0,1,117.54,36.6ZM40.36,100H86.59a152.65,152.65,0,0,0,0,56H40.36a92.09,92.09,0,0,1,0-56Zm3,64h45a129.39,129.39,0,0,0,29.19,55.4A92.25,92.25,0,0,1,43.34,164Zm95.12,55.4A129.39,129.39,0,0,0,167.65,164h45A92.25,92.25,0,0,1,138.46,219.4Z"
},null,-1)])])):ny("",!0)],16))}}),FE={key:0},ZE={key:1},QE={key:2},HE={key:3
},VE={key:4},qE={key:5},WE=Qg({name:"ScalarIconGlobeSimple",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",FE,[...t[0]||(t[0]=[Gb("path",{
d:"M128,20A108,108,0,1,0,236,128,108.12,108.12,0,0,0,128,20Zm83.13,96H179.56a144.3,144.3,0,0,0-21.35-66.36A84.22,84.22,0,0,1,211.13,116ZM128,207c-9.36-10.81-24.46-33.13-27.45-67h54.94a119.74,119.74,0,0,1-17.11,52.77A108.61,108.61,0,0,1,128,207Zm-27.45-91a119.74,119.74,0,0,1,17.11-52.77A108.61,108.61,0,0,1,128,49c9.36,10.81,24.46,33.13,27.45,67ZM97.79,49.64A144.3,144.3,0,0,0,76.44,116H44.87A84.22,84.22,0,0,1,97.79,49.64ZM44.87,140H76.44a144.3,144.3,0,0,0,21.35,66.36A84.22,84.22,0,0,1,44.87,140Zm113.34,66.36A144.3,144.3,0,0,0,179.56,140h31.57A84.22,84.22,0,0,1,158.21,206.36Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",ZE,[...t[1]||(t[1]=[Gb("path",{
d:"M224,128a96,96,0,1,1-96-96A96,96,0,0,1,224,128Z",opacity:"0.2"
},null,-1),Gb("path",{
d:"M128,24h0A104,104,0,1,0,232,128,104.12,104.12,0,0,0,128,24Zm87.62,96H175.79C174,83.49,159.94,57.67,148.41,42.4A88.19,88.19,0,0,1,215.63,120ZM96.23,136h63.54c-2.31,41.61-22.23,67.11-31.77,77C118.45,203.1,98.54,177.6,96.23,136Zm0-16C98.54,78.39,118.46,52.89,128,43c9.55,9.93,29.46,35.43,31.77,77Zm11.36-77.6C96.06,57.67,82,83.49,80.21,120H40.37A88.19,88.19,0,0,1,107.59,42.4ZM40.37,136H80.21c1.82,36.51,15.85,62.33,27.38,77.6A88.19,88.19,0,0,1,40.37,136Zm108,77.6c11.53-15.27,25.56-41.09,27.38-77.6h39.84A88.19,88.19,0,0,1,148.41,213.6Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",QE,[...t[2]||(t[2]=[Gb("path",{
d:"M128,24h0A104,104,0,1,0,232,128,104.12,104.12,0,0,0,128,24Zm87.62,96H175.79C174,83.49,159.94,57.67,148.41,42.4A88.19,88.19,0,0,1,215.63,120ZM96.23,136h63.54c-2.31,41.61-22.23,67.11-31.77,77C118.45,203.1,98.54,177.6,96.23,136Zm0-16C98.54,78.39,118.46,52.89,128,43c9.55,9.93,29.46,35.43,31.77,77Zm52.18,93.6c11.53-15.27,25.56-41.09,27.38-77.6h39.84A88.19,88.19,0,0,1,148.41,213.6Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",HE,[...t[3]||(t[3]=[Gb("path",{
d:"M128,26A102,102,0,1,0,230,128,102.12,102.12,0,0,0,128,26Zm89.8,96H173.89c-1.54-40.77-18.48-68.23-30.43-82.67A90.19,90.19,0,0,1,217.8,122ZM128,215.83a110,110,0,0,1-15.19-19.45A128.37,128.37,0,0,1,94.13,134h67.74a128.37,128.37,0,0,1-18.68,62.38A110,110,0,0,1,128,215.83ZM94.13,122a128.37,128.37,0,0,1,18.68-62.38A110,110,0,0,1,128,40.17a110,110,0,0,1,15.19,19.45A128.37,128.37,0,0,1,161.87,122Zm18.41-82.67c-12,14.44-28.89,41.9-30.43,82.67H38.2A90.19,90.19,0,0,1,112.54,39.33ZM38.2,134H82.11c1.54,40.77,18.48,68.23,30.43,82.67A90.19,90.19,0,0,1,38.2,134Zm105.26,82.67c11.95-14.44,28.89-41.9,30.43-82.67H217.8A90.19,90.19,0,0,1,143.46,216.67Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",VE,[...t[4]||(t[4]=[Gb("path",{
d:"M128,24h0A104,104,0,1,0,232,128,104.12,104.12,0,0,0,128,24Zm87.62,96H175.79C174,83.49,159.94,57.67,148.41,42.4A88.19,88.19,0,0,1,215.63,120ZM96.23,136h63.54c-2.31,41.61-22.23,67.11-31.77,77C118.45,203.1,98.54,177.6,96.23,136Zm0-16C98.54,78.39,118.46,52.89,128,43c9.55,9.93,29.46,35.43,31.77,77Zm11.36-77.6C96.06,57.67,82,83.49,80.21,120H40.37A88.19,88.19,0,0,1,107.59,42.4ZM40.37,136H80.21c1.82,36.51,15.85,62.33,27.38,77.6A88.19,88.19,0,0,1,40.37,136Zm108,77.6c11.53-15.27,25.56-41.09,27.38-77.6h39.84A88.19,88.19,0,0,1,148.41,213.6Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",qE,[...t[5]||(t[5]=[Gb("path",{
d:"M128,28h0A100,100,0,1,0,228,128,100.11,100.11,0,0,0,128,28Zm91.9,96h-48c-1.15-45.55-21.74-74.52-33.48-87.4A92.14,92.14,0,0,1,219.91,124ZM128,218.61c-8.32-8-34.57-37.13-35.93-86.61h71.86C162.57,181.48,136.32,210.61,128,218.61ZM92.07,124C93.43,74.52,119.68,45.39,128,37.39c8.32,8,34.57,37.13,35.93,86.61Zm25.47-87.4C105.8,49.48,85.21,78.45,84.06,124h-48A92.14,92.14,0,0,1,117.54,36.6ZM36.09,132h48c1.15,45.55,21.74,74.52,33.48,87.4A92.14,92.14,0,0,1,36.09,132Zm102.37,87.4c11.74-12.88,32.33-41.85,33.48-87.4h48A92.14,92.14,0,0,1,138.46,219.4Z"
},null,-1)])])):ny("",!0)],16))}}),XE={key:0},GE={key:1},YE={key:2},KE={key:3
},JE={key:4},eA={key:5},tA=Qg({name:"ScalarIconHash",props:{label:{},weight:{}},
setup(e){const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",XE,[...t[0]||(t[0]=[Gb("path",{
d:"M224,84H180.2l7.61-41.85a12,12,0,0,0-23.62-4.3L155.8,84H116.2l7.61-41.85a12,12,0,1,0-23.62-4.3L91.8,84H48a12,12,0,0,0,0,24H87.44l-7.27,40H32a12,12,0,0,0,0,24H75.8l-7.61,41.85a12,12,0,0,0,9.66,14A11.43,11.43,0,0,0,80,228a12,12,0,0,0,11.8-9.86L100.2,172h39.6l-7.61,41.85a12,12,0,0,0,9.66,14,11.43,11.43,0,0,0,2.16.2,12,12,0,0,0,11.8-9.86L164.2,172H208a12,12,0,0,0,0-24H168.56l7.27-40H224a12,12,0,0,0,0-24Zm-79.83,64H104.56l7.27-40h39.61Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",GE,[...t[1]||(t[1]=[Gb("path",{
d:"M165.82,96l-11.64,64h-64l11.64-64Z",opacity:"0.2"},null,-1),Gb("path",{
d:"M224,88H175.4l8.47-46.57a8,8,0,0,0-15.74-2.86l-9,49.43H111.4l8.47-46.57a8,8,0,0,0-15.74-2.86L95.14,88H48a8,8,0,0,0,0,16H92.23L83.5,152H32a8,8,0,0,0,0,16H80.6l-8.47,46.57a8,8,0,0,0,6.44,9.3A7.79,7.79,0,0,0,80,224a8,8,0,0,0,7.86-6.57l9-49.43H144.6l-8.47,46.57a8,8,0,0,0,6.44,9.3A7.79,7.79,0,0,0,144,224a8,8,0,0,0,7.86-6.57l9-49.43H208a8,8,0,0,0,0-16H163.77l8.73-48H224a8,8,0,0,0,0-16Zm-76.5,64H99.77l8.73-48h47.73Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",YE,[...t[2]||(t[2]=[Gb("path",{
d:"M116.25,112h31.5l-8,32h-31.5ZM224,48V208a16,16,0,0,1-16,16H48a16,16,0,0,1-16-16V48A16,16,0,0,1,48,32H208A16,16,0,0,1,224,48Zm-16,56a8,8,0,0,0-8-8H168.25l7.51-30.06a8,8,0,0,0-15.52-3.88L151.75,96h-31.5l7.51-30.06a8,8,0,0,0-15.52-3.88L103.75,96H64a8,8,0,0,0,0,16H99.75l-8,32H56a8,8,0,0,0,0,16H87.75l-7.51,30.06a8,8,0,0,0,5.82,9.7,8.13,8.13,0,0,0,2,.24,8,8,0,0,0,7.75-6.06L104.25,160h31.5l-7.51,30.06a8,8,0,0,0,5.82,9.7A8.13,8.13,0,0,0,136,200a8,8,0,0,0,7.75-6.06L152.25,160H192a8,8,0,0,0,0-16H156.25l8-32H200A8,8,0,0,0,208,104Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",KE,[...t[3]||(t[3]=[Gb("path",{
d:"M224,90H173l8.89-48.93a6,6,0,1,0-11.8-2.14L160.81,90H109l8.89-48.93a6,6,0,0,0-11.8-2.14L96.81,90H48a6,6,0,0,0,0,12H94.63l-9.46,52H32a6,6,0,0,0,0,12H83L74.1,214.93a6,6,0,0,0,4.83,7A5.64,5.64,0,0,0,80,222a6,6,0,0,0,5.89-4.93L95.19,166H147l-8.89,48.93a6,6,0,0,0,4.83,7,5.64,5.64,0,0,0,1.08.1,6,6,0,0,0,5.89-4.93L159.19,166H208a6,6,0,0,0,0-12H161.37l9.46-52H224a6,6,0,0,0,0-12Zm-74.83,64H97.37l9.46-52h51.8Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",JE,[...t[4]||(t[4]=[Gb("path",{
d:"M224,88H175.4l8.47-46.57a8,8,0,0,0-15.74-2.86l-9,49.43H111.4l8.47-46.57a8,8,0,0,0-15.74-2.86L95.14,88H48a8,8,0,0,0,0,16H92.23L83.5,152H32a8,8,0,0,0,0,16H80.6l-8.47,46.57a8,8,0,0,0,6.44,9.3A7.79,7.79,0,0,0,80,224a8,8,0,0,0,7.86-6.57l9-49.43H144.6l-8.47,46.57a8,8,0,0,0,6.44,9.3A7.79,7.79,0,0,0,144,224a8,8,0,0,0,7.86-6.57l9-49.43H208a8,8,0,0,0,0-16H163.77l8.73-48H224a8,8,0,0,0,0-16Zm-76.5,64H99.77l8.73-48h47.73Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",eA,[...t[5]||(t[5]=[Gb("path",{
d:"M224,92H170.61l9.33-51.28a4,4,0,1,0-7.88-1.44L162.48,92H106.61l9.33-51.28a4,4,0,1,0-7.88-1.44L98.48,92H48a4,4,0,0,0,0,8H97L86.84,156H32a4,4,0,0,0,0,8H85.39l-9.33,51.28a4,4,0,0,0,3.22,4.65A3.65,3.65,0,0,0,80,220a4,4,0,0,0,3.94-3.29L93.52,164h55.87l-9.33,51.28a4,4,0,0,0,3.22,4.65,3.65,3.65,0,0,0,.72.07,4,4,0,0,0,3.94-3.29L157.52,164H208a4,4,0,0,0,0-8H159l10.19-56H224a4,4,0,0,0,0-8Zm-73.16,64H95l10.19-56H161Z"
},null,-1)])])):ny("",!0)],16))}}),nA={key:0},rA={key:1},oA={key:2},aA={key:3
},iA={key:4},sA={key:5},lA=Qg({name:"ScalarIconHouse",props:{label:{},weight:{}
},setup(e){const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",nA,[...t[0]||(t[0]=[Gb("path",{
d:"M222.14,105.85l-80-80a20,20,0,0,0-28.28,0l-80,80A19.86,19.86,0,0,0,28,120v96a12,12,0,0,0,12,12h64a12,12,0,0,0,12-12V164h24v52a12,12,0,0,0,12,12h64a12,12,0,0,0,12-12V120A19.86,19.86,0,0,0,222.14,105.85ZM204,204H164V152a12,12,0,0,0-12-12H104a12,12,0,0,0-12,12v52H52V121.65l76-76,76,76Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",rA,[...t[1]||(t[1]=[Gb("path",{
d:"M216,120v96H152V152H104v64H40V120a8,8,0,0,1,2.34-5.66l80-80a8,8,0,0,1,11.32,0l80,80A8,8,0,0,1,216,120Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M219.31,108.68l-80-80a16,16,0,0,0-22.62,0l-80,80A15.87,15.87,0,0,0,32,120v96a8,8,0,0,0,8,8h64a8,8,0,0,0,8-8V160h32v56a8,8,0,0,0,8,8h64a8,8,0,0,0,8-8V120A15.87,15.87,0,0,0,219.31,108.68ZM208,208H160V152a8,8,0,0,0-8-8H104a8,8,0,0,0-8,8v56H48V120l80-80,80,80Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",oA,[...t[2]||(t[2]=[Gb("path",{
d:"M224,120v96a8,8,0,0,1-8,8H160a8,8,0,0,1-8-8V164a4,4,0,0,0-4-4H108a4,4,0,0,0-4,4v52a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V120a16,16,0,0,1,4.69-11.31l80-80a16,16,0,0,1,22.62,0l80,80A16,16,0,0,1,224,120Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",aA,[...t[3]||(t[3]=[Gb("path",{
d:"M217.9,110.1l-80-80a14,14,0,0,0-19.8,0l-80,80A13.92,13.92,0,0,0,34,120v96a6,6,0,0,0,6,6h64a6,6,0,0,0,6-6V158h36v58a6,6,0,0,0,6,6h64a6,6,0,0,0,6-6V120A13.92,13.92,0,0,0,217.9,110.1ZM210,210H158V152a6,6,0,0,0-6-6H104a6,6,0,0,0-6,6v58H46V120a2,2,0,0,1,.58-1.42l80-80a2,2,0,0,1,2.84,0l80,80A2,2,0,0,1,210,120Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",iA,[...t[4]||(t[4]=[Gb("path",{
d:"M219.31,108.68l-80-80a16,16,0,0,0-22.62,0l-80,80A15.87,15.87,0,0,0,32,120v96a8,8,0,0,0,8,8h64a8,8,0,0,0,8-8V160h32v56a8,8,0,0,0,8,8h64a8,8,0,0,0,8-8V120A15.87,15.87,0,0,0,219.31,108.68ZM208,208H160V152a8,8,0,0,0-8-8H104a8,8,0,0,0-8,8v56H48V120l80-80,80,80Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",sA,[...t[5]||(t[5]=[Gb("path",{
d:"M216.49,111.51l-80-80a12,12,0,0,0-17,0l-80,80A12,12,0,0,0,36,120v96a4,4,0,0,0,4,4h64a4,4,0,0,0,4-4V156h40v60a4,4,0,0,0,4,4h64a4,4,0,0,0,4-4V120A12,12,0,0,0,216.49,111.51ZM212,212H156V152a4,4,0,0,0-4-4H104a4,4,0,0,0-4,4v60H44V120a4,4,0,0,1,1.17-2.83l80-80a4,4,0,0,1,5.66,0l80,80A4,4,0,0,1,212,120Z"
},null,-1)])])):ny("",!0)],16))}}),cA={key:0},uA={key:1},dA={key:2},pA={key:3
},hA={key:4},fA={key:5},mA=Qg({name:"ScalarIconInfo",props:{label:{},weight:{}},
setup(e){const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",cA,[...t[0]||(t[0]=[Gb("path",{
d:"M108,84a16,16,0,1,1,16,16A16,16,0,0,1,108,84Zm128,44A108,108,0,1,1,128,20,108.12,108.12,0,0,1,236,128Zm-24,0a84,84,0,1,0-84,84A84.09,84.09,0,0,0,212,128Zm-72,36.68V132a20,20,0,0,0-20-20,12,12,0,0,0-4,23.32V168a20,20,0,0,0,20,20,12,12,0,0,0,4-23.32Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",uA,[...t[1]||(t[1]=[Gb("path",{
d:"M224,128a96,96,0,1,1-96-96A96,96,0,0,1,224,128Z",opacity:"0.2"
},null,-1),Gb("path",{
d:"M144,176a8,8,0,0,1-8,8,16,16,0,0,1-16-16V128a8,8,0,0,1,0-16,16,16,0,0,1,16,16v40A8,8,0,0,1,144,176Zm88-48A104,104,0,1,1,128,24,104.11,104.11,0,0,1,232,128Zm-16,0a88,88,0,1,0-88,88A88.1,88.1,0,0,0,216,128ZM124,96a12,12,0,1,0-12-12A12,12,0,0,0,124,96Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",dA,[...t[2]||(t[2]=[Gb("path",{
d:"M128,24A104,104,0,1,0,232,128,104.11,104.11,0,0,0,128,24Zm-4,48a12,12,0,1,1-12,12A12,12,0,0,1,124,72Zm12,112a16,16,0,0,1-16-16V128a8,8,0,0,1,0-16,16,16,0,0,1,16,16v40a8,8,0,0,1,0,16Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",pA,[...t[3]||(t[3]=[Gb("path",{
d:"M142,176a6,6,0,0,1-6,6,14,14,0,0,1-14-14V128a2,2,0,0,0-2-2,6,6,0,0,1,0-12,14,14,0,0,1,14,14v40a2,2,0,0,0,2,2A6,6,0,0,1,142,176ZM124,94a10,10,0,1,0-10-10A10,10,0,0,0,124,94Zm106,34A102,102,0,1,1,128,26,102.12,102.12,0,0,1,230,128Zm-12,0a90,90,0,1,0-90,90A90.1,90.1,0,0,0,218,128Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",hA,[...t[4]||(t[4]=[Gb("path",{
d:"M128,24A104,104,0,1,0,232,128,104.11,104.11,0,0,0,128,24Zm0,192a88,88,0,1,1,88-88A88.1,88.1,0,0,1,128,216Zm16-40a8,8,0,0,1-8,8,16,16,0,0,1-16-16V128a8,8,0,0,1,0-16,16,16,0,0,1,16,16v40A8,8,0,0,1,144,176ZM112,84a12,12,0,1,1,12,12A12,12,0,0,1,112,84Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",fA,[...t[5]||(t[5]=[Gb("path",{
d:"M140,176a4,4,0,0,1-4,4,12,12,0,0,1-12-12V128a4,4,0,0,0-4-4,4,4,0,0,1,0-8,12,12,0,0,1,12,12v40a4,4,0,0,0,4,4A4,4,0,0,1,140,176ZM124,92a8,8,0,1,0-8-8A8,8,0,0,0,124,92Zm104,36A100,100,0,1,1,128,28,100.11,100.11,0,0,1,228,128Zm-8,0a92,92,0,1,0-92,92A92.1,92.1,0,0,0,220,128Z"
},null,-1)])])):ny("",!0)],16))}}),gA={key:0},vA={key:1},bA={key:2},yA={key:3
},OA={key:4},wA={key:5},xA=Qg({name:"ScalarIconLink",props:{label:{},weight:{}},
setup(e){const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",gA,[...t[0]||(t[0]=[Gb("path",{
d:"M117.18,188.74a12,12,0,0,1,0,17l-5.12,5.12A58.26,58.26,0,0,1,70.6,228h0A58.62,58.62,0,0,1,29.14,127.92L63.89,93.17a58.64,58.64,0,0,1,98.56,28.11,12,12,0,1,1-23.37,5.44,34.65,34.65,0,0,0-58.22-16.58L46.11,144.89A34.62,34.62,0,0,0,70.57,204h0a34.41,34.41,0,0,0,24.49-10.14l5.11-5.12A12,12,0,0,1,117.18,188.74ZM226.83,45.17a58.65,58.65,0,0,0-82.93,0l-5.11,5.11a12,12,0,0,0,17,17l5.12-5.12a34.63,34.63,0,1,1,49,49L175.1,145.86A34.39,34.39,0,0,1,150.61,156h0a34.63,34.63,0,0,1-33.69-26.72,12,12,0,0,0-23.38,5.44A58.64,58.64,0,0,0,150.56,180h.05a58.28,58.28,0,0,0,41.47-17.17l34.75-34.75a58.62,58.62,0,0,0,0-82.91Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",vA,[...t[1]||(t[1]=[Gb("path",{
d:"M218.34,119.6,183.6,154.34a46.58,46.58,0,0,1-44.31,12.26c-.31.34-.62.67-.95,1L103.6,202.34A46.63,46.63,0,1,1,37.66,136.4L72.4,101.66A46.6,46.6,0,0,1,116.71,89.4c.31-.34.62-.67,1-1L152.4,53.66a46.63,46.63,0,0,1,65.94,65.94Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M240,88.23a54.43,54.43,0,0,1-16,37L189.25,160a54.27,54.27,0,0,1-38.63,16h-.05A54.63,54.63,0,0,1,96,119.84a8,8,0,0,1,16,.45A38.62,38.62,0,0,0,150.58,160h0a38.39,38.39,0,0,0,27.31-11.31l34.75-34.75a38.63,38.63,0,0,0-54.63-54.63l-11,11A8,8,0,0,1,135.7,59l11-11A54.65,54.65,0,0,1,224,48,54.86,54.86,0,0,1,240,88.23ZM109,185.66l-11,11A38.41,38.41,0,0,1,70.6,208h0a38.63,38.63,0,0,1-27.29-65.94L78,107.31A38.63,38.63,0,0,1,144,135.71a8,8,0,0,0,7.78,8.22H152a8,8,0,0,0,8-7.78A54.86,54.86,0,0,0,144,96a54.65,54.65,0,0,0-77.27,0L32,130.75A54.62,54.62,0,0,0,70.56,224h0a54.28,54.28,0,0,0,38.64-16l11-11A8,8,0,0,0,109,185.66Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",bA,[...t[2]||(t[2]=[Gb("path",{
d:"M208,32H48A16,16,0,0,0,32,48V208a16,16,0,0,0,16,16H208a16,16,0,0,0,16-16V48A16,16,0,0,0,208,32ZM115.7,192.49a43.31,43.31,0,0,1-55-66.43l25.37-25.37a43.35,43.35,0,0,1,61.25,0,42.9,42.9,0,0,1,9.95,15.43,8,8,0,1,1-15,5.6A27.33,27.33,0,0,0,97.37,112L72,137.37a27.32,27.32,0,0,0,34.68,41.91,8,8,0,1,1,9,13.21Zm79.61-62.55-25.37,25.37A43,43,0,0,1,139.32,168h0a43.35,43.35,0,0,1-40.53-28.12,8,8,0,1,1,15-5.6A27.35,27.35,0,0,0,139.28,152h0a27.14,27.14,0,0,0,19.32-8L184,118.63a27.32,27.32,0,0,0-34.68-41.91,8,8,0,1,1-9-13.21,43.32,43.32,0,0,1,55,66.43Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",yA,[...t[3]||(t[3]=[Gb("path",{
d:"M238,88.18a52.42,52.42,0,0,1-15.4,35.66l-34.75,34.75A52.28,52.28,0,0,1,150.62,174h-.05A52.63,52.63,0,0,1,98,119.9a6,6,0,0,1,6-5.84h.17a6,6,0,0,1,5.83,6.16A40.62,40.62,0,0,0,150.58,162h0a40.4,40.4,0,0,0,28.73-11.9l34.75-34.74A40.63,40.63,0,0,0,156.63,57.9l-11,11a6,6,0,0,1-8.49-8.49l11-11a52.62,52.62,0,0,1,74.43,0A52.83,52.83,0,0,1,238,88.18Zm-127.62,98.9-11,11A40.36,40.36,0,0,1,70.6,210h0a40.63,40.63,0,0,1-28.7-69.36L76.62,105.9A40.63,40.63,0,0,1,146,135.77a6,6,0,0,0,5.83,6.16H152a6,6,0,0,0,6-5.84A52.63,52.63,0,0,0,68.14,97.42L33.38,132.16A52.63,52.63,0,0,0,70.56,222h0a52.26,52.26,0,0,0,37.22-15.42l11-11a6,6,0,1,0-8.49-8.48Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",OA,[...t[4]||(t[4]=[Gb("path",{
d:"M240,88.23a54.43,54.43,0,0,1-16,37L189.25,160a54.27,54.27,0,0,1-38.63,16h-.05A54.63,54.63,0,0,1,96,119.84a8,8,0,0,1,16,.45A38.62,38.62,0,0,0,150.58,160h0a38.39,38.39,0,0,0,27.31-11.31l34.75-34.75a38.63,38.63,0,0,0-54.63-54.63l-11,11A8,8,0,0,1,135.7,59l11-11A54.65,54.65,0,0,1,224,48,54.86,54.86,0,0,1,240,88.23ZM109,185.66l-11,11A38.41,38.41,0,0,1,70.6,208h0a38.63,38.63,0,0,1-27.29-65.94L78,107.31A38.63,38.63,0,0,1,144,135.71a8,8,0,0,0,16,.45A54.86,54.86,0,0,0,144,96a54.65,54.65,0,0,0-77.27,0L32,130.75A54.62,54.62,0,0,0,70.56,224h0a54.28,54.28,0,0,0,38.64-16l11-11A8,8,0,0,0,109,185.66Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",wA,[...t[5]||(t[5]=[Gb("path",{
d:"M236,88.12a50.44,50.44,0,0,1-14.81,34.31l-34.75,34.74A50.33,50.33,0,0,1,150.62,172h-.05A50.63,50.63,0,0,1,100,120a4,4,0,0,1,4-3.89h.11a4,4,0,0,1,3.89,4.11A42.64,42.64,0,0,0,150.58,164h0a42.32,42.32,0,0,0,30.14-12.49l34.75-34.74a42.63,42.63,0,1,0-60.29-60.28l-11,11a4,4,0,0,1-5.66-5.65l11-11A50.64,50.64,0,0,1,236,88.12ZM111.78,188.49l-11,11A42.33,42.33,0,0,1,70.6,212h0a42.63,42.63,0,0,1-30.11-72.77l34.75-34.74A42.63,42.63,0,0,1,148,135.82a4,4,0,0,0,8,.23A50.64,50.64,0,0,0,69.55,98.83L34.8,133.57A50.63,50.63,0,0,0,70.56,220h0a50.33,50.33,0,0,0,35.81-14.83l11-11a4,4,0,1,0-5.65-5.66Z"
},null,-1)])])):ny("",!0)],16))}}),kA={key:0},SA={key:1},_A={key:2},TA={key:3
},EA={key:4},AA={key:5},CA=Qg({name:"ScalarIconList",props:{label:{},weight:{}},
setup(e){const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",kA,[...t[0]||(t[0]=[Gb("path",{
d:"M228,128a12,12,0,0,1-12,12H40a12,12,0,0,1,0-24H216A12,12,0,0,1,228,128ZM40,76H216a12,12,0,0,0,0-24H40a12,12,0,0,0,0,24ZM216,180H40a12,12,0,0,0,0,24H216a12,12,0,0,0,0-24Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",SA,[...t[1]||(t[1]=[Gb("path",{
d:"M216,64V192H40V64Z",opacity:"0.2"},null,-1),Gb("path",{
d:"M224,128a8,8,0,0,1-8,8H40a8,8,0,0,1,0-16H216A8,8,0,0,1,224,128ZM40,72H216a8,8,0,0,0,0-16H40a8,8,0,0,0,0,16ZM216,184H40a8,8,0,0,0,0,16H216a8,8,0,0,0,0-16Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",_A,[...t[2]||(t[2]=[Gb("path",{
d:"M208,32H48A16,16,0,0,0,32,48V208a16,16,0,0,0,16,16H208a16,16,0,0,0,16-16V48A16,16,0,0,0,208,32ZM192,184H64a8,8,0,0,1,0-16H192a8,8,0,0,1,0,16Zm0-48H64a8,8,0,0,1,0-16H192a8,8,0,0,1,0,16Zm0-48H64a8,8,0,0,1,0-16H192a8,8,0,0,1,0,16Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",TA,[...t[3]||(t[3]=[Gb("path",{
d:"M222,128a6,6,0,0,1-6,6H40a6,6,0,0,1,0-12H216A6,6,0,0,1,222,128ZM40,70H216a6,6,0,0,0,0-12H40a6,6,0,0,0,0,12ZM216,186H40a6,6,0,0,0,0,12H216a6,6,0,0,0,0-12Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",EA,[...t[4]||(t[4]=[Gb("path",{
d:"M224,128a8,8,0,0,1-8,8H40a8,8,0,0,1,0-16H216A8,8,0,0,1,224,128ZM40,72H216a8,8,0,0,0,0-16H40a8,8,0,0,0,0,16ZM216,184H40a8,8,0,0,0,0,16H216a8,8,0,0,0,0-16Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",AA,[...t[5]||(t[5]=[Gb("path",{
d:"M220,128a4,4,0,0,1-4,4H40a4,4,0,0,1,0-8H216A4,4,0,0,1,220,128ZM40,68H216a4,4,0,0,0,0-8H40a4,4,0,0,0,0,8ZM216,188H40a4,4,0,0,0,0,8H216a4,4,0,0,0,0-8Z"
},null,-1)])])):ny("",!0)],16))}}),$A={key:0},PA={key:1},DA={key:2},IA={key:3
},MA={key:4},NA={key:5},RA=Qg({name:"ScalarIconLockSimple",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",$A,[...t[0]||(t[0]=[Gb("path",{
d:"M208,76H180V56A52,52,0,0,0,76,56V76H48A20,20,0,0,0,28,96V208a20,20,0,0,0,20,20H208a20,20,0,0,0,20-20V96A20,20,0,0,0,208,76ZM100,56a28,28,0,0,1,56,0V76H100ZM204,204H52V100H204Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",PA,[...t[1]||(t[1]=[Gb("path",{
d:"M216,96V208a8,8,0,0,1-8,8H48a8,8,0,0,1-8-8V96a8,8,0,0,1,8-8H208A8,8,0,0,1,216,96Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M208,80H176V56a48,48,0,0,0-96,0V80H48A16,16,0,0,0,32,96V208a16,16,0,0,0,16,16H208a16,16,0,0,0,16-16V96A16,16,0,0,0,208,80ZM96,56a32,32,0,0,1,64,0V80H96ZM208,208H48V96H208V208Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",DA,[...t[2]||(t[2]=[Gb("path",{
d:"M208,80H176V56a48,48,0,0,0-96,0V80H48A16,16,0,0,0,32,96V208a16,16,0,0,0,16,16H208a16,16,0,0,0,16-16V96A16,16,0,0,0,208,80ZM96,56a32,32,0,0,1,64,0V80H96Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",IA,[...t[3]||(t[3]=[Gb("path",{
d:"M208,82H174V56a46,46,0,0,0-92,0V82H48A14,14,0,0,0,34,96V208a14,14,0,0,0,14,14H208a14,14,0,0,0,14-14V96A14,14,0,0,0,208,82ZM94,56a34,34,0,0,1,68,0V82H94ZM210,208a2,2,0,0,1-2,2H48a2,2,0,0,1-2-2V96a2,2,0,0,1,2-2H208a2,2,0,0,1,2,2Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",MA,[...t[4]||(t[4]=[Gb("path",{
d:"M208,80H176V56a48,48,0,0,0-96,0V80H48A16,16,0,0,0,32,96V208a16,16,0,0,0,16,16H208a16,16,0,0,0,16-16V96A16,16,0,0,0,208,80ZM96,56a32,32,0,0,1,64,0V80H96ZM208,208H48V96H208V208Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",NA,[...t[5]||(t[5]=[Gb("path",{
d:"M208,84H172V56a44,44,0,0,0-88,0V84H48A12,12,0,0,0,36,96V208a12,12,0,0,0,12,12H208a12,12,0,0,0,12-12V96A12,12,0,0,0,208,84ZM92,56a36,36,0,0,1,72,0V84H92ZM212,208a4,4,0,0,1-4,4H48a4,4,0,0,1-4-4V96a4,4,0,0,1,4-4H208a4,4,0,0,1,4,4Z"
},null,-1)])])):ny("",!0)],16))}}),LA={key:0},BA={key:1},jA={key:2},UA={key:3
},zA={key:4},FA={key:5},ZA=Qg({name:"ScalarIconMagnifyingGlass",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",LA,[...t[0]||(t[0]=[Gb("path",{
d:"M232.49,215.51,185,168a92.12,92.12,0,1,0-17,17l47.53,47.54a12,12,0,0,0,17-17ZM44,112a68,68,0,1,1,68,68A68.07,68.07,0,0,1,44,112Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",BA,[...t[1]||(t[1]=[Gb("path",{
d:"M192,112a80,80,0,1,1-80-80A80,80,0,0,1,192,112Z",opacity:"0.2"
},null,-1),Gb("path",{
d:"M229.66,218.34,179.6,168.28a88.21,88.21,0,1,0-11.32,11.31l50.06,50.07a8,8,0,0,0,11.32-11.32ZM40,112a72,72,0,1,1,72,72A72.08,72.08,0,0,1,40,112Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",jA,[...t[2]||(t[2]=[Gb("path",{
d:"M168,112a56,56,0,1,1-56-56A56,56,0,0,1,168,112Zm61.66,117.66a8,8,0,0,1-11.32,0l-50.06-50.07a88,88,0,1,1,11.32-11.31l50.06,50.06A8,8,0,0,1,229.66,229.66ZM112,184a72,72,0,1,0-72-72A72.08,72.08,0,0,0,112,184Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",UA,[...t[3]||(t[3]=[Gb("path",{
d:"M228.24,219.76l-51.38-51.38a86.15,86.15,0,1,0-8.48,8.48l51.38,51.38a6,6,0,0,0,8.48-8.48ZM38,112a74,74,0,1,1,74,74A74.09,74.09,0,0,1,38,112Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",zA,[...t[4]||(t[4]=[Gb("path",{
d:"M229.66,218.34l-50.07-50.06a88.11,88.11,0,1,0-11.31,11.31l50.06,50.07a8,8,0,0,0,11.32-11.32ZM40,112a72,72,0,1,1,72,72A72.08,72.08,0,0,1,40,112Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",FA,[...t[5]||(t[5]=[Gb("path",{
d:"M226.83,221.17l-52.7-52.7a84.1,84.1,0,1,0-5.66,5.66l52.7,52.7a4,4,0,0,0,5.66-5.66ZM36,112a76,76,0,1,1,76,76A76.08,76.08,0,0,1,36,112Z"
},null,-1)])])):ny("",!0)],16))}}),QA={key:0},HA={key:1},VA={key:2},qA={key:3
},WA={key:4},XA={key:5},GA=Qg({name:"ScalarIconPencilSimple",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",QA,[...t[0]||(t[0]=[Gb("path",{
d:"M230.14,70.54,185.46,25.85a20,20,0,0,0-28.29,0L33.86,149.17A19.85,19.85,0,0,0,28,163.31V208a20,20,0,0,0,20,20H92.69a19.86,19.86,0,0,0,14.14-5.86L230.14,98.82a20,20,0,0,0,0-28.28ZM91,204H52V165l84-84,39,39ZM192,103,153,64l18.34-18.34,39,39Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",HA,[...t[1]||(t[1]=[Gb("path",{
d:"M221.66,90.34,192,120,136,64l29.66-29.66a8,8,0,0,1,11.31,0L221.66,79A8,8,0,0,1,221.66,90.34Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M227.31,73.37,182.63,28.68a16,16,0,0,0-22.63,0L36.69,152A15.86,15.86,0,0,0,32,163.31V208a16,16,0,0,0,16,16H92.69A15.86,15.86,0,0,0,104,219.31L227.31,96a16,16,0,0,0,0-22.63ZM92.69,208H48V163.31l88-88L180.69,120ZM192,108.68,147.31,64l24-24L216,84.68Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",VA,[...t[2]||(t[2]=[Gb("path",{
d:"M227.31,73.37,182.63,28.68a16,16,0,0,0-22.63,0L36.69,152A15.86,15.86,0,0,0,32,163.31V208a16,16,0,0,0,16,16H92.69A15.86,15.86,0,0,0,104,219.31L227.31,96a16,16,0,0,0,0-22.63ZM192,108.68,147.31,64l24-24L216,84.68Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",qA,[...t[3]||(t[3]=[Gb("path",{
d:"M225.9,74.78,181.21,30.09a14,14,0,0,0-19.8,0L38.1,153.41a13.94,13.94,0,0,0-4.1,9.9V208a14,14,0,0,0,14,14H92.69a13.94,13.94,0,0,0,9.9-4.1L225.9,94.58a14,14,0,0,0,0-19.8ZM94.1,209.41a2,2,0,0,1-1.41.59H48a2,2,0,0,1-2-2V163.31a2,2,0,0,1,.59-1.41L136,72.48,183.51,120ZM217.41,86.1,192,111.51,144.49,64,169.9,38.58a2,2,0,0,1,2.83,0l44.68,44.69a2,2,0,0,1,0,2.83Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",WA,[...t[4]||(t[4]=[Gb("path",{
d:"M227.31,73.37,182.63,28.68a16,16,0,0,0-22.63,0L36.69,152A15.86,15.86,0,0,0,32,163.31V208a16,16,0,0,0,16,16H92.69A15.86,15.86,0,0,0,104,219.31L227.31,96a16,16,0,0,0,0-22.63ZM92.69,208H48V163.31l88-88L180.69,120ZM192,108.68,147.31,64l24-24L216,84.68Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",XA,[...t[5]||(t[5]=[Gb("path",{
d:"M224.49,76.2,179.8,31.51a12,12,0,0,0-17,0L133.17,61.17h0L39.52,154.83A11.9,11.9,0,0,0,36,163.31V208a12,12,0,0,0,12,12H92.69a12,12,0,0,0,8.48-3.51L224.48,93.17a12,12,0,0,0,0-17Zm-129,134.63A4,4,0,0,1,92.69,212H48a4,4,0,0,1-4-4V163.31a4,4,0,0,1,1.17-2.83L136,69.65,186.34,120ZM218.83,87.51,192,114.34,141.66,64l26.82-26.83a4,4,0,0,1,5.66,0l44.69,44.68a4,4,0,0,1,0,5.66Z"
},null,-1)])])):ny("",!0)],16))}}),YA={key:0},KA={key:1},JA={key:2},eC={key:3
},tC={key:4},nC={key:5},rC=Qg({name:"ScalarIconPlay",props:{label:{},weight:{}},
setup(e){const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",YA,[...t[0]||(t[0]=[Gb("path",{
d:"M234.49,111.07,90.41,22.94A20,20,0,0,0,60,39.87V216.13a20,20,0,0,0,30.41,16.93l144.08-88.13a19.82,19.82,0,0,0,0-33.86ZM84,208.85V47.15L216.16,128Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",KA,[...t[1]||(t[1]=[Gb("path",{
d:"M228.23,134.69,84.15,222.81A8,8,0,0,1,72,216.12V39.88a8,8,0,0,1,12.15-6.69l144.08,88.12A7.82,7.82,0,0,1,228.23,134.69Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M232.4,114.49,88.32,26.35a16,16,0,0,0-16.2-.3A15.86,15.86,0,0,0,64,39.87V216.13A15.94,15.94,0,0,0,80,232a16.07,16.07,0,0,0,8.36-2.35L232.4,141.51a15.81,15.81,0,0,0,0-27ZM80,215.94V40l143.83,88Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",JA,[...t[2]||(t[2]=[Gb("path",{
d:"M240,128a15.74,15.74,0,0,1-7.6,13.51L88.32,229.65a16,16,0,0,1-16.2.3A15.86,15.86,0,0,1,64,216.13V39.87a15.86,15.86,0,0,1,8.12-13.82,16,16,0,0,1,16.2.3L232.4,114.49A15.74,15.74,0,0,1,240,128Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",eC,[...t[3]||(t[3]=[Gb("path",{
d:"M231.36,116.19,87.28,28.06a14,14,0,0,0-14.18-.27A13.69,13.69,0,0,0,66,39.87V216.13a13.69,13.69,0,0,0,7.1,12.08,14,14,0,0,0,14.18-.27l144.08-88.13a13.82,13.82,0,0,0,0-23.62Zm-6.26,13.38L81,217.7a2,2,0,0,1-2.06,0,1.78,1.78,0,0,1-1-1.61V39.87a1.78,1.78,0,0,1,1-1.61A2.06,2.06,0,0,1,80,38a2,2,0,0,1,1,.31L225.1,126.43a1.82,1.82,0,0,1,0,3.14Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",tC,[...t[4]||(t[4]=[Gb("path",{
d:"M232.4,114.49,88.32,26.35a16,16,0,0,0-16.2-.3A15.86,15.86,0,0,0,64,39.87V216.13A15.94,15.94,0,0,0,80,232a16.07,16.07,0,0,0,8.36-2.35L232.4,141.51a15.81,15.81,0,0,0,0-27ZM80,215.94V40l143.83,88Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",nC,[...t[5]||(t[5]=[Gb("path",{
d:"M230.32,117.9,86.24,29.79a11.91,11.91,0,0,0-12.17-.23A11.71,11.71,0,0,0,68,39.89V216.11a11.71,11.71,0,0,0,6.07,10.33,11.91,11.91,0,0,0,12.17-.23L230.32,138.1a11.82,11.82,0,0,0,0-20.2Zm-4.18,13.37L82.06,219.39a4,4,0,0,1-4.07.07,3.77,3.77,0,0,1-2-3.35V39.89a3.77,3.77,0,0,1,2-3.35,4,4,0,0,1,4.07.07l144.08,88.12a3.8,3.8,0,0,1,0,6.54Z"
},null,-1)])])):ny("",!0)],16))}}),oC={key:0},aC={key:1},iC={key:2},sC={key:3
},lC={key:4},cC={key:5},uC=Qg({name:"ScalarIconPlus",props:{label:{},weight:{}},
setup(e){const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",oC,[...t[0]||(t[0]=[Gb("path",{
d:"M228,128a12,12,0,0,1-12,12H140v76a12,12,0,0,1-24,0V140H40a12,12,0,0,1,0-24h76V40a12,12,0,0,1,24,0v76h76A12,12,0,0,1,228,128Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",aC,[...t[1]||(t[1]=[Gb("path",{
d:"M216,56V200a16,16,0,0,1-16,16H56a16,16,0,0,1-16-16V56A16,16,0,0,1,56,40H200A16,16,0,0,1,216,56Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M224,128a8,8,0,0,1-8,8H136v80a8,8,0,0,1-16,0V136H40a8,8,0,0,1,0-16h80V40a8,8,0,0,1,16,0v80h80A8,8,0,0,1,224,128Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",iC,[...t[2]||(t[2]=[Gb("path",{
d:"M208,32H48A16,16,0,0,0,32,48V208a16,16,0,0,0,16,16H208a16,16,0,0,0,16-16V48A16,16,0,0,0,208,32ZM184,136H136v48a8,8,0,0,1-16,0V136H72a8,8,0,0,1,0-16h48V72a8,8,0,0,1,16,0v48h48a8,8,0,0,1,0,16Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",sC,[...t[3]||(t[3]=[Gb("path",{
d:"M222,128a6,6,0,0,1-6,6H134v82a6,6,0,0,1-12,0V134H40a6,6,0,0,1,0-12h82V40a6,6,0,0,1,12,0v82h82A6,6,0,0,1,222,128Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",lC,[...t[4]||(t[4]=[Gb("path",{
d:"M224,128a8,8,0,0,1-8,8H136v80a8,8,0,0,1-16,0V136H40a8,8,0,0,1,0-16h80V40a8,8,0,0,1,16,0v80h80A8,8,0,0,1,224,128Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",cC,[...t[5]||(t[5]=[Gb("path",{
d:"M220,128a4,4,0,0,1-4,4H132v84a4,4,0,0,1-8,0V132H40a4,4,0,0,1,0-8h84V40a4,4,0,0,1,8,0v84h84A4,4,0,0,1,220,128Z"
},null,-1)])])):ny("",!0)],16))}}),dC={key:0},pC={key:1},hC={key:2},fC={key:3
},mC={key:4},gC={key:5},vC=Qg({name:"ScalarIconScroll",props:{label:{},weight:{}
},setup(e){const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",dC,[...t[0]||(t[0]=[Gb("path",{
d:"M92,92a12,12,0,0,1,12-12h60a12,12,0,0,1,0,24H104A12,12,0,0,1,92,92Zm12,52h60a12,12,0,0,0,0-24H104a12,12,0,0,0,0,24Zm132,48a36,36,0,0,1-36,36H88a36,36,0,0,1-36-36V64a12,12,0,0,0-24,0c0,3.73,3.35,6.51,3.38,6.54l-.18-.14h0A12,12,0,1,1,16.81,89.59h0C15.49,88.62,4,79.55,4,64A36,36,0,0,1,40,28H176a36,36,0,0,1,36,36V164h4a12,12,0,0,1,7.2,2.4C224.51,167.38,236,176.45,236,192ZM92.62,172.2A12,12,0,0,1,104,164h84V64a12,12,0,0,0-12-12H73.94A35.88,35.88,0,0,1,76,64V192a12,12,0,0,0,24,0c0-3.58-3.17-6.38-3.2-6.4A12,12,0,0,1,92.62,172.2ZM212,192a7.69,7.69,0,0,0-1.24-4h-87a30.32,30.32,0,0,1,.26,4,35.84,35.84,0,0,1-2.06,12H200A12,12,0,0,0,212,192Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",pC,[...t[1]||(t[1]=[Gb("path",{
d:"M200,176H104s8,6,8,16a24,24,0,0,1-48,0V64A24,24,0,0,0,40,40H176a24,24,0,0,1,24,24Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M96,104a8,8,0,0,1,8-8h64a8,8,0,0,1,0,16H104A8,8,0,0,1,96,104Zm8,40h64a8,8,0,0,0,0-16H104a8,8,0,0,0,0,16Zm128,48a32,32,0,0,1-32,32H88a32,32,0,0,1-32-32V64a16,16,0,0,0-32,0c0,5.74,4.83,9.62,4.88,9.66h0A8,8,0,0,1,24,88a7.89,7.89,0,0,1-4.79-1.61h0C18.05,85.54,8,77.61,8,64A32,32,0,0,1,40,32H176a32,32,0,0,1,32,32V168h8a8,8,0,0,1,4.8,1.6C222,170.46,232,178.39,232,192ZM96.26,173.48A8.07,8.07,0,0,1,104,168h88V64a16,16,0,0,0-16-16H67.69A31.71,31.71,0,0,1,72,64V192a16,16,0,0,0,32,0c0-5.74-4.83-9.62-4.88-9.66A7.82,7.82,0,0,1,96.26,173.48ZM216,192a12.58,12.58,0,0,0-3.23-8h-94a26.92,26.92,0,0,1,1.21,8,31.82,31.82,0,0,1-4.29,16H200A16,16,0,0,0,216,192Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",hC,[...t[2]||(t[2]=[Gb("path",{
d:"M220.8,169.6A8,8,0,0,0,216,168h-8V64a32,32,0,0,0-32-32H40A32,32,0,0,0,8,64C8,77.61,18.05,85.54,19.2,86.4h0A7.89,7.89,0,0,0,24,88a8,8,0,0,0,4.87-14.33h0C28.83,73.62,24,69.74,24,64a16,16,0,0,1,32,0V192a32,32,0,0,0,32,32H200a32,32,0,0,0,32-32C232,178.39,222,170.46,220.8,169.6ZM104,96h64a8,8,0,0,1,0,16H104a8,8,0,0,1,0-16Zm-8,40a8,8,0,0,1,8-8h64a8,8,0,0,1,0,16H104A8,8,0,0,1,96,136Zm104,72H107.71A31.82,31.82,0,0,0,112,192a26.92,26.92,0,0,0-1.21-8h102a12.58,12.58,0,0,1,3.23,8A16,16,0,0,1,200,208Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",fC,[...t[3]||(t[3]=[Gb("path",{
d:"M98,136a6,6,0,0,1,6-6h64a6,6,0,0,1,0,12H104A6,6,0,0,1,98,136Zm6-26h64a6,6,0,0,0,0-12H104a6,6,0,0,0,0,12Zm126,82a30,30,0,0,1-30,30H88a30,30,0,0,1-30-30V64a18,18,0,0,0-36,0c0,6.76,5.58,11.19,5.64,11.23A6,6,0,1,1,20.4,84.8C20,84.48,10,76.85,10,64A30,30,0,0,1,40,34H176a30,30,0,0,1,30,30V170h10a6,6,0,0,1,3.6,1.2C220,171.52,230,179.15,230,192Zm-124,0c0-6.76-5.59-11.19-5.64-11.23A6,6,0,0,1,104,170h90V64a18,18,0,0,0-18-18H64a29.82,29.82,0,0,1,6,18V192a18,18,0,0,0,36,0Zm112,0a14.94,14.94,0,0,0-4.34-10H115.88A24.83,24.83,0,0,1,118,192a29.87,29.87,0,0,1-6,18h88A18,18,0,0,0,218,192Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",mC,[...t[4]||(t[4]=[Gb("path",{
d:"M96,104a8,8,0,0,1,8-8h64a8,8,0,0,1,0,16H104A8,8,0,0,1,96,104Zm8,40h64a8,8,0,0,0,0-16H104a8,8,0,0,0,0,16Zm128,48a32,32,0,0,1-32,32H88a32,32,0,0,1-32-32V64a16,16,0,0,0-32,0c0,5.74,4.83,9.62,4.88,9.66h0A8,8,0,0,1,24,88a7.89,7.89,0,0,1-4.79-1.61h0C18.05,85.54,8,77.61,8,64A32,32,0,0,1,40,32H176a32,32,0,0,1,32,32V168h8a8,8,0,0,1,4.8,1.6C222,170.46,232,178.39,232,192ZM96.26,173.48A8.07,8.07,0,0,1,104,168h88V64a16,16,0,0,0-16-16H67.69A31.71,31.71,0,0,1,72,64V192a16,16,0,0,0,32,0c0-5.74-4.83-9.62-4.88-9.66A7.82,7.82,0,0,1,96.26,173.48ZM216,192a12.58,12.58,0,0,0-3.23-8h-94a26.92,26.92,0,0,1,1.21,8,31.82,31.82,0,0,1-4.29,16H200A16,16,0,0,0,216,192Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",gC,[...t[5]||(t[5]=[Gb("path",{
d:"M100,104a4,4,0,0,1,4-4h64a4,4,0,0,1,0,8H104A4,4,0,0,1,100,104Zm4,36h64a4,4,0,0,0,0-8H104a4,4,0,0,0,0,8Zm124,52a28,28,0,0,1-28,28H88a28,28,0,0,1-28-28V64a20,20,0,0,0-40,0c0,7.78,6.34,12.75,6.4,12.8a4,4,0,1,1-4.8,6.4C21.21,82.91,12,75.86,12,64A28,28,0,0,1,40,36H176a28,28,0,0,1,28,28V172h12a4,4,0,0,1,2.4.8C218.79,173.09,228,180.14,228,192Zm-120,0c0-7.78-6.34-12.75-6.4-12.8A4,4,0,0,1,104,172h92V64a20,20,0,0,0-20-20H59.57A27.9,27.9,0,0,1,68,64V192a20,20,0,0,0,40,0Zm112,0c0-6-3.74-10.3-5.5-12H112.61A23.31,23.31,0,0,1,116,192a27.94,27.94,0,0,1-8.42,20H200A20,20,0,0,0,220,192Z"
},null,-1)])])):ny("",!0)],16))}}),bC={key:0},yC={key:1},OC={key:2},wC={key:3
},xC={key:4},kC={key:5},SC=Qg({name:"ScalarIconSwap",props:{label:{},weight:{}},
setup(e){const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",bC,[...t[0]||(t[0]=[Gb("path",{
d:"M228,48V152a20,20,0,0,1-20,20H112.92a12,12,0,0,1-17.41,16.49l-20-20a12,12,0,0,1,0-17l20-20A12,12,0,0,1,112.92,148H204V52H100a12,12,0,0,1-24,0V48A20,20,0,0,1,96,28H208A20,20,0,0,1,228,48ZM168,192a12,12,0,0,0-12,12H52V108h91.08a12,12,0,0,0,17.41,16.49l20-20a12,12,0,0,0,0-17l-20-20A12,12,0,0,0,143.08,84H48a20,20,0,0,0-20,20V208a20,20,0,0,0,20,20H160a20,20,0,0,0,20-20v-4A12,12,0,0,0,168,192Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",yC,[...t[1]||(t[1]=[Gb("path",{
d:"M216,48V152a8,8,0,0,1-8,8H168v48a8,8,0,0,1-8,8H48a8,8,0,0,1-8-8V104a8,8,0,0,1,8-8H88V48a8,8,0,0,1,8-8H208A8,8,0,0,1,216,48Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M224,48V152a16,16,0,0,1-16,16H99.31l10.35,10.34a8,8,0,0,1-11.32,11.32l-24-24a8,8,0,0,1,0-11.32l24-24a8,8,0,0,1,11.32,11.32L99.31,152H208V48H96v8a8,8,0,0,1-16,0V48A16,16,0,0,1,96,32H208A16,16,0,0,1,224,48ZM168,192a8,8,0,0,0-8,8v8H48V104H156.69l-10.35,10.34a8,8,0,0,0,11.32,11.32l24-24a8,8,0,0,0,0-11.32l-24-24a8,8,0,0,0-11.32,11.32L156.69,88H48a16,16,0,0,0-16,16V208a16,16,0,0,0,16,16H160a16,16,0,0,0,16-16v-8A8,8,0,0,0,168,192Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",OC,[...t[2]||(t[2]=[Gb("path",{
d:"M224,48V152a16,16,0,0,1-16,16H112v16a8,8,0,0,1-13.66,5.66l-24-24a8,8,0,0,1,0-11.32l24-24A8,8,0,0,1,112,136v16h96V48H96v8a8,8,0,0,1-16,0V48A16,16,0,0,1,96,32H208A16,16,0,0,1,224,48ZM168,192a8,8,0,0,0-8,8v8H48V104h96v16a8,8,0,0,0,13.66,5.66l24-24a8,8,0,0,0,0-11.32l-24-24A8,8,0,0,0,144,72V88H48a16,16,0,0,0-16,16V208a16,16,0,0,0,16,16H160a16,16,0,0,0,16-16v-8A8,8,0,0,0,168,192Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",wC,[...t[3]||(t[3]=[Gb("path",{
d:"M222,48V152a14,14,0,0,1-14,14H94.49l13.75,13.76a6,6,0,1,1-8.48,8.48l-24-24a6,6,0,0,1,0-8.48l24-24a6,6,0,0,1,8.48,8.48L94.49,154H208a2,2,0,0,0,2-2V48a2,2,0,0,0-2-2H96a2,2,0,0,0-2,2v8a6,6,0,0,1-12,0V48A14,14,0,0,1,96,34H208A14,14,0,0,1,222,48ZM168,194a6,6,0,0,0-6,6v8a2,2,0,0,1-2,2H48a2,2,0,0,1-2-2V104a2,2,0,0,1,2-2H161.51l-13.75,13.76a6,6,0,1,0,8.48,8.48l24-24a6,6,0,0,0,0-8.48l-24-24a6,6,0,0,0-8.48,8.48L161.51,90H48a14,14,0,0,0-14,14V208a14,14,0,0,0,14,14H160a14,14,0,0,0,14-14v-8A6,6,0,0,0,168,194Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",xC,[...t[4]||(t[4]=[Gb("path",{
d:"M224,48V152a16,16,0,0,1-16,16H99.31l10.35,10.34a8,8,0,0,1-11.32,11.32l-24-24a8,8,0,0,1,0-11.32l24-24a8,8,0,0,1,11.32,11.32L99.31,152H208V48H96v8a8,8,0,0,1-16,0V48A16,16,0,0,1,96,32H208A16,16,0,0,1,224,48ZM168,192a8,8,0,0,0-8,8v8H48V104H156.69l-10.35,10.34a8,8,0,0,0,11.32,11.32l24-24a8,8,0,0,0,0-11.32l-24-24a8,8,0,0,0-11.32,11.32L156.69,88H48a16,16,0,0,0-16,16V208a16,16,0,0,0,16,16H160a16,16,0,0,0,16-16v-8A8,8,0,0,0,168,192Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",kC,[...t[5]||(t[5]=[Gb("path",{
d:"M220,48V152a12,12,0,0,1-12,12H89.66l17.17,17.17a4,4,0,0,1-5.66,5.66l-24-24a4,4,0,0,1,0-5.66l24-24a4,4,0,0,1,5.66,5.66L89.66,156H208a4,4,0,0,0,4-4V48a4,4,0,0,0-4-4H96a4,4,0,0,0-4,4v8a4,4,0,0,1-8,0V48A12,12,0,0,1,96,36H208A12,12,0,0,1,220,48ZM168,196a4,4,0,0,0-4,4v8a4,4,0,0,1-4,4H48a4,4,0,0,1-4-4V104a4,4,0,0,1,4-4H166.34l-17.17,17.17a4,4,0,0,0,5.66,5.66l24-24a4,4,0,0,0,0-5.66l-24-24a4,4,0,0,0-5.66,5.66L166.34,92H48a12,12,0,0,0-12,12V208a12,12,0,0,0,12,12H160a12,12,0,0,0,12-12v-8A4,4,0,0,0,168,196Z"
},null,-1)])])):ny("",!0)],16))}}),_C={key:0},TC={key:1},EC={key:2},AC={key:3
},CC={key:4},$C={key:5},PC=Qg({name:"ScalarIconTag",props:{label:{},weight:{}},
setup(e){const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",_C,[...t[0]||(t[0]=[Gb("path",{
d:"M246.15,133.18,146.83,33.86A19.85,19.85,0,0,0,132.69,28H40A12,12,0,0,0,28,40v92.69a19.85,19.85,0,0,0,5.86,14.14l99.32,99.32a20,20,0,0,0,28.28,0l84.69-84.69A20,20,0,0,0,246.15,133.18Zm-98.83,93.17L52,131V52h79l95.32,95.32ZM104,88A16,16,0,1,1,88,72,16,16,0,0,1,104,88Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",TC,[...t[1]||(t[1]=[Gb("path",{
d:"M237.66,153,153,237.66a8,8,0,0,1-11.31,0L42.34,138.34A8,8,0,0,1,40,132.69V40h92.69a8,8,0,0,1,5.65,2.34l99.32,99.32A8,8,0,0,1,237.66,153Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M243.31,136,144,36.69A15.86,15.86,0,0,0,132.69,32H40a8,8,0,0,0-8,8v92.69A15.86,15.86,0,0,0,36.69,144L136,243.31a16,16,0,0,0,22.63,0l84.68-84.68a16,16,0,0,0,0-22.63Zm-96,96L48,132.69V48h84.69L232,147.31ZM96,84A12,12,0,1,1,84,72,12,12,0,0,1,96,84Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",EC,[...t[2]||(t[2]=[Gb("path",{
d:"M243.31,136,144,36.69A15.86,15.86,0,0,0,132.69,32H40a8,8,0,0,0-8,8v92.69A15.86,15.86,0,0,0,36.69,144L136,243.31a16,16,0,0,0,22.63,0l84.68-84.68a16,16,0,0,0,0-22.63ZM84,96A12,12,0,1,1,96,84,12,12,0,0,1,84,96Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",AC,[...t[3]||(t[3]=[Gb("path",{
d:"M241.91,137.42,142.59,38.1a13.94,13.94,0,0,0-9.9-4.1H40a6,6,0,0,0-6,6v92.69a13.94,13.94,0,0,0,4.1,9.9l99.32,99.32a14,14,0,0,0,19.8,0l84.69-84.69A14,14,0,0,0,241.91,137.42Zm-8.49,11.31-84.69,84.69a2,2,0,0,1-2.83,0L46.59,134.1a2,2,0,0,1-.59-1.41V46h86.69a2,2,0,0,1,1.41.59l99.32,99.31A2,2,0,0,1,233.42,148.73ZM94,84A10,10,0,1,1,84,74,10,10,0,0,1,94,84Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",CC,[...t[4]||(t[4]=[Gb("path",{
d:"M243.31,136,144,36.69A15.86,15.86,0,0,0,132.69,32H40a8,8,0,0,0-8,8v92.69A15.86,15.86,0,0,0,36.69,144L136,243.31a16,16,0,0,0,22.63,0l84.68-84.68a16,16,0,0,0,0-22.63Zm-96,96L48,132.69V48h84.69L232,147.31ZM96,84A12,12,0,1,1,84,72,12,12,0,0,1,96,84Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",$C,[...t[5]||(t[5]=[Gb("path",{
d:"M240.49,138.83,141.17,39.51A11.93,11.93,0,0,0,132.69,36H40a4,4,0,0,0-4,4v92.69a11.93,11.93,0,0,0,3.51,8.48l99.32,99.32a12,12,0,0,0,17,0l84.69-84.69a12,12,0,0,0,0-17Zm-5.66,11.31-84.69,84.69a4,4,0,0,1-5.65,0L45.17,135.51A4,4,0,0,1,44,132.69V44h88.69a4,4,0,0,1,2.82,1.17l99.32,99.32A4,4,0,0,1,234.83,150.14ZM92,84a8,8,0,1,1-8-8A8,8,0,0,1,92,84Z"
},null,-1)])])):ny("",!0)],16))}}),DC={key:0},IC={key:1},MC={key:2},NC={key:3
},RC={key:4},LC={key:5},BC=Qg({name:"ScalarIconTerminalWindow",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",DC,[...t[0]||(t[0]=[Gb("path",{
d:"M72.5,150.63,100.79,128,72.5,105.37a12,12,0,1,1,15-18.74l40,32a12,12,0,0,1,0,18.74l-40,32a12,12,0,0,1-15-18.74ZM144,172h32a12,12,0,0,0,0-24H144a12,12,0,0,0,0,24ZM236,56V200a20,20,0,0,1-20,20H40a20,20,0,0,1-20-20V56A20,20,0,0,1,40,36H216A20,20,0,0,1,236,56Zm-24,4H44V196H212Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",IC,[...t[1]||(t[1]=[Gb("path",{
d:"M224,56V200a8,8,0,0,1-8,8H40a8,8,0,0,1-8-8V56a8,8,0,0,1,8-8H216A8,8,0,0,1,224,56Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M128,128a8,8,0,0,1-3,6.25l-40,32a8,8,0,1,1-10-12.5L107.19,128,75,102.25a8,8,0,1,1,10-12.5l40,32A8,8,0,0,1,128,128Zm48,24H136a8,8,0,0,0,0,16h40a8,8,0,0,0,0-16Zm56-96V200a16,16,0,0,1-16,16H40a16,16,0,0,1-16-16V56A16,16,0,0,1,40,40H216A16,16,0,0,1,232,56ZM216,200V56H40V200H216Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",MC,[...t[2]||(t[2]=[Gb("path",{
d:"M216,40H40A16,16,0,0,0,24,56V200a16,16,0,0,0,16,16H216a16,16,0,0,0,16-16V56A16,16,0,0,0,216,40Zm-91,94.25-40,32a8,8,0,1,1-10-12.5L107.19,128,75,102.25a8,8,0,1,1,10-12.5l40,32a8,8,0,0,1,0,12.5ZM176,168H136a8,8,0,0,1,0-16h40a8,8,0,0,1,0,16Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",NC,[...t[3]||(t[3]=[Gb("path",{
d:"M126,128a6,6,0,0,1-2.25,4.69l-40,32a6,6,0,0,1-7.5-9.38L110.4,128,76.25,100.69a6,6,0,1,1,7.5-9.38l40,32A6,6,0,0,1,126,128Zm50,26H136a6,6,0,0,0,0,12h40a6,6,0,0,0,0-12Zm54-98V200a14,14,0,0,1-14,14H40a14,14,0,0,1-14-14V56A14,14,0,0,1,40,42H216A14,14,0,0,1,230,56Zm-12,0a2,2,0,0,0-2-2H40a2,2,0,0,0-2,2V200a2,2,0,0,0,2,2H216a2,2,0,0,0,2-2Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",RC,[...t[4]||(t[4]=[Gb("path",{
d:"M128,128a8,8,0,0,1-3,6.25l-40,32a8,8,0,1,1-10-12.5L107.19,128,75,102.25a8,8,0,1,1,10-12.5l40,32A8,8,0,0,1,128,128Zm48,24H136a8,8,0,0,0,0,16h40a8,8,0,0,0,0-16Zm56-96V200a16,16,0,0,1-16,16H40a16,16,0,0,1-16-16V56A16,16,0,0,1,40,40H216A16,16,0,0,1,232,56ZM216,200V56H40V200H216Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",LC,[...t[5]||(t[5]=[Gb("path",{
d:"M122.5,124.88a4,4,0,0,1,0,6.24l-40,32a4,4,0,0,1-5-6.24L113.6,128,77.5,99.12a4,4,0,0,1,5-6.24ZM176,156H136a4,4,0,0,0,0,8h40a4,4,0,0,0,0-8ZM228,56V200a12,12,0,0,1-12,12H40a12,12,0,0,1-12-12V56A12,12,0,0,1,40,44H216A12,12,0,0,1,228,56Zm-8,0a4,4,0,0,0-4-4H40a4,4,0,0,0-4,4V200a4,4,0,0,0,4,4H216a4,4,0,0,0,4-4Z"
},null,-1)])])):ny("",!0)],16))}}),jC={key:0},UC={key:1},zC={key:2},FC={key:3
},ZC={key:4},QC={key:5},HC=Qg({name:"ScalarIconTextAlignLeft",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",jC,[...t[0]||(t[0]=[Gb("path",{
d:"M28,64A12,12,0,0,1,40,52H216a12,12,0,0,1,0,24H40A12,12,0,0,1,28,64Zm12,52H168a12,12,0,0,0,0-24H40a12,12,0,0,0,0,24Zm176,16H40a12,12,0,0,0,0,24H216a12,12,0,0,0,0-24Zm-48,40H40a12,12,0,0,0,0,24H168a12,12,0,0,0,0-24Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",UC,[...t[1]||(t[1]=[Gb("path",{
d:"M216,64V168a16,16,0,0,1-16,16H40V64Z",opacity:"0.2"},null,-1),Gb("path",{
d:"M32,64a8,8,0,0,1,8-8H216a8,8,0,0,1,0,16H40A8,8,0,0,1,32,64Zm8,48H168a8,8,0,0,0,0-16H40a8,8,0,0,0,0,16Zm176,24H40a8,8,0,0,0,0,16H216a8,8,0,0,0,0-16Zm-48,40H40a8,8,0,0,0,0,16H168a8,8,0,0,0,0-16Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",zC,[...t[2]||(t[2]=[Gb("path",{
d:"M208,32H48A16,16,0,0,0,32,48V208a16,16,0,0,0,16,16H208a16,16,0,0,0,16-16V48A16,16,0,0,0,208,32ZM160,184H64a8,8,0,0,1,0-16h96a8,8,0,0,1,0,16Zm32-32H64a8,8,0,0,1,0-16H192a8,8,0,0,1,0,16ZM56,112a8,8,0,0,1,8-8h96a8,8,0,0,1,0,16H64A8,8,0,0,1,56,112ZM192,88H64a8,8,0,0,1,0-16H192a8,8,0,0,1,0,16Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",FC,[...t[3]||(t[3]=[Gb("path",{
d:"M34,64a6,6,0,0,1,6-6H216a6,6,0,0,1,0,12H40A6,6,0,0,1,34,64Zm6,46H168a6,6,0,0,0,0-12H40a6,6,0,0,0,0,12Zm176,28H40a6,6,0,0,0,0,12H216a6,6,0,0,0,0-12Zm-48,40H40a6,6,0,0,0,0,12H168a6,6,0,0,0,0-12Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",ZC,[...t[4]||(t[4]=[Gb("path",{
d:"M32,64a8,8,0,0,1,8-8H216a8,8,0,0,1,0,16H40A8,8,0,0,1,32,64Zm8,48H168a8,8,0,0,0,0-16H40a8,8,0,0,0,0,16Zm176,24H40a8,8,0,0,0,0,16H216a8,8,0,0,0,0-16Zm-48,40H40a8,8,0,0,0,0,16H168a8,8,0,0,0,0-16Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",QC,[...t[5]||(t[5]=[Gb("path",{
d:"M36,64a4,4,0,0,1,4-4H216a4,4,0,0,1,0,8H40A4,4,0,0,1,36,64Zm4,44H168a4,4,0,0,0,0-8H40a4,4,0,0,0,0,8Zm176,32H40a4,4,0,0,0,0,8H216a4,4,0,0,0,0-8Zm-48,40H40a4,4,0,0,0,0,8H168a4,4,0,0,0,0-8Z"
},null,-1)])])):ny("",!0)],16))}}),VC={key:0},qC={key:1},WC={key:2},XC={key:3
},GC={key:4},YC={key:5},KC=Qg({name:"ScalarIconTrash",props:{label:{},weight:{}
},setup(e){const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",VC,[...t[0]||(t[0]=[Gb("path",{
d:"M216,48H180V36A28,28,0,0,0,152,8H104A28,28,0,0,0,76,36V48H40a12,12,0,0,0,0,24h4V208a20,20,0,0,0,20,20H192a20,20,0,0,0,20-20V72h4a12,12,0,0,0,0-24ZM100,36a4,4,0,0,1,4-4h48a4,4,0,0,1,4,4V48H100Zm88,168H68V72H188ZM116,104v64a12,12,0,0,1-24,0V104a12,12,0,0,1,24,0Zm48,0v64a12,12,0,0,1-24,0V104a12,12,0,0,1,24,0Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",qC,[...t[1]||(t[1]=[Gb("path",{
d:"M200,56V208a8,8,0,0,1-8,8H64a8,8,0,0,1-8-8V56Z",opacity:"0.2"
},null,-1),Gb("path",{
d:"M216,48H176V40a24,24,0,0,0-24-24H104A24,24,0,0,0,80,40v8H40a8,8,0,0,0,0,16h8V208a16,16,0,0,0,16,16H192a16,16,0,0,0,16-16V64h8a8,8,0,0,0,0-16ZM96,40a8,8,0,0,1,8-8h48a8,8,0,0,1,8,8v8H96Zm96,168H64V64H192ZM112,104v64a8,8,0,0,1-16,0V104a8,8,0,0,1,16,0Zm48,0v64a8,8,0,0,1-16,0V104a8,8,0,0,1,16,0Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",WC,[...t[2]||(t[2]=[Gb("path",{
d:"M216,48H176V40a24,24,0,0,0-24-24H104A24,24,0,0,0,80,40v8H40a8,8,0,0,0,0,16h8V208a16,16,0,0,0,16,16H192a16,16,0,0,0,16-16V64h8a8,8,0,0,0,0-16ZM112,168a8,8,0,0,1-16,0V104a8,8,0,0,1,16,0Zm48,0a8,8,0,0,1-16,0V104a8,8,0,0,1,16,0Zm0-120H96V40a8,8,0,0,1,8-8h48a8,8,0,0,1,8,8Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",XC,[...t[3]||(t[3]=[Gb("path",{
d:"M216,50H174V40a22,22,0,0,0-22-22H104A22,22,0,0,0,82,40V50H40a6,6,0,0,0,0,12H50V208a14,14,0,0,0,14,14H192a14,14,0,0,0,14-14V62h10a6,6,0,0,0,0-12ZM94,40a10,10,0,0,1,10-10h48a10,10,0,0,1,10,10V50H94ZM194,208a2,2,0,0,1-2,2H64a2,2,0,0,1-2-2V62H194ZM110,104v64a6,6,0,0,1-12,0V104a6,6,0,0,1,12,0Zm48,0v64a6,6,0,0,1-12,0V104a6,6,0,0,1,12,0Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",GC,[...t[4]||(t[4]=[Gb("path",{
d:"M216,48H176V40a24,24,0,0,0-24-24H104A24,24,0,0,0,80,40v8H40a8,8,0,0,0,0,16h8V208a16,16,0,0,0,16,16H192a16,16,0,0,0,16-16V64h8a8,8,0,0,0,0-16ZM96,40a8,8,0,0,1,8-8h48a8,8,0,0,1,8,8v8H96Zm96,168H64V64H192ZM112,104v64a8,8,0,0,1-16,0V104a8,8,0,0,1,16,0Zm48,0v64a8,8,0,0,1-16,0V104a8,8,0,0,1,16,0Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",YC,[...t[5]||(t[5]=[Gb("path",{
d:"M216,52H172V40a20,20,0,0,0-20-20H104A20,20,0,0,0,84,40V52H40a4,4,0,0,0,0,8H52V208a12,12,0,0,0,12,12H192a12,12,0,0,0,12-12V60h12a4,4,0,0,0,0-8ZM92,40a12,12,0,0,1,12-12h48a12,12,0,0,1,12,12V52H92ZM196,208a4,4,0,0,1-4,4H64a4,4,0,0,1-4-4V60H196ZM108,104v64a4,4,0,0,1-8,0V104a4,4,0,0,1,8,0Zm48,0v64a4,4,0,0,1-8,0V104a4,4,0,0,1,8,0Z"
},null,-1)])])):ny("",!0)],16))}}),JC={key:0},e$={key:1},t$={key:2},n$={key:3
},r$={key:4},o$={key:5},a$=Qg({name:"ScalarIconWarning",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",JC,[...t[0]||(t[0]=[Gb("path",{
d:"M240.26,186.1,152.81,34.23h0a28.74,28.74,0,0,0-49.62,0L15.74,186.1a27.45,27.45,0,0,0,0,27.71A28.31,28.31,0,0,0,40.55,228h174.9a28.31,28.31,0,0,0,24.79-14.19A27.45,27.45,0,0,0,240.26,186.1Zm-20.8,15.7a4.46,4.46,0,0,1-4,2.2H40.55a4.46,4.46,0,0,1-4-2.2,3.56,3.56,0,0,1,0-3.73L124,46.2a4.77,4.77,0,0,1,8,0l87.44,151.87A3.56,3.56,0,0,1,219.46,201.8ZM116,136V104a12,12,0,0,1,24,0v32a12,12,0,0,1-24,0Zm28,40a16,16,0,1,1-16-16A16,16,0,0,1,144,176Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",e$,[...t[1]||(t[1]=[Gb("path",{
d:"M215.46,216H40.54C27.92,216,20,202.79,26.13,192.09L113.59,40.22c6.3-11,22.52-11,28.82,0l87.46,151.87C236,202.79,228.08,216,215.46,216Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M236.8,188.09,149.35,36.22h0a24.76,24.76,0,0,0-42.7,0L19.2,188.09a23.51,23.51,0,0,0,0,23.72A24.35,24.35,0,0,0,40.55,224h174.9a24.35,24.35,0,0,0,21.33-12.19A23.51,23.51,0,0,0,236.8,188.09ZM222.93,203.8a8.5,8.5,0,0,1-7.48,4.2H40.55a8.5,8.5,0,0,1-7.48-4.2,7.59,7.59,0,0,1,0-7.72L120.52,44.21a8.75,8.75,0,0,1,15,0l87.45,151.87A7.59,7.59,0,0,1,222.93,203.8ZM120,144V104a8,8,0,0,1,16,0v40a8,8,0,0,1-16,0Zm20,36a12,12,0,1,1-12-12A12,12,0,0,1,140,180Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",t$,[...t[2]||(t[2]=[Gb("path",{
d:"M236.8,188.09,149.35,36.22h0a24.76,24.76,0,0,0-42.7,0L19.2,188.09a23.51,23.51,0,0,0,0,23.72A24.35,24.35,0,0,0,40.55,224h174.9a24.35,24.35,0,0,0,21.33-12.19A23.51,23.51,0,0,0,236.8,188.09ZM120,104a8,8,0,0,1,16,0v40a8,8,0,0,1-16,0Zm8,88a12,12,0,1,1,12-12A12,12,0,0,1,128,192Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",n$,[...t[3]||(t[3]=[Gb("path",{
d:"M235.07,189.09,147.61,37.22h0a22.75,22.75,0,0,0-39.22,0L20.93,189.09a21.53,21.53,0,0,0,0,21.72A22.35,22.35,0,0,0,40.55,222h174.9a22.35,22.35,0,0,0,19.6-11.19A21.53,21.53,0,0,0,235.07,189.09ZM224.66,204.8a10.46,10.46,0,0,1-9.21,5.2H40.55a10.46,10.46,0,0,1-9.21-5.2,9.51,9.51,0,0,1,0-9.72L118.79,43.21a10.75,10.75,0,0,1,18.42,0l87.46,151.87A9.51,9.51,0,0,1,224.66,204.8ZM122,144V104a6,6,0,0,1,12,0v40a6,6,0,0,1-12,0Zm16,36a10,10,0,1,1-10-10A10,10,0,0,1,138,180Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",r$,[...t[4]||(t[4]=[Gb("path",{
d:"M236.8,188.09,149.35,36.22h0a24.76,24.76,0,0,0-42.7,0L19.2,188.09a23.51,23.51,0,0,0,0,23.72A24.35,24.35,0,0,0,40.55,224h174.9a24.35,24.35,0,0,0,21.33-12.19A23.51,23.51,0,0,0,236.8,188.09ZM222.93,203.8a8.5,8.5,0,0,1-7.48,4.2H40.55a8.5,8.5,0,0,1-7.48-4.2,7.59,7.59,0,0,1,0-7.72L120.52,44.21a8.75,8.75,0,0,1,15,0l87.45,151.87A7.59,7.59,0,0,1,222.93,203.8ZM120,144V104a8,8,0,0,1,16,0v40a8,8,0,0,1-16,0Zm20,36a12,12,0,1,1-12-12A12,12,0,0,1,140,180Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",o$,[...t[5]||(t[5]=[Gb("path",{
d:"M233.34,190.09,145.88,38.22h0a20.75,20.75,0,0,0-35.76,0L22.66,190.09a19.52,19.52,0,0,0,0,19.71A20.36,20.36,0,0,0,40.54,220H215.46a20.36,20.36,0,0,0,17.86-10.2A19.52,19.52,0,0,0,233.34,190.09ZM226.4,205.8a12.47,12.47,0,0,1-10.94,6.2H40.54a12.47,12.47,0,0,1-10.94-6.2,11.45,11.45,0,0,1,0-11.72L117.05,42.21a12.76,12.76,0,0,1,21.9,0L226.4,194.08A11.45,11.45,0,0,1,226.4,205.8ZM124,144V104a4,4,0,0,1,8,0v40a4,4,0,0,1-8,0Zm12,36a8,8,0,1,1-8-8A8,8,0,0,1,136,180Z"
},null,-1)])])):ny("",!0)],16))}}),i$={key:0},s$={key:1},l$={key:2},c$={key:3
},u$={key:4},d$={key:5},p$=Qg({name:"ScalarIconWarningCircle",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",i$,[...t[0]||(t[0]=[Gb("path",{
d:"M128,20A108,108,0,1,0,236,128,108.12,108.12,0,0,0,128,20Zm0,192a84,84,0,1,1,84-84A84.09,84.09,0,0,1,128,212Zm-12-80V80a12,12,0,0,1,24,0v52a12,12,0,0,1-24,0Zm28,40a16,16,0,1,1-16-16A16,16,0,0,1,144,172Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",s$,[...t[1]||(t[1]=[Gb("path",{
d:"M224,128a96,96,0,1,1-96-96A96,96,0,0,1,224,128Z",opacity:"0.2"
},null,-1),Gb("path",{
d:"M128,24A104,104,0,1,0,232,128,104.11,104.11,0,0,0,128,24Zm0,192a88,88,0,1,1,88-88A88.1,88.1,0,0,1,128,216Zm-8-80V80a8,8,0,0,1,16,0v56a8,8,0,0,1-16,0Zm20,36a12,12,0,1,1-12-12A12,12,0,0,1,140,172Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",l$,[...t[2]||(t[2]=[Gb("path",{
d:"M128,24A104,104,0,1,0,232,128,104.11,104.11,0,0,0,128,24Zm-8,56a8,8,0,0,1,16,0v56a8,8,0,0,1-16,0Zm8,104a12,12,0,1,1,12-12A12,12,0,0,1,128,184Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",c$,[...t[3]||(t[3]=[Gb("path",{
d:"M128,26A102,102,0,1,0,230,128,102.12,102.12,0,0,0,128,26Zm0,192a90,90,0,1,1,90-90A90.1,90.1,0,0,1,128,218Zm-6-82V80a6,6,0,0,1,12,0v56a6,6,0,0,1-12,0Zm16,36a10,10,0,1,1-10-10A10,10,0,0,1,138,172Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",u$,[...t[4]||(t[4]=[Gb("path",{
d:"M128,24A104,104,0,1,0,232,128,104.11,104.11,0,0,0,128,24Zm0,192a88,88,0,1,1,88-88A88.1,88.1,0,0,1,128,216Zm-8-80V80a8,8,0,0,1,16,0v56a8,8,0,0,1-16,0Zm20,36a12,12,0,1,1-12-12A12,12,0,0,1,140,172Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",d$,[...t[5]||(t[5]=[Gb("path",{
d:"M128,28A100,100,0,1,0,228,128,100.11,100.11,0,0,0,128,28Zm0,192a92,92,0,1,1,92-92A92.1,92.1,0,0,1,128,220Zm-4-84V80a4,4,0,0,1,8,0v56a4,4,0,0,1-8,0Zm12,36a8,8,0,1,1-8-8A8,8,0,0,1,136,172Z"
},null,-1)])])):ny("",!0)],16))}}),h$={key:0},f$={key:1},m$={key:2},g$={key:3
},v$={key:4},b$={key:5},y$=Qg({name:"ScalarIconWarningOctagon",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",h$,[...t[0]||(t[0]=[Gb("path",{
d:"M116,132V80a12,12,0,0,1,24,0v52a12,12,0,0,1-24,0ZM236,91.55v72.9a19.86,19.86,0,0,1-5.86,14.14l-51.55,51.55A19.85,19.85,0,0,1,164.45,236H91.55a19.85,19.85,0,0,1-14.14-5.86L25.86,178.59A19.86,19.86,0,0,1,20,164.45V91.55a19.86,19.86,0,0,1,5.86-14.14L77.41,25.86A19.85,19.85,0,0,1,91.55,20h72.9a19.85,19.85,0,0,1,14.14,5.86l51.55,51.55A19.86,19.86,0,0,1,236,91.55Zm-24,1.66L162.79,44H93.21L44,93.21v69.58L93.21,212h69.58L212,162.79ZM128,156a16,16,0,1,0,16,16A16,16,0,0,0,128,156Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",f$,[...t[1]||(t[1]=[Gb("path",{
d:"M224,91.55v72.9a8,8,0,0,1-2.34,5.66l-51.55,51.55a8,8,0,0,1-5.66,2.34H91.55a8,8,0,0,1-5.66-2.34L34.34,170.11A8,8,0,0,1,32,164.45V91.55a8,8,0,0,1,2.34-5.66L85.89,34.34A8,8,0,0,1,91.55,32h72.9a8,8,0,0,1,5.66,2.34l51.55,51.55A8,8,0,0,1,224,91.55Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M120,136V80a8,8,0,0,1,16,0v56a8,8,0,0,1-16,0ZM232,91.55v72.9a15.86,15.86,0,0,1-4.69,11.31l-51.55,51.55A15.86,15.86,0,0,1,164.45,232H91.55a15.86,15.86,0,0,1-11.31-4.69L28.69,175.76A15.86,15.86,0,0,1,24,164.45V91.55a15.86,15.86,0,0,1,4.69-11.31L80.24,28.69A15.86,15.86,0,0,1,91.55,24h72.9a15.86,15.86,0,0,1,11.31,4.69l51.55,51.55A15.86,15.86,0,0,1,232,91.55Zm-16,0L164.45,40H91.55L40,91.55v72.9L91.55,216h72.9L216,164.45ZM128,160a12,12,0,1,0,12,12A12,12,0,0,0,128,160Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",m$,[...t[2]||(t[2]=[Gb("path",{
d:"M227.31,80.23,175.77,28.69A16.13,16.13,0,0,0,164.45,24H91.55a16.13,16.13,0,0,0-11.32,4.69L28.69,80.23A16.13,16.13,0,0,0,24,91.55v72.9a16.13,16.13,0,0,0,4.69,11.32l51.54,51.54A16.13,16.13,0,0,0,91.55,232h72.9a16.13,16.13,0,0,0,11.32-4.69l51.54-51.54A16.13,16.13,0,0,0,232,164.45V91.55A16.13,16.13,0,0,0,227.31,80.23ZM120,80a8,8,0,0,1,16,0v56a8,8,0,0,1-16,0Zm8,104a12,12,0,1,1,12-12A12,12,0,0,1,128,184Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",g$,[...t[3]||(t[3]=[Gb("path",{
d:"M122,136V80a6,6,0,0,1,12,0v56a6,6,0,0,1-12,0ZM230,91.55v72.9a13.92,13.92,0,0,1-4.1,9.9L174.35,225.9a13.92,13.92,0,0,1-9.9,4.1H91.55a13.92,13.92,0,0,1-9.9-4.1L30.1,174.35a13.92,13.92,0,0,1-4.1-9.9V91.55a13.92,13.92,0,0,1,4.1-9.9L81.65,30.1a13.92,13.92,0,0,1,9.9-4.1h72.9a13.92,13.92,0,0,1,9.9,4.1L225.9,81.65A13.92,13.92,0,0,1,230,91.55Zm-12,0a2,2,0,0,0-.59-1.42L165.87,38.59a2,2,0,0,0-1.42-.59H91.55a2,2,0,0,0-1.41.59L38.58,90.13A2,2,0,0,0,38,91.55v72.9a2,2,0,0,0,.59,1.42l51.54,51.54a2,2,0,0,0,1.42.59h72.9a2,2,0,0,0,1.41-.59l51.56-51.54a2,2,0,0,0,.58-1.42ZM128,162a10,10,0,1,0,10,10A10,10,0,0,0,128,162Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",v$,[...t[4]||(t[4]=[Gb("path",{
d:"M120,136V80a8,8,0,0,1,16,0v56a8,8,0,0,1-16,0ZM232,91.55v72.9a15.86,15.86,0,0,1-4.69,11.31l-51.55,51.55A15.86,15.86,0,0,1,164.45,232H91.55a15.86,15.86,0,0,1-11.31-4.69L28.69,175.76A15.86,15.86,0,0,1,24,164.45V91.55a15.86,15.86,0,0,1,4.69-11.31L80.24,28.69A15.86,15.86,0,0,1,91.55,24h72.9a15.86,15.86,0,0,1,11.31,4.69l51.55,51.55A15.86,15.86,0,0,1,232,91.55Zm-16,0L164.45,40H91.55L40,91.55v72.9L91.55,216h72.9L216,164.45ZM128,160a12,12,0,1,0,12,12A12,12,0,0,0,128,160Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",b$,[...t[5]||(t[5]=[Gb("path",{
d:"M124,136V80a4,4,0,0,1,8,0v56a4,4,0,0,1-8,0ZM228,91.55v72.9a12,12,0,0,1-3.51,8.49l-51.55,51.55a12,12,0,0,1-8.49,3.51H91.55a12,12,0,0,1-8.49-3.51L31.51,172.94A12,12,0,0,1,28,164.45V91.55a12,12,0,0,1,3.51-8.49L83.06,31.51A12,12,0,0,1,91.55,28h72.9a12,12,0,0,1,8.49,3.51l51.55,51.55A12,12,0,0,1,228,91.55Zm-8,0a4,4,0,0,0-1.17-2.83L167.28,37.17A4.06,4.06,0,0,0,164.45,36H91.55a4.06,4.06,0,0,0-2.83,1.17L37.17,88.72A4,4,0,0,0,36,91.55v72.9a4,4,0,0,0,1.17,2.83l51.55,51.55A4.06,4.06,0,0,0,91.55,220h72.9a4.06,4.06,0,0,0,2.83-1.17l51.55-51.55a4,4,0,0,0,1.17-2.83ZM128,164a8,8,0,1,0,8,8A8,8,0,0,0,128,164Z"
},null,-1)])])):ny("",!0)],16))}}),O$={key:0},w$={key:1},x$={key:2},k$={key:3
},S$={key:4},_$={key:5},T$=Qg({name:"ScalarIconWebhooksLogo",props:{label:{},
weight:{}},setup(e){const t=e,{bind:n,weight:r}=n_(t)
;return(e,t)=>(Ub(),Qb("svg",iy({xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",O$,[...t[0]||(t[0]=[Gb("path",{
d:"M192,180H118.71a56,56,0,1,1-104.6-37.46,12,12,0,1,1,21.37,10.92A31.64,31.64,0,0,0,32,168a32,32,0,0,0,64,0,12,12,0,0,1,12-12h84a12,12,0,0,1,0,24Zm0-68a55.9,55.9,0,0,0-18.45,3.12L138.22,57.71a12,12,0,0,0-20.44,12.58l40.94,66.52a12,12,0,0,0,16.52,3.93,32,32,0,1,1,19.68,59.13A12,12,0,0,0,196,223.82a10.05,10.05,0,0,0,1.09,0A56,56,0,0,0,192,112ZM57.71,178.22a12,12,0,0,0,16.51-3.93l40.94-66.52a12,12,0,0,0-3.92-16.51,32,32,0,1,1,45.28-41.8,12,12,0,1,0,21.37-10.92A56,56,0,1,0,89.1,104.32L53.78,161.71A12,12,0,0,0,57.71,178.22Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",w$,[...t[1]||(t[1]=[Gb("path",{
d:"M128,104a40,40,0,1,1,40-40A40,40,0,0,1,128,104Zm64,24a40,40,0,1,0,40,40A40,40,0,0,0,192,128ZM64,128a40,40,0,1,0,40,40A40,40,0,0,0,64,128Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M178.16,176H111.32A48,48,0,1,1,25.6,139.19a8,8,0,0,1,12.8,9.61A31.69,31.69,0,0,0,32,168a32,32,0,0,0,64,0,8,8,0,0,1,8-8h74.16a16,16,0,1,1,0,16ZM64,184a16,16,0,0,0,14.08-23.61l35.77-58.14a8,8,0,0,0-2.62-11,32,32,0,1,1,46.1-40.06A8,8,0,1,0,172,44.79a48,48,0,1,0-75.62,55.33L64.44,152c-.15,0-.29,0-.44,0a16,16,0,0,0,0,32Zm128-64a48.18,48.18,0,0,0-18,3.49L142.08,71.6A16,16,0,1,0,128,80l.44,0,35.78,58.15a8,8,0,0,0,11,2.61A32,32,0,1,1,192,200a8,8,0,0,0,0,16,48,48,0,0,0,0-96Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",x$,[...t[2]||(t[2]=[Gb("path",{
d:"M50.15,160,89.07,92.57l-2.24-3.88a48,48,0,1,1,85.05-44.17,8.17,8.17,0,0,1-3.19,10.4,8,8,0,0,1-11.35-3.72,32,32,0,1,0-56.77,29.3.57.57,0,0,1,.08.13l13.83,23.94a8,8,0,0,1,0,8L77.86,176a16,16,0,0,1-27.71-16Zm141-40H178.81L141.86,56a16,16,0,0,0-27.71,16l34.64,60a8,8,0,0,0,6.92,4h35.63c17.89,0,32.95,14.64,32.66,32.53A32,32,0,0,1,192.31,200a8.23,8.23,0,0,0-8.28,7.33,8,8,0,0,0,8,8.67,48.05,48.05,0,0,0,48-48.93C239.49,140.79,217.48,120,191.19,120ZM208,167.23c-.4-8.61-7.82-15.23-16.43-15.23H114.81a8,8,0,0,0-6.93,4L91.72,184h0a32,32,0,1,1-53.47-35,8.2,8.2,0,0,0-.92-11,8,8,0,0,0-11.72,1.17A47.63,47.63,0,0,0,16,167.54,48,48,0,0,0,105.55,192v0l4.62-8H192A16,16,0,0,0,208,167.23Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",k$,[...t[3]||(t[3]=[Gb("path",{
d:"M179.37,174H109.6a46,46,0,1,1-82.4-33.61,6,6,0,0,1,9.6,7.21A33.68,33.68,0,0,0,30,168a34,34,0,0,0,68,0,6,6,0,0,1,6-6h75.37a14,14,0,1,1,0,12ZM64,182a14,14,0,0,0,11.73-21.62l36.42-59.18a6,6,0,0,0-2-8.25,34,34,0,1,1,49-42.57,6,6,0,1,0,11-4.79A46,46,0,1,0,99,99.7L65.52,154.08c-.5-.05-1-.08-1.52-.08a14,14,0,0,0,0,28Zm128-60a46,46,0,0,0-18.8,4L139.73,71.61A14,14,0,1,0,128,78a12.79,12.79,0,0,0,1.52-.09l36.4,59.17a6.05,6.05,0,0,0,3.73,2.69,6,6,0,0,0,4.53-.73A34,34,0,1,1,192,202a6,6,0,0,0,0,12,46,46,0,0,0,0-92Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",S$,[...t[4]||(t[4]=[Gb("path",{
d:"M178.16,176H111.32A48,48,0,1,1,25.6,139.19a8,8,0,0,1,12.8,9.61A31.69,31.69,0,0,0,32,168a32,32,0,0,0,64,0,8,8,0,0,1,8-8h74.16a16,16,0,1,1,0,16ZM64,184a16,16,0,0,0,14.08-23.61l35.77-58.14a8,8,0,0,0-2.62-11,32,32,0,1,1,46.1-40.06A8,8,0,1,0,172,44.79a48,48,0,1,0-75.62,55.33L64.44,152c-.15,0-.29,0-.44,0a16,16,0,0,0,0,32Zm128-64a48.18,48.18,0,0,0-18,3.49L142.08,71.6A16,16,0,1,0,128,80l.44,0,35.78,58.15a8,8,0,0,0,11,2.61A32,32,0,1,1,192,200a8,8,0,0,0,0,16,48,48,0,0,0,0-96Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",_$,[...t[5]||(t[5]=[Gb("path",{
d:"M180.7,172H107.81a44,44,0,1,1-79-30.41,4,4,0,0,1,6.4,4.81A35.67,35.67,0,0,0,28,168a36,36,0,0,0,72,0,4,4,0,0,1,4-4h76.7a12,12,0,1,1,0,8ZM64,180a12,12,0,0,0,9.33-19.54l37.11-60.3a4,4,0,0,0-1.31-5.51A36,36,0,1,1,161,49.58a4,4,0,1,0,7.33-3.19,44,44,0,1,0-66.71,52.83l-35.1,57.05A11.58,11.58,0,0,0,64,156a12,12,0,0,0,0,24Zm128-56a44,44,0,0,0-19.56,4.58l-35.11-57A12,12,0,1,0,128,76a12.24,12.24,0,0,0,2.52-.27L167.63,136a4,4,0,0,0,5.5,1.31A36,36,0,1,1,192,204a4,4,0,0,0,0,8,44,44,0,0,0,0-88Z"
},null,-1)])])):ny("",!0)],16))}}),E$={key:0},A$={key:1},C$={key:2},$$={key:3
},P$={key:4},D$={key:5},I$=Qg({name:"ScalarIconX",props:{label:{},weight:{}},
setup(e){const t=e,{bind:n,weight:r}=n_(t);return(e,t)=>(Ub(),Qb("svg",iy({
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 256 256",fill:"currentColor"
},xm(n)),[kv(e.$slots,"default"),"bold"===xm(r)?(Ub(),
Qb("g",E$,[...t[0]||(t[0]=[Gb("path",{
d:"M208.49,191.51a12,12,0,0,1-17,17L128,145,64.49,208.49a12,12,0,0,1-17-17L111,128,47.51,64.49a12,12,0,0,1,17-17L128,111l63.51-63.52a12,12,0,0,1,17,17L145,128Z"
},null,-1)])])):"duotone"===xm(r)?(Ub(),Qb("g",A$,[...t[1]||(t[1]=[Gb("path",{
d:"M216,56V200a16,16,0,0,1-16,16H56a16,16,0,0,1-16-16V56A16,16,0,0,1,56,40H200A16,16,0,0,1,216,56Z",
opacity:"0.2"},null,-1),Gb("path",{
d:"M205.66,194.34a8,8,0,0,1-11.32,11.32L128,139.31,61.66,205.66a8,8,0,0,1-11.32-11.32L116.69,128,50.34,61.66A8,8,0,0,1,61.66,50.34L128,116.69l66.34-66.35a8,8,0,0,1,11.32,11.32L139.31,128Z"
},null,-1)])])):"fill"===xm(r)?(Ub(),Qb("g",C$,[...t[2]||(t[2]=[Gb("path",{
d:"M208,32H48A16,16,0,0,0,32,48V208a16,16,0,0,0,16,16H208a16,16,0,0,0,16-16V48A16,16,0,0,0,208,32ZM181.66,170.34a8,8,0,0,1-11.32,11.32L128,139.31,85.66,181.66a8,8,0,0,1-11.32-11.32L116.69,128,74.34,85.66A8,8,0,0,1,85.66,74.34L128,116.69l42.34-42.35a8,8,0,0,1,11.32,11.32L139.31,128Z"
},null,-1)])])):"light"===xm(r)?(Ub(),Qb("g",$$,[...t[3]||(t[3]=[Gb("path",{
d:"M204.24,195.76a6,6,0,1,1-8.48,8.48L128,136.49,60.24,204.24a6,6,0,0,1-8.48-8.48L119.51,128,51.76,60.24a6,6,0,0,1,8.48-8.48L128,119.51l67.76-67.75a6,6,0,0,1,8.48,8.48L136.49,128Z"
},null,-1)])])):"regular"===xm(r)?(Ub(),Qb("g",P$,[...t[4]||(t[4]=[Gb("path",{
d:"M205.66,194.34a8,8,0,0,1-11.32,11.32L128,139.31,61.66,205.66a8,8,0,0,1-11.32-11.32L116.69,128,50.34,61.66A8,8,0,0,1,61.66,50.34L128,116.69l66.34-66.35a8,8,0,0,1,11.32,11.32L139.31,128Z"
},null,-1)])])):"thin"===xm(r)?(Ub(),Qb("g",D$,[...t[5]||(t[5]=[Gb("path",{
d:"M202.83,197.17a4,4,0,0,1-5.66,5.66L128,133.66,58.83,202.83a4,4,0,0,1-5.66-5.66L122.34,128,53.17,58.83a4,4,0,0,1,5.66-5.66L128,122.34l69.17-69.17a4,4,0,1,1,5.66,5.66L133.66,128Z"
},null,-1)])])):ny("",!0)],16))}}),M$=Qg({__name:"ScalarCheckbox",props:{
selected:{type:Boolean},type:{default:"checkbox"}},
setup:e=>(t,n)=>(Ub(),Qb("div",{
class:Ih(["flex size-4 items-center justify-center p-0.75",[e.selected?"bg-c-accent text-b-1":"text-transparent shadow-border","checkbox"===e.type?"rounded":"rounded-full"]])
},[e.selected?(Ub(),Hb(xm(oT),{key:0,class:"size-3",weight:"bold"
})):ny("",!0)],2))}),N$=Symbol(),R$=Qg({inheritAttrs:!1,
__name:"ScalarFormInput",props:{is:{default:"button"}},setup(e){
const{cx:t}=zS(),n=ug(N$,!1),r=jS({
base:["bg-b-1.5 flex items-center text-c-2 gap-0.75 px-3 py-2.5 ","outline-offset-[-1px] has-[:focus-visible]:outline"],
variants:{grouped:{true:"first:rounded-t-[inherit] last:rounded-b-[inherit]",
false:"rounded border"},button:{true:"cursor-pointer hover:bg-b-2"}}})
;return(o,a)=>(Ub(),Hb(bv(e.is),iy({type:"button"===e.is?"button":void 0
},xm(t)(xm(r)({button:"button"===e.is,grouped:xm(n)}))),{
default:ig((()=>[kv(o.$slots,"default")])),_:3},16,["type"]))}}),L$={
class:"flex-1 text-left min-w-0 truncate"},B$=["type"],j$=Qg({inheritAttrs:!1,
__name:"ScalarCheckboxInput",props:Nv({type:{default:"checkbox"}},{modelValue:{
type:Boolean},modelModifiers:{}}),emits:["update:modelValue"],setup(e){
const t=Kv(e,"modelValue"),{stylingAttrsCx:n,otherAttrs:r}=zS()
;return(o,a)=>(Ub(),Hb(xm(R$),iy({is:"label"
},xm(n)("cursor-pointer gap-2 hover:bg-b-2",{"text-c-1":t.value})),{
default:ig((()=>[Yb(M$,{class:"shrink-0",selected:t.value,type:e.type
},null,8,["selected","type"]),Gb("div",L$,[kv(o.$slots,"default")]),sg(Gb("input",iy({
"onUpdate:modelValue":a[0]||(a[0]=e=>t.value=e),class:"sr-only",type:e.type
},xm(r)),null,16,B$),[[MO,t.value]])])),_:3},16))}}),U$=Qg({inheritAttrs:!1,
__name:"ScalarFormInputGroup",props:{is:{default:"div"}},setup(e){
const{cx:t}=zS()
;return cg(N$,!0),(n,r)=>(Ub(),Hb(bv(e.is),Mh(Kb(xm(t)("flex flex-col border rounded divide-y"))),{
default:ig((()=>[kv(n.$slots,"default")])),_:3},16))}}),z$=Qg({
__name:"ScalarCheckboxRadioGroup",props:Nv({options:{default:()=>[]}},{
modelValue:{},modelModifiers:{}}),emits:["update:modelValue"],setup(e){
const t=Kv(e,"modelValue"),n=Hg();return(r,o)=>(Ub(),Hb(xm(U$),null,{
default:ig((()=>[(Ub(!0),Qb(Mb,null,wv(e.options,(e=>(Ub(),Hb(j$,{key:e.value,
modelValue:t.value?.value===e.value,name:xm(n),type:"radio",value:e.value,
"onUpdate:modelValue":n=>t.value=n?e:void 0},{
default:ig((()=>[ey(Uh(e.label),1)])),_:2
},1032,["modelValue","name","value","onUpdate:modelValue"])))),128))])),_:1}))}
});let F$=class{constructor(e,t,n){
this.property=e,this.normal=t,n&&(this.space=n)}};function Z$(e,t){
const n={},r={};let o=-1
;for(;++o<e.length;)Object.assign(n,e[o].property),Object.assign(r,e[o].normal)
;return new F$(n,r,t)}function Q$(e){return e.toLowerCase()}
F$.prototype.property={},F$.prototype.normal={},F$.prototype.space=null
;let H$=class{constructor(e,t){this.property=e,this.attribute=t}}
;H$.prototype.space=null,
H$.prototype.boolean=!1,H$.prototype.booleanish=!1,H$.prototype.overloadedBoolean=!1,
H$.prototype.number=!1,
H$.prototype.commaSeparated=!1,H$.prototype.spaceSeparated=!1,
H$.prototype.commaOrSpaceSeparated=!1,
H$.prototype.mustUseProperty=!1,H$.prototype.defined=!1;let V$=0
;const q$=eP(),W$=eP(),X$=eP(),G$=eP(),Y$=eP(),K$=eP(),J$=eP();function eP(){
return 2**++V$}const tP=Object.freeze(Object.defineProperty({__proto__:null,
boolean:q$,booleanish:W$,commaOrSpaceSeparated:J$,commaSeparated:K$,number:G$,
overloadedBoolean:X$,spaceSeparated:Y$},Symbol.toStringTag,{value:"Module"
})),nP=Object.keys(tP);let rP=class extends H${constructor(e,t,n,r){let o=-1
;if(super(e,t),oP(this,"space",r),"number"==typeof n)for(;++o<nP.length;){
const e=nP[o];oP(this,nP[o],(n&tP[e])===tP[e])}}};function oP(e,t,n){n&&(e[t]=n)
}rP.prototype.defined=!0;const aP={}.hasOwnProperty;function iP(e){
const t={},n={};let r;for(r in e.properties)if(aP.call(e.properties,r)){
const o=e.properties[r],a=new rP(r,e.transform(e.attributes||{},r),o,e.space)
;e.mustUseProperty&&e.mustUseProperty.includes(r)&&(a.mustUseProperty=!0),
t[r]=a,n[Q$(r)]=r,n[Q$(a.attribute)]=r}return new F$(t,n,e.space)}const sP=iP({
space:"xlink",transform:(e,t)=>"xlink:"+t.slice(5).toLowerCase(),properties:{
xLinkActuate:null,xLinkArcRole:null,xLinkHref:null,xLinkRole:null,
xLinkShow:null,xLinkTitle:null,xLinkType:null}}),lP=iP({space:"xml",
transform:(e,t)=>"xml:"+t.slice(3).toLowerCase(),properties:{xmlLang:null,
xmlBase:null,xmlSpace:null}});function cP(e,t){return t in e?e[t]:t}
function uP(e,t){return cP(e,t.toLowerCase())}const dP=iP({space:"xmlns",
attributes:{xmlnsxlink:"xmlns:xlink"},transform:uP,properties:{xmlns:null,
xmlnsXLink:null}}),pP=iP({
transform:(e,t)=>"role"===t?t:"aria-"+t.slice(4).toLowerCase(),properties:{
ariaActiveDescendant:null,ariaAtomic:W$,ariaAutoComplete:null,ariaBusy:W$,
ariaChecked:W$,ariaColCount:G$,ariaColIndex:G$,ariaColSpan:G$,ariaControls:Y$,
ariaCurrent:null,ariaDescribedBy:Y$,ariaDetails:null,ariaDisabled:W$,
ariaDropEffect:Y$,ariaErrorMessage:null,ariaExpanded:W$,ariaFlowTo:Y$,
ariaGrabbed:W$,ariaHasPopup:null,ariaHidden:W$,ariaInvalid:null,
ariaKeyShortcuts:null,ariaLabel:null,ariaLabelledBy:Y$,ariaLevel:G$,
ariaLive:null,ariaModal:W$,ariaMultiLine:W$,ariaMultiSelectable:W$,
ariaOrientation:null,ariaOwns:Y$,ariaPlaceholder:null,ariaPosInSet:G$,
ariaPressed:W$,ariaReadOnly:W$,ariaRelevant:null,ariaRequired:W$,
ariaRoleDescription:Y$,ariaRowCount:G$,ariaRowIndex:G$,ariaRowSpan:G$,
ariaSelected:W$,ariaSetSize:G$,ariaSort:null,ariaValueMax:G$,ariaValueMin:G$,
ariaValueNow:G$,ariaValueText:null,role:null}}),hP=iP({space:"html",attributes:{
acceptcharset:"accept-charset",classname:"class",htmlfor:"for",
httpequiv:"http-equiv"},transform:uP,
mustUseProperty:["checked","multiple","muted","selected"],properties:{abbr:null,
accept:K$,acceptCharset:Y$,accessKey:Y$,action:null,allow:null,
allowFullScreen:q$,allowPaymentRequest:q$,allowUserMedia:q$,alt:null,as:null,
async:q$,autoCapitalize:null,autoComplete:Y$,autoFocus:q$,autoPlay:q$,
blocking:Y$,capture:null,charSet:null,checked:q$,cite:null,className:Y$,cols:G$,
colSpan:null,content:null,contentEditable:W$,controls:q$,controlsList:Y$,
coords:G$|K$,crossOrigin:null,data:null,dateTime:null,decoding:null,default:q$,
defer:q$,dir:null,dirName:null,disabled:q$,download:X$,draggable:W$,
encType:null,enterKeyHint:null,fetchPriority:null,form:null,formAction:null,
formEncType:null,formMethod:null,formNoValidate:q$,formTarget:null,headers:Y$,
height:G$,hidden:q$,high:G$,href:null,hrefLang:null,htmlFor:Y$,httpEquiv:Y$,
id:null,imageSizes:null,imageSrcSet:null,inert:q$,inputMode:null,integrity:null,
is:null,isMap:q$,itemId:null,itemProp:Y$,itemRef:Y$,itemScope:q$,itemType:Y$,
kind:null,label:null,lang:null,language:null,list:null,loading:null,loop:q$,
low:G$,manifest:null,max:null,maxLength:G$,media:null,method:null,min:null,
minLength:G$,multiple:q$,muted:q$,name:null,nonce:null,noModule:q$,
noValidate:q$,onAbort:null,onAfterPrint:null,onAuxClick:null,onBeforeMatch:null,
onBeforePrint:null,onBeforeToggle:null,onBeforeUnload:null,onBlur:null,
onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,
onClose:null,onContextLost:null,onContextMenu:null,onContextRestored:null,
onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,
onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,
onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,
onEmptied:null,onEnded:null,onError:null,onFocus:null,onFormData:null,
onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,
onKeyUp:null,onLanguageChange:null,onLoad:null,onLoadedData:null,
onLoadedMetadata:null,onLoadEnd:null,onLoadStart:null,onMessage:null,
onMessageError:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,
onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onOffline:null,
onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,
onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,
onRejectionHandled:null,onReset:null,onResize:null,onScroll:null,
onScrollEnd:null,onSecurityPolicyViolation:null,onSeeked:null,onSeeking:null,
onSelect:null,onSlotChange:null,onStalled:null,onStorage:null,onSubmit:null,
onSuspend:null,onTimeUpdate:null,onToggle:null,onUnhandledRejection:null,
onUnload:null,onVolumeChange:null,onWaiting:null,onWheel:null,open:q$,
optimum:G$,pattern:null,ping:Y$,placeholder:null,playsInline:q$,popover:null,
popoverTarget:null,popoverTargetAction:null,poster:null,preload:null,
readOnly:q$,referrerPolicy:null,rel:Y$,required:q$,reversed:q$,rows:G$,
rowSpan:G$,sandbox:Y$,scope:null,scoped:q$,seamless:q$,selected:q$,
shadowRootClonable:q$,shadowRootDelegatesFocus:q$,shadowRootMode:null,
shape:null,size:G$,sizes:null,slot:null,span:G$,spellCheck:W$,src:null,
srcDoc:null,srcLang:null,srcSet:null,start:G$,step:null,style:null,tabIndex:G$,
target:null,title:null,translate:null,type:null,typeMustMatch:q$,useMap:null,
value:W$,width:G$,wrap:null,writingSuggestions:null,align:null,aLink:null,
archive:Y$,axis:null,background:null,bgColor:null,border:G$,borderColor:null,
bottomMargin:G$,cellPadding:null,cellSpacing:null,char:null,charOff:null,
classId:null,clear:null,code:null,codeBase:null,codeType:null,color:null,
compact:q$,declare:q$,event:null,face:null,frame:null,frameBorder:null,
hSpace:G$,leftMargin:G$,link:null,longDesc:null,lowSrc:null,marginHeight:G$,
marginWidth:G$,noResize:q$,noHref:q$,noShade:q$,noWrap:q$,object:null,
profile:null,prompt:null,rev:null,rightMargin:G$,rules:null,scheme:null,
scrolling:W$,standby:null,summary:null,text:null,topMargin:G$,valueType:null,
version:null,vAlign:null,vLink:null,vSpace:G$,allowTransparency:null,
autoCorrect:null,autoSave:null,disablePictureInPicture:q$,
disableRemotePlayback:q$,prefix:null,property:null,results:G$,security:null,
unselectable:null}}),fP=iP({space:"svg",attributes:{
accentHeight:"accent-height",alignmentBaseline:"alignment-baseline",
arabicForm:"arabic-form",baselineShift:"baseline-shift",capHeight:"cap-height",
className:"class",clipPath:"clip-path",clipRule:"clip-rule",
colorInterpolation:"color-interpolation",
colorInterpolationFilters:"color-interpolation-filters",
colorProfile:"color-profile",colorRendering:"color-rendering",
crossOrigin:"crossorigin",dataType:"datatype",
dominantBaseline:"dominant-baseline",enableBackground:"enable-background",
fillOpacity:"fill-opacity",fillRule:"fill-rule",floodColor:"flood-color",
floodOpacity:"flood-opacity",fontFamily:"font-family",fontSize:"font-size",
fontSizeAdjust:"font-size-adjust",fontStretch:"font-stretch",
fontStyle:"font-style",fontVariant:"font-variant",fontWeight:"font-weight",
glyphName:"glyph-name",
glyphOrientationHorizontal:"glyph-orientation-horizontal",
glyphOrientationVertical:"glyph-orientation-vertical",hrefLang:"hreflang",
horizAdvX:"horiz-adv-x",horizOriginX:"horiz-origin-x",
horizOriginY:"horiz-origin-y",imageRendering:"image-rendering",
letterSpacing:"letter-spacing",lightingColor:"lighting-color",
markerEnd:"marker-end",markerMid:"marker-mid",markerStart:"marker-start",
navDown:"nav-down",navDownLeft:"nav-down-left",navDownRight:"nav-down-right",
navLeft:"nav-left",navNext:"nav-next",navPrev:"nav-prev",navRight:"nav-right",
navUp:"nav-up",navUpLeft:"nav-up-left",navUpRight:"nav-up-right",
onAbort:"onabort",onActivate:"onactivate",onAfterPrint:"onafterprint",
onBeforePrint:"onbeforeprint",onBegin:"onbegin",onCancel:"oncancel",
onCanPlay:"oncanplay",onCanPlayThrough:"oncanplaythrough",onChange:"onchange",
onClick:"onclick",onClose:"onclose",onCopy:"oncopy",onCueChange:"oncuechange",
onCut:"oncut",onDblClick:"ondblclick",onDrag:"ondrag",onDragEnd:"ondragend",
onDragEnter:"ondragenter",onDragExit:"ondragexit",onDragLeave:"ondragleave",
onDragOver:"ondragover",onDragStart:"ondragstart",onDrop:"ondrop",
onDurationChange:"ondurationchange",onEmptied:"onemptied",onEnd:"onend",
onEnded:"onended",onError:"onerror",onFocus:"onfocus",onFocusIn:"onfocusin",
onFocusOut:"onfocusout",onHashChange:"onhashchange",onInput:"oninput",
onInvalid:"oninvalid",onKeyDown:"onkeydown",onKeyPress:"onkeypress",
onKeyUp:"onkeyup",onLoad:"onload",onLoadedData:"onloadeddata",
onLoadedMetadata:"onloadedmetadata",onLoadStart:"onloadstart",
onMessage:"onmessage",onMouseDown:"onmousedown",onMouseEnter:"onmouseenter",
onMouseLeave:"onmouseleave",onMouseMove:"onmousemove",onMouseOut:"onmouseout",
onMouseOver:"onmouseover",onMouseUp:"onmouseup",onMouseWheel:"onmousewheel",
onOffline:"onoffline",onOnline:"ononline",onPageHide:"onpagehide",
onPageShow:"onpageshow",onPaste:"onpaste",onPause:"onpause",onPlay:"onplay",
onPlaying:"onplaying",onPopState:"onpopstate",onProgress:"onprogress",
onRateChange:"onratechange",onRepeat:"onrepeat",onReset:"onreset",
onResize:"onresize",onScroll:"onscroll",onSeeked:"onseeked",
onSeeking:"onseeking",onSelect:"onselect",onShow:"onshow",onStalled:"onstalled",
onStorage:"onstorage",onSubmit:"onsubmit",onSuspend:"onsuspend",
onTimeUpdate:"ontimeupdate",onToggle:"ontoggle",onUnload:"onunload",
onVolumeChange:"onvolumechange",onWaiting:"onwaiting",onZoom:"onzoom",
overlinePosition:"overline-position",overlineThickness:"overline-thickness",
paintOrder:"paint-order",panose1:"panose-1",pointerEvents:"pointer-events",
referrerPolicy:"referrerpolicy",renderingIntent:"rendering-intent",
shapeRendering:"shape-rendering",stopColor:"stop-color",
stopOpacity:"stop-opacity",strikethroughPosition:"strikethrough-position",
strikethroughThickness:"strikethrough-thickness",
strokeDashArray:"stroke-dasharray",strokeDashOffset:"stroke-dashoffset",
strokeLineCap:"stroke-linecap",strokeLineJoin:"stroke-linejoin",
strokeMiterLimit:"stroke-miterlimit",strokeOpacity:"stroke-opacity",
strokeWidth:"stroke-width",tabIndex:"tabindex",textAnchor:"text-anchor",
textDecoration:"text-decoration",textRendering:"text-rendering",
transformOrigin:"transform-origin",typeOf:"typeof",
underlinePosition:"underline-position",underlineThickness:"underline-thickness",
unicodeBidi:"unicode-bidi",unicodeRange:"unicode-range",
unitsPerEm:"units-per-em",vAlphabetic:"v-alphabetic",vHanging:"v-hanging",
vIdeographic:"v-ideographic",vMathematical:"v-mathematical",
vectorEffect:"vector-effect",vertAdvY:"vert-adv-y",vertOriginX:"vert-origin-x",
vertOriginY:"vert-origin-y",wordSpacing:"word-spacing",
writingMode:"writing-mode",xHeight:"x-height",playbackOrder:"playbackorder",
timelineBegin:"timelinebegin"},transform:cP,properties:{about:J$,
accentHeight:G$,accumulate:null,additive:null,alignmentBaseline:null,
alphabetic:G$,amplitude:G$,arabicForm:null,ascent:G$,attributeName:null,
attributeType:null,azimuth:G$,bandwidth:null,baselineShift:null,
baseFrequency:null,baseProfile:null,bbox:null,begin:null,bias:G$,by:null,
calcMode:null,capHeight:G$,className:Y$,clip:null,clipPath:null,
clipPathUnits:null,clipRule:null,color:null,colorInterpolation:null,
colorInterpolationFilters:null,colorProfile:null,colorRendering:null,
content:null,contentScriptType:null,contentStyleType:null,crossOrigin:null,
cursor:null,cx:null,cy:null,d:null,dataType:null,defaultAction:null,descent:G$,
diffuseConstant:G$,direction:null,display:null,dur:null,divisor:G$,
dominantBaseline:null,download:q$,dx:null,dy:null,edgeMode:null,editable:null,
elevation:G$,enableBackground:null,end:null,event:null,exponent:G$,
externalResourcesRequired:null,fill:null,fillOpacity:G$,fillRule:null,
filter:null,filterRes:null,filterUnits:null,floodColor:null,floodOpacity:null,
focusable:null,focusHighlight:null,fontFamily:null,fontSize:null,
fontSizeAdjust:null,fontStretch:null,fontStyle:null,fontVariant:null,
fontWeight:null,format:null,fr:null,from:null,fx:null,fy:null,g1:K$,g2:K$,
glyphName:K$,glyphOrientationHorizontal:null,glyphOrientationVertical:null,
glyphRef:null,gradientTransform:null,gradientUnits:null,handler:null,hanging:G$,
hatchContentUnits:null,hatchUnits:null,height:null,href:null,hrefLang:null,
horizAdvX:G$,horizOriginX:G$,horizOriginY:G$,id:null,ideographic:G$,
imageRendering:null,initialVisibility:null,in:null,in2:null,intercept:G$,k:G$,
k1:G$,k2:G$,k3:G$,k4:G$,kernelMatrix:J$,kernelUnitLength:null,keyPoints:null,
keySplines:null,keyTimes:null,kerning:null,lang:null,lengthAdjust:null,
letterSpacing:null,lightingColor:null,limitingConeAngle:G$,local:null,
markerEnd:null,markerMid:null,markerStart:null,markerHeight:null,
markerUnits:null,markerWidth:null,mask:null,maskContentUnits:null,
maskUnits:null,mathematical:null,max:null,media:null,
mediaCharacterEncoding:null,mediaContentEncodings:null,mediaSize:G$,
mediaTime:null,method:null,min:null,mode:null,name:null,navDown:null,
navDownLeft:null,navDownRight:null,navLeft:null,navNext:null,navPrev:null,
navRight:null,navUp:null,navUpLeft:null,navUpRight:null,numOctaves:null,
observer:null,offset:null,onAbort:null,onActivate:null,onAfterPrint:null,
onBeforePrint:null,onBegin:null,onCancel:null,onCanPlay:null,
onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onCopy:null,
onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,
onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,
onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnd:null,
onEnded:null,onError:null,onFocus:null,onFocusIn:null,onFocusOut:null,
onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,
onKeyUp:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,
onLoadStart:null,onMessage:null,onMouseDown:null,onMouseEnter:null,
onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,
onMouseUp:null,onMouseWheel:null,onOffline:null,onOnline:null,onPageHide:null,
onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,
onPopState:null,onProgress:null,onRateChange:null,onRepeat:null,onReset:null,
onResize:null,onScroll:null,onSeeked:null,onSeeking:null,onSelect:null,
onShow:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,
onTimeUpdate:null,onToggle:null,onUnload:null,onVolumeChange:null,
onWaiting:null,onZoom:null,opacity:null,operator:null,order:null,orient:null,
orientation:null,origin:null,overflow:null,overlay:null,overlinePosition:G$,
overlineThickness:G$,paintOrder:null,panose1:null,path:null,pathLength:G$,
patternContentUnits:null,patternTransform:null,patternUnits:null,phase:null,
ping:Y$,pitch:null,playbackOrder:null,pointerEvents:null,points:null,
pointsAtX:G$,pointsAtY:G$,pointsAtZ:G$,preserveAlpha:null,
preserveAspectRatio:null,primitiveUnits:null,propagate:null,property:J$,r:null,
radius:null,referrerPolicy:null,refX:null,refY:null,rel:J$,rev:J$,
renderingIntent:null,repeatCount:null,repeatDur:null,requiredExtensions:J$,
requiredFeatures:J$,requiredFonts:J$,requiredFormats:J$,resource:null,
restart:null,result:null,rotate:null,rx:null,ry:null,scale:null,seed:null,
shapeRendering:null,side:null,slope:null,snapshotTime:null,specularConstant:G$,
specularExponent:G$,spreadMethod:null,spacing:null,startOffset:null,
stdDeviation:null,stemh:null,stemv:null,stitchTiles:null,stopColor:null,
stopOpacity:null,strikethroughPosition:G$,strikethroughThickness:G$,string:null,
stroke:null,strokeDashArray:J$,strokeDashOffset:null,strokeLineCap:null,
strokeLineJoin:null,strokeMiterLimit:G$,strokeOpacity:G$,strokeWidth:null,
style:null,surfaceScale:G$,syncBehavior:null,syncBehaviorDefault:null,
syncMaster:null,syncTolerance:null,syncToleranceDefault:null,systemLanguage:J$,
tabIndex:G$,tableValues:null,target:null,targetX:G$,targetY:G$,textAnchor:null,
textDecoration:null,textRendering:null,textLength:null,timelineBegin:null,
title:null,transformBehavior:null,type:null,typeOf:J$,to:null,transform:null,
transformOrigin:null,u1:null,u2:null,underlinePosition:G$,underlineThickness:G$,
unicode:null,unicodeBidi:null,unicodeRange:null,unitsPerEm:G$,values:null,
vAlphabetic:G$,vMathematical:G$,vectorEffect:null,vHanging:G$,vIdeographic:G$,
version:null,vertAdvY:G$,vertOriginX:G$,vertOriginY:G$,viewBox:null,
viewTarget:null,visibility:null,width:null,widths:null,wordSpacing:null,
writingMode:null,x:null,x1:null,x2:null,xChannelSelector:null,xHeight:G$,y:null,
y1:null,y2:null,yChannelSelector:null,z:null,zoomAndPan:null}
}),mP=/^data[-\w.:]+$/i,gP=/-[a-z]/g,vP=/[A-Z]/g;function bP(e,t){const n=Q$(t)
;let r=t,o=H$;if(n in e.normal)return e.property[e.normal[n]]
;if(n.length>4&&"data"===n.slice(0,4)&&mP.test(t)){if("-"===t.charAt(4)){
const e=t.slice(5).replace(gP,OP);r="data"+e.charAt(0).toUpperCase()+e.slice(1)
}else{const e=t.slice(4);if(!gP.test(e)){let n=e.replace(vP,yP)
;"-"!==n.charAt(0)&&(n="-"+n),t="data"+n}}o=rP}return new o(r,t)}function yP(e){
return"-"+e.toLowerCase()}function OP(e){return e.charAt(1).toUpperCase()}
const wP=Z$([lP,sP,dP,pP,hP],"html"),xP=Z$([lP,sP,dP,pP,fP],"svg")
;function kP(e){const t=[],n=String(e||"");let r=n.indexOf(","),o=0,a=!1
;for(;!a;){-1===r&&(r=n.length,a=!0);const e=n.slice(o,r).trim()
;!e&&a||t.push(e),o=r+1,r=n.indexOf(",",o)}return t}function SP(e,t){
const n=t||{}
;return(""===e[e.length-1]?[...e,""]:e).join((n.padRight?" ":"")+","+(!1===n.padLeft?"":" ")).trim()
}const _P=/[#.]/g;function TP(e){const t=String(e||"").trim()
;return t?t.split(/[ \t\n\r\f]+/g):[]}function EP(e){return e.join(" ").trim()}
const AP=new Set(["button","menu","reset","submit"]),CP={}.hasOwnProperty
;function $P(e,t,n){const r=n&&function(e){const t={};let n=-1
;for(;++n<e.length;)t[e[n].toLowerCase()]=e[n];return t}(n)
;return function(n,o,...a){let i,s=-1;if(null==n){i={type:"root",children:[]}
;const e=o;a.unshift(e)}else if(i=function(e,t){const n=e||"",r={};let o,a,i=0
;for(;i<n.length;){_P.lastIndex=i
;const e=_P.exec(n),t=n.slice(i,e?e.index:n.length)
;t&&(o?"#"===o?r.id=t:Array.isArray(r.className)?r.className.push(t):r.className=[t]:a=t,
i+=t.length),e&&(o=e[0],i++)}return{type:"element",tagName:a||t||"div",
properties:r,children:[]}
}(n,t),i.tagName=i.tagName.toLowerCase(),r&&CP.call(r,i.tagName)&&(i.tagName=r[i.tagName]),
function(e,t){if(null==e||"object"!=typeof e||Array.isArray(e))return!1
;if("input"===t||!e.type||"string"!=typeof e.type)return!0
;if("children"in e&&Array.isArray(e.children))return!1
;if("button"===t)return AP.has(e.type.toLowerCase());return!("value"in e)
}(o,i.tagName)){let t;for(t in o)CP.call(o,t)&&PP(e,i.properties,t,o[t])
}else a.unshift(o);for(;++s<a.length;)DP(i.children,a[s])
;return"element"===i.type&&"template"===i.tagName&&(i.content={type:"root",
children:i.children},i.children=[]),i}}function PP(e,t,n,r){const o=bP(e,n)
;let a,i=-1;if(null!=r){if("number"==typeof r){if(Number.isNaN(r))return;a=r
}else a="boolean"==typeof r?r:"string"==typeof r?o.spaceSeparated?TP(r):o.commaSeparated?kP(r):o.commaOrSpaceSeparated?TP(kP(r).join(" ")):IP(o,o.property,r):Array.isArray(r)?r.concat():"style"===o.property?function(e){
const t=[];let n;for(n in e)CP.call(e,n)&&t.push([n,e[n]].join(": "))
;return t.join("; ")}(r):String(r);if(Array.isArray(a)){const e=[]
;for(;++i<a.length;){const t=IP(o,o.property,a[i]);e[i]=t}a=e}
if("className"===o.property&&Array.isArray(t.className)){const e=a
;a=t.className.concat(e)}t[o.property]=a}}function DP(e,t){let n=-1
;if(null==t);else if("string"==typeof t||"number"==typeof t)e.push({type:"text",
value:String(t)});else if(Array.isArray(t))for(;++n<t.length;)DP(e,t[n]);else{
if("object"!=typeof t||!("type"in t))throw new Error("Expected node, nodes, or string, got `"+t+"`")
;"root"===t.type?DP(e,t.children):e.push(t)}}function IP(e,t,n){
if("string"==typeof n){if(e.number&&n&&!Number.isNaN(Number(n)))return Number(n)
;if((e.boolean||e.overloadedBoolean)&&(""===n||Q$(n)===Q$(t)))return!0}return n}
const MP=$P(wP,"div"),NP=$P(xP,"g",["altGlyph","altGlyphDef","altGlyphItem","animateColor","animateMotion","animateTransform","clipPath","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feDistantLight","feDropShadow","feFlood","feFuncA","feFuncB","feFuncG","feFuncR","feGaussianBlur","feImage","feMerge","feMergeNode","feMorphology","feOffset","fePointLight","feSpecularLighting","feSpotLight","feTile","feTurbulence","foreignObject","glyphRef","linearGradient","radialGradient","solidColor","textArea","textPath"]),RP=/\r?\n|\r/g
;const LP={html:"http://www.w3.org/1999/xhtml",
mathml:"http://www.w3.org/1998/Math/MathML",svg:"http://www.w3.org/2000/svg",
xlink:"http://www.w3.org/1999/xlink",xml:"http://www.w3.org/XML/1998/namespace",
xmlns:"http://www.w3.org/2000/xmlns/"},BP={}.hasOwnProperty,jP=Object.prototype
;function UP(e,t){const n=t||{};return zP({file:n.file||void 0,location:!1,
schema:"svg"===n.space?xP:wP,verbose:n.verbose||!1},e)}function zP(e,t){let n
;switch(t.nodeName){case"#comment":{const r=t;return n={type:"comment",
value:r.data},ZP(e,r,n),n}case"#document":case"#document-fragment":{
const r=t,o="mode"in r&&("quirks"===r.mode||"limited-quirks"===r.mode);if(n={
type:"root",children:FP(e,t.childNodes),data:{quirksMode:o}
},e.file&&e.location){const t=String(e.file),r=function(e){
const t=String(e),n=[];for(RP.lastIndex=0;RP.test(t);)n.push(RP.lastIndex)
;return n.push(t.length+1),{toPoint:function(e){let t=-1
;if("number"==typeof e&&e>-1&&e<n[n.length-1])for(;++t<n.length;)if(n[t]>e)return{
line:t+1,column:e-(t>0?n[t-1]:0)+1,offset:e}},toOffset:function(e){
const t=e&&e.line,r=e&&e.column
;if("number"==typeof t&&"number"==typeof r&&!Number.isNaN(t)&&!Number.isNaN(r)&&t-1 in n){
const e=(n[t-2]||0)+r-1||0;if(e>-1&&e<n[n.length-1])return e}}}
}(t),o=r.toPoint(0),a=r.toPoint(t.length);n.position={start:o,end:a}}return n}
case"#documentType":return n={type:"doctype"},ZP(e,t,n),n;case"#text":{const r=t
;return n={type:"text",value:r.value},ZP(e,r,n),n}default:
return n=function(e,t){const n=e.schema;e.schema=t.namespaceURI===LP.svg?xP:wP
;let r=-1;const o={};for(;++r<t.attrs.length;){
const e=t.attrs[r],n=(e.prefix?e.prefix+":":"")+e.name
;BP.call(jP,n)||(o[n]=e.value)}
const a="svg"===e.schema.space?NP:MP,i=a(t.tagName,o,FP(e,t.childNodes))
;if(ZP(e,t,i),"template"===i.tagName){
const n=t,r=n.sourceCodeLocation,o=r&&r.startTag&&QP(r.startTag),a=r&&r.endTag&&QP(r.endTag),s=zP(e,n.content)
;o&&a&&e.file&&(s.position={start:o.end,end:a.start}),i.content=s}
return e.schema=n,i}(e,t),n}}function FP(e,t){let n=-1;const r=[]
;for(;++n<t.length;){const o=zP(e,t[n]);r.push(o)}return r}function ZP(e,t,n){
if("sourceCodeLocation"in t&&t.sourceCodeLocation&&e.file){
const r=function(e,t,n){const r=QP(n);if("element"===t.type){
const o=t.children[t.children.length-1]
;if(r&&!n.endTag&&o&&o.position&&o.position.end&&(r.end=Object.assign({},o.position.end)),
e.verbose){const r={};let o
;if(n.attrs)for(o in n.attrs)BP.call(n.attrs,o)&&(r[bP(e.schema,o).property]=QP(n.attrs[o]))
;n.startTag;const a=QP(n.startTag),i=n.endTag?QP(n.endTag):void 0,s={opening:a}
;i&&(s.closing=i),s.properties=r,t.data={position:s}}}return r
}(e,n,t.sourceCodeLocation);r&&(e.location=!0,n.position=r)}}function QP(e){
const t=HP({line:e.startLine,column:e.startCol,offset:e.startOffset}),n=HP({
line:e.endLine,column:e.endCol,offset:e.endOffset});return t||n?{start:t,end:n
}:void 0}function HP(e){return e.line&&e.column?e:void 0}
const VP=new Set([65534,65535,131070,131071,196606,196607,262142,262143,327678,327679,393214,393215,458750,458751,524286,524287,589822,589823,655358,655359,720894,720895,786430,786431,851966,851967,917502,917503,983038,983039,1048574,1048575,1114110,1114111]),qP="�"
;var WP,XP
;(XP=WP||(WP={}))[XP.EOF=-1]="EOF",XP[XP.NULL=0]="NULL",XP[XP.TABULATION=9]="TABULATION",
XP[XP.CARRIAGE_RETURN=13]="CARRIAGE_RETURN",
XP[XP.LINE_FEED=10]="LINE_FEED",XP[XP.FORM_FEED=12]="FORM_FEED",
XP[XP.SPACE=32]="SPACE",
XP[XP.EXCLAMATION_MARK=33]="EXCLAMATION_MARK",XP[XP.QUOTATION_MARK=34]="QUOTATION_MARK",
XP[XP.AMPERSAND=38]="AMPERSAND",
XP[XP.APOSTROPHE=39]="APOSTROPHE",XP[XP.HYPHEN_MINUS=45]="HYPHEN_MINUS",
XP[XP.SOLIDUS=47]="SOLIDUS",
XP[XP.DIGIT_0=48]="DIGIT_0",XP[XP.DIGIT_9=57]="DIGIT_9",
XP[XP.SEMICOLON=59]="SEMICOLON",
XP[XP.LESS_THAN_SIGN=60]="LESS_THAN_SIGN",XP[XP.EQUALS_SIGN=61]="EQUALS_SIGN",
XP[XP.GREATER_THAN_SIGN=62]="GREATER_THAN_SIGN",
XP[XP.QUESTION_MARK=63]="QUESTION_MARK",
XP[XP.LATIN_CAPITAL_A=65]="LATIN_CAPITAL_A",
XP[XP.LATIN_CAPITAL_Z=90]="LATIN_CAPITAL_Z",
XP[XP.RIGHT_SQUARE_BRACKET=93]="RIGHT_SQUARE_BRACKET",
XP[XP.GRAVE_ACCENT=96]="GRAVE_ACCENT",
XP[XP.LATIN_SMALL_A=97]="LATIN_SMALL_A",XP[XP.LATIN_SMALL_Z=122]="LATIN_SMALL_Z"
;const GP="--",YP="[CDATA[",KP="doctype",JP="script",eD="public",tD="system"
;function nD(e){return e>=55296&&e<=57343}function rD(e){
return 32!==e&&10!==e&&13!==e&&9!==e&&12!==e&&e>=1&&e<=31||e>=127&&e<=159}
function oD(e){return e>=64976&&e<=65007||VP.has(e)}var aD,iD
;(iD=aD||(aD={})).controlCharacterInInputStream="control-character-in-input-stream",
iD.noncharacterInInputStream="noncharacter-in-input-stream",
iD.surrogateInInputStream="surrogate-in-input-stream",
iD.nonVoidHtmlElementStartTagWithTrailingSolidus="non-void-html-element-start-tag-with-trailing-solidus",
iD.endTagWithAttributes="end-tag-with-attributes",
iD.endTagWithTrailingSolidus="end-tag-with-trailing-solidus",
iD.unexpectedSolidusInTag="unexpected-solidus-in-tag",
iD.unexpectedNullCharacter="unexpected-null-character",
iD.unexpectedQuestionMarkInsteadOfTagName="unexpected-question-mark-instead-of-tag-name",
iD.invalidFirstCharacterOfTagName="invalid-first-character-of-tag-name",
iD.unexpectedEqualsSignBeforeAttributeName="unexpected-equals-sign-before-attribute-name",
iD.missingEndTagName="missing-end-tag-name",
iD.unexpectedCharacterInAttributeName="unexpected-character-in-attribute-name",
iD.unknownNamedCharacterReference="unknown-named-character-reference",
iD.missingSemicolonAfterCharacterReference="missing-semicolon-after-character-reference",
iD.unexpectedCharacterAfterDoctypeSystemIdentifier="unexpected-character-after-doctype-system-identifier",
iD.unexpectedCharacterInUnquotedAttributeValue="unexpected-character-in-unquoted-attribute-value",
iD.eofBeforeTagName="eof-before-tag-name",
iD.eofInTag="eof-in-tag",iD.missingAttributeValue="missing-attribute-value",
iD.missingWhitespaceBetweenAttributes="missing-whitespace-between-attributes",
iD.missingWhitespaceAfterDoctypePublicKeyword="missing-whitespace-after-doctype-public-keyword",
iD.missingWhitespaceBetweenDoctypePublicAndSystemIdentifiers="missing-whitespace-between-doctype-public-and-system-identifiers",
iD.missingWhitespaceAfterDoctypeSystemKeyword="missing-whitespace-after-doctype-system-keyword",
iD.missingQuoteBeforeDoctypePublicIdentifier="missing-quote-before-doctype-public-identifier",
iD.missingQuoteBeforeDoctypeSystemIdentifier="missing-quote-before-doctype-system-identifier",
iD.missingDoctypePublicIdentifier="missing-doctype-public-identifier",
iD.missingDoctypeSystemIdentifier="missing-doctype-system-identifier",
iD.abruptDoctypePublicIdentifier="abrupt-doctype-public-identifier",
iD.abruptDoctypeSystemIdentifier="abrupt-doctype-system-identifier",
iD.cdataInHtmlContent="cdata-in-html-content",
iD.incorrectlyOpenedComment="incorrectly-opened-comment",
iD.eofInScriptHtmlCommentLikeText="eof-in-script-html-comment-like-text",
iD.eofInDoctype="eof-in-doctype",
iD.nestedComment="nested-comment",iD.abruptClosingOfEmptyComment="abrupt-closing-of-empty-comment",
iD.eofInComment="eof-in-comment",
iD.incorrectlyClosedComment="incorrectly-closed-comment",
iD.eofInCdata="eof-in-cdata",
iD.absenceOfDigitsInNumericCharacterReference="absence-of-digits-in-numeric-character-reference",
iD.nullCharacterReference="null-character-reference",
iD.surrogateCharacterReference="surrogate-character-reference",
iD.characterReferenceOutsideUnicodeRange="character-reference-outside-unicode-range",
iD.controlCharacterReference="control-character-reference",
iD.noncharacterCharacterReference="noncharacter-character-reference",
iD.missingWhitespaceBeforeDoctypeName="missing-whitespace-before-doctype-name",
iD.missingDoctypeName="missing-doctype-name",
iD.invalidCharacterSequenceAfterDoctypeName="invalid-character-sequence-after-doctype-name",
iD.duplicateAttribute="duplicate-attribute",
iD.nonConformingDoctype="non-conforming-doctype",
iD.missingDoctype="missing-doctype",
iD.misplacedDoctype="misplaced-doctype",iD.endTagWithoutMatchingOpenElement="end-tag-without-matching-open-element",
iD.closingOfElementWithOpenChildElements="closing-of-element-with-open-child-elements",
iD.disallowedContentInNoscriptInHead="disallowed-content-in-noscript-in-head",
iD.openElementsLeftAfterEof="open-elements-left-after-eof",
iD.abandonedHeadElementChild="abandoned-head-element-child",
iD.misplacedStartTagForHeadElement="misplaced-start-tag-for-head-element",
iD.nestedNoscriptInHead="nested-noscript-in-head",
iD.eofInElementThatCanContainOnlyText="eof-in-element-that-can-contain-only-text"
;class sD{constructor(e){
this.handler=e,this.html="",this.pos=-1,this.lastGapPos=-2,
this.gapStack=[],this.skipNextNewLine=!1,
this.lastChunkWritten=!1,this.endOfChunkHit=!1,
this.bufferWaterline=65536,this.isEol=!1,
this.lineStartPos=0,this.droppedBufferSize=0,this.line=1,this.lastErrOffset=-1}
get col(){return this.pos-this.lineStartPos+Number(this.lastGapPos!==this.pos)}
get offset(){return this.droppedBufferSize+this.pos}getError(e,t){
const{line:n,col:r,offset:o}=this,a=r+t,i=o+t;return{code:e,startLine:n,
endLine:n,startCol:a,endCol:a,startOffset:i,endOffset:i}}_err(e){
this.handler.onParseError&&this.lastErrOffset!==this.offset&&(this.lastErrOffset=this.offset,
this.handler.onParseError(this.getError(e,0)))}_addGap(){
this.gapStack.push(this.lastGapPos),this.lastGapPos=this.pos}
_processSurrogate(e){if(this.pos!==this.html.length-1){
const t=this.html.charCodeAt(this.pos+1);if(function(e){
return e>=56320&&e<=57343
}(t))return this.pos++,this._addGap(),1024*(e-55296)+9216+t
}else if(!this.lastChunkWritten)return this.endOfChunkHit=!0,WP.EOF
;return this._err(aD.surrogateInInputStream),e}willDropParsedChunk(){
return this.pos>this.bufferWaterline}dropParsedChunk(){
this.willDropParsedChunk()&&(this.html=this.html.substring(this.pos),
this.lineStartPos-=this.pos,
this.droppedBufferSize+=this.pos,this.pos=0,this.lastGapPos=-2,
this.gapStack.length=0)}write(e,t){
this.html.length>0?this.html+=e:this.html=e,this.endOfChunkHit=!1,
this.lastChunkWritten=t}insertHtmlAtCurrentPos(e){
this.html=this.html.substring(0,this.pos+1)+e+this.html.substring(this.pos+1),
this.endOfChunkHit=!1}startsWith(e,t){
if(this.pos+e.length>this.html.length)return this.endOfChunkHit=!this.lastChunkWritten,
!1;if(t)return this.html.startsWith(e,this.pos);for(let n=0;n<e.length;n++){
if((32|this.html.charCodeAt(this.pos+n))!==e.charCodeAt(n))return!1}return!0}
peek(e){const t=this.pos+e
;if(t>=this.html.length)return this.endOfChunkHit=!this.lastChunkWritten,WP.EOF
;const n=this.html.charCodeAt(t);return n===WP.CARRIAGE_RETURN?WP.LINE_FEED:n}
advance(){
if(this.pos++,this.isEol&&(this.isEol=!1,this.line++,this.lineStartPos=this.pos),
this.pos>=this.html.length)return this.endOfChunkHit=!this.lastChunkWritten,
WP.EOF;let e=this.html.charCodeAt(this.pos)
;if(e===WP.CARRIAGE_RETURN)return this.isEol=!0,
this.skipNextNewLine=!0,WP.LINE_FEED
;if(e===WP.LINE_FEED&&(this.isEol=!0,this.skipNextNewLine))return this.line--,
this.skipNextNewLine=!1,this._addGap(),this.advance()
;this.skipNextNewLine=!1,nD(e)&&(e=this._processSurrogate(e))
;return null===this.handler.onParseError||e>31&&e<127||e===WP.LINE_FEED||e===WP.CARRIAGE_RETURN||e>159&&e<64976||this._checkForProblematicCharacters(e),
e}_checkForProblematicCharacters(e){
rD(e)?this._err(aD.controlCharacterInInputStream):oD(e)&&this._err(aD.noncharacterInInputStream)
}retreat(e){
for(this.pos-=e;this.pos<this.lastGapPos;)this.lastGapPos=this.gapStack.pop(),
this.pos--;this.isEol=!1}}var lD,cD;function uD(e,t){
for(let n=e.attrs.length-1;n>=0;n--)if(e.attrs[n].name===t)return e.attrs[n].value
;return null}
(cD=lD||(lD={}))[cD.CHARACTER=0]="CHARACTER",cD[cD.NULL_CHARACTER=1]="NULL_CHARACTER",
cD[cD.WHITESPACE_CHARACTER=2]="WHITESPACE_CHARACTER",
cD[cD.START_TAG=3]="START_TAG",
cD[cD.END_TAG=4]="END_TAG",cD[cD.COMMENT=5]="COMMENT",
cD[cD.DOCTYPE=6]="DOCTYPE",cD[cD.EOF=7]="EOF",cD[cD.HIBERNATION=8]="HIBERNATION"
;const dD=new Uint16Array('ᵁ<Õıʊҝջאٵ۞ޢߖࠏ੊ઑඡ๭༉༦჊ረዡᐕᒝᓃᓟᔥ\0\0\0\0\0\0ᕫᛍᦍᰒᷝ὾⁠↰⊍⏀⏻⑂⠤⤒ⴈ⹈⿎〖㊺㘹㞬㣾㨨㩱㫠㬮ࠀEMabcfglmnoprstu\\bfms¦³¹ÈÏlig耻Æ䃆P耻&䀦cute耻Á䃁reve;䄂Āiyx}rc耻Â䃂;䐐r;쀀𝔄rave耻À䃀pha;䎑acr;䄀d;橓Āgp¡on;䄄f;쀀𝔸plyFunction;恡ing耻Å䃅Ācs¾Ãr;쀀𝒜ign;扔ilde耻Ã䃃ml耻Ä䃄ЀaceforsuåûþėĜĢħĪĀcrêòkslash;或Ŷöø;櫧ed;挆y;䐑ƀcrtąċĔause;戵noullis;愬a;䎒r;쀀𝔅pf;쀀𝔹eve;䋘còēmpeq;扎܀HOacdefhilorsuōőŖƀƞƢƵƷƺǜȕɳɸɾcy;䐧PY耻©䂩ƀcpyŝŢźute;䄆Ā;iŧŨ拒talDifferentialD;慅leys;愭ȀaeioƉƎƔƘron;䄌dil耻Ç䃇rc;䄈nint;戰ot;䄊ĀdnƧƭilla;䂸terDot;䂷òſi;䎧rcleȀDMPTǇǋǑǖot;抙inus;抖lus;投imes;抗oĀcsǢǸkwiseContourIntegral;戲eCurlyĀDQȃȏoubleQuote;思uote;怙ȀlnpuȞȨɇɕonĀ;eȥȦ户;橴ƀgitȯȶȺruent;扡nt;戯ourIntegral;戮ĀfrɌɎ;愂oduct;成nterClockwiseContourIntegral;戳oss;樯cr;쀀𝒞pĀ;Cʄʅ拓ap;才րDJSZacefiosʠʬʰʴʸˋ˗ˡ˦̳ҍĀ;oŹʥtrahd;椑cy;䐂cy;䐅cy;䐏ƀgrsʿ˄ˇger;怡r;憡hv;櫤Āayː˕ron;䄎;䐔lĀ;t˝˞戇a;䎔r;쀀𝔇Āaf˫̧Ācm˰̢riticalȀADGT̖̜̀̆cute;䂴oŴ̋̍;䋙bleAcute;䋝rave;䁠ilde;䋜ond;拄ferentialD;慆Ѱ̽\0\0\0͔͂\0Ѕf;쀀𝔻ƀ;DE͈͉͍䂨ot;惜qual;扐blèCDLRUVͣͲ΂ϏϢϸontourIntegraìȹoɴ͹\0\0ͻ»͉nArrow;懓Āeo·ΤftƀARTΐΖΡrrow;懐ightArrow;懔eåˊngĀLRΫτeftĀARγιrrow;柸ightArrow;柺ightArrow;柹ightĀATϘϞrrow;懒ee;抨pɁϩ\0\0ϯrrow;懑ownArrow;懕erticalBar;戥ǹABLRTaВЪаўѿͼrrowƀ;BUНОТ憓ar;椓pArrow;懵reve;䌑eft˒к\0ц\0ѐightVector;楐eeVector;楞ectorĀ;Bљњ憽ar;楖ightǔѧ\0ѱeeVector;楟ectorĀ;BѺѻ懁ar;楗eeĀ;A҆҇护rrow;憧ĀctҒҗr;쀀𝒟rok;䄐ࠀNTacdfglmopqstuxҽӀӄӋӞӢӧӮӵԡԯԶՒ՝ՠեG;䅊H耻Ð䃐cute耻É䃉ƀaiyӒӗӜron;䄚rc耻Ê䃊;䐭ot;䄖r;쀀𝔈rave耻È䃈ement;戈ĀapӺӾcr;䄒tyɓԆ\0\0ԒmallSquare;旻erySmallSquare;斫ĀgpԦԪon;䄘f;쀀𝔼silon;䎕uĀaiԼՉlĀ;TՂՃ橵ilde;扂librium;懌Āci՗՚r;愰m;橳a;䎗ml耻Ë䃋Āipժկsts;戃onentialE;慇ʀcfiosօֈ֍ֲ׌y;䐤r;쀀𝔉lledɓ֗\0\0֣mallSquare;旼erySmallSquare;斪Ͱֺ\0ֿ\0\0ׄf;쀀𝔽All;戀riertrf;愱cò׋؀JTabcdfgorstר׬ׯ׺؀ؒؖ؛؝أ٬ٲcy;䐃耻>䀾mmaĀ;d׷׸䎓;䏜reve;䄞ƀeiy؇،ؐdil;䄢rc;䄜;䐓ot;䄠r;쀀𝔊;拙pf;쀀𝔾eater̀EFGLSTصلَٖٛ٦qualĀ;Lؾؿ扥ess;招ullEqual;执reater;檢ess;扷lantEqual;橾ilde;扳cr;쀀𝒢;扫ЀAacfiosuڅڋږڛڞڪھۊRDcy;䐪Āctڐڔek;䋇;䁞irc;䄤r;愌lbertSpace;愋ǰگ\0ڲf;愍izontalLine;攀Āctۃۅòکrok;䄦mpńېۘownHumðįqual;扏܀EJOacdfgmnostuۺ۾܃܇܎ܚܞܡܨ݄ݸދޏޕcy;䐕lig;䄲cy;䐁cute耻Í䃍Āiyܓܘrc耻Î䃎;䐘ot;䄰r;愑rave耻Ì䃌ƀ;apܠܯܿĀcgܴܷr;䄪inaryI;慈lieóϝǴ݉\0ݢĀ;eݍݎ戬Āgrݓݘral;戫section;拂isibleĀCTݬݲomma;恣imes;恢ƀgptݿރވon;䄮f;쀀𝕀a;䎙cr;愐ilde;䄨ǫޚ\0ޞcy;䐆l耻Ï䃏ʀcfosuެ޷޼߂ߐĀiyޱ޵rc;䄴;䐙r;쀀𝔍pf;쀀𝕁ǣ߇\0ߌr;쀀𝒥rcy;䐈kcy;䐄΀HJacfosߤߨ߽߬߱ࠂࠈcy;䐥cy;䐌ppa;䎚Āey߶߻dil;䄶;䐚r;쀀𝔎pf;쀀𝕂cr;쀀𝒦րJTaceflmostࠥࠩࠬࡐࡣ঳সে্਷ੇcy;䐉耻<䀼ʀcmnpr࠷࠼ࡁࡄࡍute;䄹bda;䎛g;柪lacetrf;愒r;憞ƀaeyࡗ࡜ࡡron;䄽dil;䄻;䐛Āfsࡨ॰tԀACDFRTUVarࡾࢩࢱࣦ࣠ࣼयज़ΐ४Ānrࢃ࢏gleBracket;柨rowƀ;BR࢙࢚࢞憐ar;懤ightArrow;懆eiling;挈oǵࢷ\0ࣃbleBracket;柦nǔࣈ\0࣒eeVector;楡ectorĀ;Bࣛࣜ懃ar;楙loor;挊ightĀAV࣯ࣵrrow;憔ector;楎Āerँगeƀ;AVउऊऐ抣rrow;憤ector;楚iangleƀ;BEतथऩ抲ar;槏qual;抴pƀDTVषूौownVector;楑eeVector;楠ectorĀ;Bॖॗ憿ar;楘ectorĀ;B॥०憼ar;楒ightáΜs̀EFGLSTॾঋকঝঢভqualGreater;拚ullEqual;扦reater;扶ess;檡lantEqual;橽ilde;扲r;쀀𝔏Ā;eঽা拘ftarrow;懚idot;䄿ƀnpw৔ਖਛgȀLRlr৞৷ਂਐeftĀAR০৬rrow;柵ightArrow;柷ightArrow;柶eftĀarγਊightáοightáϊf;쀀𝕃erĀLRਢਬeftArrow;憙ightArrow;憘ƀchtਾੀੂòࡌ;憰rok;䅁;扪Ѐacefiosuਗ਼੝੠੷੼અઋ઎p;椅y;䐜Ādl੥੯iumSpace;恟lintrf;愳r;쀀𝔐nusPlus;戓pf;쀀𝕄cò੶;䎜ҀJacefostuણધભીଔଙඑ඗ඞcy;䐊cute;䅃ƀaey઴હાron;䅇dil;䅅;䐝ƀgswે૰଎ativeƀMTV૓૟૨ediumSpace;怋hiĀcn૦૘ë૙eryThiî૙tedĀGL૸ଆreaterGreateòٳessLesóੈLine;䀊r;쀀𝔑ȀBnptଢନଷ଺reak;恠BreakingSpace;䂠f;愕ڀ;CDEGHLNPRSTV୕ୖ୪୼஡௫ఄ౞಄ದ೘ൡඅ櫬Āou୛୤ngruent;扢pCap;扭oubleVerticalBar;戦ƀlqxஃஊ஛ement;戉ualĀ;Tஒஓ扠ilde;쀀≂̸ists;戄reater΀;EFGLSTஶஷ஽௉௓௘௥扯qual;扱ullEqual;쀀≧̸reater;쀀≫̸ess;批lantEqual;쀀⩾̸ilde;扵umpń௲௽ownHump;쀀≎̸qual;쀀≏̸eĀfsఊధtTriangleƀ;BEచఛడ拪ar;쀀⧏̸qual;括s̀;EGLSTవశ఼ౄోౘ扮qual;扰reater;扸ess;쀀≪̸lantEqual;쀀⩽̸ilde;扴estedĀGL౨౹reaterGreater;쀀⪢̸essLess;쀀⪡̸recedesƀ;ESಒಓಛ技qual;쀀⪯̸lantEqual;拠ĀeiಫಹverseElement;戌ghtTriangleƀ;BEೋೌ೒拫ar;쀀⧐̸qual;拭ĀquೝഌuareSuĀbp೨೹setĀ;E೰ೳ쀀⊏̸qual;拢ersetĀ;Eഃആ쀀⊐̸qual;拣ƀbcpഓതൎsetĀ;Eഛഞ쀀⊂⃒qual;抈ceedsȀ;ESTലള഻െ抁qual;쀀⪰̸lantEqual;拡ilde;쀀≿̸ersetĀ;E൘൛쀀⊃⃒qual;抉ildeȀ;EFT൮൯൵ൿ扁qual;扄ullEqual;扇ilde;扉erticalBar;戤cr;쀀𝒩ilde耻Ñ䃑;䎝܀Eacdfgmoprstuvලෂ෉෕ෛ෠෧෼ขภยา฿ไlig;䅒cute耻Ó䃓Āiy෎ීrc耻Ô䃔;䐞blac;䅐r;쀀𝔒rave耻Ò䃒ƀaei෮ෲ෶cr;䅌ga;䎩cron;䎟pf;쀀𝕆enCurlyĀDQฎบoubleQuote;怜uote;怘;橔Āclวฬr;쀀𝒪ash耻Ø䃘iŬื฼de耻Õ䃕es;樷ml耻Ö䃖erĀBP๋๠Āar๐๓r;怾acĀek๚๜;揞et;掴arenthesis;揜Ҁacfhilors๿ງຊຏຒດຝະ໼rtialD;戂y;䐟r;쀀𝔓i;䎦;䎠usMinus;䂱Āipຢອncareplanåڝf;愙Ȁ;eio຺ູ໠໤檻cedesȀ;EST່້໏໚扺qual;檯lantEqual;扼ilde;找me;怳Ādp໩໮uct;戏ortionĀ;aȥ໹l;戝Āci༁༆r;쀀𝒫;䎨ȀUfos༑༖༛༟OT耻"䀢r;쀀𝔔pf;愚cr;쀀𝒬؀BEacefhiorsu༾གྷཇའཱིྦྷྪྭ႖ႩႴႾarr;椐G耻®䂮ƀcnrཎནབute;䅔g;柫rĀ;tཛྷཝ憠l;椖ƀaeyཧཬཱron;䅘dil;䅖;䐠Ā;vླྀཹ愜erseĀEUྂྙĀlq྇ྎement;戋uilibrium;懋pEquilibrium;楯r»ཹo;䎡ghtЀACDFTUVa࿁࿫࿳ဢဨၛႇϘĀnr࿆࿒gleBracket;柩rowƀ;BL࿜࿝࿡憒ar;懥eftArrow;懄eiling;按oǵ࿹\0စbleBracket;柧nǔည\0နeeVector;楝ectorĀ;Bဝသ懂ar;楕loor;挋Āerိ၃eƀ;AVဵံြ抢rrow;憦ector;楛iangleƀ;BEၐၑၕ抳ar;槐qual;抵pƀDTVၣၮၸownVector;楏eeVector;楜ectorĀ;Bႂႃ憾ar;楔ectorĀ;B႑႒懀ar;楓Āpuႛ႞f;愝ndImplies;楰ightarrow;懛ĀchႹႼr;愛;憱leDelayed;槴ڀHOacfhimoqstuფჱჷჽᄙᄞᅑᅖᅡᅧᆵᆻᆿĀCcჩხHcy;䐩y;䐨FTcy;䐬cute;䅚ʀ;aeiyᄈᄉᄎᄓᄗ檼ron;䅠dil;䅞rc;䅜;䐡r;쀀𝔖ortȀDLRUᄪᄴᄾᅉownArrow»ОeftArrow»࢚ightArrow»࿝pArrow;憑gma;䎣allCircle;战pf;쀀𝕊ɲᅭ\0\0ᅰt;戚areȀ;ISUᅻᅼᆉᆯ斡ntersection;抓uĀbpᆏᆞsetĀ;Eᆗᆘ抏qual;抑ersetĀ;Eᆨᆩ抐qual;抒nion;抔cr;쀀𝒮ar;拆ȀbcmpᇈᇛሉላĀ;sᇍᇎ拐etĀ;Eᇍᇕqual;抆ĀchᇠህeedsȀ;ESTᇭᇮᇴᇿ扻qual;檰lantEqual;扽ilde;承Tháྌ;我ƀ;esሒሓሣ拑rsetĀ;Eሜም抃qual;抇et»ሓրHRSacfhiorsሾቄ቉ቕ቞ቱቶኟዂወዑORN耻Þ䃞ADE;愢ĀHc቎ቒcy;䐋y;䐦Ābuቚቜ;䀉;䎤ƀaeyብቪቯron;䅤dil;䅢;䐢r;쀀𝔗Āeiቻ኉ǲኀ\0ኇefore;戴a;䎘Ācn኎ኘkSpace;쀀  Space;怉ldeȀ;EFTካኬኲኼ戼qual;扃ullEqual;扅ilde;扈pf;쀀𝕋ipleDot;惛Āctዖዛr;쀀𝒯rok;䅦ૡዷጎጚጦ\0ጬጱ\0\0\0\0\0ጸጽ፷ᎅ\0᏿ᐄᐊᐐĀcrዻጁute耻Ú䃚rĀ;oጇገ憟cir;楉rǣጓ\0጖y;䐎ve;䅬Āiyጞጣrc耻Û䃛;䐣blac;䅰r;쀀𝔘rave耻Ù䃙acr;䅪Ādiፁ፩erĀBPፈ፝Āarፍፐr;䁟acĀekፗፙ;揟et;掵arenthesis;揝onĀ;P፰፱拃lus;抎Āgp፻፿on;䅲f;쀀𝕌ЀADETadps᎕ᎮᎸᏄϨᏒᏗᏳrrowƀ;BDᅐᎠᎤar;椒ownArrow;懅ownArrow;憕quilibrium;楮eeĀ;AᏋᏌ报rrow;憥ownáϳerĀLRᏞᏨeftArrow;憖ightArrow;憗iĀ;lᏹᏺ䏒on;䎥ing;䅮cr;쀀𝒰ilde;䅨ml耻Ü䃜ҀDbcdefosvᐧᐬᐰᐳᐾᒅᒊᒐᒖash;披ar;櫫y;䐒ashĀ;lᐻᐼ抩;櫦Āerᑃᑅ;拁ƀbtyᑌᑐᑺar;怖Ā;iᑏᑕcalȀBLSTᑡᑥᑪᑴar;戣ine;䁼eparator;杘ilde;所ThinSpace;怊r;쀀𝔙pf;쀀𝕍cr;쀀𝒱dash;抪ʀcefosᒧᒬᒱᒶᒼirc;䅴dge;拀r;쀀𝔚pf;쀀𝕎cr;쀀𝒲Ȁfiosᓋᓐᓒᓘr;쀀𝔛;䎞pf;쀀𝕏cr;쀀𝒳ҀAIUacfosuᓱᓵᓹᓽᔄᔏᔔᔚᔠcy;䐯cy;䐇cy;䐮cute耻Ý䃝Āiyᔉᔍrc;䅶;䐫r;쀀𝔜pf;쀀𝕐cr;쀀𝒴ml;䅸ЀHacdefosᔵᔹᔿᕋᕏᕝᕠᕤcy;䐖cute;䅹Āayᕄᕉron;䅽;䐗ot;䅻ǲᕔ\0ᕛoWidtè૙a;䎖r;愨pf;愤cr;쀀𝒵௡ᖃᖊᖐ\0ᖰᖶᖿ\0\0\0\0ᗆᗛᗫᙟ᙭\0ᚕ᚛ᚲᚹ\0ᚾcute耻á䃡reve;䄃̀;Ediuyᖜᖝᖡᖣᖨᖭ戾;쀀∾̳;房rc耻â䃢te肻´̆;䐰lig耻æ䃦Ā;r²ᖺ;쀀𝔞rave耻à䃠ĀepᗊᗖĀfpᗏᗔsym;愵èᗓha;䎱ĀapᗟcĀclᗤᗧr;䄁g;樿ɤᗰ\0\0ᘊʀ;adsvᗺᗻᗿᘁᘇ戧nd;橕;橜lope;橘;橚΀;elmrszᘘᘙᘛᘞᘿᙏᙙ戠;榤e»ᘙsdĀ;aᘥᘦ戡ѡᘰᘲᘴᘶᘸᘺᘼᘾ;榨;榩;榪;榫;榬;榭;榮;榯tĀ;vᙅᙆ戟bĀ;dᙌᙍ抾;榝Āptᙔᙗh;戢»¹arr;捼Āgpᙣᙧon;䄅f;쀀𝕒΀;Eaeiop዁ᙻᙽᚂᚄᚇᚊ;橰cir;橯;扊d;手s;䀧roxĀ;e዁ᚒñᚃing耻å䃥ƀctyᚡᚦᚨr;쀀𝒶;䀪mpĀ;e዁ᚯñʈilde耻ã䃣ml耻ä䃤Āciᛂᛈoninôɲnt;樑ࠀNabcdefiklnoprsu᛭ᛱᜰ᜼ᝃᝈ᝸᝽០៦ᠹᡐᜍ᤽᥈ᥰot;櫭Ācrᛶ᜞kȀcepsᜀᜅᜍᜓong;扌psilon;䏶rime;怵imĀ;e᜚᜛戽q;拍Ŷᜢᜦee;抽edĀ;gᜬᜭ挅e»ᜭrkĀ;t፜᜷brk;掶Āoyᜁᝁ;䐱quo;怞ʀcmprtᝓ᝛ᝡᝤᝨausĀ;eĊĉptyv;榰séᜌnoõēƀahwᝯ᝱ᝳ;䎲;愶een;扬r;쀀𝔟g΀costuvwឍឝឳេ៕៛៞ƀaiuបពរðݠrc;旯p»፱ƀdptឤឨឭot;樀lus;樁imes;樂ɱឹ\0\0ើcup;樆ar;昅riangleĀdu៍្own;施p;斳plus;樄eåᑄåᒭarow;植ƀako៭ᠦᠵĀcn៲ᠣkƀlst៺֫᠂ozenge;槫riangleȀ;dlr᠒᠓᠘᠝斴own;斾eft;旂ight;斸k;搣Ʊᠫ\0ᠳƲᠯ\0ᠱ;斒;斑4;斓ck;斈ĀeoᠾᡍĀ;qᡃᡆ쀀=⃥uiv;쀀≡⃥t;挐Ȁptwxᡙᡞᡧᡬf;쀀𝕓Ā;tᏋᡣom»Ꮜtie;拈؀DHUVbdhmptuvᢅᢖᢪᢻᣗᣛᣬ᣿ᤅᤊᤐᤡȀLRlrᢎᢐᢒᢔ;敗;敔;敖;敓ʀ;DUduᢡᢢᢤᢦᢨ敐;敦;敩;敤;敧ȀLRlrᢳᢵᢷᢹ;敝;敚;敜;教΀;HLRhlrᣊᣋᣍᣏᣑᣓᣕ救;敬;散;敠;敫;敢;敟ox;槉ȀLRlrᣤᣦᣨᣪ;敕;敒;攐;攌ʀ;DUduڽ᣷᣹᣻᣽;敥;敨;攬;攴inus;抟lus;択imes;抠ȀLRlrᤙᤛᤝ᤟;敛;敘;攘;攔΀;HLRhlrᤰᤱᤳᤵᤷ᤻᤹攂;敪;敡;敞;攼;攤;攜Āevģ᥂bar耻¦䂦Ȁceioᥑᥖᥚᥠr;쀀𝒷mi;恏mĀ;e᜚᜜lƀ;bhᥨᥩᥫ䁜;槅sub;柈Ŭᥴ᥾lĀ;e᥹᥺怢t»᥺pƀ;Eeįᦅᦇ;檮Ā;qۜۛೡᦧ\0᧨ᨑᨕᨲ\0ᨷᩐ\0\0᪴\0\0᫁\0\0ᬡᬮ᭍᭒\0᯽\0ᰌƀcpr᦭ᦲ᧝ute;䄇̀;abcdsᦿᧀᧄ᧊᧕᧙戩nd;橄rcup;橉Āau᧏᧒p;橋p;橇ot;橀;쀀∩︀Āeo᧢᧥t;恁îړȀaeiu᧰᧻ᨁᨅǰ᧵\0᧸s;橍on;䄍dil耻ç䃧rc;䄉psĀ;sᨌᨍ橌m;橐ot;䄋ƀdmnᨛᨠᨦil肻¸ƭptyv;榲t脀¢;eᨭᨮ䂢räƲr;쀀𝔠ƀceiᨽᩀᩍy;䑇ckĀ;mᩇᩈ朓ark»ᩈ;䏇r΀;Ecefms᩟᩠ᩢᩫ᪤᪪᪮旋;槃ƀ;elᩩᩪᩭ䋆q;扗eɡᩴ\0\0᪈rrowĀlr᩼᪁eft;憺ight;憻ʀRSacd᪒᪔᪖᪚᪟»ཇ;擈st;抛irc;抚ash;抝nint;樐id;櫯cir;槂ubsĀ;u᪻᪼晣it»᪼ˬ᫇᫔᫺\0ᬊonĀ;eᫍᫎ䀺Ā;qÇÆɭ᫙\0\0᫢aĀ;t᫞᫟䀬;䁀ƀ;fl᫨᫩᫫戁îᅠeĀmx᫱᫶ent»᫩eóɍǧ᫾\0ᬇĀ;dኻᬂot;橭nôɆƀfryᬐᬔᬗ;쀀𝕔oäɔ脀©;sŕᬝr;愗Āaoᬥᬩrr;憵ss;朗Ācuᬲᬷr;쀀𝒸Ābpᬼ᭄Ā;eᭁᭂ櫏;櫑Ā;eᭉᭊ櫐;櫒dot;拯΀delprvw᭠᭬᭷ᮂᮬᯔ᯹arrĀlr᭨᭪;椸;椵ɰ᭲\0\0᭵r;拞c;拟arrĀ;p᭿ᮀ憶;椽̀;bcdosᮏᮐᮖᮡᮥᮨ截rcap;橈Āauᮛᮞp;橆p;橊ot;抍r;橅;쀀∪︀Ȁalrv᮵ᮿᯞᯣrrĀ;mᮼᮽ憷;椼yƀevwᯇᯔᯘqɰᯎ\0\0ᯒreã᭳uã᭵ee;拎edge;拏en耻¤䂤earrowĀlrᯮ᯳eft»ᮀight»ᮽeäᯝĀciᰁᰇoninôǷnt;戱lcty;挭ঀAHabcdefhijlorstuwz᰸᰻᰿ᱝᱩᱵᲊᲞᲬᲷ᳻᳿ᴍᵻᶑᶫᶻ᷆᷍rò΁ar;楥Ȁglrs᱈ᱍ᱒᱔ger;怠eth;愸òᄳhĀ;vᱚᱛ怐»ऊūᱡᱧarow;椏aã̕Āayᱮᱳron;䄏;䐴ƀ;ao̲ᱼᲄĀgrʿᲁr;懊tseq;橷ƀglmᲑᲔᲘ耻°䂰ta;䎴ptyv;榱ĀirᲣᲨsht;楿;쀀𝔡arĀlrᲳᲵ»ࣜ»သʀaegsv᳂͸᳖᳜᳠mƀ;oș᳊᳔ndĀ;ș᳑uit;晦amma;䏝in;拲ƀ;io᳧᳨᳸䃷de脀÷;o᳧ᳰntimes;拇nø᳷cy;䑒cɯᴆ\0\0ᴊrn;挞op;挍ʀlptuwᴘᴝᴢᵉᵕlar;䀤f;쀀𝕕ʀ;emps̋ᴭᴷᴽᵂqĀ;d͒ᴳot;扑inus;戸lus;戔quare;抡blebarwedgåúnƀadhᄮᵝᵧownarrowóᲃarpoonĀlrᵲᵶefôᲴighôᲶŢᵿᶅkaro÷གɯᶊ\0\0ᶎrn;挟op;挌ƀcotᶘᶣᶦĀryᶝᶡ;쀀𝒹;䑕l;槶rok;䄑Ādrᶰᶴot;拱iĀ;fᶺ᠖斿Āah᷀᷃ròЩaòྦangle;榦Āci᷒ᷕy;䑟grarr;柿ऀDacdefglmnopqrstuxḁḉḙḸոḼṉṡṾấắẽỡἪἷὄ὎὚ĀDoḆᴴoôᲉĀcsḎḔute耻é䃩ter;橮ȀaioyḢḧḱḶron;䄛rĀ;cḭḮ扖耻ê䃪lon;払;䑍ot;䄗ĀDrṁṅot;扒;쀀𝔢ƀ;rsṐṑṗ檚ave耻è䃨Ā;dṜṝ檖ot;檘Ȁ;ilsṪṫṲṴ檙nters;揧;愓Ā;dṹṺ檕ot;檗ƀapsẅẉẗcr;䄓tyƀ;svẒẓẕ戅et»ẓpĀ1;ẝẤĳạả;怄;怅怃ĀgsẪẬ;䅋p;怂ĀgpẴẸon;䄙f;쀀𝕖ƀalsỄỎỒrĀ;sỊị拕l;槣us;橱iƀ;lvỚớở䎵on»ớ;䏵ȀcsuvỪỳἋἣĀioữḱrc»Ḯɩỹ\0\0ỻíՈantĀglἂἆtr»ṝess»Ṻƀaeiἒ἖Ἒls;䀽st;扟vĀ;DȵἠD;橸parsl;槥ĀDaἯἳot;打rr;楱ƀcdiἾὁỸr;愯oô͒ĀahὉὋ;䎷耻ð䃰Āmrὓὗl耻ë䃫o;悬ƀcipὡὤὧl;䀡sôծĀeoὬὴctatioîՙnentialåչৡᾒ\0ᾞ\0ᾡᾧ\0\0ῆῌ\0ΐ\0ῦῪ \0 ⁚llingdotseñṄy;䑄male;晀ƀilrᾭᾳ῁lig;耀ﬃɩᾹ\0\0᾽g;耀ﬀig;耀ﬄ;쀀𝔣lig;耀ﬁlig;쀀fjƀaltῙ῜ῡt;晭ig;耀ﬂns;斱of;䆒ǰ΅\0ῳf;쀀𝕗ĀakֿῷĀ;vῼ´拔;櫙artint;樍Āao‌⁕Ācs‑⁒α‚‰‸⁅⁈\0⁐β•‥‧‪‬\0‮耻½䂽;慓耻¼䂼;慕;慙;慛Ƴ‴\0‶;慔;慖ʴ‾⁁\0\0⁃耻¾䂾;慗;慜5;慘ƶ⁌\0⁎;慚;慝8;慞l;恄wn;挢cr;쀀𝒻ࢀEabcdefgijlnorstv₂₉₟₥₰₴⃰⃵⃺⃿℃ℒℸ̗ℾ⅒↞Ā;lٍ₇;檌ƀcmpₐₕ₝ute;䇵maĀ;dₜ᳚䎳;檆reve;䄟Āiy₪₮rc;䄝;䐳ot;䄡Ȁ;lqsؾق₽⃉ƀ;qsؾٌ⃄lanô٥Ȁ;cdl٥⃒⃥⃕c;檩otĀ;o⃜⃝檀Ā;l⃢⃣檂;檄Ā;e⃪⃭쀀⋛︀s;檔r;쀀𝔤Ā;gٳ؛mel;愷cy;䑓Ȁ;Eajٚℌℎℐ;檒;檥;檤ȀEaesℛℝ℩ℴ;扩pĀ;p℣ℤ檊rox»ℤĀ;q℮ℯ檈Ā;q℮ℛim;拧pf;쀀𝕘Āci⅃ⅆr;愊mƀ;el٫ⅎ⅐;檎;檐茀>;cdlqr׮ⅠⅪⅮⅳⅹĀciⅥⅧ;檧r;橺ot;拗Par;榕uest;橼ʀadelsↄⅪ←ٖ↛ǰ↉\0↎proø₞r;楸qĀlqؿ↖lesó₈ií٫Āen↣↭rtneqq;쀀≩︀Å↪ԀAabcefkosy⇄⇇⇱⇵⇺∘∝∯≨≽ròΠȀilmr⇐⇔⇗⇛rsðᒄf»․ilôکĀdr⇠⇤cy;䑊ƀ;cwࣴ⇫⇯ir;楈;憭ar;意irc;䄥ƀalr∁∎∓rtsĀ;u∉∊晥it»∊lip;怦con;抹r;쀀𝔥sĀew∣∩arow;椥arow;椦ʀamopr∺∾≃≞≣rr;懿tht;戻kĀlr≉≓eftarrow;憩ightarrow;憪f;쀀𝕙bar;怕ƀclt≯≴≸r;쀀𝒽asè⇴rok;䄧Ābp⊂⊇ull;恃hen»ᱛૡ⊣\0⊪\0⊸⋅⋎\0⋕⋳\0\0⋸⌢⍧⍢⍿\0⎆⎪⎴cute耻í䃭ƀ;iyݱ⊰⊵rc耻î䃮;䐸Ācx⊼⊿y;䐵cl耻¡䂡ĀfrΟ⋉;쀀𝔦rave耻ì䃬Ȁ;inoܾ⋝⋩⋮Āin⋢⋦nt;樌t;戭fin;槜ta;愩lig;䄳ƀaop⋾⌚⌝ƀcgt⌅⌈⌗r;䄫ƀelpܟ⌏⌓inåގarôܠh;䄱f;抷ed;䆵ʀ;cfotӴ⌬⌱⌽⍁are;愅inĀ;t⌸⌹戞ie;槝doô⌙ʀ;celpݗ⍌⍐⍛⍡al;抺Āgr⍕⍙eróᕣã⍍arhk;樗rod;樼Ȁcgpt⍯⍲⍶⍻y;䑑on;䄯f;쀀𝕚a;䎹uest耻¿䂿Āci⎊⎏r;쀀𝒾nʀ;EdsvӴ⎛⎝⎡ӳ;拹ot;拵Ā;v⎦⎧拴;拳Ā;iݷ⎮lde;䄩ǫ⎸\0⎼cy;䑖l耻ï䃯̀cfmosu⏌⏗⏜⏡⏧⏵Āiy⏑⏕rc;䄵;䐹r;쀀𝔧ath;䈷pf;쀀𝕛ǣ⏬\0⏱r;쀀𝒿rcy;䑘kcy;䑔Ѐacfghjos␋␖␢␧␭␱␵␻ppaĀ;v␓␔䎺;䏰Āey␛␠dil;䄷;䐺r;쀀𝔨reen;䄸cy;䑅cy;䑜pf;쀀𝕜cr;쀀𝓀஀ABEHabcdefghjlmnoprstuv⑰⒁⒆⒍⒑┎┽╚▀♎♞♥♹♽⚚⚲⛘❝❨➋⟀⠁⠒ƀart⑷⑺⑼rò৆òΕail;椛arr;椎Ā;gঔ⒋;檋ar;楢ॣ⒥\0⒪\0⒱\0\0\0\0\0⒵Ⓔ\0ⓆⓈⓍ\0⓹ute;䄺mptyv;榴raîࡌbda;䎻gƀ;dlࢎⓁⓃ;榑åࢎ;檅uo耻«䂫rЀ;bfhlpst࢙ⓞⓦⓩ⓫⓮⓱⓵Ā;f࢝ⓣs;椟s;椝ë≒p;憫l;椹im;楳l;憢ƀ;ae⓿─┄檫il;椙Ā;s┉┊檭;쀀⪭︀ƀabr┕┙┝rr;椌rk;杲Āak┢┬cĀek┨┪;䁻;䁛Āes┱┳;榋lĀdu┹┻;榏;榍Ȁaeuy╆╋╖╘ron;䄾Ādi═╔il;䄼ìࢰâ┩;䐻Ȁcqrs╣╦╭╽a;椶uoĀ;rนᝆĀdu╲╷har;楧shar;楋h;憲ʀ;fgqs▋▌উ◳◿扤tʀahlrt▘▤▷◂◨rrowĀ;t࢙□aé⓶arpoonĀdu▯▴own»њp»०eftarrows;懇ightƀahs◍◖◞rrowĀ;sࣴࢧarpoonó྘quigarro÷⇰hreetimes;拋ƀ;qs▋ও◺lanôবʀ;cdgsব☊☍☝☨c;檨otĀ;o☔☕橿Ā;r☚☛檁;檃Ā;e☢☥쀀⋚︀s;檓ʀadegs☳☹☽♉♋pproøⓆot;拖qĀgq♃♅ôউgtò⒌ôছiíলƀilr♕࣡♚sht;楼;쀀𝔩Ā;Eজ♣;檑š♩♶rĀdu▲♮Ā;l॥♳;楪lk;斄cy;䑙ʀ;achtੈ⚈⚋⚑⚖rò◁orneòᴈard;楫ri;旺Āio⚟⚤dot;䅀ustĀ;a⚬⚭掰che»⚭ȀEaes⚻⚽⛉⛔;扨pĀ;p⛃⛄檉rox»⛄Ā;q⛎⛏檇Ā;q⛎⚻im;拦Ѐabnoptwz⛩⛴⛷✚✯❁❇❐Ānr⛮⛱g;柬r;懽rëࣁgƀlmr⛿✍✔eftĀar০✇ightá৲apsto;柼ightá৽parrowĀlr✥✩efô⓭ight;憬ƀafl✶✹✽r;榅;쀀𝕝us;樭imes;樴š❋❏st;戗áፎƀ;ef❗❘᠀旊nge»❘arĀ;l❤❥䀨t;榓ʀachmt❳❶❼➅➇ròࢨorneòᶌarĀ;d྘➃;業;怎ri;抿̀achiqt➘➝ੀ➢➮➻quo;怹r;쀀𝓁mƀ;egল➪➬;檍;檏Ābu┪➳oĀ;rฟ➹;怚rok;䅂萀<;cdhilqrࠫ⟒☹⟜⟠⟥⟪⟰Āci⟗⟙;檦r;橹reå◲mes;拉arr;楶uest;橻ĀPi⟵⟹ar;榖ƀ;ef⠀भ᠛旃rĀdu⠇⠍shar;楊har;楦Āen⠗⠡rtneqq;쀀≨︀Å⠞܀Dacdefhilnopsu⡀⡅⢂⢎⢓⢠⢥⢨⣚⣢⣤ઃ⣳⤂Dot;戺Ȁclpr⡎⡒⡣⡽r耻¯䂯Āet⡗⡙;時Ā;e⡞⡟朠se»⡟Ā;sျ⡨toȀ;dluျ⡳⡷⡻owîҌefôएðᏑker;斮Āoy⢇⢌mma;権;䐼ash;怔asuredangle»ᘦr;쀀𝔪o;愧ƀcdn⢯⢴⣉ro耻µ䂵Ȁ;acdᑤ⢽⣀⣄sôᚧir;櫰ot肻·Ƶusƀ;bd⣒ᤃ⣓戒Ā;uᴼ⣘;横ţ⣞⣡p;櫛ò−ðઁĀdp⣩⣮els;抧f;쀀𝕞Āct⣸⣽r;쀀𝓂pos»ᖝƀ;lm⤉⤊⤍䎼timap;抸ఀGLRVabcdefghijlmoprstuvw⥂⥓⥾⦉⦘⧚⧩⨕⨚⩘⩝⪃⪕⪤⪨⬄⬇⭄⭿⮮ⰴⱧⱼ⳩Āgt⥇⥋;쀀⋙̸Ā;v⥐௏쀀≫⃒ƀelt⥚⥲⥶ftĀar⥡⥧rrow;懍ightarrow;懎;쀀⋘̸Ā;v⥻ే쀀≪⃒ightarrow;懏ĀDd⦎⦓ash;抯ash;抮ʀbcnpt⦣⦧⦬⦱⧌la»˞ute;䅄g;쀀∠⃒ʀ;Eiop඄⦼⧀⧅⧈;쀀⩰̸d;쀀≋̸s;䅉roø඄urĀ;a⧓⧔普lĀ;s⧓ସǳ⧟\0⧣p肻 ଷmpĀ;e௹ఀʀaeouy⧴⧾⨃⨐⨓ǰ⧹\0⧻;橃on;䅈dil;䅆ngĀ;dൾ⨊ot;쀀⩭̸p;橂;䐽ash;怓΀;Aadqsxஒ⨩⨭⨻⩁⩅⩐rr;懗rĀhr⨳⨶k;椤Ā;oᏲᏰot;쀀≐̸uiöୣĀei⩊⩎ar;椨í஘istĀ;s஠டr;쀀𝔫ȀEest௅⩦⩹⩼ƀ;qs஼⩭௡ƀ;qs஼௅⩴lanô௢ií௪Ā;rஶ⪁»ஷƀAap⪊⪍⪑rò⥱rr;憮ar;櫲ƀ;svྍ⪜ྌĀ;d⪡⪢拼;拺cy;䑚΀AEadest⪷⪺⪾⫂⫅⫶⫹rò⥦;쀀≦̸rr;憚r;急Ȁ;fqs఻⫎⫣⫯tĀar⫔⫙rro÷⫁ightarro÷⪐ƀ;qs఻⪺⫪lanôౕĀ;sౕ⫴»శiíౝĀ;rవ⫾iĀ;eచథiäඐĀpt⬌⬑f;쀀𝕟膀¬;in⬙⬚⬶䂬nȀ;Edvஉ⬤⬨⬮;쀀⋹̸ot;쀀⋵̸ǡஉ⬳⬵;拷;拶iĀ;vಸ⬼ǡಸ⭁⭃;拾;拽ƀaor⭋⭣⭩rȀ;ast୻⭕⭚⭟lleì୻l;쀀⫽⃥;쀀∂̸lint;樔ƀ;ceಒ⭰⭳uåಥĀ;cಘ⭸Ā;eಒ⭽ñಘȀAait⮈⮋⮝⮧rò⦈rrƀ;cw⮔⮕⮙憛;쀀⤳̸;쀀↝̸ghtarrow»⮕riĀ;eೋೖ΀chimpqu⮽⯍⯙⬄୸⯤⯯Ȁ;cerല⯆ഷ⯉uå൅;쀀𝓃ortɭ⬅\0\0⯖ará⭖mĀ;e൮⯟Ā;q൴൳suĀbp⯫⯭å೸åഋƀbcp⯶ⰑⰙȀ;Ees⯿ⰀഢⰄ抄;쀀⫅̸etĀ;eഛⰋqĀ;qണⰀcĀ;eലⰗñസȀ;EesⰢⰣൟⰧ抅;쀀⫆̸etĀ;e൘ⰮqĀ;qൠⰣȀgilrⰽⰿⱅⱇìௗlde耻ñ䃱çృiangleĀlrⱒⱜeftĀ;eచⱚñదightĀ;eೋⱥñ೗Ā;mⱬⱭ䎽ƀ;esⱴⱵⱹ䀣ro;愖p;怇ҀDHadgilrsⲏⲔⲙⲞⲣⲰⲶⳓⳣash;抭arr;椄p;쀀≍⃒ash;抬ĀetⲨⲬ;쀀≥⃒;쀀>⃒nfin;槞ƀAetⲽⳁⳅrr;椂;쀀≤⃒Ā;rⳊⳍ쀀<⃒ie;쀀⊴⃒ĀAtⳘⳜrr;椃rie;쀀⊵⃒im;쀀∼⃒ƀAan⳰⳴ⴂrr;懖rĀhr⳺⳽k;椣Ā;oᏧᏥear;椧ቓ᪕\0\0\0\0\0\0\0\0\0\0\0\0\0ⴭ\0ⴸⵈⵠⵥ⵲ⶄᬇ\0\0ⶍⶫ\0ⷈⷎ\0ⷜ⸙⸫⸾⹃Ācsⴱ᪗ute耻ó䃳ĀiyⴼⵅrĀ;c᪞ⵂ耻ô䃴;䐾ʀabios᪠ⵒⵗǈⵚlac;䅑v;樸old;榼lig;䅓Ācr⵩⵭ir;榿;쀀𝔬ͯ⵹\0\0⵼\0ⶂn;䋛ave耻ò䃲;槁Ābmⶈ෴ar;榵Ȁacitⶕ⶘ⶥⶨrò᪀Āir⶝ⶠr;榾oss;榻nå๒;槀ƀaeiⶱⶵⶹcr;䅍ga;䏉ƀcdnⷀⷅǍron;䎿;榶pf;쀀𝕠ƀaelⷔ⷗ǒr;榷rp;榹΀;adiosvⷪⷫⷮ⸈⸍⸐⸖戨rò᪆Ȁ;efmⷷⷸ⸂⸅橝rĀ;oⷾⷿ愴f»ⷿ耻ª䂪耻º䂺gof;抶r;橖lope;橗;橛ƀclo⸟⸡⸧ò⸁ash耻ø䃸l;折iŬⸯ⸴de耻õ䃵esĀ;aǛ⸺s;樶ml耻ö䃶bar;挽ૡ⹞\0⹽\0⺀⺝\0⺢⺹\0\0⻋ຜ\0⼓\0\0⼫⾼\0⿈rȀ;astЃ⹧⹲຅脀¶;l⹭⹮䂶leìЃɩ⹸\0\0⹻m;櫳;櫽y;䐿rʀcimpt⺋⺏⺓ᡥ⺗nt;䀥od;䀮il;怰enk;怱r;쀀𝔭ƀimo⺨⺰⺴Ā;v⺭⺮䏆;䏕maô੶ne;明ƀ;tv⺿⻀⻈䏀chfork»´;䏖Āau⻏⻟nĀck⻕⻝kĀ;h⇴⻛;愎ö⇴sҀ;abcdemst⻳⻴ᤈ⻹⻽⼄⼆⼊⼎䀫cir;樣ir;樢Āouᵀ⼂;樥;橲n肻±ຝim;樦wo;樧ƀipu⼙⼠⼥ntint;樕f;쀀𝕡nd耻£䂣Ԁ;Eaceinosu່⼿⽁⽄⽇⾁⾉⾒⽾⾶;檳p;檷uå໙Ā;c໎⽌̀;acens່⽙⽟⽦⽨⽾pproø⽃urlyeñ໙ñ໎ƀaes⽯⽶⽺pprox;檹qq;檵im;拨iíໟmeĀ;s⾈ຮ怲ƀEas⽸⾐⽺ð⽵ƀdfp໬⾙⾯ƀals⾠⾥⾪lar;挮ine;挒urf;挓Ā;t໻⾴ï໻rel;抰Āci⿀⿅r;쀀𝓅;䏈ncsp;怈̀fiopsu⿚⋢⿟⿥⿫⿱r;쀀𝔮pf;쀀𝕢rime;恗cr;쀀𝓆ƀaeo⿸〉〓tĀei⿾々rnionóڰnt;樖stĀ;e【】䀿ñἙô༔઀ABHabcdefhilmnoprstux぀けさすムㄎㄫㅇㅢㅲㆎ㈆㈕㈤㈩㉘㉮㉲㊐㊰㊷ƀartぇおがròႳòϝail;検aròᱥar;楤΀cdenqrtとふへみわゔヌĀeuねぱ;쀀∽̱te;䅕iãᅮmptyv;榳gȀ;del࿑らるろ;榒;榥å࿑uo耻»䂻rր;abcfhlpstw࿜ガクシスゼゾダッデナp;極Ā;f࿠ゴs;椠;椳s;椞ë≝ð✮l;楅im;楴l;憣;憝Āaiパフil;椚oĀ;nホボ戶aló༞ƀabrョリヮrò៥rk;杳ĀakンヽcĀekヹ・;䁽;䁝Āes㄂㄄;榌lĀduㄊㄌ;榎;榐Ȁaeuyㄗㄜㄧㄩron;䅙Ādiㄡㄥil;䅗ì࿲âヺ;䑀Ȁclqsㄴㄷㄽㅄa;椷dhar;楩uoĀ;rȎȍh;憳ƀacgㅎㅟངlȀ;ipsླྀㅘㅛႜnåႻarôྩt;断ƀilrㅩဣㅮsht;楽;쀀𝔯ĀaoㅷㆆrĀduㅽㅿ»ѻĀ;l႑ㆄ;楬Ā;vㆋㆌ䏁;䏱ƀgns㆕ㇹㇼht̀ahlrstㆤㆰ㇂㇘㇤㇮rrowĀ;t࿜ㆭaéトarpoonĀduㆻㆿowîㅾp»႒eftĀah㇊㇐rrowó࿪arpoonóՑightarrows;應quigarro÷ニhreetimes;拌g;䋚ingdotseñἲƀahm㈍㈐㈓rò࿪aòՑ;怏oustĀ;a㈞㈟掱che»㈟mid;櫮Ȁabpt㈲㈽㉀㉒Ānr㈷㈺g;柭r;懾rëဃƀafl㉇㉊㉎r;榆;쀀𝕣us;樮imes;樵Āap㉝㉧rĀ;g㉣㉤䀩t;榔olint;樒arò㇣Ȁachq㉻㊀Ⴜ㊅quo;怺r;쀀𝓇Ābu・㊊oĀ;rȔȓƀhir㊗㊛㊠reåㇸmes;拊iȀ;efl㊪ၙᠡ㊫方tri;槎luhar;楨;愞ൡ㋕㋛㋟㌬㌸㍱\0㍺㎤\0\0㏬㏰\0㐨㑈㑚㒭㒱㓊㓱\0㘖\0\0㘳cute;䅛quï➺Ԁ;Eaceinpsyᇭ㋳㋵㋿㌂㌋㌏㌟㌦㌩;檴ǰ㋺\0㋼;檸on;䅡uåᇾĀ;dᇳ㌇il;䅟rc;䅝ƀEas㌖㌘㌛;檶p;檺im;择olint;樓iíሄ;䑁otƀ;be㌴ᵇ㌵担;橦΀Aacmstx㍆㍊㍗㍛㍞㍣㍭rr;懘rĀhr㍐㍒ë∨Ā;oਸ਼਴t耻§䂧i;䀻war;椩mĀin㍩ðnuóñt;朶rĀ;o㍶⁕쀀𝔰Ȁacoy㎂㎆㎑㎠rp;景Āhy㎋㎏cy;䑉;䑈rtɭ㎙\0\0㎜iäᑤaraì⹯耻­䂭Āgm㎨㎴maƀ;fv㎱㎲㎲䏃;䏂Ѐ;deglnprካ㏅㏉㏎㏖㏞㏡㏦ot;橪Ā;q኱ኰĀ;E㏓㏔檞;檠Ā;E㏛㏜檝;檟e;扆lus;樤arr;楲aròᄽȀaeit㏸㐈㐏㐗Āls㏽㐄lsetmé㍪hp;樳parsl;槤Ādlᑣ㐔e;挣Ā;e㐜㐝檪Ā;s㐢㐣檬;쀀⪬︀ƀflp㐮㐳㑂tcy;䑌Ā;b㐸㐹䀯Ā;a㐾㐿槄r;挿f;쀀𝕤aĀdr㑍ЂesĀ;u㑔㑕晠it»㑕ƀcsu㑠㑹㒟Āau㑥㑯pĀ;sᆈ㑫;쀀⊓︀pĀ;sᆴ㑵;쀀⊔︀uĀbp㑿㒏ƀ;esᆗᆜ㒆etĀ;eᆗ㒍ñᆝƀ;esᆨᆭ㒖etĀ;eᆨ㒝ñᆮƀ;afᅻ㒦ְrť㒫ֱ»ᅼaròᅈȀcemt㒹㒾㓂㓅r;쀀𝓈tmîñiì㐕aræᆾĀar㓎㓕rĀ;f㓔ឿ昆Āan㓚㓭ightĀep㓣㓪psiloîỠhé⺯s»⡒ʀbcmnp㓻㕞ሉ㖋㖎Ҁ;Edemnprs㔎㔏㔑㔕㔞㔣㔬㔱㔶抂;櫅ot;檽Ā;dᇚ㔚ot;櫃ult;櫁ĀEe㔨㔪;櫋;把lus;檿arr;楹ƀeiu㔽㕒㕕tƀ;en㔎㕅㕋qĀ;qᇚ㔏eqĀ;q㔫㔨m;櫇Ābp㕚㕜;櫕;櫓c̀;acensᇭ㕬㕲㕹㕻㌦pproø㋺urlyeñᇾñᇳƀaes㖂㖈㌛pproø㌚qñ㌗g;晪ڀ123;Edehlmnps㖩㖬㖯ሜ㖲㖴㗀㗉㗕㗚㗟㗨㗭耻¹䂹耻²䂲耻³䂳;櫆Āos㖹㖼t;檾ub;櫘Ā;dሢ㗅ot;櫄sĀou㗏㗒l;柉b;櫗arr;楻ult;櫂ĀEe㗤㗦;櫌;抋lus;櫀ƀeiu㗴㘉㘌tƀ;enሜ㗼㘂qĀ;qሢ㖲eqĀ;q㗧㗤m;櫈Ābp㘑㘓;櫔;櫖ƀAan㘜㘠㘭rr;懙rĀhr㘦㘨ë∮Ā;oਫ਩war;椪lig耻ß䃟௡㙑㙝㙠ዎ㙳㙹\0㙾㛂\0\0\0\0\0㛛㜃\0㜉㝬\0\0\0㞇ɲ㙖\0\0㙛get;挖;䏄rë๟ƀaey㙦㙫㙰ron;䅥dil;䅣;䑂lrec;挕r;쀀𝔱Ȁeiko㚆㚝㚵㚼ǲ㚋\0㚑eĀ4fኄኁaƀ;sv㚘㚙㚛䎸ym;䏑Ācn㚢㚲kĀas㚨㚮pproø዁im»ኬsðኞĀas㚺㚮ð዁rn耻þ䃾Ǭ̟㛆⋧es膀×;bd㛏㛐㛘䃗Ā;aᤏ㛕r;樱;樰ƀeps㛡㛣㜀á⩍Ȁ;bcf҆㛬㛰㛴ot;挶ir;櫱Ā;o㛹㛼쀀𝕥rk;櫚á㍢rime;怴ƀaip㜏㜒㝤dåቈ΀adempst㜡㝍㝀㝑㝗㝜㝟ngleʀ;dlqr㜰㜱㜶㝀㝂斵own»ᶻeftĀ;e⠀㜾ñम;扜ightĀ;e㊪㝋ñၚot;旬inus;樺lus;樹b;槍ime;樻ezium;揢ƀcht㝲㝽㞁Āry㝷㝻;쀀𝓉;䑆cy;䑛rok;䅧Āio㞋㞎xô᝷headĀlr㞗㞠eftarro÷ࡏightarrow»ཝऀAHabcdfghlmoprstuw㟐㟓㟗㟤㟰㟼㠎㠜㠣㠴㡑㡝㡫㢩㣌㣒㣪㣶ròϭar;楣Ācr㟜㟢ute耻ú䃺òᅐrǣ㟪\0㟭y;䑞ve;䅭Āiy㟵㟺rc耻û䃻;䑃ƀabh㠃㠆㠋ròᎭlac;䅱aòᏃĀir㠓㠘sht;楾;쀀𝔲rave耻ù䃹š㠧㠱rĀlr㠬㠮»ॗ»ႃlk;斀Āct㠹㡍ɯ㠿\0\0㡊rnĀ;e㡅㡆挜r»㡆op;挏ri;旸Āal㡖㡚cr;䅫肻¨͉Āgp㡢㡦on;䅳f;쀀𝕦̀adhlsuᅋ㡸㡽፲㢑㢠ownáᎳarpoonĀlr㢈㢌efô㠭ighô㠯iƀ;hl㢙㢚㢜䏅»ᏺon»㢚parrows;懈ƀcit㢰㣄㣈ɯ㢶\0\0㣁rnĀ;e㢼㢽挝r»㢽op;挎ng;䅯ri;旹cr;쀀𝓊ƀdir㣙㣝㣢ot;拰lde;䅩iĀ;f㜰㣨»᠓Āam㣯㣲rò㢨l耻ü䃼angle;榧ހABDacdeflnoprsz㤜㤟㤩㤭㦵㦸㦽㧟㧤㧨㧳㧹㧽㨁㨠ròϷarĀ;v㤦㤧櫨;櫩asèϡĀnr㤲㤷grt;榜΀eknprst㓣㥆㥋㥒㥝㥤㦖appá␕othinçẖƀhir㓫⻈㥙opô⾵Ā;hᎷ㥢ïㆍĀiu㥩㥭gmá㎳Ābp㥲㦄setneqĀ;q㥽㦀쀀⊊︀;쀀⫋︀setneqĀ;q㦏㦒쀀⊋︀;쀀⫌︀Āhr㦛㦟etá㚜iangleĀlr㦪㦯eft»थight»ၑy;䐲ash»ံƀelr㧄㧒㧗ƀ;beⷪ㧋㧏ar;抻q;扚lip;拮Ābt㧜ᑨaòᑩr;쀀𝔳tré㦮suĀbp㧯㧱»ജ»൙pf;쀀𝕧roð໻tré㦴Ācu㨆㨋r;쀀𝓋Ābp㨐㨘nĀEe㦀㨖»㥾nĀEe㦒㨞»㦐igzag;榚΀cefoprs㨶㨻㩖㩛㩔㩡㩪irc;䅵Ādi㩀㩑Ābg㩅㩉ar;機eĀ;qᗺ㩏;扙erp;愘r;쀀𝔴pf;쀀𝕨Ā;eᑹ㩦atèᑹcr;쀀𝓌ૣណ㪇\0㪋\0㪐㪛\0\0㪝㪨㪫㪯\0\0㫃㫎\0㫘ៜ៟tré៑r;쀀𝔵ĀAa㪔㪗ròσrò৶;䎾ĀAa㪡㪤ròθrò৫að✓is;拻ƀdptឤ㪵㪾Āfl㪺ឩ;쀀𝕩imåឲĀAa㫇㫊ròώròਁĀcq㫒ីr;쀀𝓍Āpt៖㫜ré។Ѐacefiosu㫰㫽㬈㬌㬑㬕㬛㬡cĀuy㫶㫻te耻ý䃽;䑏Āiy㬂㬆rc;䅷;䑋n耻¥䂥r;쀀𝔶cy;䑗pf;쀀𝕪cr;쀀𝓎Ācm㬦㬩y;䑎l耻ÿ䃿Ԁacdefhiosw㭂㭈㭔㭘㭤㭩㭭㭴㭺㮀cute;䅺Āay㭍㭒ron;䅾;䐷ot;䅼Āet㭝㭡træᕟa;䎶r;쀀𝔷cy;䐶grarr;懝pf;쀀𝕫cr;쀀𝓏Ājn㮅㮇;怍j;怌'.split("").map((e=>e.charCodeAt(0)))),pD=new Map([[0,65533],[128,8364],[130,8218],[131,402],[132,8222],[133,8230],[134,8224],[135,8225],[136,710],[137,8240],[138,352],[139,8249],[140,338],[142,381],[145,8216],[146,8217],[147,8220],[148,8221],[149,8226],[150,8211],[151,8212],[152,732],[153,8482],[154,353],[155,8250],[156,339],[158,382],[159,376]])
;var hD,fD
;(fD=hD||(hD={}))[fD.NUM=35]="NUM",fD[fD.SEMI=59]="SEMI",fD[fD.EQUALS=61]="EQUALS",
fD[fD.ZERO=48]="ZERO",
fD[fD.NINE=57]="NINE",fD[fD.LOWER_A=97]="LOWER_A",fD[fD.LOWER_F=102]="LOWER_F",
fD[fD.LOWER_X=120]="LOWER_X",
fD[fD.LOWER_Z=122]="LOWER_Z",fD[fD.UPPER_A=65]="UPPER_A",
fD[fD.UPPER_F=70]="UPPER_F",fD[fD.UPPER_Z=90]="UPPER_Z"
;var mD,gD,vD,bD,yD,OD,wD,xD,kD,SD,_D,TD,ED,AD,CD,$D;function PD(e){
return e>=hD.ZERO&&e<=hD.NINE}function DD(e){return e===hD.EQUALS||function(e){
return e>=hD.UPPER_A&&e<=hD.UPPER_Z||e>=hD.LOWER_A&&e<=hD.LOWER_Z||PD(e)}(e)}
(gD=mD||(mD={}))[gD.VALUE_LENGTH=49152]="VALUE_LENGTH",
gD[gD.BRANCH_LENGTH=16256]="BRANCH_LENGTH",
gD[gD.JUMP_TABLE=127]="JUMP_TABLE",(bD=vD||(vD={}))[bD.EntityStart=0]="EntityStart",
bD[bD.NumericStart=1]="NumericStart",
bD[bD.NumericDecimal=2]="NumericDecimal",bD[bD.NumericHex=3]="NumericHex",
bD[bD.NamedEntity=4]="NamedEntity",
(OD=yD||(yD={}))[OD.Legacy=0]="Legacy",OD[OD.Strict=1]="Strict",
OD[OD.Attribute=2]="Attribute";class ID{constructor(e,t,n){
this.decodeTree=e,this.emitCodePoint=t,
this.errors=n,this.state=vD.EntityStart,this.consumed=1,
this.result=0,this.treeIndex=0,this.excess=1,this.decodeMode=yD.Strict}
startEntity(e){
this.decodeMode=e,this.state=vD.EntityStart,this.result=0,this.treeIndex=0,
this.excess=1,this.consumed=1}write(e,t){switch(this.state){case vD.EntityStart:
return e.charCodeAt(t)===hD.NUM?(this.state=vD.NumericStart,
this.consumed+=1,this.stateNumericStart(e,t+1)):(this.state=vD.NamedEntity,
this.stateNamedEntity(e,t));case vD.NumericStart:
return this.stateNumericStart(e,t);case vD.NumericDecimal:
return this.stateNumericDecimal(e,t);case vD.NumericHex:
return this.stateNumericHex(e,t);case vD.NamedEntity:
return this.stateNamedEntity(e,t)}}stateNumericStart(e,t){
return t>=e.length?-1:(32|e.charCodeAt(t))===hD.LOWER_X?(this.state=vD.NumericHex,
this.consumed+=1,
this.stateNumericHex(e,t+1)):(this.state=vD.NumericDecimal,this.stateNumericDecimal(e,t))
}addToNumericResult(e,t,n,r){if(t!==n){const o=n-t
;this.result=this.result*Math.pow(r,o)+Number.parseInt(e.substr(t,o),r),
this.consumed+=o}}stateNumericHex(e,t){const n=t;for(;t<e.length;){
const o=e.charCodeAt(t)
;if(!(PD(o)||(r=o,r>=hD.UPPER_A&&r<=hD.UPPER_F||r>=hD.LOWER_A&&r<=hD.LOWER_F)))return this.addToNumericResult(e,n,t,16),
this.emitNumericEntity(o,3);t+=1}var r;return this.addToNumericResult(e,n,t,16),
-1}stateNumericDecimal(e,t){const n=t;for(;t<e.length;){const r=e.charCodeAt(t)
;if(!PD(r))return this.addToNumericResult(e,n,t,10),this.emitNumericEntity(r,2)
;t+=1}return this.addToNumericResult(e,n,t,10),-1}emitNumericEntity(e,t){var n
;if(this.consumed<=t)return null===(n=this.errors)||void 0===n||n.absenceOfDigitsInNumericCharacterReference(this.consumed),
0;if(e===hD.SEMI)this.consumed+=1;else if(this.decodeMode===yD.Strict)return 0
;return this.emitCodePoint(function(e){var t
;return e>=55296&&e<=57343||e>1114111?65533:null!==(t=pD.get(e))&&void 0!==t?t:e
}(this.result),this.consumed),
this.errors&&(e!==hD.SEMI&&this.errors.missingSemicolonAfterCharacterReference(),
this.errors.validateNumericCharacterReference(this.result)),this.consumed}
stateNamedEntity(e,t){const{decodeTree:n}=this
;let r=n[this.treeIndex],o=(r&mD.VALUE_LENGTH)>>14
;for(;t<e.length;t++,this.excess++){const a=e.charCodeAt(t)
;if(this.treeIndex=MD(n,r,this.treeIndex+Math.max(1,o),a),
this.treeIndex<0)return 0===this.result||this.decodeMode===yD.Attribute&&(0===o||DD(a))?0:this.emitNotTerminatedNamedEntity()
;if(r=n[this.treeIndex],o=(r&mD.VALUE_LENGTH)>>14,0!==o){
if(a===hD.SEMI)return this.emitNamedEntityData(this.treeIndex,o,this.consumed+this.excess)
;this.decodeMode!==yD.Strict&&(this.result=this.treeIndex,
this.consumed+=this.excess,this.excess=0)}}return-1}
emitNotTerminatedNamedEntity(){var e
;const{result:t,decodeTree:n}=this,r=(n[t]&mD.VALUE_LENGTH)>>14
;return this.emitNamedEntityData(t,r,this.consumed),
null===(e=this.errors)||void 0===e||e.missingSemicolonAfterCharacterReference(),
this.consumed}emitNamedEntityData(e,t,n){const{decodeTree:r}=this
;return this.emitCodePoint(1===t?r[e]&~mD.VALUE_LENGTH:r[e+1],n),
3===t&&this.emitCodePoint(r[e+2],n),n}end(){var e;switch(this.state){
case vD.NamedEntity:
return 0===this.result||this.decodeMode===yD.Attribute&&this.result!==this.treeIndex?0:this.emitNotTerminatedNamedEntity()
;case vD.NumericDecimal:return this.emitNumericEntity(0,2);case vD.NumericHex:
return this.emitNumericEntity(0,3);case vD.NumericStart:
return null===(e=this.errors)||void 0===e||e.absenceOfDigitsInNumericCharacterReference(this.consumed),
0;case vD.EntityStart:return 0}}}function MD(e,t,n,r){
const o=(t&mD.BRANCH_LENGTH)>>7,a=t&mD.JUMP_TABLE
;if(0===o)return 0!==a&&r===a?n:-1;if(a){const t=r-a
;return t<0||t>=o?-1:e[n+t]-1}let i=n,s=i+o-1;for(;i<=s;){const t=i+s>>>1,n=e[t]
;if(n<r)i=t+1;else{if(!(n>r))return e[t+o];s=t-1}}return-1}
(xD=wD||(wD={})).HTML="http://www.w3.org/1999/xhtml",
xD.MATHML="http://www.w3.org/1998/Math/MathML",
xD.SVG="http://www.w3.org/2000/svg",
xD.XLINK="http://www.w3.org/1999/xlink",xD.XML="http://www.w3.org/XML/1998/namespace",
xD.XMLNS="http://www.w3.org/2000/xmlns/",
(SD=kD||(kD={})).TYPE="type",SD.ACTION="action",
SD.ENCODING="encoding",SD.PROMPT="prompt",
SD.NAME="name",SD.COLOR="color",SD.FACE="face",
SD.SIZE="size",(TD=_D||(_D={})).NO_QUIRKS="no-quirks",
TD.QUIRKS="quirks",TD.LIMITED_QUIRKS="limited-quirks",
(AD=ED||(ED={})).A="a",AD.ADDRESS="address",
AD.ANNOTATION_XML="annotation-xml",AD.APPLET="applet",
AD.AREA="area",AD.ARTICLE="article",
AD.ASIDE="aside",AD.B="b",AD.BASE="base",AD.BASEFONT="basefont",
AD.BGSOUND="bgsound",
AD.BIG="big",AD.BLOCKQUOTE="blockquote",AD.BODY="body",AD.BR="br",
AD.BUTTON="button",
AD.CAPTION="caption",AD.CENTER="center",AD.CODE="code",AD.COL="col",
AD.COLGROUP="colgroup",
AD.DD="dd",AD.DESC="desc",AD.DETAILS="details",AD.DIALOG="dialog",
AD.DIR="dir",AD.DIV="div",
AD.DL="dl",AD.DT="dt",AD.EM="em",AD.EMBED="embed",AD.FIELDSET="fieldset",
AD.FIGCAPTION="figcaption",AD.FIGURE="figure",AD.FONT="font",AD.FOOTER="footer",
AD.FOREIGN_OBJECT="foreignObject",
AD.FORM="form",AD.FRAME="frame",AD.FRAMESET="frameset",
AD.H1="h1",AD.H2="h2",AD.H3="h3",
AD.H4="h4",AD.H5="h5",AD.H6="h6",AD.HEAD="head",
AD.HEADER="header",AD.HGROUP="hgroup",
AD.HR="hr",AD.HTML="html",AD.I="i",AD.IMG="img",
AD.IMAGE="image",AD.INPUT="input",
AD.IFRAME="iframe",AD.KEYGEN="keygen",AD.LABEL="label",
AD.LI="li",AD.LINK="link",
AD.LISTING="listing",AD.MAIN="main",AD.MALIGNMARK="malignmark",
AD.MARQUEE="marquee",
AD.MATH="math",AD.MENU="menu",AD.META="meta",AD.MGLYPH="mglyph",
AD.MI="mi",AD.MO="mo",
AD.MN="mn",AD.MS="ms",AD.MTEXT="mtext",AD.NAV="nav",AD.NOBR="nobr",
AD.NOFRAMES="noframes",
AD.NOEMBED="noembed",AD.NOSCRIPT="noscript",AD.OBJECT="object",
AD.OL="ol",AD.OPTGROUP="optgroup",
AD.OPTION="option",AD.P="p",AD.PARAM="param",AD.PLAINTEXT="plaintext",
AD.PRE="pre",
AD.RB="rb",AD.RP="rp",AD.RT="rt",AD.RTC="rtc",AD.RUBY="ruby",AD.S="s",
AD.SCRIPT="script",
AD.SEARCH="search",AD.SECTION="section",AD.SELECT="select",AD.SOURCE="source",
AD.SMALL="small",
AD.SPAN="span",AD.STRIKE="strike",AD.STRONG="strong",AD.STYLE="style",
AD.SUB="sub",
AD.SUMMARY="summary",AD.SUP="sup",AD.TABLE="table",AD.TBODY="tbody",
AD.TEMPLATE="template",
AD.TEXTAREA="textarea",AD.TFOOT="tfoot",AD.TD="td",AD.TH="th",
AD.THEAD="thead",AD.TITLE="title",
AD.TR="tr",AD.TRACK="track",AD.TT="tt",AD.U="u",
AD.UL="ul",AD.SVG="svg",AD.VAR="var",
AD.WBR="wbr",AD.XMP="xmp",($D=CD||(CD={}))[$D.UNKNOWN=0]="UNKNOWN",
$D[$D.A=1]="A",
$D[$D.ADDRESS=2]="ADDRESS",$D[$D.ANNOTATION_XML=3]="ANNOTATION_XML",
$D[$D.APPLET=4]="APPLET",
$D[$D.AREA=5]="AREA",$D[$D.ARTICLE=6]="ARTICLE",$D[$D.ASIDE=7]="ASIDE",
$D[$D.B=8]="B",
$D[$D.BASE=9]="BASE",$D[$D.BASEFONT=10]="BASEFONT",$D[$D.BGSOUND=11]="BGSOUND",
$D[$D.BIG=12]="BIG",
$D[$D.BLOCKQUOTE=13]="BLOCKQUOTE",$D[$D.BODY=14]="BODY",$D[$D.BR=15]="BR",
$D[$D.BUTTON=16]="BUTTON",$D[$D.CAPTION=17]="CAPTION",$D[$D.CENTER=18]="CENTER",
$D[$D.CODE=19]="CODE",
$D[$D.COL=20]="COL",$D[$D.COLGROUP=21]="COLGROUP",$D[$D.DD=22]="DD",
$D[$D.DESC=23]="DESC",
$D[$D.DETAILS=24]="DETAILS",$D[$D.DIALOG=25]="DIALOG",$D[$D.DIR=26]="DIR",
$D[$D.DIV=27]="DIV",
$D[$D.DL=28]="DL",$D[$D.DT=29]="DT",$D[$D.EM=30]="EM",$D[$D.EMBED=31]="EMBED",
$D[$D.FIELDSET=32]="FIELDSET",
$D[$D.FIGCAPTION=33]="FIGCAPTION",$D[$D.FIGURE=34]="FIGURE",
$D[$D.FONT=35]="FONT",
$D[$D.FOOTER=36]="FOOTER",$D[$D.FOREIGN_OBJECT=37]="FOREIGN_OBJECT",
$D[$D.FORM=38]="FORM",
$D[$D.FRAME=39]="FRAME",$D[$D.FRAMESET=40]="FRAMESET",$D[$D.H1=41]="H1",
$D[$D.H2=42]="H2",
$D[$D.H3=43]="H3",$D[$D.H4=44]="H4",$D[$D.H5=45]="H5",$D[$D.H6=46]="H6",
$D[$D.HEAD=47]="HEAD",
$D[$D.HEADER=48]="HEADER",$D[$D.HGROUP=49]="HGROUP",$D[$D.HR=50]="HR",
$D[$D.HTML=51]="HTML",
$D[$D.I=52]="I",$D[$D.IMG=53]="IMG",$D[$D.IMAGE=54]="IMAGE",
$D[$D.INPUT=55]="INPUT",
$D[$D.IFRAME=56]="IFRAME",$D[$D.KEYGEN=57]="KEYGEN",$D[$D.LABEL=58]="LABEL",
$D[$D.LI=59]="LI",
$D[$D.LINK=60]="LINK",$D[$D.LISTING=61]="LISTING",$D[$D.MAIN=62]="MAIN",
$D[$D.MALIGNMARK=63]="MALIGNMARK",
$D[$D.MARQUEE=64]="MARQUEE",$D[$D.MATH=65]="MATH",
$D[$D.MENU=66]="MENU",$D[$D.META=67]="META",
$D[$D.MGLYPH=68]="MGLYPH",$D[$D.MI=69]="MI",$D[$D.MO=70]="MO",$D[$D.MN=71]="MN",
$D[$D.MS=72]="MS",
$D[$D.MTEXT=73]="MTEXT",$D[$D.NAV=74]="NAV",$D[$D.NOBR=75]="NOBR",
$D[$D.NOFRAMES=76]="NOFRAMES",
$D[$D.NOEMBED=77]="NOEMBED",$D[$D.NOSCRIPT=78]="NOSCRIPT",
$D[$D.OBJECT=79]="OBJECT",
$D[$D.OL=80]="OL",$D[$D.OPTGROUP=81]="OPTGROUP",$D[$D.OPTION=82]="OPTION",
$D[$D.P=83]="P",
$D[$D.PARAM=84]="PARAM",$D[$D.PLAINTEXT=85]="PLAINTEXT",$D[$D.PRE=86]="PRE",
$D[$D.RB=87]="RB",
$D[$D.RP=88]="RP",$D[$D.RT=89]="RT",$D[$D.RTC=90]="RTC",$D[$D.RUBY=91]="RUBY",
$D[$D.S=92]="S",
$D[$D.SCRIPT=93]="SCRIPT",$D[$D.SEARCH=94]="SEARCH",$D[$D.SECTION=95]="SECTION",
$D[$D.SELECT=96]="SELECT",
$D[$D.SOURCE=97]="SOURCE",$D[$D.SMALL=98]="SMALL",$D[$D.SPAN=99]="SPAN",
$D[$D.STRIKE=100]="STRIKE",
$D[$D.STRONG=101]="STRONG",$D[$D.STYLE=102]="STYLE",$D[$D.SUB=103]="SUB",
$D[$D.SUMMARY=104]="SUMMARY",
$D[$D.SUP=105]="SUP",$D[$D.TABLE=106]="TABLE",$D[$D.TBODY=107]="TBODY",
$D[$D.TEMPLATE=108]="TEMPLATE",
$D[$D.TEXTAREA=109]="TEXTAREA",$D[$D.TFOOT=110]="TFOOT",
$D[$D.TD=111]="TD",$D[$D.TH=112]="TH",
$D[$D.THEAD=113]="THEAD",$D[$D.TITLE=114]="TITLE",
$D[$D.TR=115]="TR",$D[$D.TRACK=116]="TRACK",$D[$D.TT=117]="TT",$D[$D.U=118]="U",
$D[$D.UL=119]="UL",
$D[$D.SVG=120]="SVG",$D[$D.VAR=121]="VAR",$D[$D.WBR=122]="WBR",
$D[$D.XMP=123]="XMP"
;const ND=new Map([[ED.A,CD.A],[ED.ADDRESS,CD.ADDRESS],[ED.ANNOTATION_XML,CD.ANNOTATION_XML],[ED.APPLET,CD.APPLET],[ED.AREA,CD.AREA],[ED.ARTICLE,CD.ARTICLE],[ED.ASIDE,CD.ASIDE],[ED.B,CD.B],[ED.BASE,CD.BASE],[ED.BASEFONT,CD.BASEFONT],[ED.BGSOUND,CD.BGSOUND],[ED.BIG,CD.BIG],[ED.BLOCKQUOTE,CD.BLOCKQUOTE],[ED.BODY,CD.BODY],[ED.BR,CD.BR],[ED.BUTTON,CD.BUTTON],[ED.CAPTION,CD.CAPTION],[ED.CENTER,CD.CENTER],[ED.CODE,CD.CODE],[ED.COL,CD.COL],[ED.COLGROUP,CD.COLGROUP],[ED.DD,CD.DD],[ED.DESC,CD.DESC],[ED.DETAILS,CD.DETAILS],[ED.DIALOG,CD.DIALOG],[ED.DIR,CD.DIR],[ED.DIV,CD.DIV],[ED.DL,CD.DL],[ED.DT,CD.DT],[ED.EM,CD.EM],[ED.EMBED,CD.EMBED],[ED.FIELDSET,CD.FIELDSET],[ED.FIGCAPTION,CD.FIGCAPTION],[ED.FIGURE,CD.FIGURE],[ED.FONT,CD.FONT],[ED.FOOTER,CD.FOOTER],[ED.FOREIGN_OBJECT,CD.FOREIGN_OBJECT],[ED.FORM,CD.FORM],[ED.FRAME,CD.FRAME],[ED.FRAMESET,CD.FRAMESET],[ED.H1,CD.H1],[ED.H2,CD.H2],[ED.H3,CD.H3],[ED.H4,CD.H4],[ED.H5,CD.H5],[ED.H6,CD.H6],[ED.HEAD,CD.HEAD],[ED.HEADER,CD.HEADER],[ED.HGROUP,CD.HGROUP],[ED.HR,CD.HR],[ED.HTML,CD.HTML],[ED.I,CD.I],[ED.IMG,CD.IMG],[ED.IMAGE,CD.IMAGE],[ED.INPUT,CD.INPUT],[ED.IFRAME,CD.IFRAME],[ED.KEYGEN,CD.KEYGEN],[ED.LABEL,CD.LABEL],[ED.LI,CD.LI],[ED.LINK,CD.LINK],[ED.LISTING,CD.LISTING],[ED.MAIN,CD.MAIN],[ED.MALIGNMARK,CD.MALIGNMARK],[ED.MARQUEE,CD.MARQUEE],[ED.MATH,CD.MATH],[ED.MENU,CD.MENU],[ED.META,CD.META],[ED.MGLYPH,CD.MGLYPH],[ED.MI,CD.MI],[ED.MO,CD.MO],[ED.MN,CD.MN],[ED.MS,CD.MS],[ED.MTEXT,CD.MTEXT],[ED.NAV,CD.NAV],[ED.NOBR,CD.NOBR],[ED.NOFRAMES,CD.NOFRAMES],[ED.NOEMBED,CD.NOEMBED],[ED.NOSCRIPT,CD.NOSCRIPT],[ED.OBJECT,CD.OBJECT],[ED.OL,CD.OL],[ED.OPTGROUP,CD.OPTGROUP],[ED.OPTION,CD.OPTION],[ED.P,CD.P],[ED.PARAM,CD.PARAM],[ED.PLAINTEXT,CD.PLAINTEXT],[ED.PRE,CD.PRE],[ED.RB,CD.RB],[ED.RP,CD.RP],[ED.RT,CD.RT],[ED.RTC,CD.RTC],[ED.RUBY,CD.RUBY],[ED.S,CD.S],[ED.SCRIPT,CD.SCRIPT],[ED.SEARCH,CD.SEARCH],[ED.SECTION,CD.SECTION],[ED.SELECT,CD.SELECT],[ED.SOURCE,CD.SOURCE],[ED.SMALL,CD.SMALL],[ED.SPAN,CD.SPAN],[ED.STRIKE,CD.STRIKE],[ED.STRONG,CD.STRONG],[ED.STYLE,CD.STYLE],[ED.SUB,CD.SUB],[ED.SUMMARY,CD.SUMMARY],[ED.SUP,CD.SUP],[ED.TABLE,CD.TABLE],[ED.TBODY,CD.TBODY],[ED.TEMPLATE,CD.TEMPLATE],[ED.TEXTAREA,CD.TEXTAREA],[ED.TFOOT,CD.TFOOT],[ED.TD,CD.TD],[ED.TH,CD.TH],[ED.THEAD,CD.THEAD],[ED.TITLE,CD.TITLE],[ED.TR,CD.TR],[ED.TRACK,CD.TRACK],[ED.TT,CD.TT],[ED.U,CD.U],[ED.UL,CD.UL],[ED.SVG,CD.SVG],[ED.VAR,CD.VAR],[ED.WBR,CD.WBR],[ED.XMP,CD.XMP]])
;function RD(e){var t;return null!==(t=ND.get(e))&&void 0!==t?t:CD.UNKNOWN}
const LD=CD,BD={
[wD.HTML]:new Set([LD.ADDRESS,LD.APPLET,LD.AREA,LD.ARTICLE,LD.ASIDE,LD.BASE,LD.BASEFONT,LD.BGSOUND,LD.BLOCKQUOTE,LD.BODY,LD.BR,LD.BUTTON,LD.CAPTION,LD.CENTER,LD.COL,LD.COLGROUP,LD.DD,LD.DETAILS,LD.DIR,LD.DIV,LD.DL,LD.DT,LD.EMBED,LD.FIELDSET,LD.FIGCAPTION,LD.FIGURE,LD.FOOTER,LD.FORM,LD.FRAME,LD.FRAMESET,LD.H1,LD.H2,LD.H3,LD.H4,LD.H5,LD.H6,LD.HEAD,LD.HEADER,LD.HGROUP,LD.HR,LD.HTML,LD.IFRAME,LD.IMG,LD.INPUT,LD.LI,LD.LINK,LD.LISTING,LD.MAIN,LD.MARQUEE,LD.MENU,LD.META,LD.NAV,LD.NOEMBED,LD.NOFRAMES,LD.NOSCRIPT,LD.OBJECT,LD.OL,LD.P,LD.PARAM,LD.PLAINTEXT,LD.PRE,LD.SCRIPT,LD.SECTION,LD.SELECT,LD.SOURCE,LD.STYLE,LD.SUMMARY,LD.TABLE,LD.TBODY,LD.TD,LD.TEMPLATE,LD.TEXTAREA,LD.TFOOT,LD.TH,LD.THEAD,LD.TITLE,LD.TR,LD.TRACK,LD.UL,LD.WBR,LD.XMP]),
[wD.MATHML]:new Set([LD.MI,LD.MO,LD.MN,LD.MS,LD.MTEXT,LD.ANNOTATION_XML]),
[wD.SVG]:new Set([LD.TITLE,LD.FOREIGN_OBJECT,LD.DESC]),[wD.XLINK]:new Set,
[wD.XML]:new Set,[wD.XMLNS]:new Set
},jD=new Set([LD.H1,LD.H2,LD.H3,LD.H4,LD.H5,LD.H6]);var UD,zD
;ED.STYLE,ED.SCRIPT,
ED.XMP,ED.IFRAME,ED.NOEMBED,ED.NOFRAMES,ED.PLAINTEXT,(zD=UD||(UD={}))[zD.DATA=0]="DATA",
zD[zD.RCDATA=1]="RCDATA",
zD[zD.RAWTEXT=2]="RAWTEXT",zD[zD.SCRIPT_DATA=3]="SCRIPT_DATA",
zD[zD.PLAINTEXT=4]="PLAINTEXT",
zD[zD.TAG_OPEN=5]="TAG_OPEN",zD[zD.END_TAG_OPEN=6]="END_TAG_OPEN",
zD[zD.TAG_NAME=7]="TAG_NAME",
zD[zD.RCDATA_LESS_THAN_SIGN=8]="RCDATA_LESS_THAN_SIGN",
zD[zD.RCDATA_END_TAG_OPEN=9]="RCDATA_END_TAG_OPEN",
zD[zD.RCDATA_END_TAG_NAME=10]="RCDATA_END_TAG_NAME",
zD[zD.RAWTEXT_LESS_THAN_SIGN=11]="RAWTEXT_LESS_THAN_SIGN",
zD[zD.RAWTEXT_END_TAG_OPEN=12]="RAWTEXT_END_TAG_OPEN",
zD[zD.RAWTEXT_END_TAG_NAME=13]="RAWTEXT_END_TAG_NAME",
zD[zD.SCRIPT_DATA_LESS_THAN_SIGN=14]="SCRIPT_DATA_LESS_THAN_SIGN",
zD[zD.SCRIPT_DATA_END_TAG_OPEN=15]="SCRIPT_DATA_END_TAG_OPEN",
zD[zD.SCRIPT_DATA_END_TAG_NAME=16]="SCRIPT_DATA_END_TAG_NAME",
zD[zD.SCRIPT_DATA_ESCAPE_START=17]="SCRIPT_DATA_ESCAPE_START",
zD[zD.SCRIPT_DATA_ESCAPE_START_DASH=18]="SCRIPT_DATA_ESCAPE_START_DASH",
zD[zD.SCRIPT_DATA_ESCAPED=19]="SCRIPT_DATA_ESCAPED",
zD[zD.SCRIPT_DATA_ESCAPED_DASH=20]="SCRIPT_DATA_ESCAPED_DASH",
zD[zD.SCRIPT_DATA_ESCAPED_DASH_DASH=21]="SCRIPT_DATA_ESCAPED_DASH_DASH",
zD[zD.SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN=22]="SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN",
zD[zD.SCRIPT_DATA_ESCAPED_END_TAG_OPEN=23]="SCRIPT_DATA_ESCAPED_END_TAG_OPEN",
zD[zD.SCRIPT_DATA_ESCAPED_END_TAG_NAME=24]="SCRIPT_DATA_ESCAPED_END_TAG_NAME",
zD[zD.SCRIPT_DATA_DOUBLE_ESCAPE_START=25]="SCRIPT_DATA_DOUBLE_ESCAPE_START",
zD[zD.SCRIPT_DATA_DOUBLE_ESCAPED=26]="SCRIPT_DATA_DOUBLE_ESCAPED",
zD[zD.SCRIPT_DATA_DOUBLE_ESCAPED_DASH=27]="SCRIPT_DATA_DOUBLE_ESCAPED_DASH",
zD[zD.SCRIPT_DATA_DOUBLE_ESCAPED_DASH_DASH=28]="SCRIPT_DATA_DOUBLE_ESCAPED_DASH_DASH",
zD[zD.SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN=29]="SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN",
zD[zD.SCRIPT_DATA_DOUBLE_ESCAPE_END=30]="SCRIPT_DATA_DOUBLE_ESCAPE_END",
zD[zD.BEFORE_ATTRIBUTE_NAME=31]="BEFORE_ATTRIBUTE_NAME",
zD[zD.ATTRIBUTE_NAME=32]="ATTRIBUTE_NAME",
zD[zD.AFTER_ATTRIBUTE_NAME=33]="AFTER_ATTRIBUTE_NAME",
zD[zD.BEFORE_ATTRIBUTE_VALUE=34]="BEFORE_ATTRIBUTE_VALUE",
zD[zD.ATTRIBUTE_VALUE_DOUBLE_QUOTED=35]="ATTRIBUTE_VALUE_DOUBLE_QUOTED",
zD[zD.ATTRIBUTE_VALUE_SINGLE_QUOTED=36]="ATTRIBUTE_VALUE_SINGLE_QUOTED",
zD[zD.ATTRIBUTE_VALUE_UNQUOTED=37]="ATTRIBUTE_VALUE_UNQUOTED",
zD[zD.AFTER_ATTRIBUTE_VALUE_QUOTED=38]="AFTER_ATTRIBUTE_VALUE_QUOTED",
zD[zD.SELF_CLOSING_START_TAG=39]="SELF_CLOSING_START_TAG",
zD[zD.BOGUS_COMMENT=40]="BOGUS_COMMENT",
zD[zD.MARKUP_DECLARATION_OPEN=41]="MARKUP_DECLARATION_OPEN",
zD[zD.COMMENT_START=42]="COMMENT_START",
zD[zD.COMMENT_START_DASH=43]="COMMENT_START_DASH",
zD[zD.COMMENT=44]="COMMENT",zD[zD.COMMENT_LESS_THAN_SIGN=45]="COMMENT_LESS_THAN_SIGN",
zD[zD.COMMENT_LESS_THAN_SIGN_BANG=46]="COMMENT_LESS_THAN_SIGN_BANG",
zD[zD.COMMENT_LESS_THAN_SIGN_BANG_DASH=47]="COMMENT_LESS_THAN_SIGN_BANG_DASH",
zD[zD.COMMENT_LESS_THAN_SIGN_BANG_DASH_DASH=48]="COMMENT_LESS_THAN_SIGN_BANG_DASH_DASH",
zD[zD.COMMENT_END_DASH=49]="COMMENT_END_DASH",
zD[zD.COMMENT_END=50]="COMMENT_END",
zD[zD.COMMENT_END_BANG=51]="COMMENT_END_BANG",
zD[zD.DOCTYPE=52]="DOCTYPE",zD[zD.BEFORE_DOCTYPE_NAME=53]="BEFORE_DOCTYPE_NAME",
zD[zD.DOCTYPE_NAME=54]="DOCTYPE_NAME",
zD[zD.AFTER_DOCTYPE_NAME=55]="AFTER_DOCTYPE_NAME",
zD[zD.AFTER_DOCTYPE_PUBLIC_KEYWORD=56]="AFTER_DOCTYPE_PUBLIC_KEYWORD",
zD[zD.BEFORE_DOCTYPE_PUBLIC_IDENTIFIER=57]="BEFORE_DOCTYPE_PUBLIC_IDENTIFIER",
zD[zD.DOCTYPE_PUBLIC_IDENTIFIER_DOUBLE_QUOTED=58]="DOCTYPE_PUBLIC_IDENTIFIER_DOUBLE_QUOTED",
zD[zD.DOCTYPE_PUBLIC_IDENTIFIER_SINGLE_QUOTED=59]="DOCTYPE_PUBLIC_IDENTIFIER_SINGLE_QUOTED",
zD[zD.AFTER_DOCTYPE_PUBLIC_IDENTIFIER=60]="AFTER_DOCTYPE_PUBLIC_IDENTIFIER",
zD[zD.BETWEEN_DOCTYPE_PUBLIC_AND_SYSTEM_IDENTIFIERS=61]="BETWEEN_DOCTYPE_PUBLIC_AND_SYSTEM_IDENTIFIERS",
zD[zD.AFTER_DOCTYPE_SYSTEM_KEYWORD=62]="AFTER_DOCTYPE_SYSTEM_KEYWORD",
zD[zD.BEFORE_DOCTYPE_SYSTEM_IDENTIFIER=63]="BEFORE_DOCTYPE_SYSTEM_IDENTIFIER",
zD[zD.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED=64]="DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED",
zD[zD.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED=65]="DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED",
zD[zD.AFTER_DOCTYPE_SYSTEM_IDENTIFIER=66]="AFTER_DOCTYPE_SYSTEM_IDENTIFIER",
zD[zD.BOGUS_DOCTYPE=67]="BOGUS_DOCTYPE",zD[zD.CDATA_SECTION=68]="CDATA_SECTION",
zD[zD.CDATA_SECTION_BRACKET=69]="CDATA_SECTION_BRACKET",
zD[zD.CDATA_SECTION_END=70]="CDATA_SECTION_END",
zD[zD.CHARACTER_REFERENCE=71]="CHARACTER_REFERENCE",
zD[zD.AMBIGUOUS_AMPERSAND=72]="AMBIGUOUS_AMPERSAND";const FD={DATA:UD.DATA,
RCDATA:UD.RCDATA,RAWTEXT:UD.RAWTEXT,SCRIPT_DATA:UD.SCRIPT_DATA,
PLAINTEXT:UD.PLAINTEXT,CDATA_SECTION:UD.CDATA_SECTION};function ZD(e){
return e>=WP.LATIN_CAPITAL_A&&e<=WP.LATIN_CAPITAL_Z}function QD(e){
return function(e){return e>=WP.LATIN_SMALL_A&&e<=WP.LATIN_SMALL_Z}(e)||ZD(e)}
function HD(e){return QD(e)||function(e){return e>=WP.DIGIT_0&&e<=WP.DIGIT_9}(e)
}function VD(e){return e+32}function qD(e){
return e===WP.SPACE||e===WP.LINE_FEED||e===WP.TABULATION||e===WP.FORM_FEED}
function WD(e){return qD(e)||e===WP.SOLIDUS||e===WP.GREATER_THAN_SIGN}class XD{
constructor(e,t){
this.options=e,this.handler=t,this.paused=!1,this.inLoop=!1,this.inForeignNode=!1,
this.lastStartTagName="",
this.active=!1,this.state=UD.DATA,this.returnState=UD.DATA,
this.entityStartPos=0,
this.consumedAfterSnapshot=-1,this.currentCharacterToken=null,
this.currentToken=null,this.currentAttr={name:"",value:""
},this.preprocessor=new sD(t),
this.currentLocation=this.getCurrentLocation(-1),this.entityDecoder=new ID(dD,((e,t)=>{
this.preprocessor.pos=this.entityStartPos+t-1,
this._flushCodePointConsumedAsCharacterReference(e)}),t.onParseError?{
missingSemicolonAfterCharacterReference:()=>{
this._err(aD.missingSemicolonAfterCharacterReference,1)},
absenceOfDigitsInNumericCharacterReference:e=>{
this._err(aD.absenceOfDigitsInNumericCharacterReference,this.entityStartPos-this.preprocessor.pos+e)
},validateNumericCharacterReference:e=>{const t=function(e){
return e===WP.NULL?aD.nullCharacterReference:e>1114111?aD.characterReferenceOutsideUnicodeRange:nD(e)?aD.surrogateCharacterReference:oD(e)?aD.noncharacterCharacterReference:rD(e)||e===WP.CARRIAGE_RETURN?aD.controlCharacterReference:null
}(e);t&&this._err(t,1)}}:void 0)}_err(e,t=0){var n,r
;null===(r=(n=this.handler).onParseError)||void 0===r||r.call(n,this.preprocessor.getError(e,t))
}getCurrentLocation(e){return this.options.sourceCodeLocationInfo?{
startLine:this.preprocessor.line,startCol:this.preprocessor.col-e,
startOffset:this.preprocessor.offset-e,endLine:-1,endCol:-1,endOffset:-1}:null}
_runParsingLoop(){if(!this.inLoop){
for(this.inLoop=!0;this.active&&!this.paused;){this.consumedAfterSnapshot=0
;const e=this._consume();this._ensureHibernation()||this._callState(e)}
this.inLoop=!1}}pause(){this.paused=!0}resume(e){
if(!this.paused)throw new Error("Parser was already resumed")
;this.paused=!1,this.inLoop||(this._runParsingLoop(),this.paused||null==e||e())}
write(e,t,n){this.active=!0,this.preprocessor.write(e,t),this._runParsingLoop(),
this.paused||null==n||n()}insertHtmlAtCurrentPos(e){
this.active=!0,this.preprocessor.insertHtmlAtCurrentPos(e),
this._runParsingLoop()}_ensureHibernation(){
return!!this.preprocessor.endOfChunkHit&&(this.preprocessor.retreat(this.consumedAfterSnapshot),
this.consumedAfterSnapshot=0,this.active=!1,!0)}_consume(){
return this.consumedAfterSnapshot++,this.preprocessor.advance()}_advanceBy(e){
this.consumedAfterSnapshot+=e;for(let t=0;t<e;t++)this.preprocessor.advance()}
_consumeSequenceIfMatch(e,t){
return!!this.preprocessor.startsWith(e,t)&&(this._advanceBy(e.length-1),!0)}
_createStartTagToken(){this.currentToken={type:lD.START_TAG,tagName:"",
tagID:CD.UNKNOWN,selfClosing:!1,ackSelfClosing:!1,attrs:[],
location:this.getCurrentLocation(1)}}_createEndTagToken(){this.currentToken={
type:lD.END_TAG,tagName:"",tagID:CD.UNKNOWN,selfClosing:!1,ackSelfClosing:!1,
attrs:[],location:this.getCurrentLocation(2)}}_createCommentToken(e){
this.currentToken={type:lD.COMMENT,data:"",location:this.getCurrentLocation(e)}}
_createDoctypeToken(e){this.currentToken={type:lD.DOCTYPE,name:e,forceQuirks:!1,
publicId:null,systemId:null,location:this.currentLocation}}
_createCharacterToken(e,t){this.currentCharacterToken={type:e,chars:t,
location:this.currentLocation}}_createAttr(e){this.currentAttr={name:e,value:""
},this.currentLocation=this.getCurrentLocation(0)}_leaveAttrName(){var e,t
;const n=this.currentToken;if(null===uD(n,this.currentAttr.name)){
if(n.attrs.push(this.currentAttr),n.location&&this.currentLocation){
(null!==(e=(t=n.location).attrs)&&void 0!==e?e:t.attrs=Object.create(null))[this.currentAttr.name]=this.currentLocation,
this._leaveAttrValue()}}else this._err(aD.duplicateAttribute)}_leaveAttrValue(){
this.currentLocation&&(this.currentLocation.endLine=this.preprocessor.line,
this.currentLocation.endCol=this.preprocessor.col,
this.currentLocation.endOffset=this.preprocessor.offset)}prepareToken(e){
this._emitCurrentCharacterToken(e.location),
this.currentToken=null,e.location&&(e.location.endLine=this.preprocessor.line,
e.location.endCol=this.preprocessor.col+1,
e.location.endOffset=this.preprocessor.offset+1),
this.currentLocation=this.getCurrentLocation(-1)}emitCurrentTagToken(){
const e=this.currentToken
;this.prepareToken(e),e.tagID=RD(e.tagName),e.type===lD.START_TAG?(this.lastStartTagName=e.tagName,
this.handler.onStartTag(e)):(e.attrs.length>0&&this._err(aD.endTagWithAttributes),
e.selfClosing&&this._err(aD.endTagWithTrailingSolidus),
this.handler.onEndTag(e)),this.preprocessor.dropParsedChunk()}
emitCurrentComment(e){
this.prepareToken(e),this.handler.onComment(e),this.preprocessor.dropParsedChunk()
}emitCurrentDoctype(e){
this.prepareToken(e),this.handler.onDoctype(e),this.preprocessor.dropParsedChunk()
}_emitCurrentCharacterToken(e){if(this.currentCharacterToken){
switch(e&&this.currentCharacterToken.location&&(this.currentCharacterToken.location.endLine=e.startLine,
this.currentCharacterToken.location.endCol=e.startCol,
this.currentCharacterToken.location.endOffset=e.startOffset),
this.currentCharacterToken.type){case lD.CHARACTER:
this.handler.onCharacter(this.currentCharacterToken);break
;case lD.NULL_CHARACTER:this.handler.onNullCharacter(this.currentCharacterToken)
;break;case lD.WHITESPACE_CHARACTER:
this.handler.onWhitespaceCharacter(this.currentCharacterToken)}
this.currentCharacterToken=null}}_emitEOFToken(){
const e=this.getCurrentLocation(0)
;e&&(e.endLine=e.startLine,e.endCol=e.startCol,
e.endOffset=e.startOffset),this._emitCurrentCharacterToken(e),
this.handler.onEof({type:lD.EOF,location:e}),this.active=!1}
_appendCharToCurrentCharacterToken(e,t){if(this.currentCharacterToken){
if(this.currentCharacterToken.type===e)return void(this.currentCharacterToken.chars+=t)
;this.currentLocation=this.getCurrentLocation(0),
this._emitCurrentCharacterToken(this.currentLocation),
this.preprocessor.dropParsedChunk()}this._createCharacterToken(e,t)}
_emitCodePoint(e){
const t=qD(e)?lD.WHITESPACE_CHARACTER:e===WP.NULL?lD.NULL_CHARACTER:lD.CHARACTER
;this._appendCharToCurrentCharacterToken(t,String.fromCodePoint(e))}
_emitChars(e){this._appendCharToCurrentCharacterToken(lD.CHARACTER,e)}
_startCharacterReference(){
this.returnState=this.state,this.state=UD.CHARACTER_REFERENCE,
this.entityStartPos=this.preprocessor.pos,
this.entityDecoder.startEntity(this._isCharacterReferenceInAttribute()?yD.Attribute:yD.Legacy)
}_isCharacterReferenceInAttribute(){
return this.returnState===UD.ATTRIBUTE_VALUE_DOUBLE_QUOTED||this.returnState===UD.ATTRIBUTE_VALUE_SINGLE_QUOTED||this.returnState===UD.ATTRIBUTE_VALUE_UNQUOTED
}_flushCodePointConsumedAsCharacterReference(e){
this._isCharacterReferenceInAttribute()?this.currentAttr.value+=String.fromCodePoint(e):this._emitCodePoint(e)
}_callState(e){switch(this.state){case UD.DATA:this._stateData(e);break
;case UD.RCDATA:this._stateRcdata(e);break;case UD.RAWTEXT:this._stateRawtext(e)
;break;case UD.SCRIPT_DATA:this._stateScriptData(e);break;case UD.PLAINTEXT:
this._statePlaintext(e);break;case UD.TAG_OPEN:this._stateTagOpen(e);break
;case UD.END_TAG_OPEN:this._stateEndTagOpen(e);break;case UD.TAG_NAME:
this._stateTagName(e);break;case UD.RCDATA_LESS_THAN_SIGN:
this._stateRcdataLessThanSign(e);break;case UD.RCDATA_END_TAG_OPEN:
this._stateRcdataEndTagOpen(e);break;case UD.RCDATA_END_TAG_NAME:
this._stateRcdataEndTagName(e);break;case UD.RAWTEXT_LESS_THAN_SIGN:
this._stateRawtextLessThanSign(e);break;case UD.RAWTEXT_END_TAG_OPEN:
this._stateRawtextEndTagOpen(e);break;case UD.RAWTEXT_END_TAG_NAME:
this._stateRawtextEndTagName(e);break;case UD.SCRIPT_DATA_LESS_THAN_SIGN:
this._stateScriptDataLessThanSign(e);break;case UD.SCRIPT_DATA_END_TAG_OPEN:
this._stateScriptDataEndTagOpen(e);break;case UD.SCRIPT_DATA_END_TAG_NAME:
this._stateScriptDataEndTagName(e);break;case UD.SCRIPT_DATA_ESCAPE_START:
this._stateScriptDataEscapeStart(e);break;case UD.SCRIPT_DATA_ESCAPE_START_DASH:
this._stateScriptDataEscapeStartDash(e);break;case UD.SCRIPT_DATA_ESCAPED:
this._stateScriptDataEscaped(e);break;case UD.SCRIPT_DATA_ESCAPED_DASH:
this._stateScriptDataEscapedDash(e);break;case UD.SCRIPT_DATA_ESCAPED_DASH_DASH:
this._stateScriptDataEscapedDashDash(e);break
;case UD.SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN:
this._stateScriptDataEscapedLessThanSign(e);break
;case UD.SCRIPT_DATA_ESCAPED_END_TAG_OPEN:
this._stateScriptDataEscapedEndTagOpen(e);break
;case UD.SCRIPT_DATA_ESCAPED_END_TAG_NAME:
this._stateScriptDataEscapedEndTagName(e);break
;case UD.SCRIPT_DATA_DOUBLE_ESCAPE_START:
this._stateScriptDataDoubleEscapeStart(e);break
;case UD.SCRIPT_DATA_DOUBLE_ESCAPED:this._stateScriptDataDoubleEscaped(e);break
;case UD.SCRIPT_DATA_DOUBLE_ESCAPED_DASH:
this._stateScriptDataDoubleEscapedDash(e);break
;case UD.SCRIPT_DATA_DOUBLE_ESCAPED_DASH_DASH:
this._stateScriptDataDoubleEscapedDashDash(e);break
;case UD.SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN:
this._stateScriptDataDoubleEscapedLessThanSign(e);break
;case UD.SCRIPT_DATA_DOUBLE_ESCAPE_END:this._stateScriptDataDoubleEscapeEnd(e)
;break;case UD.BEFORE_ATTRIBUTE_NAME:this._stateBeforeAttributeName(e);break
;case UD.ATTRIBUTE_NAME:this._stateAttributeName(e);break
;case UD.AFTER_ATTRIBUTE_NAME:this._stateAfterAttributeName(e);break
;case UD.BEFORE_ATTRIBUTE_VALUE:this._stateBeforeAttributeValue(e);break
;case UD.ATTRIBUTE_VALUE_DOUBLE_QUOTED:this._stateAttributeValueDoubleQuoted(e)
;break;case UD.ATTRIBUTE_VALUE_SINGLE_QUOTED:
this._stateAttributeValueSingleQuoted(e);break;case UD.ATTRIBUTE_VALUE_UNQUOTED:
this._stateAttributeValueUnquoted(e);break;case UD.AFTER_ATTRIBUTE_VALUE_QUOTED:
this._stateAfterAttributeValueQuoted(e);break;case UD.SELF_CLOSING_START_TAG:
this._stateSelfClosingStartTag(e);break;case UD.BOGUS_COMMENT:
this._stateBogusComment(e);break;case UD.MARKUP_DECLARATION_OPEN:
this._stateMarkupDeclarationOpen(e);break;case UD.COMMENT_START:
this._stateCommentStart(e);break;case UD.COMMENT_START_DASH:
this._stateCommentStartDash(e);break;case UD.COMMENT:this._stateComment(e);break
;case UD.COMMENT_LESS_THAN_SIGN:this._stateCommentLessThanSign(e);break
;case UD.COMMENT_LESS_THAN_SIGN_BANG:this._stateCommentLessThanSignBang(e);break
;case UD.COMMENT_LESS_THAN_SIGN_BANG_DASH:
this._stateCommentLessThanSignBangDash(e);break
;case UD.COMMENT_LESS_THAN_SIGN_BANG_DASH_DASH:
this._stateCommentLessThanSignBangDashDash(e);break;case UD.COMMENT_END_DASH:
this._stateCommentEndDash(e);break;case UD.COMMENT_END:this._stateCommentEnd(e)
;break;case UD.COMMENT_END_BANG:this._stateCommentEndBang(e);break
;case UD.DOCTYPE:this._stateDoctype(e);break;case UD.BEFORE_DOCTYPE_NAME:
this._stateBeforeDoctypeName(e);break;case UD.DOCTYPE_NAME:
this._stateDoctypeName(e);break;case UD.AFTER_DOCTYPE_NAME:
this._stateAfterDoctypeName(e);break;case UD.AFTER_DOCTYPE_PUBLIC_KEYWORD:
this._stateAfterDoctypePublicKeyword(e);break
;case UD.BEFORE_DOCTYPE_PUBLIC_IDENTIFIER:
this._stateBeforeDoctypePublicIdentifier(e);break
;case UD.DOCTYPE_PUBLIC_IDENTIFIER_DOUBLE_QUOTED:
this._stateDoctypePublicIdentifierDoubleQuoted(e);break
;case UD.DOCTYPE_PUBLIC_IDENTIFIER_SINGLE_QUOTED:
this._stateDoctypePublicIdentifierSingleQuoted(e);break
;case UD.AFTER_DOCTYPE_PUBLIC_IDENTIFIER:
this._stateAfterDoctypePublicIdentifier(e);break
;case UD.BETWEEN_DOCTYPE_PUBLIC_AND_SYSTEM_IDENTIFIERS:
this._stateBetweenDoctypePublicAndSystemIdentifiers(e);break
;case UD.AFTER_DOCTYPE_SYSTEM_KEYWORD:this._stateAfterDoctypeSystemKeyword(e)
;break;case UD.BEFORE_DOCTYPE_SYSTEM_IDENTIFIER:
this._stateBeforeDoctypeSystemIdentifier(e);break
;case UD.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED:
this._stateDoctypeSystemIdentifierDoubleQuoted(e);break
;case UD.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED:
this._stateDoctypeSystemIdentifierSingleQuoted(e);break
;case UD.AFTER_DOCTYPE_SYSTEM_IDENTIFIER:
this._stateAfterDoctypeSystemIdentifier(e);break;case UD.BOGUS_DOCTYPE:
this._stateBogusDoctype(e);break;case UD.CDATA_SECTION:
this._stateCdataSection(e);break;case UD.CDATA_SECTION_BRACKET:
this._stateCdataSectionBracket(e);break;case UD.CDATA_SECTION_END:
this._stateCdataSectionEnd(e);break;case UD.CHARACTER_REFERENCE:
this._stateCharacterReference();break;case UD.AMBIGUOUS_AMPERSAND:
this._stateAmbiguousAmpersand(e);break;default:throw new Error("Unknown state")}
}_stateData(e){switch(e){case WP.LESS_THAN_SIGN:this.state=UD.TAG_OPEN;break
;case WP.AMPERSAND:this._startCharacterReference();break;case WP.NULL:
this._err(aD.unexpectedNullCharacter),this._emitCodePoint(e);break;case WP.EOF:
this._emitEOFToken();break;default:this._emitCodePoint(e)}}_stateRcdata(e){
switch(e){case WP.AMPERSAND:this._startCharacterReference();break
;case WP.LESS_THAN_SIGN:this.state=UD.RCDATA_LESS_THAN_SIGN;break;case WP.NULL:
this._err(aD.unexpectedNullCharacter),this._emitChars(qP);break;case WP.EOF:
this._emitEOFToken();break;default:this._emitCodePoint(e)}}_stateRawtext(e){
switch(e){case WP.LESS_THAN_SIGN:this.state=UD.RAWTEXT_LESS_THAN_SIGN;break
;case WP.NULL:this._err(aD.unexpectedNullCharacter),this._emitChars(qP);break
;case WP.EOF:this._emitEOFToken();break;default:this._emitCodePoint(e)}}
_stateScriptData(e){switch(e){case WP.LESS_THAN_SIGN:
this.state=UD.SCRIPT_DATA_LESS_THAN_SIGN;break;case WP.NULL:
this._err(aD.unexpectedNullCharacter),this._emitChars(qP);break;case WP.EOF:
this._emitEOFToken();break;default:this._emitCodePoint(e)}}_statePlaintext(e){
switch(e){case WP.NULL:this._err(aD.unexpectedNullCharacter),this._emitChars(qP)
;break;case WP.EOF:this._emitEOFToken();break;default:this._emitCodePoint(e)}}
_stateTagOpen(e){
if(QD(e))this._createStartTagToken(),this.state=UD.TAG_NAME,this._stateTagName(e);else switch(e){
case WP.EXCLAMATION_MARK:this.state=UD.MARKUP_DECLARATION_OPEN;break
;case WP.SOLIDUS:this.state=UD.END_TAG_OPEN;break;case WP.QUESTION_MARK:
this._err(aD.unexpectedQuestionMarkInsteadOfTagName),
this._createCommentToken(1),
this.state=UD.BOGUS_COMMENT,this._stateBogusComment(e);break;case WP.EOF:
this._err(aD.eofBeforeTagName),this._emitChars("<"),this._emitEOFToken();break
;default:
this._err(aD.invalidFirstCharacterOfTagName),this._emitChars("<"),this.state=UD.DATA,
this._stateData(e)}}_stateEndTagOpen(e){
if(QD(e))this._createEndTagToken(),this.state=UD.TAG_NAME,
this._stateTagName(e);else switch(e){case WP.GREATER_THAN_SIGN:
this._err(aD.missingEndTagName),this.state=UD.DATA;break;case WP.EOF:
this._err(aD.eofBeforeTagName),this._emitChars("</"),this._emitEOFToken();break
;default:
this._err(aD.invalidFirstCharacterOfTagName),this._createCommentToken(2),
this.state=UD.BOGUS_COMMENT,this._stateBogusComment(e)}}_stateTagName(e){
const t=this.currentToken;switch(e){case WP.SPACE:case WP.LINE_FEED:
case WP.TABULATION:case WP.FORM_FEED:this.state=UD.BEFORE_ATTRIBUTE_NAME;break
;case WP.SOLIDUS:this.state=UD.SELF_CLOSING_START_TAG;break
;case WP.GREATER_THAN_SIGN:this.state=UD.DATA,this.emitCurrentTagToken();break
;case WP.NULL:this._err(aD.unexpectedNullCharacter),t.tagName+=qP;break
;case WP.EOF:this._err(aD.eofInTag),this._emitEOFToken();break;default:
t.tagName+=String.fromCodePoint(ZD(e)?VD(e):e)}}_stateRcdataLessThanSign(e){
e===WP.SOLIDUS?this.state=UD.RCDATA_END_TAG_OPEN:(this._emitChars("<"),
this.state=UD.RCDATA,this._stateRcdata(e))}_stateRcdataEndTagOpen(e){
QD(e)?(this.state=UD.RCDATA_END_TAG_NAME,
this._stateRcdataEndTagName(e)):(this._emitChars("</"),
this.state=UD.RCDATA,this._stateRcdata(e))}handleSpecialEndTag(e){
if(!this.preprocessor.startsWith(this.lastStartTagName,!1))return!this._ensureHibernation()
;this._createEndTagToken();this.currentToken.tagName=this.lastStartTagName
;switch(this.preprocessor.peek(this.lastStartTagName.length)){case WP.SPACE:
case WP.LINE_FEED:case WP.TABULATION:case WP.FORM_FEED:
return this._advanceBy(this.lastStartTagName.length),
this.state=UD.BEFORE_ATTRIBUTE_NAME,!1;case WP.SOLIDUS:
return this._advanceBy(this.lastStartTagName.length),
this.state=UD.SELF_CLOSING_START_TAG,!1;case WP.GREATER_THAN_SIGN:
return this._advanceBy(this.lastStartTagName.length),this.emitCurrentTagToken(),
this.state=UD.DATA,!1;default:return!this._ensureHibernation()}}
_stateRcdataEndTagName(e){
this.handleSpecialEndTag(e)&&(this._emitChars("</"),this.state=UD.RCDATA,
this._stateRcdata(e))}_stateRawtextLessThanSign(e){
e===WP.SOLIDUS?this.state=UD.RAWTEXT_END_TAG_OPEN:(this._emitChars("<"),
this.state=UD.RAWTEXT,this._stateRawtext(e))}_stateRawtextEndTagOpen(e){
QD(e)?(this.state=UD.RAWTEXT_END_TAG_NAME,
this._stateRawtextEndTagName(e)):(this._emitChars("</"),
this.state=UD.RAWTEXT,this._stateRawtext(e))}_stateRawtextEndTagName(e){
this.handleSpecialEndTag(e)&&(this._emitChars("</"),
this.state=UD.RAWTEXT,this._stateRawtext(e))}_stateScriptDataLessThanSign(e){
switch(e){case WP.SOLIDUS:this.state=UD.SCRIPT_DATA_END_TAG_OPEN;break
;case WP.EXCLAMATION_MARK:
this.state=UD.SCRIPT_DATA_ESCAPE_START,this._emitChars("<!");break;default:
this._emitChars("<"),this.state=UD.SCRIPT_DATA,this._stateScriptData(e)}}
_stateScriptDataEndTagOpen(e){
QD(e)?(this.state=UD.SCRIPT_DATA_END_TAG_NAME,this._stateScriptDataEndTagName(e)):(this._emitChars("</"),
this.state=UD.SCRIPT_DATA,this._stateScriptData(e))}
_stateScriptDataEndTagName(e){
this.handleSpecialEndTag(e)&&(this._emitChars("</"),
this.state=UD.SCRIPT_DATA,this._stateScriptData(e))}
_stateScriptDataEscapeStart(e){
e===WP.HYPHEN_MINUS?(this.state=UD.SCRIPT_DATA_ESCAPE_START_DASH,
this._emitChars("-")):(this.state=UD.SCRIPT_DATA,this._stateScriptData(e))}
_stateScriptDataEscapeStartDash(e){
e===WP.HYPHEN_MINUS?(this.state=UD.SCRIPT_DATA_ESCAPED_DASH_DASH,
this._emitChars("-")):(this.state=UD.SCRIPT_DATA,this._stateScriptData(e))}
_stateScriptDataEscaped(e){switch(e){case WP.HYPHEN_MINUS:
this.state=UD.SCRIPT_DATA_ESCAPED_DASH,this._emitChars("-");break
;case WP.LESS_THAN_SIGN:this.state=UD.SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN;break
;case WP.NULL:this._err(aD.unexpectedNullCharacter),this._emitChars(qP);break
;case WP.EOF:this._err(aD.eofInScriptHtmlCommentLikeText),this._emitEOFToken()
;break;default:this._emitCodePoint(e)}}_stateScriptDataEscapedDash(e){switch(e){
case WP.HYPHEN_MINUS:
this.state=UD.SCRIPT_DATA_ESCAPED_DASH_DASH,this._emitChars("-");break
;case WP.LESS_THAN_SIGN:this.state=UD.SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN;break
;case WP.NULL:
this._err(aD.unexpectedNullCharacter),this.state=UD.SCRIPT_DATA_ESCAPED,
this._emitChars(qP);break;case WP.EOF:
this._err(aD.eofInScriptHtmlCommentLikeText),this._emitEOFToken();break;default:
this.state=UD.SCRIPT_DATA_ESCAPED,this._emitCodePoint(e)}}
_stateScriptDataEscapedDashDash(e){switch(e){case WP.HYPHEN_MINUS:
this._emitChars("-");break;case WP.LESS_THAN_SIGN:
this.state=UD.SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN;break
;case WP.GREATER_THAN_SIGN:this.state=UD.SCRIPT_DATA,this._emitChars(">");break
;case WP.NULL:
this._err(aD.unexpectedNullCharacter),this.state=UD.SCRIPT_DATA_ESCAPED,
this._emitChars(qP);break;case WP.EOF:
this._err(aD.eofInScriptHtmlCommentLikeText),this._emitEOFToken();break;default:
this.state=UD.SCRIPT_DATA_ESCAPED,this._emitCodePoint(e)}}
_stateScriptDataEscapedLessThanSign(e){
e===WP.SOLIDUS?this.state=UD.SCRIPT_DATA_ESCAPED_END_TAG_OPEN:QD(e)?(this._emitChars("<"),
this.state=UD.SCRIPT_DATA_DOUBLE_ESCAPE_START,
this._stateScriptDataDoubleEscapeStart(e)):(this._emitChars("<"),
this.state=UD.SCRIPT_DATA_ESCAPED,this._stateScriptDataEscaped(e))}
_stateScriptDataEscapedEndTagOpen(e){
QD(e)?(this.state=UD.SCRIPT_DATA_ESCAPED_END_TAG_NAME,
this._stateScriptDataEscapedEndTagName(e)):(this._emitChars("</"),
this.state=UD.SCRIPT_DATA_ESCAPED,this._stateScriptDataEscaped(e))}
_stateScriptDataEscapedEndTagName(e){
this.handleSpecialEndTag(e)&&(this._emitChars("</"),
this.state=UD.SCRIPT_DATA_ESCAPED,this._stateScriptDataEscaped(e))}
_stateScriptDataDoubleEscapeStart(e){
if(this.preprocessor.startsWith(JP,!1)&&WD(this.preprocessor.peek(JP.length))){
this._emitCodePoint(e)
;for(let e=0;e<JP.length;e++)this._emitCodePoint(this._consume())
;this.state=UD.SCRIPT_DATA_DOUBLE_ESCAPED
}else this._ensureHibernation()||(this.state=UD.SCRIPT_DATA_ESCAPED,
this._stateScriptDataEscaped(e))}_stateScriptDataDoubleEscaped(e){switch(e){
case WP.HYPHEN_MINUS:
this.state=UD.SCRIPT_DATA_DOUBLE_ESCAPED_DASH,this._emitChars("-");break
;case WP.LESS_THAN_SIGN:this.state=UD.SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN,
this._emitChars("<");break;case WP.NULL:
this._err(aD.unexpectedNullCharacter),this._emitChars(qP);break;case WP.EOF:
this._err(aD.eofInScriptHtmlCommentLikeText),this._emitEOFToken();break;default:
this._emitCodePoint(e)}}_stateScriptDataDoubleEscapedDash(e){switch(e){
case WP.HYPHEN_MINUS:
this.state=UD.SCRIPT_DATA_DOUBLE_ESCAPED_DASH_DASH,this._emitChars("-");break
;case WP.LESS_THAN_SIGN:this.state=UD.SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN,
this._emitChars("<");break;case WP.NULL:
this._err(aD.unexpectedNullCharacter),this.state=UD.SCRIPT_DATA_DOUBLE_ESCAPED,
this._emitChars(qP);break;case WP.EOF:
this._err(aD.eofInScriptHtmlCommentLikeText),this._emitEOFToken();break;default:
this.state=UD.SCRIPT_DATA_DOUBLE_ESCAPED,this._emitCodePoint(e)}}
_stateScriptDataDoubleEscapedDashDash(e){switch(e){case WP.HYPHEN_MINUS:
this._emitChars("-");break;case WP.LESS_THAN_SIGN:
this.state=UD.SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN,this._emitChars("<")
;break;case WP.GREATER_THAN_SIGN:this.state=UD.SCRIPT_DATA,this._emitChars(">")
;break;case WP.NULL:
this._err(aD.unexpectedNullCharacter),this.state=UD.SCRIPT_DATA_DOUBLE_ESCAPED,
this._emitChars(qP);break;case WP.EOF:
this._err(aD.eofInScriptHtmlCommentLikeText),this._emitEOFToken();break;default:
this.state=UD.SCRIPT_DATA_DOUBLE_ESCAPED,this._emitCodePoint(e)}}
_stateScriptDataDoubleEscapedLessThanSign(e){
e===WP.SOLIDUS?(this.state=UD.SCRIPT_DATA_DOUBLE_ESCAPE_END,
this._emitChars("/")):(this.state=UD.SCRIPT_DATA_DOUBLE_ESCAPED,
this._stateScriptDataDoubleEscaped(e))}_stateScriptDataDoubleEscapeEnd(e){
if(this.preprocessor.startsWith(JP,!1)&&WD(this.preprocessor.peek(JP.length))){
this._emitCodePoint(e)
;for(let e=0;e<JP.length;e++)this._emitCodePoint(this._consume())
;this.state=UD.SCRIPT_DATA_ESCAPED
}else this._ensureHibernation()||(this.state=UD.SCRIPT_DATA_DOUBLE_ESCAPED,
this._stateScriptDataDoubleEscaped(e))}_stateBeforeAttributeName(e){switch(e){
case WP.SPACE:case WP.LINE_FEED:case WP.TABULATION:case WP.FORM_FEED:break
;case WP.SOLIDUS:case WP.GREATER_THAN_SIGN:case WP.EOF:
this.state=UD.AFTER_ATTRIBUTE_NAME,this._stateAfterAttributeName(e);break
;case WP.EQUALS_SIGN:
this._err(aD.unexpectedEqualsSignBeforeAttributeName),this._createAttr("="),
this.state=UD.ATTRIBUTE_NAME;break;default:
this._createAttr(""),this.state=UD.ATTRIBUTE_NAME,this._stateAttributeName(e)}}
_stateAttributeName(e){switch(e){case WP.SPACE:case WP.LINE_FEED:
case WP.TABULATION:case WP.FORM_FEED:case WP.SOLIDUS:case WP.GREATER_THAN_SIGN:
case WP.EOF:
this._leaveAttrName(),this.state=UD.AFTER_ATTRIBUTE_NAME,this._stateAfterAttributeName(e)
;break;case WP.EQUALS_SIGN:
this._leaveAttrName(),this.state=UD.BEFORE_ATTRIBUTE_VALUE;break
;case WP.QUOTATION_MARK:case WP.APOSTROPHE:case WP.LESS_THAN_SIGN:
this._err(aD.unexpectedCharacterInAttributeName),
this.currentAttr.name+=String.fromCodePoint(e);break;case WP.NULL:
this._err(aD.unexpectedNullCharacter),this.currentAttr.name+=qP;break;default:
this.currentAttr.name+=String.fromCodePoint(ZD(e)?VD(e):e)}}
_stateAfterAttributeName(e){switch(e){case WP.SPACE:case WP.LINE_FEED:
case WP.TABULATION:case WP.FORM_FEED:break;case WP.SOLIDUS:
this.state=UD.SELF_CLOSING_START_TAG;break;case WP.EQUALS_SIGN:
this.state=UD.BEFORE_ATTRIBUTE_VALUE;break;case WP.GREATER_THAN_SIGN:
this.state=UD.DATA,this.emitCurrentTagToken();break;case WP.EOF:
this._err(aD.eofInTag),this._emitEOFToken();break;default:
this._createAttr(""),this.state=UD.ATTRIBUTE_NAME,this._stateAttributeName(e)}}
_stateBeforeAttributeValue(e){switch(e){case WP.SPACE:case WP.LINE_FEED:
case WP.TABULATION:case WP.FORM_FEED:break;case WP.QUOTATION_MARK:
this.state=UD.ATTRIBUTE_VALUE_DOUBLE_QUOTED;break;case WP.APOSTROPHE:
this.state=UD.ATTRIBUTE_VALUE_SINGLE_QUOTED;break;case WP.GREATER_THAN_SIGN:
this._err(aD.missingAttributeValue),
this.state=UD.DATA,this.emitCurrentTagToken();break;default:
this.state=UD.ATTRIBUTE_VALUE_UNQUOTED,this._stateAttributeValueUnquoted(e)}}
_stateAttributeValueDoubleQuoted(e){switch(e){case WP.QUOTATION_MARK:
this.state=UD.AFTER_ATTRIBUTE_VALUE_QUOTED;break;case WP.AMPERSAND:
this._startCharacterReference();break;case WP.NULL:
this._err(aD.unexpectedNullCharacter),this.currentAttr.value+=qP;break
;case WP.EOF:this._err(aD.eofInTag),this._emitEOFToken();break;default:
this.currentAttr.value+=String.fromCodePoint(e)}}
_stateAttributeValueSingleQuoted(e){switch(e){case WP.APOSTROPHE:
this.state=UD.AFTER_ATTRIBUTE_VALUE_QUOTED;break;case WP.AMPERSAND:
this._startCharacterReference();break;case WP.NULL:
this._err(aD.unexpectedNullCharacter),this.currentAttr.value+=qP;break
;case WP.EOF:this._err(aD.eofInTag),this._emitEOFToken();break;default:
this.currentAttr.value+=String.fromCodePoint(e)}}
_stateAttributeValueUnquoted(e){switch(e){case WP.SPACE:case WP.LINE_FEED:
case WP.TABULATION:case WP.FORM_FEED:
this._leaveAttrValue(),this.state=UD.BEFORE_ATTRIBUTE_NAME;break
;case WP.AMPERSAND:this._startCharacterReference();break
;case WP.GREATER_THAN_SIGN:
this._leaveAttrValue(),this.state=UD.DATA,this.emitCurrentTagToken();break
;case WP.NULL:this._err(aD.unexpectedNullCharacter),this.currentAttr.value+=qP
;break;case WP.QUOTATION_MARK:case WP.APOSTROPHE:case WP.LESS_THAN_SIGN:
case WP.EQUALS_SIGN:case WP.GRAVE_ACCENT:
this._err(aD.unexpectedCharacterInUnquotedAttributeValue),
this.currentAttr.value+=String.fromCodePoint(e);break;case WP.EOF:
this._err(aD.eofInTag),this._emitEOFToken();break;default:
this.currentAttr.value+=String.fromCodePoint(e)}}
_stateAfterAttributeValueQuoted(e){switch(e){case WP.SPACE:case WP.LINE_FEED:
case WP.TABULATION:case WP.FORM_FEED:
this._leaveAttrValue(),this.state=UD.BEFORE_ATTRIBUTE_NAME;break
;case WP.SOLIDUS:this._leaveAttrValue(),this.state=UD.SELF_CLOSING_START_TAG
;break;case WP.GREATER_THAN_SIGN:
this._leaveAttrValue(),this.state=UD.DATA,this.emitCurrentTagToken();break
;case WP.EOF:this._err(aD.eofInTag),this._emitEOFToken();break;default:
this._err(aD.missingWhitespaceBetweenAttributes),
this.state=UD.BEFORE_ATTRIBUTE_NAME,this._stateBeforeAttributeName(e)}}
_stateSelfClosingStartTag(e){switch(e){case WP.GREATER_THAN_SIGN:
this.currentToken.selfClosing=!0,this.state=UD.DATA,this.emitCurrentTagToken()
;break;case WP.EOF:this._err(aD.eofInTag),this._emitEOFToken();break;default:
this._err(aD.unexpectedSolidusInTag),
this.state=UD.BEFORE_ATTRIBUTE_NAME,this._stateBeforeAttributeName(e)}}
_stateBogusComment(e){const t=this.currentToken;switch(e){
case WP.GREATER_THAN_SIGN:this.state=UD.DATA,this.emitCurrentComment(t);break
;case WP.EOF:this.emitCurrentComment(t),this._emitEOFToken();break;case WP.NULL:
this._err(aD.unexpectedNullCharacter),t.data+=qP;break;default:
t.data+=String.fromCodePoint(e)}}_stateMarkupDeclarationOpen(e){
this._consumeSequenceIfMatch(GP,!0)?(this._createCommentToken(GP.length+1),
this.state=UD.COMMENT_START):this._consumeSequenceIfMatch(KP,!1)?(this.currentLocation=this.getCurrentLocation(KP.length+1),
this.state=UD.DOCTYPE):this._consumeSequenceIfMatch(YP,!0)?this.inForeignNode?this.state=UD.CDATA_SECTION:(this._err(aD.cdataInHtmlContent),
this._createCommentToken(YP.length+1),
this.currentToken.data="[CDATA[",this.state=UD.BOGUS_COMMENT):this._ensureHibernation()||(this._err(aD.incorrectlyOpenedComment),
this._createCommentToken(2),
this.state=UD.BOGUS_COMMENT,this._stateBogusComment(e))}_stateCommentStart(e){
switch(e){case WP.HYPHEN_MINUS:this.state=UD.COMMENT_START_DASH;break
;case WP.GREATER_THAN_SIGN:{
this._err(aD.abruptClosingOfEmptyComment),this.state=UD.DATA
;const e=this.currentToken;this.emitCurrentComment(e);break}default:
this.state=UD.COMMENT,this._stateComment(e)}}_stateCommentStartDash(e){
const t=this.currentToken;switch(e){case WP.HYPHEN_MINUS:
this.state=UD.COMMENT_END;break;case WP.GREATER_THAN_SIGN:
this._err(aD.abruptClosingOfEmptyComment),
this.state=UD.DATA,this.emitCurrentComment(t);break;case WP.EOF:
this._err(aD.eofInComment),this.emitCurrentComment(t),this._emitEOFToken();break
;default:t.data+="-",this.state=UD.COMMENT,this._stateComment(e)}}
_stateComment(e){const t=this.currentToken;switch(e){case WP.HYPHEN_MINUS:
this.state=UD.COMMENT_END_DASH;break;case WP.LESS_THAN_SIGN:
t.data+="<",this.state=UD.COMMENT_LESS_THAN_SIGN;break;case WP.NULL:
this._err(aD.unexpectedNullCharacter),t.data+=qP;break;case WP.EOF:
this._err(aD.eofInComment),this.emitCurrentComment(t),this._emitEOFToken();break
;default:t.data+=String.fromCodePoint(e)}}_stateCommentLessThanSign(e){
const t=this.currentToken;switch(e){case WP.EXCLAMATION_MARK:
t.data+="!",this.state=UD.COMMENT_LESS_THAN_SIGN_BANG;break
;case WP.LESS_THAN_SIGN:t.data+="<";break;default:
this.state=UD.COMMENT,this._stateComment(e)}}_stateCommentLessThanSignBang(e){
e===WP.HYPHEN_MINUS?this.state=UD.COMMENT_LESS_THAN_SIGN_BANG_DASH:(this.state=UD.COMMENT,
this._stateComment(e))}_stateCommentLessThanSignBangDash(e){
e===WP.HYPHEN_MINUS?this.state=UD.COMMENT_LESS_THAN_SIGN_BANG_DASH_DASH:(this.state=UD.COMMENT_END_DASH,
this._stateCommentEndDash(e))}_stateCommentLessThanSignBangDashDash(e){
e!==WP.GREATER_THAN_SIGN&&e!==WP.EOF&&this._err(aD.nestedComment),
this.state=UD.COMMENT_END,this._stateCommentEnd(e)}_stateCommentEndDash(e){
const t=this.currentToken;switch(e){case WP.HYPHEN_MINUS:
this.state=UD.COMMENT_END;break;case WP.EOF:
this._err(aD.eofInComment),this.emitCurrentComment(t),this._emitEOFToken();break
;default:t.data+="-",this.state=UD.COMMENT,this._stateComment(e)}}
_stateCommentEnd(e){const t=this.currentToken;switch(e){
case WP.GREATER_THAN_SIGN:this.state=UD.DATA,this.emitCurrentComment(t);break
;case WP.EXCLAMATION_MARK:this.state=UD.COMMENT_END_BANG;break
;case WP.HYPHEN_MINUS:t.data+="-";break;case WP.EOF:
this._err(aD.eofInComment),this.emitCurrentComment(t),this._emitEOFToken();break
;default:t.data+="--",this.state=UD.COMMENT,this._stateComment(e)}}
_stateCommentEndBang(e){const t=this.currentToken;switch(e){
case WP.HYPHEN_MINUS:t.data+="--!",this.state=UD.COMMENT_END_DASH;break
;case WP.GREATER_THAN_SIGN:
this._err(aD.incorrectlyClosedComment),this.state=UD.DATA,
this.emitCurrentComment(t);break;case WP.EOF:
this._err(aD.eofInComment),this.emitCurrentComment(t),this._emitEOFToken();break
;default:t.data+="--!",this.state=UD.COMMENT,this._stateComment(e)}}
_stateDoctype(e){switch(e){case WP.SPACE:case WP.LINE_FEED:case WP.TABULATION:
case WP.FORM_FEED:this.state=UD.BEFORE_DOCTYPE_NAME;break
;case WP.GREATER_THAN_SIGN:
this.state=UD.BEFORE_DOCTYPE_NAME,this._stateBeforeDoctypeName(e);break
;case WP.EOF:{this._err(aD.eofInDoctype),this._createDoctypeToken(null)
;const e=this.currentToken
;e.forceQuirks=!0,this.emitCurrentDoctype(e),this._emitEOFToken();break}default:
this._err(aD.missingWhitespaceBeforeDoctypeName),
this.state=UD.BEFORE_DOCTYPE_NAME,this._stateBeforeDoctypeName(e)}}
_stateBeforeDoctypeName(e){
if(ZD(e))this._createDoctypeToken(String.fromCharCode(VD(e))),
this.state=UD.DOCTYPE_NAME;else switch(e){case WP.SPACE:case WP.LINE_FEED:
case WP.TABULATION:case WP.FORM_FEED:break;case WP.NULL:
this._err(aD.unexpectedNullCharacter),
this._createDoctypeToken(qP),this.state=UD.DOCTYPE_NAME;break
;case WP.GREATER_THAN_SIGN:{
this._err(aD.missingDoctypeName),this._createDoctypeToken(null)
;const e=this.currentToken
;e.forceQuirks=!0,this.emitCurrentDoctype(e),this.state=UD.DATA;break}
case WP.EOF:{this._err(aD.eofInDoctype),this._createDoctypeToken(null)
;const e=this.currentToken
;e.forceQuirks=!0,this.emitCurrentDoctype(e),this._emitEOFToken();break}default:
this._createDoctypeToken(String.fromCodePoint(e)),this.state=UD.DOCTYPE_NAME}}
_stateDoctypeName(e){const t=this.currentToken;switch(e){case WP.SPACE:
case WP.LINE_FEED:case WP.TABULATION:case WP.FORM_FEED:
this.state=UD.AFTER_DOCTYPE_NAME;break;case WP.GREATER_THAN_SIGN:
this.state=UD.DATA,this.emitCurrentDoctype(t);break;case WP.NULL:
this._err(aD.unexpectedNullCharacter),t.name+=qP;break;case WP.EOF:
this._err(aD.eofInDoctype),
t.forceQuirks=!0,this.emitCurrentDoctype(t),this._emitEOFToken();break;default:
t.name+=String.fromCodePoint(ZD(e)?VD(e):e)}}_stateAfterDoctypeName(e){
const t=this.currentToken;switch(e){case WP.SPACE:case WP.LINE_FEED:
case WP.TABULATION:case WP.FORM_FEED:break;case WP.GREATER_THAN_SIGN:
this.state=UD.DATA,this.emitCurrentDoctype(t);break;case WP.EOF:
this._err(aD.eofInDoctype),
t.forceQuirks=!0,this.emitCurrentDoctype(t),this._emitEOFToken();break;default:
this._consumeSequenceIfMatch(eD,!1)?this.state=UD.AFTER_DOCTYPE_PUBLIC_KEYWORD:this._consumeSequenceIfMatch(tD,!1)?this.state=UD.AFTER_DOCTYPE_SYSTEM_KEYWORD:this._ensureHibernation()||(this._err(aD.invalidCharacterSequenceAfterDoctypeName),
t.forceQuirks=!0,this.state=UD.BOGUS_DOCTYPE,this._stateBogusDoctype(e))}}
_stateAfterDoctypePublicKeyword(e){const t=this.currentToken;switch(e){
case WP.SPACE:case WP.LINE_FEED:case WP.TABULATION:case WP.FORM_FEED:
this.state=UD.BEFORE_DOCTYPE_PUBLIC_IDENTIFIER;break;case WP.QUOTATION_MARK:
this._err(aD.missingWhitespaceAfterDoctypePublicKeyword),
t.publicId="",this.state=UD.DOCTYPE_PUBLIC_IDENTIFIER_DOUBLE_QUOTED;break
;case WP.APOSTROPHE:
this._err(aD.missingWhitespaceAfterDoctypePublicKeyword),t.publicId="",
this.state=UD.DOCTYPE_PUBLIC_IDENTIFIER_SINGLE_QUOTED;break
;case WP.GREATER_THAN_SIGN:
this._err(aD.missingDoctypePublicIdentifier),t.forceQuirks=!0,
this.state=UD.DATA,this.emitCurrentDoctype(t);break;case WP.EOF:
this._err(aD.eofInDoctype),
t.forceQuirks=!0,this.emitCurrentDoctype(t),this._emitEOFToken();break;default:
this._err(aD.missingQuoteBeforeDoctypePublicIdentifier),
t.forceQuirks=!0,this.state=UD.BOGUS_DOCTYPE,this._stateBogusDoctype(e)}}
_stateBeforeDoctypePublicIdentifier(e){const t=this.currentToken;switch(e){
case WP.SPACE:case WP.LINE_FEED:case WP.TABULATION:case WP.FORM_FEED:break
;case WP.QUOTATION_MARK:
t.publicId="",this.state=UD.DOCTYPE_PUBLIC_IDENTIFIER_DOUBLE_QUOTED;break
;case WP.APOSTROPHE:
t.publicId="",this.state=UD.DOCTYPE_PUBLIC_IDENTIFIER_SINGLE_QUOTED;break
;case WP.GREATER_THAN_SIGN:
this._err(aD.missingDoctypePublicIdentifier),t.forceQuirks=!0,
this.state=UD.DATA,this.emitCurrentDoctype(t);break;case WP.EOF:
this._err(aD.eofInDoctype),
t.forceQuirks=!0,this.emitCurrentDoctype(t),this._emitEOFToken();break;default:
this._err(aD.missingQuoteBeforeDoctypePublicIdentifier),
t.forceQuirks=!0,this.state=UD.BOGUS_DOCTYPE,this._stateBogusDoctype(e)}}
_stateDoctypePublicIdentifierDoubleQuoted(e){const t=this.currentToken
;switch(e){case WP.QUOTATION_MARK:this.state=UD.AFTER_DOCTYPE_PUBLIC_IDENTIFIER
;break;case WP.NULL:this._err(aD.unexpectedNullCharacter),t.publicId+=qP;break
;case WP.GREATER_THAN_SIGN:
this._err(aD.abruptDoctypePublicIdentifier),t.forceQuirks=!0,
this.emitCurrentDoctype(t),this.state=UD.DATA;break;case WP.EOF:
this._err(aD.eofInDoctype),
t.forceQuirks=!0,this.emitCurrentDoctype(t),this._emitEOFToken();break;default:
t.publicId+=String.fromCodePoint(e)}}
_stateDoctypePublicIdentifierSingleQuoted(e){const t=this.currentToken
;switch(e){case WP.APOSTROPHE:this.state=UD.AFTER_DOCTYPE_PUBLIC_IDENTIFIER
;break;case WP.NULL:this._err(aD.unexpectedNullCharacter),t.publicId+=qP;break
;case WP.GREATER_THAN_SIGN:
this._err(aD.abruptDoctypePublicIdentifier),t.forceQuirks=!0,
this.emitCurrentDoctype(t),this.state=UD.DATA;break;case WP.EOF:
this._err(aD.eofInDoctype),
t.forceQuirks=!0,this.emitCurrentDoctype(t),this._emitEOFToken();break;default:
t.publicId+=String.fromCodePoint(e)}}_stateAfterDoctypePublicIdentifier(e){
const t=this.currentToken;switch(e){case WP.SPACE:case WP.LINE_FEED:
case WP.TABULATION:case WP.FORM_FEED:
this.state=UD.BETWEEN_DOCTYPE_PUBLIC_AND_SYSTEM_IDENTIFIERS;break
;case WP.GREATER_THAN_SIGN:this.state=UD.DATA,this.emitCurrentDoctype(t);break
;case WP.QUOTATION_MARK:
this._err(aD.missingWhitespaceBetweenDoctypePublicAndSystemIdentifiers),
t.systemId="",this.state=UD.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED;break
;case WP.APOSTROPHE:
this._err(aD.missingWhitespaceBetweenDoctypePublicAndSystemIdentifiers),
t.systemId="",this.state=UD.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED;break
;case WP.EOF:
this._err(aD.eofInDoctype),t.forceQuirks=!0,this.emitCurrentDoctype(t),
this._emitEOFToken();break;default:
this._err(aD.missingQuoteBeforeDoctypeSystemIdentifier),
t.forceQuirks=!0,this.state=UD.BOGUS_DOCTYPE,this._stateBogusDoctype(e)}}
_stateBetweenDoctypePublicAndSystemIdentifiers(e){const t=this.currentToken
;switch(e){case WP.SPACE:case WP.LINE_FEED:case WP.TABULATION:case WP.FORM_FEED:
break;case WP.GREATER_THAN_SIGN:this.emitCurrentDoctype(t),this.state=UD.DATA
;break;case WP.QUOTATION_MARK:
t.systemId="",this.state=UD.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED;break
;case WP.APOSTROPHE:
t.systemId="",this.state=UD.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED;break
;case WP.EOF:
this._err(aD.eofInDoctype),t.forceQuirks=!0,this.emitCurrentDoctype(t),
this._emitEOFToken();break;default:
this._err(aD.missingQuoteBeforeDoctypeSystemIdentifier),
t.forceQuirks=!0,this.state=UD.BOGUS_DOCTYPE,this._stateBogusDoctype(e)}}
_stateAfterDoctypeSystemKeyword(e){const t=this.currentToken;switch(e){
case WP.SPACE:case WP.LINE_FEED:case WP.TABULATION:case WP.FORM_FEED:
this.state=UD.BEFORE_DOCTYPE_SYSTEM_IDENTIFIER;break;case WP.QUOTATION_MARK:
this._err(aD.missingWhitespaceAfterDoctypeSystemKeyword),
t.systemId="",this.state=UD.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED;break
;case WP.APOSTROPHE:
this._err(aD.missingWhitespaceAfterDoctypeSystemKeyword),t.systemId="",
this.state=UD.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED;break
;case WP.GREATER_THAN_SIGN:
this._err(aD.missingDoctypeSystemIdentifier),t.forceQuirks=!0,
this.state=UD.DATA,this.emitCurrentDoctype(t);break;case WP.EOF:
this._err(aD.eofInDoctype),
t.forceQuirks=!0,this.emitCurrentDoctype(t),this._emitEOFToken();break;default:
this._err(aD.missingQuoteBeforeDoctypeSystemIdentifier),
t.forceQuirks=!0,this.state=UD.BOGUS_DOCTYPE,this._stateBogusDoctype(e)}}
_stateBeforeDoctypeSystemIdentifier(e){const t=this.currentToken;switch(e){
case WP.SPACE:case WP.LINE_FEED:case WP.TABULATION:case WP.FORM_FEED:break
;case WP.QUOTATION_MARK:
t.systemId="",this.state=UD.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED;break
;case WP.APOSTROPHE:
t.systemId="",this.state=UD.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED;break
;case WP.GREATER_THAN_SIGN:
this._err(aD.missingDoctypeSystemIdentifier),t.forceQuirks=!0,
this.state=UD.DATA,this.emitCurrentDoctype(t);break;case WP.EOF:
this._err(aD.eofInDoctype),
t.forceQuirks=!0,this.emitCurrentDoctype(t),this._emitEOFToken();break;default:
this._err(aD.missingQuoteBeforeDoctypeSystemIdentifier),
t.forceQuirks=!0,this.state=UD.BOGUS_DOCTYPE,this._stateBogusDoctype(e)}}
_stateDoctypeSystemIdentifierDoubleQuoted(e){const t=this.currentToken
;switch(e){case WP.QUOTATION_MARK:this.state=UD.AFTER_DOCTYPE_SYSTEM_IDENTIFIER
;break;case WP.NULL:this._err(aD.unexpectedNullCharacter),t.systemId+=qP;break
;case WP.GREATER_THAN_SIGN:
this._err(aD.abruptDoctypeSystemIdentifier),t.forceQuirks=!0,
this.emitCurrentDoctype(t),this.state=UD.DATA;break;case WP.EOF:
this._err(aD.eofInDoctype),
t.forceQuirks=!0,this.emitCurrentDoctype(t),this._emitEOFToken();break;default:
t.systemId+=String.fromCodePoint(e)}}
_stateDoctypeSystemIdentifierSingleQuoted(e){const t=this.currentToken
;switch(e){case WP.APOSTROPHE:this.state=UD.AFTER_DOCTYPE_SYSTEM_IDENTIFIER
;break;case WP.NULL:this._err(aD.unexpectedNullCharacter),t.systemId+=qP;break
;case WP.GREATER_THAN_SIGN:
this._err(aD.abruptDoctypeSystemIdentifier),t.forceQuirks=!0,
this.emitCurrentDoctype(t),this.state=UD.DATA;break;case WP.EOF:
this._err(aD.eofInDoctype),
t.forceQuirks=!0,this.emitCurrentDoctype(t),this._emitEOFToken();break;default:
t.systemId+=String.fromCodePoint(e)}}_stateAfterDoctypeSystemIdentifier(e){
const t=this.currentToken;switch(e){case WP.SPACE:case WP.LINE_FEED:
case WP.TABULATION:case WP.FORM_FEED:break;case WP.GREATER_THAN_SIGN:
this.emitCurrentDoctype(t),this.state=UD.DATA;break;case WP.EOF:
this._err(aD.eofInDoctype),
t.forceQuirks=!0,this.emitCurrentDoctype(t),this._emitEOFToken();break;default:
this._err(aD.unexpectedCharacterAfterDoctypeSystemIdentifier),
this.state=UD.BOGUS_DOCTYPE,this._stateBogusDoctype(e)}}_stateBogusDoctype(e){
const t=this.currentToken;switch(e){case WP.GREATER_THAN_SIGN:
this.emitCurrentDoctype(t),this.state=UD.DATA;break;case WP.NULL:
this._err(aD.unexpectedNullCharacter);break;case WP.EOF:
this.emitCurrentDoctype(t),this._emitEOFToken()}}_stateCdataSection(e){
switch(e){case WP.RIGHT_SQUARE_BRACKET:this.state=UD.CDATA_SECTION_BRACKET;break
;case WP.EOF:this._err(aD.eofInCdata),this._emitEOFToken();break;default:
this._emitCodePoint(e)}}_stateCdataSectionBracket(e){
e===WP.RIGHT_SQUARE_BRACKET?this.state=UD.CDATA_SECTION_END:(this._emitChars("]"),
this.state=UD.CDATA_SECTION,this._stateCdataSection(e))}
_stateCdataSectionEnd(e){switch(e){case WP.GREATER_THAN_SIGN:this.state=UD.DATA
;break;case WP.RIGHT_SQUARE_BRACKET:this._emitChars("]");break;default:
this._emitChars("]]"),this.state=UD.CDATA_SECTION,this._stateCdataSection(e)}}
_stateCharacterReference(){
let e=this.entityDecoder.write(this.preprocessor.html,this.preprocessor.pos)
;if(e<0){
if(!this.preprocessor.lastChunkWritten)return this.active=!1,this.preprocessor.pos=this.preprocessor.html.length-1,
this.consumedAfterSnapshot=0,void(this.preprocessor.endOfChunkHit=!0)
;e=this.entityDecoder.end()}
0===e?(this.preprocessor.pos=this.entityStartPos,this._flushCodePointConsumedAsCharacterReference(WP.AMPERSAND),
this.state=!this._isCharacterReferenceInAttribute()&&HD(this.preprocessor.peek(1))?UD.AMBIGUOUS_AMPERSAND:this.returnState):this.state=this.returnState
}_stateAmbiguousAmpersand(e){
HD(e)?this._flushCodePointConsumedAsCharacterReference(e):(e===WP.SEMICOLON&&this._err(aD.unknownNamedCharacterReference),
this.state=this.returnState,this._callState(e))}}
const GD=new Set([CD.DD,CD.DT,CD.LI,CD.OPTGROUP,CD.OPTION,CD.P,CD.RB,CD.RP,CD.RT,CD.RTC]),YD=new Set([...GD,CD.CAPTION,CD.COLGROUP,CD.TBODY,CD.TD,CD.TFOOT,CD.TH,CD.THEAD,CD.TR]),KD=new Set([CD.APPLET,CD.CAPTION,CD.HTML,CD.MARQUEE,CD.OBJECT,CD.TABLE,CD.TD,CD.TEMPLATE,CD.TH]),JD=new Set([...KD,CD.OL,CD.UL]),eI=new Set([...KD,CD.BUTTON]),tI=new Set([CD.ANNOTATION_XML,CD.MI,CD.MN,CD.MO,CD.MS,CD.MTEXT]),nI=new Set([CD.DESC,CD.FOREIGN_OBJECT,CD.TITLE]),rI=new Set([CD.TR,CD.TEMPLATE,CD.HTML]),oI=new Set([CD.TBODY,CD.TFOOT,CD.THEAD,CD.TEMPLATE,CD.HTML]),aI=new Set([CD.TABLE,CD.TEMPLATE,CD.HTML]),iI=new Set([CD.TD,CD.TH])
;class sI{get currentTmplContentOrNode(){
return this._isInTemplate()?this.treeAdapter.getTemplateContent(this.current):this.current
}constructor(e,t,n){
this.treeAdapter=t,this.handler=n,this.items=[],this.tagIDs=[],this.stackTop=-1,
this.tmplCount=0,this.currentTagId=CD.UNKNOWN,this.current=e}_indexOf(e){
return this.items.lastIndexOf(e,this.stackTop)}_isInTemplate(){
return this.currentTagId===CD.TEMPLATE&&this.treeAdapter.getNamespaceURI(this.current)===wD.HTML
}_updateCurrentElement(){
this.current=this.items[this.stackTop],this.currentTagId=this.tagIDs[this.stackTop]
}push(e,t){
this.stackTop++,this.items[this.stackTop]=e,this.current=e,this.tagIDs[this.stackTop]=t,
this.currentTagId=t,
this._isInTemplate()&&this.tmplCount++,this.handler.onItemPush(e,t,!0)}pop(){
const e=this.current
;this.tmplCount>0&&this._isInTemplate()&&this.tmplCount--,this.stackTop--,
this._updateCurrentElement(),this.handler.onItemPop(e,!0)}replace(e,t){
const n=this._indexOf(e);this.items[n]=t,n===this.stackTop&&(this.current=t)}
insertAfter(e,t,n){const r=this._indexOf(e)+1
;this.items.splice(r,0,t),this.tagIDs.splice(r,0,n),
this.stackTop++,r===this.stackTop&&this._updateCurrentElement(),
this.current&&void 0!==this.currentTagId&&this.handler.onItemPush(this.current,this.currentTagId,r===this.stackTop)
}popUntilTagNamePopped(e){let t=this.stackTop+1;do{
t=this.tagIDs.lastIndexOf(e,t-1)
}while(t>0&&this.treeAdapter.getNamespaceURI(this.items[t])!==wD.HTML)
;this.shortenToLength(Math.max(t,0))}shortenToLength(e){for(;this.stackTop>=e;){
const t=this.current
;this.tmplCount>0&&this._isInTemplate()&&(this.tmplCount-=1),
this.stackTop--,this._updateCurrentElement(),
this.handler.onItemPop(t,this.stackTop<e)}}popUntilElementPopped(e){
const t=this._indexOf(e);this.shortenToLength(Math.max(t,0))}
popUntilPopped(e,t){const n=this._indexOfTagNames(e,t)
;this.shortenToLength(Math.max(n,0))}popUntilNumberedHeaderPopped(){
this.popUntilPopped(jD,wD.HTML)}popUntilTableCellPopped(){
this.popUntilPopped(iI,wD.HTML)}popAllUpToHtmlElement(){
this.tmplCount=0,this.shortenToLength(1)}_indexOfTagNames(e,t){
for(let n=this.stackTop;n>=0;n--)if(e.has(this.tagIDs[n])&&this.treeAdapter.getNamespaceURI(this.items[n])===t)return n
;return-1}clearBackTo(e,t){const n=this._indexOfTagNames(e,t)
;this.shortenToLength(n+1)}clearBackToTableContext(){
this.clearBackTo(aI,wD.HTML)}clearBackToTableBodyContext(){
this.clearBackTo(oI,wD.HTML)}clearBackToTableRowContext(){
this.clearBackTo(rI,wD.HTML)}remove(e){const t=this._indexOf(e)
;t>=0&&(t===this.stackTop?this.pop():(this.items.splice(t,1),
this.tagIDs.splice(t,1),
this.stackTop--,this._updateCurrentElement(),this.handler.onItemPop(e,!1)))}
tryPeekProperlyNestedBodyElement(){
return this.stackTop>=1&&this.tagIDs[1]===CD.BODY?this.items[1]:null}
contains(e){return this._indexOf(e)>-1}getCommonAncestor(e){
const t=this._indexOf(e)-1;return t>=0?this.items[t]:null}
isRootHtmlElementCurrent(){return 0===this.stackTop&&this.tagIDs[0]===CD.HTML}
hasInDynamicScope(e,t){for(let n=this.stackTop;n>=0;n--){const r=this.tagIDs[n]
;switch(this.treeAdapter.getNamespaceURI(this.items[n])){case wD.HTML:
if(r===e)return!0;if(t.has(r))return!1;break;case wD.SVG:if(nI.has(r))return!1
;break;case wD.MATHML:if(tI.has(r))return!1}}return!0}hasInScope(e){
return this.hasInDynamicScope(e,KD)}hasInListItemScope(e){
return this.hasInDynamicScope(e,JD)}hasInButtonScope(e){
return this.hasInDynamicScope(e,eI)}hasNumberedHeaderInScope(){
for(let e=this.stackTop;e>=0;e--){const t=this.tagIDs[e]
;switch(this.treeAdapter.getNamespaceURI(this.items[e])){case wD.HTML:
if(jD.has(t))return!0;if(KD.has(t))return!1;break;case wD.SVG:
if(nI.has(t))return!1;break;case wD.MATHML:if(tI.has(t))return!1}}return!0}
hasInTableScope(e){
for(let t=this.stackTop;t>=0;t--)if(this.treeAdapter.getNamespaceURI(this.items[t])===wD.HTML)switch(this.tagIDs[t]){
case e:return!0;case CD.TABLE:case CD.HTML:return!1}return!0}
hasTableBodyContextInTableScope(){
for(let e=this.stackTop;e>=0;e--)if(this.treeAdapter.getNamespaceURI(this.items[e])===wD.HTML)switch(this.tagIDs[e]){
case CD.TBODY:case CD.THEAD:case CD.TFOOT:return!0;case CD.TABLE:case CD.HTML:
return!1}return!0}hasInSelectScope(e){
for(let t=this.stackTop;t>=0;t--)if(this.treeAdapter.getNamespaceURI(this.items[t])===wD.HTML)switch(this.tagIDs[t]){
case e:return!0;case CD.OPTION:case CD.OPTGROUP:break;default:return!1}return!0}
generateImpliedEndTags(){
for(;void 0!==this.currentTagId&&GD.has(this.currentTagId);)this.pop()}
generateImpliedEndTagsThoroughly(){
for(;void 0!==this.currentTagId&&YD.has(this.currentTagId);)this.pop()}
generateImpliedEndTagsWithExclusion(e){
for(;void 0!==this.currentTagId&&this.currentTagId!==e&&YD.has(this.currentTagId);)this.pop()
}}var lI,cI;(cI=lI||(lI={}))[cI.Marker=0]="Marker",cI[cI.Element=1]="Element"
;const uI={type:lI.Marker};class dI{constructor(e){
this.treeAdapter=e,this.entries=[],this.bookmark=null}
_getNoahArkConditionCandidates(e,t){
const n=[],r=t.length,o=this.treeAdapter.getTagName(e),a=this.treeAdapter.getNamespaceURI(e)
;for(let i=0;i<this.entries.length;i++){const e=this.entries[i]
;if(e.type===lI.Marker)break;const{element:t}=e
;if(this.treeAdapter.getTagName(t)===o&&this.treeAdapter.getNamespaceURI(t)===a){
const e=this.treeAdapter.getAttrList(t);e.length===r&&n.push({idx:i,attrs:e})}}
return n}_ensureNoahArkCondition(e){if(this.entries.length<3)return
;const t=this.treeAdapter.getAttrList(e),n=this._getNoahArkConditionCandidates(e,t)
;if(n.length<3)return;const r=new Map(t.map((e=>[e.name,e.value])));let o=0
;for(let a=0;a<n.length;a++){const e=n[a]
;e.attrs.every((e=>r.get(e.name)===e.value))&&(o+=1,
o>=3&&this.entries.splice(e.idx,1))}}insertMarker(){this.entries.unshift(uI)}
pushElement(e,t){this._ensureNoahArkCondition(e),this.entries.unshift({
type:lI.Element,element:e,token:t})}insertElementAfterBookmark(e,t){
const n=this.entries.indexOf(this.bookmark);this.entries.splice(n,0,{
type:lI.Element,element:e,token:t})}removeEntry(e){
const t=this.entries.indexOf(e);-1!==t&&this.entries.splice(t,1)}
clearToLastMarker(){const e=this.entries.indexOf(uI)
;-1===e?this.entries.length=0:this.entries.splice(0,e+1)}
getElementEntryInScopeWithTagName(e){
const t=this.entries.find((t=>t.type===lI.Marker||this.treeAdapter.getTagName(t.element)===e))
;return t&&t.type===lI.Element?t:null}getElementEntry(e){
return this.entries.find((t=>t.type===lI.Element&&t.element===e))}}const pI={
createDocument:()=>({nodeName:"#document",mode:_D.NO_QUIRKS,childNodes:[]}),
createDocumentFragment:()=>({nodeName:"#document-fragment",childNodes:[]}),
createElement:(e,t,n)=>({nodeName:e,tagName:e,attrs:n,namespaceURI:t,
childNodes:[],parentNode:null}),createCommentNode:e=>({nodeName:"#comment",
data:e,parentNode:null}),createTextNode:e=>({nodeName:"#text",value:e,
parentNode:null}),appendChild(e,t){e.childNodes.push(t),t.parentNode=e},
insertBefore(e,t,n){const r=e.childNodes.indexOf(n)
;e.childNodes.splice(r,0,t),t.parentNode=e},setTemplateContent(e,t){e.content=t
},getTemplateContent:e=>e.content,setDocumentType(e,t,n,r){
const o=e.childNodes.find((e=>"#documentType"===e.nodeName))
;if(o)o.name=t,o.publicId=n,o.systemId=r;else{const o={nodeName:"#documentType",
name:t,publicId:n,systemId:r,parentNode:null};pI.appendChild(e,o)}},
setDocumentMode(e,t){e.mode=t},getDocumentMode:e=>e.mode,detachNode(e){
if(e.parentNode){const t=e.parentNode.childNodes.indexOf(e)
;e.parentNode.childNodes.splice(t,1),e.parentNode=null}},insertText(e,t){
if(e.childNodes.length>0){const n=e.childNodes[e.childNodes.length-1]
;if(pI.isTextNode(n))return void(n.value+=t)}
pI.appendChild(e,pI.createTextNode(t))},insertTextBefore(e,t,n){
const r=e.childNodes[e.childNodes.indexOf(n)-1]
;r&&pI.isTextNode(r)?r.value+=t:pI.insertBefore(e,pI.createTextNode(t),n)},
adoptAttributes(e,t){const n=new Set(e.attrs.map((e=>e.name)))
;for(let r=0;r<t.length;r++)n.has(t[r].name)||e.attrs.push(t[r])},
getFirstChild:e=>e.childNodes[0],getChildNodes:e=>e.childNodes,
getParentNode:e=>e.parentNode,getAttrList:e=>e.attrs,getTagName:e=>e.tagName,
getNamespaceURI:e=>e.namespaceURI,getTextNodeContent:e=>e.value,
getCommentNodeContent:e=>e.data,getDocumentTypeNodeName:e=>e.name,
getDocumentTypeNodePublicId:e=>e.publicId,
getDocumentTypeNodeSystemId:e=>e.systemId,isTextNode:e=>"#text"===e.nodeName,
isCommentNode:e=>"#comment"===e.nodeName,
isDocumentTypeNode:e=>"#documentType"===e.nodeName,
isElementNode:e=>Object.prototype.hasOwnProperty.call(e,"tagName"),
setNodeSourceCodeLocation(e,t){e.sourceCodeLocation=t},
getNodeSourceCodeLocation:e=>e.sourceCodeLocation,
updateNodeSourceCodeLocation(e,t){e.sourceCodeLocation={...e.sourceCodeLocation,
...t}}
},hI="html",fI="about:legacy-compat",mI="http://www.ibm.com/data/dtd/v11/ibmxhtml1-transitional.dtd",gI=["+//silmaril//dtd html pro v0r11 19970101//","-//as//dtd html 3.0 aswedit + extensions//","-//advasoft ltd//dtd html 3.0 aswedit + extensions//","-//ietf//dtd html 2.0 level 1//","-//ietf//dtd html 2.0 level 2//","-//ietf//dtd html 2.0 strict level 1//","-//ietf//dtd html 2.0 strict level 2//","-//ietf//dtd html 2.0 strict//","-//ietf//dtd html 2.0//","-//ietf//dtd html 2.1e//","-//ietf//dtd html 3.0//","-//ietf//dtd html 3.2 final//","-//ietf//dtd html 3.2//","-//ietf//dtd html 3//","-//ietf//dtd html level 0//","-//ietf//dtd html level 1//","-//ietf//dtd html level 2//","-//ietf//dtd html level 3//","-//ietf//dtd html strict level 0//","-//ietf//dtd html strict level 1//","-//ietf//dtd html strict level 2//","-//ietf//dtd html strict level 3//","-//ietf//dtd html strict//","-//ietf//dtd html//","-//metrius//dtd metrius presentational//","-//microsoft//dtd internet explorer 2.0 html strict//","-//microsoft//dtd internet explorer 2.0 html//","-//microsoft//dtd internet explorer 2.0 tables//","-//microsoft//dtd internet explorer 3.0 html strict//","-//microsoft//dtd internet explorer 3.0 html//","-//microsoft//dtd internet explorer 3.0 tables//","-//netscape comm. corp.//dtd html//","-//netscape comm. corp.//dtd strict html//","-//o'reilly and associates//dtd html 2.0//","-//o'reilly and associates//dtd html extended 1.0//","-//o'reilly and associates//dtd html extended relaxed 1.0//","-//sq//dtd html 2.0 hotmetal + extensions//","-//softquad software//dtd hotmetal pro 6.0::19990601::extensions to html 4.0//","-//softquad//dtd hotmetal pro 4.0::19971010::extensions to html 4.0//","-//spyglass//dtd html 2.0 extended//","-//sun microsystems corp.//dtd hotjava html//","-//sun microsystems corp.//dtd hotjava strict html//","-//w3c//dtd html 3 1995-03-24//","-//w3c//dtd html 3.2 draft//","-//w3c//dtd html 3.2 final//","-//w3c//dtd html 3.2//","-//w3c//dtd html 3.2s draft//","-//w3c//dtd html 4.0 frameset//","-//w3c//dtd html 4.0 transitional//","-//w3c//dtd html experimental 19960712//","-//w3c//dtd html experimental 970421//","-//w3c//dtd w3 html//","-//w3o//dtd w3 html 3.0//","-//webtechs//dtd mozilla html 2.0//","-//webtechs//dtd mozilla html//"],vI=[...gI,"-//w3c//dtd html 4.01 frameset//","-//w3c//dtd html 4.01 transitional//"],bI=new Set(["-//w3o//dtd w3 html strict 3.0//en//","-/w3c/dtd html 4.0 transitional/en","html"]),yI=["-//w3c//dtd xhtml 1.0 frameset//","-//w3c//dtd xhtml 1.0 transitional//"],OI=[...yI,"-//w3c//dtd html 4.01 frameset//","-//w3c//dtd html 4.01 transitional//"]
;function wI(e,t){return t.some((t=>e.startsWith(t)))}const xI={
TEXT_HTML:"text/html",APPLICATION_XML:"application/xhtml+xml"
},kI="definitionurl",SI="definitionURL",_I=new Map(["attributeName","attributeType","baseFrequency","baseProfile","calcMode","clipPathUnits","diffuseConstant","edgeMode","filterUnits","glyphRef","gradientTransform","gradientUnits","kernelMatrix","kernelUnitLength","keyPoints","keySplines","keyTimes","lengthAdjust","limitingConeAngle","markerHeight","markerUnits","markerWidth","maskContentUnits","maskUnits","numOctaves","pathLength","patternContentUnits","patternTransform","patternUnits","pointsAtX","pointsAtY","pointsAtZ","preserveAlpha","preserveAspectRatio","primitiveUnits","refX","refY","repeatCount","repeatDur","requiredExtensions","requiredFeatures","specularConstant","specularExponent","spreadMethod","startOffset","stdDeviation","stitchTiles","surfaceScale","systemLanguage","tableValues","targetX","targetY","textLength","viewBox","viewTarget","xChannelSelector","yChannelSelector","zoomAndPan"].map((e=>[e.toLowerCase(),e]))),TI=new Map([["xlink:actuate",{
prefix:"xlink",name:"actuate",namespace:wD.XLINK}],["xlink:arcrole",{
prefix:"xlink",name:"arcrole",namespace:wD.XLINK}],["xlink:href",{
prefix:"xlink",name:"href",namespace:wD.XLINK}],["xlink:role",{prefix:"xlink",
name:"role",namespace:wD.XLINK}],["xlink:show",{prefix:"xlink",name:"show",
namespace:wD.XLINK}],["xlink:title",{prefix:"xlink",name:"title",
namespace:wD.XLINK}],["xlink:type",{prefix:"xlink",name:"type",
namespace:wD.XLINK}],["xml:lang",{prefix:"xml",name:"lang",namespace:wD.XML
}],["xml:space",{prefix:"xml",name:"space",namespace:wD.XML}],["xmlns",{
prefix:"",name:"xmlns",namespace:wD.XMLNS}],["xmlns:xlink",{prefix:"xmlns",
name:"xlink",namespace:wD.XMLNS
}]]),EI=new Map(["altGlyph","altGlyphDef","altGlyphItem","animateColor","animateMotion","animateTransform","clipPath","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feDistantLight","feFlood","feFuncA","feFuncB","feFuncG","feFuncR","feGaussianBlur","feImage","feMerge","feMergeNode","feMorphology","feOffset","fePointLight","feSpecularLighting","feSpotLight","feTile","feTurbulence","foreignObject","glyphRef","linearGradient","radialGradient","textPath"].map((e=>[e.toLowerCase(),e]))),AI=new Set([CD.B,CD.BIG,CD.BLOCKQUOTE,CD.BODY,CD.BR,CD.CENTER,CD.CODE,CD.DD,CD.DIV,CD.DL,CD.DT,CD.EM,CD.EMBED,CD.H1,CD.H2,CD.H3,CD.H4,CD.H5,CD.H6,CD.HEAD,CD.HR,CD.I,CD.IMG,CD.LI,CD.LISTING,CD.MENU,CD.META,CD.NOBR,CD.OL,CD.P,CD.PRE,CD.RUBY,CD.S,CD.SMALL,CD.SPAN,CD.STRONG,CD.STRIKE,CD.SUB,CD.SUP,CD.TABLE,CD.TT,CD.U,CD.UL,CD.VAR])
;function CI(e){for(let t=0;t<e.attrs.length;t++)if(e.attrs[t].name===kI){
e.attrs[t].name=SI;break}}function $I(e){for(let t=0;t<e.attrs.length;t++){
const n=_I.get(e.attrs[t].name);null!=n&&(e.attrs[t].name=n)}}function PI(e){
for(let t=0;t<e.attrs.length;t++){const n=TI.get(e.attrs[t].name)
;n&&(e.attrs[t].prefix=n.prefix,
e.attrs[t].name=n.name,e.attrs[t].namespace=n.namespace)}}function DI(e,t,n,r){
return(!r||r===wD.HTML)&&function(e,t,n){
if(t===wD.MATHML&&e===CD.ANNOTATION_XML)for(let r=0;r<n.length;r++)if(n[r].name===kD.ENCODING){
const e=n[r].value.toLowerCase();return e===xI.TEXT_HTML||e===xI.APPLICATION_XML
}return t===wD.SVG&&(e===CD.FOREIGN_OBJECT||e===CD.DESC||e===CD.TITLE)
}(e,t,n)||(!r||r===wD.MATHML)&&function(e,t){
return t===wD.MATHML&&(e===CD.MI||e===CD.MO||e===CD.MN||e===CD.MS||e===CD.MTEXT)
}(e,t)}const II="hidden",MI=8,NI=3;var RI,LI
;(LI=RI||(RI={}))[LI.INITIAL=0]="INITIAL",
LI[LI.BEFORE_HTML=1]="BEFORE_HTML",LI[LI.BEFORE_HEAD=2]="BEFORE_HEAD",
LI[LI.IN_HEAD=3]="IN_HEAD",
LI[LI.IN_HEAD_NO_SCRIPT=4]="IN_HEAD_NO_SCRIPT",LI[LI.AFTER_HEAD=5]="AFTER_HEAD",
LI[LI.IN_BODY=6]="IN_BODY",
LI[LI.TEXT=7]="TEXT",LI[LI.IN_TABLE=8]="IN_TABLE",LI[LI.IN_TABLE_TEXT=9]="IN_TABLE_TEXT",
LI[LI.IN_CAPTION=10]="IN_CAPTION",
LI[LI.IN_COLUMN_GROUP=11]="IN_COLUMN_GROUP",LI[LI.IN_TABLE_BODY=12]="IN_TABLE_BODY",
LI[LI.IN_ROW=13]="IN_ROW",
LI[LI.IN_CELL=14]="IN_CELL",LI[LI.IN_SELECT=15]="IN_SELECT",
LI[LI.IN_SELECT_IN_TABLE=16]="IN_SELECT_IN_TABLE",
LI[LI.IN_TEMPLATE=17]="IN_TEMPLATE",
LI[LI.AFTER_BODY=18]="AFTER_BODY",LI[LI.IN_FRAMESET=19]="IN_FRAMESET",
LI[LI.AFTER_FRAMESET=20]="AFTER_FRAMESET",
LI[LI.AFTER_AFTER_BODY=21]="AFTER_AFTER_BODY",
LI[LI.AFTER_AFTER_FRAMESET=22]="AFTER_AFTER_FRAMESET";const BI={startLine:-1,
startCol:-1,startOffset:-1,endLine:-1,endCol:-1,endOffset:-1
},jI=new Set([CD.TABLE,CD.TBODY,CD.TFOOT,CD.THEAD,CD.TR]),UI={
scriptingEnabled:!0,sourceCodeLocationInfo:!1,treeAdapter:pI,onParseError:null}
;let zI=class{constructor(e,t,n=null,r=null){
this.fragmentContext=n,this.scriptHandler=r,
this.currentToken=null,this.stopped=!1,
this.insertionMode=RI.INITIAL,this.originalInsertionMode=RI.INITIAL,
this.headElement=null,
this.formElement=null,this.currentNotInHTML=!1,this.tmplInsertionModeStack=[],
this.pendingCharacterTokens=[],
this.hasNonWhitespacePendingCharacterToken=!1,this.framesetOk=!0,
this.skipNextNewLine=!1,this.fosterParentingEnabled=!1,this.options={...UI,...e
},
this.treeAdapter=this.options.treeAdapter,this.onParseError=this.options.onParseError,
this.onParseError&&(this.options.sourceCodeLocationInfo=!0),
this.document=null!=t?t:this.treeAdapter.createDocument(),
this.tokenizer=new XD(this.options,this),
this.activeFormattingElements=new dI(this.treeAdapter),
this.fragmentContextID=n?RD(this.treeAdapter.getTagName(n)):CD.UNKNOWN,
this._setContextModes(null!=n?n:this.document,this.fragmentContextID),
this.openElements=new sI(this.document,this.treeAdapter,this)}static parse(e,t){
const n=new this(t);return n.tokenizer.write(e,!0),n.document}
static getFragmentParser(e,t){const n={...UI,...t}
;null!=e||(e=n.treeAdapter.createElement(ED.TEMPLATE,wD.HTML,[]))
;const r=n.treeAdapter.createElement("documentmock",wD.HTML,[]),o=new this(n,r,e)
;return o.fragmentContextID===CD.TEMPLATE&&o.tmplInsertionModeStack.unshift(RI.IN_TEMPLATE),
o._initTokenizerForFragmentParsing(),
o._insertFakeRootElement(),o._resetInsertionMode(),
o._findFormInFragmentContext(),o}getFragment(){
const e=this.treeAdapter.getFirstChild(this.document),t=this.treeAdapter.createDocumentFragment()
;return this._adoptNodes(e,t),t}_err(e,t,n){var r;if(!this.onParseError)return
;const o=null!==(r=e.location)&&void 0!==r?r:BI,a={code:t,startLine:o.startLine,
startCol:o.startCol,startOffset:o.startOffset,endLine:n?o.startLine:o.endLine,
endCol:n?o.startCol:o.endCol,endOffset:n?o.startOffset:o.endOffset}
;this.onParseError(a)}onItemPush(e,t,n){var r,o
;null===(o=(r=this.treeAdapter).onItemPush)||void 0===o||o.call(r,e),
n&&this.openElements.stackTop>0&&this._setContextModes(e,t)}onItemPop(e,t){
var n,r
;if(this.options.sourceCodeLocationInfo&&this._setEndLocation(e,this.currentToken),
null===(r=(n=this.treeAdapter).onItemPop)||void 0===r||r.call(n,e,this.openElements.current),
t){let e,t
;0===this.openElements.stackTop&&this.fragmentContext?(e=this.fragmentContext,
t=this.fragmentContextID):({current:e,currentTagId:t}=this.openElements),
this._setContextModes(e,t)}}_setContextModes(e,t){
const n=e===this.document||e&&this.treeAdapter.getNamespaceURI(e)===wD.HTML
;this.currentNotInHTML=!n,
this.tokenizer.inForeignNode=!n&&void 0!==e&&void 0!==t&&!this._isIntegrationPoint(t,e)
}_switchToTextParsing(e,t){
this._insertElement(e,wD.HTML),this.tokenizer.state=t,
this.originalInsertionMode=this.insertionMode,this.insertionMode=RI.TEXT}
switchToPlaintextParsing(){
this.insertionMode=RI.TEXT,this.originalInsertionMode=RI.IN_BODY,
this.tokenizer.state=FD.PLAINTEXT}_getAdjustedCurrentElement(){
return 0===this.openElements.stackTop&&this.fragmentContext?this.fragmentContext:this.openElements.current
}_findFormInFragmentContext(){let e=this.fragmentContext;for(;e;){
if(this.treeAdapter.getTagName(e)===ED.FORM){this.formElement=e;break}
e=this.treeAdapter.getParentNode(e)}}_initTokenizerForFragmentParsing(){
if(this.fragmentContext&&this.treeAdapter.getNamespaceURI(this.fragmentContext)===wD.HTML)switch(this.fragmentContextID){
case CD.TITLE:case CD.TEXTAREA:this.tokenizer.state=FD.RCDATA;break
;case CD.STYLE:case CD.XMP:case CD.IFRAME:case CD.NOEMBED:case CD.NOFRAMES:
case CD.NOSCRIPT:this.tokenizer.state=FD.RAWTEXT;break;case CD.SCRIPT:
this.tokenizer.state=FD.SCRIPT_DATA;break;case CD.PLAINTEXT:
this.tokenizer.state=FD.PLAINTEXT}}_setDocumentType(e){
const t=e.name||"",n=e.publicId||"",r=e.systemId||""
;if(this.treeAdapter.setDocumentType(this.document,t,n,r),e.location){
const t=this.treeAdapter.getChildNodes(this.document).find((e=>this.treeAdapter.isDocumentTypeNode(e)))
;t&&this.treeAdapter.setNodeSourceCodeLocation(t,e.location)}}
_attachElementToTree(e,t){if(this.options.sourceCodeLocationInfo){const n=t&&{
...t,startTag:t};this.treeAdapter.setNodeSourceCodeLocation(e,n)}
if(this._shouldFosterParentOnInsertion())this._fosterParentElement(e);else{
const t=this.openElements.currentTmplContentOrNode
;this.treeAdapter.appendChild(null!=t?t:this.document,e)}}_appendElement(e,t){
const n=this.treeAdapter.createElement(e.tagName,t,e.attrs)
;this._attachElementToTree(n,e.location)}_insertElement(e,t){
const n=this.treeAdapter.createElement(e.tagName,t,e.attrs)
;this._attachElementToTree(n,e.location),this.openElements.push(n,e.tagID)}
_insertFakeElement(e,t){const n=this.treeAdapter.createElement(e,wD.HTML,[])
;this._attachElementToTree(n,null),this.openElements.push(n,t)}
_insertTemplate(e){
const t=this.treeAdapter.createElement(e.tagName,wD.HTML,e.attrs),n=this.treeAdapter.createDocumentFragment()
;this.treeAdapter.setTemplateContent(t,n),
this._attachElementToTree(t,e.location),
this.openElements.push(t,e.tagID),this.options.sourceCodeLocationInfo&&this.treeAdapter.setNodeSourceCodeLocation(n,null)
}_insertFakeRootElement(){
const e=this.treeAdapter.createElement(ED.HTML,wD.HTML,[])
;this.options.sourceCodeLocationInfo&&this.treeAdapter.setNodeSourceCodeLocation(e,null),
this.treeAdapter.appendChild(this.openElements.current,e),
this.openElements.push(e,CD.HTML)}_appendCommentNode(e,t){
const n=this.treeAdapter.createCommentNode(e.data)
;this.treeAdapter.appendChild(t,n),
this.options.sourceCodeLocationInfo&&this.treeAdapter.setNodeSourceCodeLocation(n,e.location)
}_insertCharacters(e){let t,n
;if(this._shouldFosterParentOnInsertion()?(({parent:t,beforeElement:n}=this._findFosterParentingLocation()),
n?this.treeAdapter.insertTextBefore(t,e.chars,n):this.treeAdapter.insertText(t,e.chars)):(t=this.openElements.currentTmplContentOrNode,
this.treeAdapter.insertText(t,e.chars)),!e.location)return
;const r=this.treeAdapter.getChildNodes(t),o=n?r.lastIndexOf(n):r.length,a=r[o-1]
;if(this.treeAdapter.getNodeSourceCodeLocation(a)){
const{endLine:t,endCol:n,endOffset:r}=e.location
;this.treeAdapter.updateNodeSourceCodeLocation(a,{endLine:t,endCol:n,endOffset:r
})
}else this.options.sourceCodeLocationInfo&&this.treeAdapter.setNodeSourceCodeLocation(a,e.location)
}_adoptNodes(e,t){
for(let n=this.treeAdapter.getFirstChild(e);n;n=this.treeAdapter.getFirstChild(e))this.treeAdapter.detachNode(n),
this.treeAdapter.appendChild(t,n)}_setEndLocation(e,t){
if(this.treeAdapter.getNodeSourceCodeLocation(e)&&t.location){
const n=t.location,r=this.treeAdapter.getTagName(e),o=t.type===lD.END_TAG&&r===t.tagName?{
endTag:{...n},endLine:n.endLine,endCol:n.endCol,endOffset:n.endOffset}:{
endLine:n.startLine,endCol:n.startCol,endOffset:n.startOffset}
;this.treeAdapter.updateNodeSourceCodeLocation(e,o)}}
shouldProcessStartTagTokenInForeignContent(e){if(!this.currentNotInHTML)return!1
;let t,n
;return 0===this.openElements.stackTop&&this.fragmentContext?(t=this.fragmentContext,
n=this.fragmentContextID):({current:t,currentTagId:n}=this.openElements),
(e.tagID!==CD.SVG||this.treeAdapter.getTagName(t)!==ED.ANNOTATION_XML||this.treeAdapter.getNamespaceURI(t)!==wD.MATHML)&&(this.tokenizer.inForeignNode||(e.tagID===CD.MGLYPH||e.tagID===CD.MALIGNMARK)&&void 0!==n&&!this._isIntegrationPoint(n,t,wD.HTML))
}_processToken(e){switch(e.type){case lD.CHARACTER:this.onCharacter(e);break
;case lD.NULL_CHARACTER:this.onNullCharacter(e);break;case lD.COMMENT:
this.onComment(e);break;case lD.DOCTYPE:this.onDoctype(e);break
;case lD.START_TAG:this._processStartTag(e);break;case lD.END_TAG:
this.onEndTag(e);break;case lD.EOF:this.onEof(e);break
;case lD.WHITESPACE_CHARACTER:this.onWhitespaceCharacter(e)}}
_isIntegrationPoint(e,t,n){
return DI(e,this.treeAdapter.getNamespaceURI(t),this.treeAdapter.getAttrList(t),n)
}_reconstructActiveFormattingElements(){
const e=this.activeFormattingElements.entries.length;if(e){
const t=this.activeFormattingElements.entries.findIndex((e=>e.type===lI.Marker||this.openElements.contains(e.element)))
;for(let n=-1===t?e-1:t-1;n>=0;n--){
const e=this.activeFormattingElements.entries[n]
;this._insertElement(e.token,this.treeAdapter.getNamespaceURI(e.element)),
e.element=this.openElements.current}}}_closeTableCell(){
this.openElements.generateImpliedEndTags(),
this.openElements.popUntilTableCellPopped(),
this.activeFormattingElements.clearToLastMarker(),this.insertionMode=RI.IN_ROW}
_closePElement(){
this.openElements.generateImpliedEndTagsWithExclusion(CD.P),this.openElements.popUntilTagNamePopped(CD.P)
}_resetInsertionMode(){
for(let e=this.openElements.stackTop;e>=0;e--)switch(0===e&&this.fragmentContext?this.fragmentContextID:this.openElements.tagIDs[e]){
case CD.TR:return void(this.insertionMode=RI.IN_ROW);case CD.TBODY:
case CD.THEAD:case CD.TFOOT:return void(this.insertionMode=RI.IN_TABLE_BODY)
;case CD.CAPTION:return void(this.insertionMode=RI.IN_CAPTION);case CD.COLGROUP:
return void(this.insertionMode=RI.IN_COLUMN_GROUP);case CD.TABLE:
return void(this.insertionMode=RI.IN_TABLE);case CD.BODY:
return void(this.insertionMode=RI.IN_BODY);case CD.FRAMESET:
return void(this.insertionMode=RI.IN_FRAMESET);case CD.SELECT:
return void this._resetInsertionModeForSelect(e);case CD.TEMPLATE:
return void(this.insertionMode=this.tmplInsertionModeStack[0]);case CD.HTML:
return void(this.insertionMode=this.headElement?RI.AFTER_HEAD:RI.BEFORE_HEAD)
;case CD.TD:case CD.TH:if(e>0)return void(this.insertionMode=RI.IN_CELL);break
;case CD.HEAD:if(e>0)return void(this.insertionMode=RI.IN_HEAD)}
this.insertionMode=RI.IN_BODY}_resetInsertionModeForSelect(e){
if(e>0)for(let t=e-1;t>0;t--){const e=this.openElements.tagIDs[t]
;if(e===CD.TEMPLATE)break
;if(e===CD.TABLE)return void(this.insertionMode=RI.IN_SELECT_IN_TABLE)}
this.insertionMode=RI.IN_SELECT}_isElementCausesFosterParenting(e){
return jI.has(e)}_shouldFosterParentOnInsertion(){
return this.fosterParentingEnabled&&void 0!==this.openElements.currentTagId&&this._isElementCausesFosterParenting(this.openElements.currentTagId)
}_findFosterParentingLocation(){for(let e=this.openElements.stackTop;e>=0;e--){
const t=this.openElements.items[e];switch(this.openElements.tagIDs[e]){
case CD.TEMPLATE:if(this.treeAdapter.getNamespaceURI(t)===wD.HTML)return{
parent:this.treeAdapter.getTemplateContent(t),beforeElement:null};break
;case CD.TABLE:{const n=this.treeAdapter.getParentNode(t);return n?{parent:n,
beforeElement:t}:{parent:this.openElements.items[e-1],beforeElement:null}}}}
return{parent:this.openElements.items[0],beforeElement:null}}
_fosterParentElement(e){const t=this._findFosterParentingLocation()
;t.beforeElement?this.treeAdapter.insertBefore(t.parent,e,t.beforeElement):this.treeAdapter.appendChild(t.parent,e)
}_isSpecialElement(e,t){const n=this.treeAdapter.getNamespaceURI(e)
;return BD[n].has(t)}onCharacter(e){
if(this.skipNextNewLine=!1,this.tokenizer.inForeignNode)!function(e,t){
e._insertCharacters(t),e.framesetOk=!1}(this,e);else switch(this.insertionMode){
case RI.INITIAL:YI(this,e);break;case RI.BEFORE_HTML:KI(this,e);break
;case RI.BEFORE_HEAD:JI(this,e);break;case RI.IN_HEAD:nM(this,e);break
;case RI.IN_HEAD_NO_SCRIPT:rM(this,e);break;case RI.AFTER_HEAD:oM(this,e);break
;case RI.IN_BODY:case RI.IN_CAPTION:case RI.IN_CELL:case RI.IN_TEMPLATE:
sM(this,e);break;case RI.TEXT:case RI.IN_SELECT:case RI.IN_SELECT_IN_TABLE:
this._insertCharacters(e);break;case RI.IN_TABLE:case RI.IN_TABLE_BODY:
case RI.IN_ROW:gM(this,e);break;case RI.IN_TABLE_TEXT:wM(this,e);break
;case RI.IN_COLUMN_GROUP:_M(this,e);break;case RI.AFTER_BODY:MM(this,e);break
;case RI.AFTER_AFTER_BODY:NM(this,e)}}onNullCharacter(e){
if(this.skipNextNewLine=!1,this.tokenizer.inForeignNode)!function(e,t){
t.chars=qP,e._insertCharacters(t)}(this,e);else switch(this.insertionMode){
case RI.INITIAL:YI(this,e);break;case RI.BEFORE_HTML:KI(this,e);break
;case RI.BEFORE_HEAD:JI(this,e);break;case RI.IN_HEAD:nM(this,e);break
;case RI.IN_HEAD_NO_SCRIPT:rM(this,e);break;case RI.AFTER_HEAD:oM(this,e);break
;case RI.TEXT:this._insertCharacters(e);break;case RI.IN_TABLE:
case RI.IN_TABLE_BODY:case RI.IN_ROW:gM(this,e);break;case RI.IN_COLUMN_GROUP:
_M(this,e);break;case RI.AFTER_BODY:MM(this,e);break;case RI.AFTER_AFTER_BODY:
NM(this,e)}}onComment(e){
if(this.skipNextNewLine=!1,this.currentNotInHTML)XI(this,e);else switch(this.insertionMode){
case RI.INITIAL:case RI.BEFORE_HTML:case RI.BEFORE_HEAD:case RI.IN_HEAD:
case RI.IN_HEAD_NO_SCRIPT:case RI.AFTER_HEAD:case RI.IN_BODY:case RI.IN_TABLE:
case RI.IN_CAPTION:case RI.IN_COLUMN_GROUP:case RI.IN_TABLE_BODY:case RI.IN_ROW:
case RI.IN_CELL:case RI.IN_SELECT:case RI.IN_SELECT_IN_TABLE:
case RI.IN_TEMPLATE:case RI.IN_FRAMESET:case RI.AFTER_FRAMESET:XI(this,e);break
;case RI.IN_TABLE_TEXT:xM(this,e);break;case RI.AFTER_BODY:!function(e,t){
e._appendCommentNode(t,e.openElements.items[0])}(this,e);break
;case RI.AFTER_AFTER_BODY:case RI.AFTER_AFTER_FRAMESET:!function(e,t){
e._appendCommentNode(t,e.document)}(this,e)}}onDoctype(e){
switch(this.skipNextNewLine=!1,this.insertionMode){case RI.INITIAL:
!function(e,t){e._setDocumentType(t)
;const n=t.forceQuirks?_D.QUIRKS:function(e){if(e.name!==hI)return _D.QUIRKS
;const{systemId:t}=e;if(t&&t.toLowerCase()===mI)return _D.QUIRKS
;let{publicId:n}=e;if(null!==n){if(n=n.toLowerCase(),bI.has(n))return _D.QUIRKS
;let e=null===t?vI:gI;if(wI(n,e))return _D.QUIRKS
;if(e=null===t?yI:OI,wI(n,e))return _D.LIMITED_QUIRKS}return _D.NO_QUIRKS}(t)
;(function(e){
return e.name===hI&&null===e.publicId&&(null===e.systemId||e.systemId===fI)
})(t)||e._err(t,aD.nonConformingDoctype)
;e.treeAdapter.setDocumentMode(e.document,n),e.insertionMode=RI.BEFORE_HTML
}(this,e);break;case RI.BEFORE_HEAD:case RI.IN_HEAD:case RI.IN_HEAD_NO_SCRIPT:
case RI.AFTER_HEAD:this._err(e,aD.misplacedDoctype);break;case RI.IN_TABLE_TEXT:
xM(this,e)}}onStartTag(e){
this.skipNextNewLine=!1,this.currentToken=e,this._processStartTag(e),
e.selfClosing&&!e.ackSelfClosing&&this._err(e,aD.nonVoidHtmlElementStartTagWithTrailingSolidus)
}_processStartTag(e){
this.shouldProcessStartTagTokenInForeignContent(e)?function(e,t){if(function(e){
const t=e.tagID
;return t===CD.FONT&&e.attrs.some((({name:e})=>e===kD.COLOR||e===kD.SIZE||e===kD.FACE))||AI.has(t)
}(t))RM(e),e._startTagOutsideForeignContent(t);else{
const n=e._getAdjustedCurrentElement(),r=e.treeAdapter.getNamespaceURI(n)
;r===wD.MATHML?CI(t):r===wD.SVG&&(!function(e){const t=EI.get(e.tagName)
;null!=t&&(e.tagName=t,e.tagID=RD(e.tagName))
}(t),$I(t)),PI(t),t.selfClosing?e._appendElement(t,r):e._insertElement(t,r),
t.ackSelfClosing=!0}}(this,e):this._startTagOutsideForeignContent(e)}
_startTagOutsideForeignContent(e){switch(this.insertionMode){case RI.INITIAL:
YI(this,e);break;case RI.BEFORE_HTML:!function(e,t){
t.tagID===CD.HTML?(e._insertElement(t,wD.HTML),
e.insertionMode=RI.BEFORE_HEAD):KI(e,t)}(this,e);break;case RI.BEFORE_HEAD:
!function(e,t){switch(t.tagID){case CD.HTML:pM(e,t);break;case CD.HEAD:
e._insertElement(t,wD.HTML),
e.headElement=e.openElements.current,e.insertionMode=RI.IN_HEAD;break;default:
JI(e,t)}}(this,e);break;case RI.IN_HEAD:eM(this,e);break
;case RI.IN_HEAD_NO_SCRIPT:!function(e,t){switch(t.tagID){case CD.HTML:pM(e,t)
;break;case CD.BASEFONT:case CD.BGSOUND:case CD.HEAD:case CD.LINK:case CD.META:
case CD.NOFRAMES:case CD.STYLE:eM(e,t);break;case CD.NOSCRIPT:
e._err(t,aD.nestedNoscriptInHead);break;default:rM(e,t)}}(this,e);break
;case RI.AFTER_HEAD:!function(e,t){switch(t.tagID){case CD.HTML:pM(e,t);break
;case CD.BODY:
e._insertElement(t,wD.HTML),e.framesetOk=!1,e.insertionMode=RI.IN_BODY;break
;case CD.FRAMESET:e._insertElement(t,wD.HTML),e.insertionMode=RI.IN_FRAMESET
;break;case CD.BASE:case CD.BASEFONT:case CD.BGSOUND:case CD.LINK:case CD.META:
case CD.NOFRAMES:case CD.SCRIPT:case CD.STYLE:case CD.TEMPLATE:case CD.TITLE:
e._err(t,aD.abandonedHeadElementChild),
e.openElements.push(e.headElement,CD.HEAD),
eM(e,t),e.openElements.remove(e.headElement);break;case CD.HEAD:
e._err(t,aD.misplacedStartTagForHeadElement);break;default:oM(e,t)}}(this,e)
;break;case RI.IN_BODY:pM(this,e);break;case RI.IN_TABLE:vM(this,e);break
;case RI.IN_TABLE_TEXT:xM(this,e);break;case RI.IN_CAPTION:!function(e,t){
const n=t.tagID
;kM.has(n)?e.openElements.hasInTableScope(CD.CAPTION)&&(e.openElements.generateImpliedEndTags(),
e.openElements.popUntilTagNamePopped(CD.CAPTION),
e.activeFormattingElements.clearToLastMarker(),
e.insertionMode=RI.IN_TABLE,vM(e,t)):pM(e,t)}(this,e);break
;case RI.IN_COLUMN_GROUP:SM(this,e);break;case RI.IN_TABLE_BODY:TM(this,e);break
;case RI.IN_ROW:AM(this,e);break;case RI.IN_CELL:!function(e,t){const n=t.tagID
;kM.has(n)?(e.openElements.hasInTableScope(CD.TD)||e.openElements.hasInTableScope(CD.TH))&&(e._closeTableCell(),
AM(e,t)):pM(e,t)}(this,e);break;case RI.IN_SELECT:$M(this,e);break
;case RI.IN_SELECT_IN_TABLE:!function(e,t){const n=t.tagID
;n===CD.CAPTION||n===CD.TABLE||n===CD.TBODY||n===CD.TFOOT||n===CD.THEAD||n===CD.TR||n===CD.TD||n===CD.TH?(e.openElements.popUntilTagNamePopped(CD.SELECT),
e._resetInsertionMode(),e._processStartTag(t)):$M(e,t)}(this,e);break
;case RI.IN_TEMPLATE:!function(e,t){switch(t.tagID){case CD.BASE:
case CD.BASEFONT:case CD.BGSOUND:case CD.LINK:case CD.META:case CD.NOFRAMES:
case CD.SCRIPT:case CD.STYLE:case CD.TEMPLATE:case CD.TITLE:eM(e,t);break
;case CD.CAPTION:case CD.COLGROUP:case CD.TBODY:case CD.TFOOT:case CD.THEAD:
e.tmplInsertionModeStack[0]=RI.IN_TABLE,e.insertionMode=RI.IN_TABLE,vM(e,t)
;break;case CD.COL:
e.tmplInsertionModeStack[0]=RI.IN_COLUMN_GROUP,e.insertionMode=RI.IN_COLUMN_GROUP,
SM(e,t);break;case CD.TR:
e.tmplInsertionModeStack[0]=RI.IN_TABLE_BODY,e.insertionMode=RI.IN_TABLE_BODY,
TM(e,t);break;case CD.TD:case CD.TH:
e.tmplInsertionModeStack[0]=RI.IN_ROW,e.insertionMode=RI.IN_ROW,AM(e,t);break
;default:
e.tmplInsertionModeStack[0]=RI.IN_BODY,e.insertionMode=RI.IN_BODY,pM(e,t)}
}(this,e);break;case RI.AFTER_BODY:!function(e,t){
t.tagID===CD.HTML?pM(e,t):MM(e,t)}(this,e);break;case RI.IN_FRAMESET:
!function(e,t){switch(t.tagID){case CD.HTML:pM(e,t);break;case CD.FRAMESET:
e._insertElement(t,wD.HTML);break;case CD.FRAME:
e._appendElement(t,wD.HTML),t.ackSelfClosing=!0;break;case CD.NOFRAMES:eM(e,t)}
}(this,e);break;case RI.AFTER_FRAMESET:!function(e,t){switch(t.tagID){
case CD.HTML:pM(e,t);break;case CD.NOFRAMES:eM(e,t)}}(this,e);break
;case RI.AFTER_AFTER_BODY:!function(e,t){t.tagID===CD.HTML?pM(e,t):NM(e,t)
}(this,e);break;case RI.AFTER_AFTER_FRAMESET:!function(e,t){switch(t.tagID){
case CD.HTML:pM(e,t);break;case CD.NOFRAMES:eM(e,t)}}(this,e)}}onEndTag(e){
this.skipNextNewLine=!1,this.currentToken=e,this.currentNotInHTML?function(e,t){
if(t.tagID===CD.P||t.tagID===CD.BR)return RM(e),
void e._endTagOutsideForeignContent(t)
;for(let n=e.openElements.stackTop;n>0;n--){const r=e.openElements.items[n]
;if(e.treeAdapter.getNamespaceURI(r)===wD.HTML){
e._endTagOutsideForeignContent(t);break}const o=e.treeAdapter.getTagName(r)
;if(o.toLowerCase()===t.tagName){t.tagName=o,e.openElements.shortenToLength(n)
;break}}}(this,e):this._endTagOutsideForeignContent(e)}
_endTagOutsideForeignContent(e){switch(this.insertionMode){case RI.INITIAL:
YI(this,e);break;case RI.BEFORE_HTML:!function(e,t){const n=t.tagID
;n!==CD.HTML&&n!==CD.HEAD&&n!==CD.BODY&&n!==CD.BR||KI(e,t)}(this,e);break
;case RI.BEFORE_HEAD:!function(e,t){const n=t.tagID
;n===CD.HEAD||n===CD.BODY||n===CD.HTML||n===CD.BR?JI(e,t):e._err(t,aD.endTagWithoutMatchingOpenElement)
}(this,e);break;case RI.IN_HEAD:!function(e,t){switch(t.tagID){case CD.HEAD:
e.openElements.pop(),e.insertionMode=RI.AFTER_HEAD;break;case CD.BODY:
case CD.BR:case CD.HTML:nM(e,t);break;case CD.TEMPLATE:tM(e,t);break;default:
e._err(t,aD.endTagWithoutMatchingOpenElement)}}(this,e);break
;case RI.IN_HEAD_NO_SCRIPT:!function(e,t){switch(t.tagID){case CD.NOSCRIPT:
e.openElements.pop(),e.insertionMode=RI.IN_HEAD;break;case CD.BR:rM(e,t);break
;default:e._err(t,aD.endTagWithoutMatchingOpenElement)}}(this,e);break
;case RI.AFTER_HEAD:!function(e,t){switch(t.tagID){case CD.BODY:case CD.HTML:
case CD.BR:oM(e,t);break;case CD.TEMPLATE:tM(e,t);break;default:
e._err(t,aD.endTagWithoutMatchingOpenElement)}}(this,e);break;case RI.IN_BODY:
fM(this,e);break;case RI.TEXT:!function(e,t){var n
;t.tagID===CD.SCRIPT&&(null===(n=e.scriptHandler)||void 0===n||n.call(e,e.openElements.current))
;e.openElements.pop(),e.insertionMode=e.originalInsertionMode}(this,e);break
;case RI.IN_TABLE:bM(this,e);break;case RI.IN_TABLE_TEXT:xM(this,e);break
;case RI.IN_CAPTION:!function(e,t){const n=t.tagID;switch(n){case CD.CAPTION:
case CD.TABLE:
e.openElements.hasInTableScope(CD.CAPTION)&&(e.openElements.generateImpliedEndTags(),
e.openElements.popUntilTagNamePopped(CD.CAPTION),
e.activeFormattingElements.clearToLastMarker(),
e.insertionMode=RI.IN_TABLE,n===CD.TABLE&&bM(e,t));break;case CD.BODY:
case CD.COL:case CD.COLGROUP:case CD.HTML:case CD.TBODY:case CD.TD:
case CD.TFOOT:case CD.TH:case CD.THEAD:case CD.TR:break;default:fM(e,t)}
}(this,e);break;case RI.IN_COLUMN_GROUP:!function(e,t){switch(t.tagID){
case CD.COLGROUP:
e.openElements.currentTagId===CD.COLGROUP&&(e.openElements.pop(),
e.insertionMode=RI.IN_TABLE);break;case CD.TEMPLATE:tM(e,t);break;case CD.COL:
break;default:_M(e,t)}}(this,e);break;case RI.IN_TABLE_BODY:EM(this,e);break
;case RI.IN_ROW:CM(this,e);break;case RI.IN_CELL:!function(e,t){const n=t.tagID
;switch(n){case CD.TD:case CD.TH:
e.openElements.hasInTableScope(n)&&(e.openElements.generateImpliedEndTags(),
e.openElements.popUntilTagNamePopped(n),
e.activeFormattingElements.clearToLastMarker(),e.insertionMode=RI.IN_ROW);break
;case CD.TABLE:case CD.TBODY:case CD.TFOOT:case CD.THEAD:case CD.TR:
e.openElements.hasInTableScope(n)&&(e._closeTableCell(),CM(e,t));break
;case CD.BODY:case CD.CAPTION:case CD.COL:case CD.COLGROUP:case CD.HTML:break
;default:fM(e,t)}}(this,e);break;case RI.IN_SELECT:PM(this,e);break
;case RI.IN_SELECT_IN_TABLE:!function(e,t){const n=t.tagID
;n===CD.CAPTION||n===CD.TABLE||n===CD.TBODY||n===CD.TFOOT||n===CD.THEAD||n===CD.TR||n===CD.TD||n===CD.TH?e.openElements.hasInTableScope(n)&&(e.openElements.popUntilTagNamePopped(CD.SELECT),
e._resetInsertionMode(),e.onEndTag(t)):PM(e,t)}(this,e);break
;case RI.IN_TEMPLATE:!function(e,t){t.tagID===CD.TEMPLATE&&tM(e,t)}(this,e)
;break;case RI.AFTER_BODY:IM(this,e);break;case RI.IN_FRAMESET:!function(e,t){
t.tagID!==CD.FRAMESET||e.openElements.isRootHtmlElementCurrent()||(e.openElements.pop(),
e.fragmentContext||e.openElements.currentTagId===CD.FRAMESET||(e.insertionMode=RI.AFTER_FRAMESET))
}(this,e);break;case RI.AFTER_FRAMESET:!function(e,t){
t.tagID===CD.HTML&&(e.insertionMode=RI.AFTER_AFTER_FRAMESET)}(this,e);break
;case RI.AFTER_AFTER_BODY:NM(this,e)}}onEof(e){switch(this.insertionMode){
case RI.INITIAL:YI(this,e);break;case RI.BEFORE_HTML:KI(this,e);break
;case RI.BEFORE_HEAD:JI(this,e);break;case RI.IN_HEAD:nM(this,e);break
;case RI.IN_HEAD_NO_SCRIPT:rM(this,e);break;case RI.AFTER_HEAD:oM(this,e);break
;case RI.IN_BODY:case RI.IN_TABLE:case RI.IN_CAPTION:case RI.IN_COLUMN_GROUP:
case RI.IN_TABLE_BODY:case RI.IN_ROW:case RI.IN_CELL:case RI.IN_SELECT:
case RI.IN_SELECT_IN_TABLE:mM(this,e);break;case RI.TEXT:!function(e,t){
e._err(t,aD.eofInElementThatCanContainOnlyText),
e.openElements.pop(),e.insertionMode=e.originalInsertionMode,e.onEof(t)}(this,e)
;break;case RI.IN_TABLE_TEXT:xM(this,e);break;case RI.IN_TEMPLATE:DM(this,e)
;break;case RI.AFTER_BODY:case RI.IN_FRAMESET:case RI.AFTER_FRAMESET:
case RI.AFTER_AFTER_BODY:case RI.AFTER_AFTER_FRAMESET:GI(this,e)}}
onWhitespaceCharacter(e){
if(this.skipNextNewLine&&(this.skipNextNewLine=!1,e.chars.charCodeAt(0)===WP.LINE_FEED)){
if(1===e.chars.length)return;e.chars=e.chars.substr(1)}
if(this.tokenizer.inForeignNode)this._insertCharacters(e);else switch(this.insertionMode){
case RI.IN_HEAD:case RI.IN_HEAD_NO_SCRIPT:case RI.AFTER_HEAD:case RI.TEXT:
case RI.IN_COLUMN_GROUP:case RI.IN_SELECT:case RI.IN_SELECT_IN_TABLE:
case RI.IN_FRAMESET:case RI.AFTER_FRAMESET:this._insertCharacters(e);break
;case RI.IN_BODY:case RI.IN_CAPTION:case RI.IN_CELL:case RI.IN_TEMPLATE:
case RI.AFTER_BODY:case RI.AFTER_AFTER_BODY:case RI.AFTER_AFTER_FRAMESET:
iM(this,e);break;case RI.IN_TABLE:case RI.IN_TABLE_BODY:case RI.IN_ROW:
gM(this,e);break;case RI.IN_TABLE_TEXT:OM(this,e)}}};function FI(e,t){
let n=e.activeFormattingElements.getElementEntryInScopeWithTagName(t.tagName)
;return n?e.openElements.contains(n.element)?e.openElements.hasInScope(t.tagID)||(n=null):(e.activeFormattingElements.removeEntry(n),
n=null):hM(e,t),n}function ZI(e,t){let n=null,r=e.openElements.stackTop
;for(;r>=0;r--){const o=e.openElements.items[r];if(o===t.element)break
;e._isSpecialElement(o,e.openElements.tagIDs[r])&&(n=o)}
return n||(e.openElements.shortenToLength(Math.max(r,0)),
e.activeFormattingElements.removeEntry(t)),n}function QI(e,t,n){
let r=t,o=e.openElements.getCommonAncestor(t);for(let a=0,i=o;i!==n;a++,i=o){
o=e.openElements.getCommonAncestor(i)
;const n=e.activeFormattingElements.getElementEntry(i),s=n&&a>=NI
;!n||s?(s&&e.activeFormattingElements.removeEntry(n),
e.openElements.remove(i)):(i=HI(e,n),
r===t&&(e.activeFormattingElements.bookmark=n),
e.treeAdapter.detachNode(r),e.treeAdapter.appendChild(i,r),r=i)}return r}
function HI(e,t){
const n=e.treeAdapter.getNamespaceURI(t.element),r=e.treeAdapter.createElement(t.token.tagName,n,t.token.attrs)
;return e.openElements.replace(t.element,r),t.element=r,r}function VI(e,t,n){
const r=RD(e.treeAdapter.getTagName(t))
;if(e._isElementCausesFosterParenting(r))e._fosterParentElement(n);else{
const o=e.treeAdapter.getNamespaceURI(t)
;r===CD.TEMPLATE&&o===wD.HTML&&(t=e.treeAdapter.getTemplateContent(t)),
e.treeAdapter.appendChild(t,n)}}function qI(e,t,n){
const r=e.treeAdapter.getNamespaceURI(n.element),{token:o}=n,a=e.treeAdapter.createElement(o.tagName,r,o.attrs)
;e._adoptNodes(t,a),
e.treeAdapter.appendChild(t,a),e.activeFormattingElements.insertElementAfterBookmark(a,o),
e.activeFormattingElements.removeEntry(n),
e.openElements.remove(n.element),e.openElements.insertAfter(t,a,o.tagID)}
function WI(e,t){for(let n=0;n<MI;n++){const n=FI(e,t);if(!n)break
;const r=ZI(e,n);if(!r)break;e.activeFormattingElements.bookmark=n
;const o=QI(e,r,n.element),a=e.openElements.getCommonAncestor(n.element)
;e.treeAdapter.detachNode(o),a&&VI(e,a,o),qI(e,r,n)}}function XI(e,t){
e._appendCommentNode(t,e.openElements.currentTmplContentOrNode)}
function GI(e,t){if(e.stopped=!0,t.location){const n=e.fragmentContext?0:2
;for(let r=e.openElements.stackTop;r>=n;r--)e._setEndLocation(e.openElements.items[r],t)
;if(!e.fragmentContext&&e.openElements.stackTop>=0){
const n=e.openElements.items[0],r=e.treeAdapter.getNodeSourceCodeLocation(n)
;if(r&&!r.endTag&&(e._setEndLocation(n,t),e.openElements.stackTop>=1)){
const n=e.openElements.items[1],r=e.treeAdapter.getNodeSourceCodeLocation(n)
;r&&!r.endTag&&e._setEndLocation(n,t)}}}}function YI(e,t){
e._err(t,aD.missingDoctype,!0),
e.treeAdapter.setDocumentMode(e.document,_D.QUIRKS),
e.insertionMode=RI.BEFORE_HTML,e._processToken(t)}function KI(e,t){
e._insertFakeRootElement(),e.insertionMode=RI.BEFORE_HEAD,e._processToken(t)}
function JI(e,t){
e._insertFakeElement(ED.HEAD,CD.HEAD),e.headElement=e.openElements.current,
e.insertionMode=RI.IN_HEAD,e._processToken(t)}function eM(e,t){switch(t.tagID){
case CD.HTML:pM(e,t);break;case CD.BASE:case CD.BASEFONT:case CD.BGSOUND:
case CD.LINK:case CD.META:e._appendElement(t,wD.HTML),t.ackSelfClosing=!0;break
;case CD.TITLE:e._switchToTextParsing(t,FD.RCDATA);break;case CD.NOSCRIPT:
e.options.scriptingEnabled?e._switchToTextParsing(t,FD.RAWTEXT):(e._insertElement(t,wD.HTML),
e.insertionMode=RI.IN_HEAD_NO_SCRIPT);break;case CD.NOFRAMES:case CD.STYLE:
e._switchToTextParsing(t,FD.RAWTEXT);break;case CD.SCRIPT:
e._switchToTextParsing(t,FD.SCRIPT_DATA);break;case CD.TEMPLATE:
e._insertTemplate(t),
e.activeFormattingElements.insertMarker(),e.framesetOk=!1,e.insertionMode=RI.IN_TEMPLATE,
e.tmplInsertionModeStack.unshift(RI.IN_TEMPLATE);break;case CD.HEAD:
e._err(t,aD.misplacedStartTagForHeadElement);break;default:nM(e,t)}}
function tM(e,t){
e.openElements.tmplCount>0?(e.openElements.generateImpliedEndTagsThoroughly(),
e.openElements.currentTagId!==CD.TEMPLATE&&e._err(t,aD.closingOfElementWithOpenChildElements),
e.openElements.popUntilTagNamePopped(CD.TEMPLATE),
e.activeFormattingElements.clearToLastMarker(),e.tmplInsertionModeStack.shift(),
e._resetInsertionMode()):e._err(t,aD.endTagWithoutMatchingOpenElement)}
function nM(e,t){
e.openElements.pop(),e.insertionMode=RI.AFTER_HEAD,e._processToken(t)}
function rM(e,t){
const n=t.type===lD.EOF?aD.openElementsLeftAfterEof:aD.disallowedContentInNoscriptInHead
;e._err(t,n),e.openElements.pop(),e.insertionMode=RI.IN_HEAD,e._processToken(t)}
function oM(e,t){
e._insertFakeElement(ED.BODY,CD.BODY),e.insertionMode=RI.IN_BODY,aM(e,t)}
function aM(e,t){switch(t.type){case lD.CHARACTER:sM(e,t);break
;case lD.WHITESPACE_CHARACTER:iM(e,t);break;case lD.COMMENT:XI(e,t);break
;case lD.START_TAG:pM(e,t);break;case lD.END_TAG:fM(e,t);break;case lD.EOF:
mM(e,t)}}function iM(e,t){
e._reconstructActiveFormattingElements(),e._insertCharacters(t)}
function sM(e,t){
e._reconstructActiveFormattingElements(),e._insertCharacters(t),e.framesetOk=!1}
function lM(e,t){
e._reconstructActiveFormattingElements(),e._appendElement(t,wD.HTML),
e.framesetOk=!1,t.ackSelfClosing=!0}function cM(e){const t=uD(e,kD.TYPE)
;return null!=t&&t.toLowerCase()===II}function uM(e,t){
e._switchToTextParsing(t,FD.RAWTEXT)}function dM(e,t){
e._reconstructActiveFormattingElements(),e._insertElement(t,wD.HTML)}
function pM(e,t){switch(t.tagID){case CD.I:case CD.S:case CD.B:case CD.U:
case CD.EM:case CD.TT:case CD.BIG:case CD.CODE:case CD.FONT:case CD.SMALL:
case CD.STRIKE:case CD.STRONG:!function(e,t){
e._reconstructActiveFormattingElements(),
e._insertElement(t,wD.HTML),e.activeFormattingElements.pushElement(e.openElements.current,t)
}(e,t);break;case CD.A:!function(e,t){
const n=e.activeFormattingElements.getElementEntryInScopeWithTagName(ED.A)
;n&&(WI(e,t),
e.openElements.remove(n.element),e.activeFormattingElements.removeEntry(n)),
e._reconstructActiveFormattingElements(),
e._insertElement(t,wD.HTML),e.activeFormattingElements.pushElement(e.openElements.current,t)
}(e,t);break;case CD.H1:case CD.H2:case CD.H3:case CD.H4:case CD.H5:case CD.H6:
!function(e,t){
e.openElements.hasInButtonScope(CD.P)&&e._closePElement(),void 0!==e.openElements.currentTagId&&jD.has(e.openElements.currentTagId)&&e.openElements.pop(),
e._insertElement(t,wD.HTML)}(e,t);break;case CD.P:case CD.DL:case CD.OL:
case CD.UL:case CD.DIV:case CD.DIR:case CD.NAV:case CD.MAIN:case CD.MENU:
case CD.ASIDE:case CD.CENTER:case CD.FIGURE:case CD.FOOTER:case CD.HEADER:
case CD.HGROUP:case CD.DIALOG:case CD.DETAILS:case CD.ADDRESS:case CD.ARTICLE:
case CD.SEARCH:case CD.SECTION:case CD.SUMMARY:case CD.FIELDSET:
case CD.BLOCKQUOTE:case CD.FIGCAPTION:!function(e,t){
e.openElements.hasInButtonScope(CD.P)&&e._closePElement(),
e._insertElement(t,wD.HTML)}(e,t);break;case CD.LI:case CD.DD:case CD.DT:
!function(e,t){e.framesetOk=!1;const n=t.tagID
;for(let r=e.openElements.stackTop;r>=0;r--){const t=e.openElements.tagIDs[r]
;if(n===CD.LI&&t===CD.LI||(n===CD.DD||n===CD.DT)&&(t===CD.DD||t===CD.DT)){
e.openElements.generateImpliedEndTagsWithExclusion(t),
e.openElements.popUntilTagNamePopped(t);break}
if(t!==CD.ADDRESS&&t!==CD.DIV&&t!==CD.P&&e._isSpecialElement(e.openElements.items[r],t))break
}
e.openElements.hasInButtonScope(CD.P)&&e._closePElement(),e._insertElement(t,wD.HTML)
}(e,t);break;case CD.BR:case CD.IMG:case CD.WBR:case CD.AREA:case CD.EMBED:
case CD.KEYGEN:lM(e,t);break;case CD.HR:!function(e,t){
e.openElements.hasInButtonScope(CD.P)&&e._closePElement(),
e._appendElement(t,wD.HTML),e.framesetOk=!1,t.ackSelfClosing=!0}(e,t);break
;case CD.RB:case CD.RTC:!function(e,t){
e.openElements.hasInScope(CD.RUBY)&&e.openElements.generateImpliedEndTags(),
e._insertElement(t,wD.HTML)}(e,t);break;case CD.RT:case CD.RP:!function(e,t){
e.openElements.hasInScope(CD.RUBY)&&e.openElements.generateImpliedEndTagsWithExclusion(CD.RTC),
e._insertElement(t,wD.HTML)}(e,t);break;case CD.PRE:case CD.LISTING:
!function(e,t){
e.openElements.hasInButtonScope(CD.P)&&e._closePElement(),e._insertElement(t,wD.HTML),
e.skipNextNewLine=!0,e.framesetOk=!1}(e,t);break;case CD.XMP:!function(e,t){
e.openElements.hasInButtonScope(CD.P)&&e._closePElement(),
e._reconstructActiveFormattingElements(),
e.framesetOk=!1,e._switchToTextParsing(t,FD.RAWTEXT)}(e,t);break;case CD.SVG:
!function(e,t){
e._reconstructActiveFormattingElements(),$I(t),PI(t),t.selfClosing?e._appendElement(t,wD.SVG):e._insertElement(t,wD.SVG),
t.ackSelfClosing=!0}(e,t);break;case CD.HTML:!function(e,t){
0===e.openElements.tmplCount&&e.treeAdapter.adoptAttributes(e.openElements.items[0],t.attrs)
}(e,t);break;case CD.BASE:case CD.LINK:case CD.META:case CD.STYLE:case CD.TITLE:
case CD.SCRIPT:case CD.BGSOUND:case CD.BASEFONT:case CD.TEMPLATE:eM(e,t);break
;case CD.BODY:!function(e,t){
const n=e.openElements.tryPeekProperlyNestedBodyElement()
;n&&0===e.openElements.tmplCount&&(e.framesetOk=!1,
e.treeAdapter.adoptAttributes(n,t.attrs))}(e,t);break;case CD.FORM:
!function(e,t){const n=e.openElements.tmplCount>0
;e.formElement&&!n||(e.openElements.hasInButtonScope(CD.P)&&e._closePElement(),
e._insertElement(t,wD.HTML),n||(e.formElement=e.openElements.current))}(e,t)
;break;case CD.NOBR:!function(e,t){
e._reconstructActiveFormattingElements(),e.openElements.hasInScope(CD.NOBR)&&(WI(e,t),
e._reconstructActiveFormattingElements()),
e._insertElement(t,wD.HTML),e.activeFormattingElements.pushElement(e.openElements.current,t)
}(e,t);break;case CD.MATH:!function(e,t){
e._reconstructActiveFormattingElements(),
CI(t),PI(t),t.selfClosing?e._appendElement(t,wD.MATHML):e._insertElement(t,wD.MATHML),
t.ackSelfClosing=!0}(e,t);break;case CD.TABLE:!function(e,t){
e.treeAdapter.getDocumentMode(e.document)!==_D.QUIRKS&&e.openElements.hasInButtonScope(CD.P)&&e._closePElement(),
e._insertElement(t,wD.HTML),e.framesetOk=!1,e.insertionMode=RI.IN_TABLE}(e,t)
;break;case CD.INPUT:!function(e,t){
e._reconstructActiveFormattingElements(),e._appendElement(t,wD.HTML),
cM(t)||(e.framesetOk=!1),t.ackSelfClosing=!0}(e,t);break;case CD.PARAM:
case CD.TRACK:case CD.SOURCE:!function(e,t){
e._appendElement(t,wD.HTML),t.ackSelfClosing=!0}(e,t);break;case CD.IMAGE:
!function(e,t){t.tagName=ED.IMG,t.tagID=CD.IMG,lM(e,t)}(e,t);break
;case CD.BUTTON:!function(e,t){
e.openElements.hasInScope(CD.BUTTON)&&(e.openElements.generateImpliedEndTags(),
e.openElements.popUntilTagNamePopped(CD.BUTTON)),
e._reconstructActiveFormattingElements(),
e._insertElement(t,wD.HTML),e.framesetOk=!1}(e,t);break;case CD.APPLET:
case CD.OBJECT:case CD.MARQUEE:!function(e,t){
e._reconstructActiveFormattingElements(),
e._insertElement(t,wD.HTML),e.activeFormattingElements.insertMarker(),
e.framesetOk=!1}(e,t);break;case CD.IFRAME:!function(e,t){
e.framesetOk=!1,e._switchToTextParsing(t,FD.RAWTEXT)}(e,t);break;case CD.SELECT:
!function(e,t){
e._reconstructActiveFormattingElements(),e._insertElement(t,wD.HTML),
e.framesetOk=!1,
e.insertionMode=e.insertionMode===RI.IN_TABLE||e.insertionMode===RI.IN_CAPTION||e.insertionMode===RI.IN_TABLE_BODY||e.insertionMode===RI.IN_ROW||e.insertionMode===RI.IN_CELL?RI.IN_SELECT_IN_TABLE:RI.IN_SELECT
}(e,t);break;case CD.OPTION:case CD.OPTGROUP:!function(e,t){
e.openElements.currentTagId===CD.OPTION&&e.openElements.pop(),
e._reconstructActiveFormattingElements(),e._insertElement(t,wD.HTML)}(e,t);break
;case CD.NOEMBED:case CD.NOFRAMES:uM(e,t);break;case CD.FRAMESET:!function(e,t){
const n=e.openElements.tryPeekProperlyNestedBodyElement()
;e.framesetOk&&n&&(e.treeAdapter.detachNode(n),
e.openElements.popAllUpToHtmlElement(),
e._insertElement(t,wD.HTML),e.insertionMode=RI.IN_FRAMESET)}(e,t);break
;case CD.TEXTAREA:!function(e,t){
e._insertElement(t,wD.HTML),e.skipNextNewLine=!0,
e.tokenizer.state=FD.RCDATA,e.originalInsertionMode=e.insertionMode,
e.framesetOk=!1,e.insertionMode=RI.TEXT}(e,t);break;case CD.NOSCRIPT:
e.options.scriptingEnabled?uM(e,t):dM(e,t);break;case CD.PLAINTEXT:
!function(e,t){
e.openElements.hasInButtonScope(CD.P)&&e._closePElement(),e._insertElement(t,wD.HTML),
e.tokenizer.state=FD.PLAINTEXT}(e,t);break;case CD.COL:case CD.TH:case CD.TD:
case CD.TR:case CD.HEAD:case CD.FRAME:case CD.TBODY:case CD.TFOOT:case CD.THEAD:
case CD.CAPTION:case CD.COLGROUP:break;default:dM(e,t)}}function hM(e,t){
const n=t.tagName,r=t.tagID;for(let o=e.openElements.stackTop;o>0;o--){
const t=e.openElements.items[o],a=e.openElements.tagIDs[o]
;if(r===a&&(r!==CD.UNKNOWN||e.treeAdapter.getTagName(t)===n)){
e.openElements.generateImpliedEndTagsWithExclusion(r),
e.openElements.stackTop>=o&&e.openElements.shortenToLength(o);break}
if(e._isSpecialElement(t,a))break}}function fM(e,t){switch(t.tagID){case CD.A:
case CD.B:case CD.I:case CD.S:case CD.U:case CD.EM:case CD.TT:case CD.BIG:
case CD.CODE:case CD.FONT:case CD.NOBR:case CD.SMALL:case CD.STRIKE:
case CD.STRONG:WI(e,t);break;case CD.P:!function(e){
e.openElements.hasInButtonScope(CD.P)||e._insertFakeElement(ED.P,CD.P),
e._closePElement()}(e);break;case CD.DL:case CD.UL:case CD.OL:case CD.DIR:
case CD.DIV:case CD.NAV:case CD.PRE:case CD.MAIN:case CD.MENU:case CD.ASIDE:
case CD.BUTTON:case CD.CENTER:case CD.FIGURE:case CD.FOOTER:case CD.HEADER:
case CD.HGROUP:case CD.DIALOG:case CD.ADDRESS:case CD.ARTICLE:case CD.DETAILS:
case CD.SEARCH:case CD.SECTION:case CD.SUMMARY:case CD.LISTING:case CD.FIELDSET:
case CD.BLOCKQUOTE:case CD.FIGCAPTION:!function(e,t){const n=t.tagID
;e.openElements.hasInScope(n)&&(e.openElements.generateImpliedEndTags(),
e.openElements.popUntilTagNamePopped(n))}(e,t);break;case CD.LI:!function(e){
e.openElements.hasInListItemScope(CD.LI)&&(e.openElements.generateImpliedEndTagsWithExclusion(CD.LI),
e.openElements.popUntilTagNamePopped(CD.LI))}(e);break;case CD.DD:case CD.DT:
!function(e,t){const n=t.tagID
;e.openElements.hasInScope(n)&&(e.openElements.generateImpliedEndTagsWithExclusion(n),
e.openElements.popUntilTagNamePopped(n))}(e,t);break;case CD.H1:case CD.H2:
case CD.H3:case CD.H4:case CD.H5:case CD.H6:!function(e){
e.openElements.hasNumberedHeaderInScope()&&(e.openElements.generateImpliedEndTags(),
e.openElements.popUntilNumberedHeaderPopped())}(e);break;case CD.BR:
!function(e){
e._reconstructActiveFormattingElements(),e._insertFakeElement(ED.BR,CD.BR),
e.openElements.pop(),e.framesetOk=!1}(e);break;case CD.BODY:!function(e,t){
if(e.openElements.hasInScope(CD.BODY)&&(e.insertionMode=RI.AFTER_BODY,
e.options.sourceCodeLocationInfo)){
const n=e.openElements.tryPeekProperlyNestedBodyElement()
;n&&e._setEndLocation(n,t)}}(e,t);break;case CD.HTML:!function(e,t){
e.openElements.hasInScope(CD.BODY)&&(e.insertionMode=RI.AFTER_BODY,IM(e,t))
}(e,t);break;case CD.FORM:!function(e){
const t=e.openElements.tmplCount>0,{formElement:n}=e
;t||(e.formElement=null),(n||t)&&e.openElements.hasInScope(CD.FORM)&&(e.openElements.generateImpliedEndTags(),
t?e.openElements.popUntilTagNamePopped(CD.FORM):n&&e.openElements.remove(n))}(e)
;break;case CD.APPLET:case CD.OBJECT:case CD.MARQUEE:!function(e,t){
const n=t.tagID
;e.openElements.hasInScope(n)&&(e.openElements.generateImpliedEndTags(),
e.openElements.popUntilTagNamePopped(n),
e.activeFormattingElements.clearToLastMarker())}(e,t);break;case CD.TEMPLATE:
tM(e,t);break;default:hM(e,t)}}function mM(e,t){
e.tmplInsertionModeStack.length>0?DM(e,t):GI(e,t)}function gM(e,t){
if(void 0!==e.openElements.currentTagId&&jI.has(e.openElements.currentTagId))switch(e.pendingCharacterTokens.length=0,
e.hasNonWhitespacePendingCharacterToken=!1,
e.originalInsertionMode=e.insertionMode,
e.insertionMode=RI.IN_TABLE_TEXT,t.type){case lD.CHARACTER:wM(e,t);break
;case lD.WHITESPACE_CHARACTER:OM(e,t)}else yM(e,t)}function vM(e,t){
switch(t.tagID){case CD.TD:case CD.TH:case CD.TR:!function(e,t){
e.openElements.clearBackToTableContext(),
e._insertFakeElement(ED.TBODY,CD.TBODY),e.insertionMode=RI.IN_TABLE_BODY,TM(e,t)
}(e,t);break;case CD.STYLE:case CD.SCRIPT:case CD.TEMPLATE:eM(e,t);break
;case CD.COL:!function(e,t){
e.openElements.clearBackToTableContext(),e._insertFakeElement(ED.COLGROUP,CD.COLGROUP),
e.insertionMode=RI.IN_COLUMN_GROUP,SM(e,t)}(e,t);break;case CD.FORM:
!function(e,t){
e.formElement||0!==e.openElements.tmplCount||(e._insertElement(t,wD.HTML),
e.formElement=e.openElements.current,e.openElements.pop())}(e,t);break
;case CD.TABLE:!function(e,t){
e.openElements.hasInTableScope(CD.TABLE)&&(e.openElements.popUntilTagNamePopped(CD.TABLE),
e._resetInsertionMode(),e._processStartTag(t))}(e,t);break;case CD.TBODY:
case CD.TFOOT:case CD.THEAD:!function(e,t){
e.openElements.clearBackToTableContext(),
e._insertElement(t,wD.HTML),e.insertionMode=RI.IN_TABLE_BODY}(e,t);break
;case CD.INPUT:!function(e,t){
cM(t)?e._appendElement(t,wD.HTML):yM(e,t),t.ackSelfClosing=!0}(e,t);break
;case CD.CAPTION:!function(e,t){
e.openElements.clearBackToTableContext(),e.activeFormattingElements.insertMarker(),
e._insertElement(t,wD.HTML),e.insertionMode=RI.IN_CAPTION}(e,t);break
;case CD.COLGROUP:!function(e,t){
e.openElements.clearBackToTableContext(),e._insertElement(t,wD.HTML),
e.insertionMode=RI.IN_COLUMN_GROUP}(e,t);break;default:yM(e,t)}}
function bM(e,t){switch(t.tagID){case CD.TABLE:
e.openElements.hasInTableScope(CD.TABLE)&&(e.openElements.popUntilTagNamePopped(CD.TABLE),
e._resetInsertionMode());break;case CD.TEMPLATE:tM(e,t);break;case CD.BODY:
case CD.CAPTION:case CD.COL:case CD.COLGROUP:case CD.HTML:case CD.TBODY:
case CD.TD:case CD.TFOOT:case CD.TH:case CD.THEAD:case CD.TR:break;default:
yM(e,t)}}function yM(e,t){const n=e.fosterParentingEnabled
;e.fosterParentingEnabled=!0,aM(e,t),e.fosterParentingEnabled=n}
function OM(e,t){e.pendingCharacterTokens.push(t)}function wM(e,t){
e.pendingCharacterTokens.push(t),e.hasNonWhitespacePendingCharacterToken=!0}
function xM(e,t){let n=0
;if(e.hasNonWhitespacePendingCharacterToken)for(;n<e.pendingCharacterTokens.length;n++)yM(e,e.pendingCharacterTokens[n]);else for(;n<e.pendingCharacterTokens.length;n++)e._insertCharacters(e.pendingCharacterTokens[n])
;e.insertionMode=e.originalInsertionMode,e._processToken(t)}
const kM=new Set([CD.CAPTION,CD.COL,CD.COLGROUP,CD.TBODY,CD.TD,CD.TFOOT,CD.TH,CD.THEAD,CD.TR])
;function SM(e,t){switch(t.tagID){case CD.HTML:pM(e,t);break;case CD.COL:
e._appendElement(t,wD.HTML),t.ackSelfClosing=!0;break;case CD.TEMPLATE:eM(e,t)
;break;default:_M(e,t)}}function _M(e,t){
e.openElements.currentTagId===CD.COLGROUP&&(e.openElements.pop(),
e.insertionMode=RI.IN_TABLE,e._processToken(t))}function TM(e,t){
switch(t.tagID){case CD.TR:
e.openElements.clearBackToTableBodyContext(),e._insertElement(t,wD.HTML),
e.insertionMode=RI.IN_ROW;break;case CD.TH:case CD.TD:
e.openElements.clearBackToTableBodyContext(),
e._insertFakeElement(ED.TR,CD.TR),e.insertionMode=RI.IN_ROW,AM(e,t);break
;case CD.CAPTION:case CD.COL:case CD.COLGROUP:case CD.TBODY:case CD.TFOOT:
case CD.THEAD:
e.openElements.hasTableBodyContextInTableScope()&&(e.openElements.clearBackToTableBodyContext(),
e.openElements.pop(),e.insertionMode=RI.IN_TABLE,vM(e,t));break;default:vM(e,t)}
}function EM(e,t){const n=t.tagID;switch(t.tagID){case CD.TBODY:case CD.TFOOT:
case CD.THEAD:
e.openElements.hasInTableScope(n)&&(e.openElements.clearBackToTableBodyContext(),
e.openElements.pop(),e.insertionMode=RI.IN_TABLE);break;case CD.TABLE:
e.openElements.hasTableBodyContextInTableScope()&&(e.openElements.clearBackToTableBodyContext(),
e.openElements.pop(),e.insertionMode=RI.IN_TABLE,bM(e,t));break;case CD.BODY:
case CD.CAPTION:case CD.COL:case CD.COLGROUP:case CD.HTML:case CD.TD:case CD.TH:
case CD.TR:break;default:bM(e,t)}}function AM(e,t){switch(t.tagID){case CD.TH:
case CD.TD:
e.openElements.clearBackToTableRowContext(),e._insertElement(t,wD.HTML),
e.insertionMode=RI.IN_CELL,e.activeFormattingElements.insertMarker();break
;case CD.CAPTION:case CD.COL:case CD.COLGROUP:case CD.TBODY:case CD.TFOOT:
case CD.THEAD:case CD.TR:
e.openElements.hasInTableScope(CD.TR)&&(e.openElements.clearBackToTableRowContext(),
e.openElements.pop(),e.insertionMode=RI.IN_TABLE_BODY,TM(e,t));break;default:
vM(e,t)}}function CM(e,t){switch(t.tagID){case CD.TR:
e.openElements.hasInTableScope(CD.TR)&&(e.openElements.clearBackToTableRowContext(),
e.openElements.pop(),e.insertionMode=RI.IN_TABLE_BODY);break;case CD.TABLE:
e.openElements.hasInTableScope(CD.TR)&&(e.openElements.clearBackToTableRowContext(),
e.openElements.pop(),e.insertionMode=RI.IN_TABLE_BODY,EM(e,t));break
;case CD.TBODY:case CD.TFOOT:case CD.THEAD:
(e.openElements.hasInTableScope(t.tagID)||e.openElements.hasInTableScope(CD.TR))&&(e.openElements.clearBackToTableRowContext(),
e.openElements.pop(),e.insertionMode=RI.IN_TABLE_BODY,EM(e,t));break
;case CD.BODY:case CD.CAPTION:case CD.COL:case CD.COLGROUP:case CD.HTML:
case CD.TD:case CD.TH:break;default:bM(e,t)}}function $M(e,t){switch(t.tagID){
case CD.HTML:pM(e,t);break;case CD.OPTION:
e.openElements.currentTagId===CD.OPTION&&e.openElements.pop(),
e._insertElement(t,wD.HTML);break;case CD.OPTGROUP:
e.openElements.currentTagId===CD.OPTION&&e.openElements.pop(),
e.openElements.currentTagId===CD.OPTGROUP&&e.openElements.pop(),
e._insertElement(t,wD.HTML);break;case CD.HR:
e.openElements.currentTagId===CD.OPTION&&e.openElements.pop(),
e.openElements.currentTagId===CD.OPTGROUP&&e.openElements.pop(),
e._appendElement(t,wD.HTML),t.ackSelfClosing=!0;break;case CD.INPUT:
case CD.KEYGEN:case CD.TEXTAREA:case CD.SELECT:
e.openElements.hasInSelectScope(CD.SELECT)&&(e.openElements.popUntilTagNamePopped(CD.SELECT),
e._resetInsertionMode(),t.tagID!==CD.SELECT&&e._processStartTag(t));break
;case CD.SCRIPT:case CD.TEMPLATE:eM(e,t)}}function PM(e,t){switch(t.tagID){
case CD.OPTGROUP:
e.openElements.stackTop>0&&e.openElements.currentTagId===CD.OPTION&&e.openElements.tagIDs[e.openElements.stackTop-1]===CD.OPTGROUP&&e.openElements.pop(),
e.openElements.currentTagId===CD.OPTGROUP&&e.openElements.pop();break
;case CD.OPTION:e.openElements.currentTagId===CD.OPTION&&e.openElements.pop()
;break;case CD.SELECT:
e.openElements.hasInSelectScope(CD.SELECT)&&(e.openElements.popUntilTagNamePopped(CD.SELECT),
e._resetInsertionMode());break;case CD.TEMPLATE:tM(e,t)}}function DM(e,t){
e.openElements.tmplCount>0?(e.openElements.popUntilTagNamePopped(CD.TEMPLATE),
e.activeFormattingElements.clearToLastMarker(),e.tmplInsertionModeStack.shift(),
e._resetInsertionMode(),e.onEof(t)):GI(e,t)}function IM(e,t){var n
;if(t.tagID===CD.HTML){
if(e.fragmentContext||(e.insertionMode=RI.AFTER_AFTER_BODY),
e.options.sourceCodeLocationInfo&&e.openElements.tagIDs[0]===CD.HTML){
e._setEndLocation(e.openElements.items[0],t);const r=e.openElements.items[1]
;r&&!(null===(n=e.treeAdapter.getNodeSourceCodeLocation(r))||void 0===n?void 0:n.endTag)&&e._setEndLocation(r,t)
}}else MM(e,t)}function MM(e,t){e.insertionMode=RI.IN_BODY,aM(e,t)}
function NM(e,t){e.insertionMode=RI.IN_BODY,aM(e,t)}function RM(e){
for(;e.treeAdapter.getNamespaceURI(e.openElements.current)!==wD.HTML&&void 0!==e.openElements.currentTagId&&!e._isIntegrationPoint(e.openElements.currentTagId,e.openElements.current);)e.openElements.pop()
}function LM(e,t){return zI.parse(e,t)}function BM(e,t,n){
"string"==typeof e&&(n=t,t=e,e=null);const r=zI.getFragmentParser(e,n)
;return r.tokenizer.write(t,!0),r.getFragment()}function jM(e){
return e&&"object"==typeof e?"position"in e||"type"in e?zM(e.position):"start"in e||"end"in e?zM(e):"line"in e||"column"in e?UM(e):"":""
}function UM(e){return FM(e&&e.line)+":"+FM(e&&e.column)}function zM(e){
return UM(e&&e.start)+"-"+UM(e&&e.end)}function FM(e){
return e&&"number"==typeof e?e:1}
ED.AREA,ED.BASE,ED.BASEFONT,ED.BGSOUND,ED.BR,ED.COL,
ED.EMBED,ED.FRAME,ED.HR,ED.IMG,
ED.INPUT,ED.KEYGEN,ED.LINK,ED.META,ED.PARAM,ED.SOURCE,ED.TRACK,ED.WBR
;class ZM extends Error{constructor(e,t,n){
super(),"string"==typeof t&&(n=t,t=void 0);let r="",o={},a=!1
;if(t&&(o="line"in t&&"column"in t||"start"in t&&"end"in t?{place:t
}:"type"in t?{ancestors:[t],place:t.position}:{...t
}),"string"==typeof e?r=e:!o.cause&&e&&(a=!0,
r=e.message,o.cause=e),!o.ruleId&&!o.source&&"string"==typeof n){
const e=n.indexOf(":")
;-1===e?o.ruleId=n:(o.source=n.slice(0,e),o.ruleId=n.slice(e+1))}
if(!o.place&&o.ancestors&&o.ancestors){const e=o.ancestors[o.ancestors.length-1]
;e&&(o.place=e.position)}
const i=o.place&&"start"in o.place?o.place.start:o.place
;this.ancestors=o.ancestors||void 0,
this.cause=o.cause||void 0,this.column=i?i.column:void 0,
this.fatal=void 0,this.file,
this.message=r,this.line=i?i.line:void 0,this.name=jM(o.place)||"1:1",
this.place=o.place||void 0,
this.reason=this.message,this.ruleId=o.ruleId||void 0,
this.source=o.source||void 0,
this.stack=a&&o.cause&&"string"==typeof o.cause.stack?o.cause.stack:"",
this.actual,this.expected,this.note,this.url}}
ZM.prototype.file="",ZM.prototype.name="",
ZM.prototype.reason="",ZM.prototype.message="",
ZM.prototype.stack="",ZM.prototype.column=void 0,
ZM.prototype.line=void 0,ZM.prototype.ancestors=void 0,
ZM.prototype.cause=void 0,
ZM.prototype.fatal=void 0,ZM.prototype.place=void 0,ZM.prototype.ruleId=void 0,
ZM.prototype.source=void 0;const QM={basename:function(e,t){
if(void 0!==t&&"string"!=typeof t)throw new TypeError('"ext" argument must be a string')
;HM(e);let n,r=0,o=-1,a=e.length
;if(void 0===t||0===t.length||t.length>e.length){
for(;a--;)if(47===e.codePointAt(a)){if(n){r=a+1;break}}else o<0&&(n=!0,o=a+1)
;return o<0?"":e.slice(r,o)}if(t===e)return"";let i=-1,s=t.length-1
;for(;a--;)if(47===e.codePointAt(a)){if(n){r=a+1;break}
}else i<0&&(n=!0,i=a+1),s>-1&&(e.codePointAt(a)===t.codePointAt(s--)?s<0&&(o=a):(s=-1,
o=i));r===o?o=i:o<0&&(o=e.length);return e.slice(r,o)},dirname:function(e){
if(HM(e),0===e.length)return".";let t,n=-1,r=e.length
;for(;--r;)if(47===e.codePointAt(r)){if(t){n=r;break}}else t||(t=!0)
;return n<0?47===e.codePointAt(0)?"/":".":1===n&&47===e.codePointAt(0)?"//":e.slice(0,n)
},extname:function(e){HM(e);let t,n=e.length,r=-1,o=0,a=-1,i=0;for(;n--;){
const s=e.codePointAt(n)
;if(47!==s)r<0&&(t=!0,r=n+1),46===s?a<0?a=n:1!==i&&(i=1):a>-1&&(i=-1);else if(t){
o=n+1;break}}if(a<0||r<0||0===i||1===i&&a===r-1&&a===o+1)return""
;return e.slice(a,r)},join:function(...e){let t,n=-1
;for(;++n<e.length;)HM(e[n]),e[n]&&(t=void 0===t?e[n]:t+"/"+e[n])
;return void 0===t?".":function(e){HM(e);const t=47===e.codePointAt(0)
;let n=function(e,t){let n,r,o="",a=0,i=-1,s=0,l=-1;for(;++l<=e.length;){
if(l<e.length)n=e.codePointAt(l);else{if(47===n)break;n=47}if(47===n){
if(i===l-1||1===s);else if(i!==l-1&&2===s){
if(o.length<2||2!==a||46!==o.codePointAt(o.length-1)||46!==o.codePointAt(o.length-2))if(o.length>2){
if(r=o.lastIndexOf("/"),r!==o.length-1){
r<0?(o="",a=0):(o=o.slice(0,r),a=o.length-1-o.lastIndexOf("/")),i=l,s=0;continue
}}else if(o.length>0){o="",a=0,i=l,s=0;continue}
t&&(o=o.length>0?o+"/..":"..",a=2)
}else o.length>0?o+="/"+e.slice(i+1,l):o=e.slice(i+1,l),a=l-i-1;i=l,s=0
}else 46===n&&s>-1?s++:s=-1}return o}(e,!t);0!==n.length||t||(n=".")
;n.length>0&&47===e.codePointAt(e.length-1)&&(n+="/");return t?"/"+n:n}(t)},
sep:"/"};function HM(e){
if("string"!=typeof e)throw new TypeError("Path must be a string. Received "+JSON.stringify(e))
}const VM={cwd:function(){return"/"}};function qM(e){
return Boolean(null!==e&&"object"==typeof e&&"href"in e&&e.href&&"protocol"in e&&e.protocol&&void 0===e.auth)
}function WM(e){if("string"==typeof e)e=new URL(e);else if(!qM(e)){
const t=new TypeError('The "path" argument must be of type string or an instance of URL. Received `'+e+"`")
;throw t.code="ERR_INVALID_ARG_TYPE",t}if("file:"!==e.protocol){
const e=new TypeError("The URL must be of scheme file")
;throw e.code="ERR_INVALID_URL_SCHEME",e}return function(e){if(""!==e.hostname){
const e=new TypeError('File URL host must be "localhost" or empty on darwin')
;throw e.code="ERR_INVALID_FILE_URL_HOST",e}const t=e.pathname;let n=-1
;for(;++n<t.length;)if(37===t.codePointAt(n)&&50===t.codePointAt(n+1)){
const e=t.codePointAt(n+2);if(70===e||102===e){
const e=new TypeError("File URL path must not include encoded / characters")
;throw e.code="ERR_INVALID_FILE_URL_PATH",e}}return decodeURIComponent(t)}(e)}
const XM=["history","path","basename","stem","extname","dirname"];class GM{
constructor(e){let t;t=e?qM(e)?{path:e}:"string"==typeof e||function(e){
return Boolean(e&&"object"==typeof e&&"byteLength"in e&&"byteOffset"in e)}(e)?{
value:e
}:e:{},this.cwd="cwd"in t?"":VM.cwd(),this.data={},this.history=[],this.messages=[],
this.value,this.map,this.result,this.stored;let n,r=-1;for(;++r<XM.length;){
const e=XM[r]
;e in t&&void 0!==t[e]&&null!==t[e]&&(this[e]="history"===e?[...t[e]]:t[e])}
for(n in t)XM.includes(n)||(this[n]=t[n])}get basename(){
return"string"==typeof this.path?QM.basename(this.path):void 0}set basename(e){
KM(e,"basename"),YM(e,"basename"),this.path=QM.join(this.dirname||"",e)}
get dirname(){return"string"==typeof this.path?QM.dirname(this.path):void 0}
set dirname(e){
JM(this.basename,"dirname"),this.path=QM.join(e||"",this.basename)}
get extname(){return"string"==typeof this.path?QM.extname(this.path):void 0}
set extname(e){if(YM(e,"extname"),JM(this.dirname,"extname"),e){
if(46!==e.codePointAt(0))throw new Error("`extname` must start with `.`")
;if(e.includes(".",1))throw new Error("`extname` cannot contain multiple dots")}
this.path=QM.join(this.dirname,this.stem+(e||""))}get path(){
return this.history[this.history.length-1]}set path(e){
qM(e)&&(e=WM(e)),KM(e,"path"),this.path!==e&&this.history.push(e)}get stem(){
return"string"==typeof this.path?QM.basename(this.path,this.extname):void 0}
set stem(e){
KM(e,"stem"),YM(e,"stem"),this.path=QM.join(this.dirname||"",e+(this.extname||""))
}fail(e,t,n){const r=this.message(e,t,n);throw r.fatal=!0,r}info(e,t,n){
const r=this.message(e,t,n);return r.fatal=void 0,r}message(e,t,n){
const r=new ZM(e,t,n)
;return this.path&&(r.name=this.path+":"+r.name,r.file=this.path),
r.fatal=!1,this.messages.push(r),r}toString(e){if(void 0===this.value)return""
;if("string"==typeof this.value)return this.value
;return new TextDecoder(e||void 0).decode(this.value)}}function YM(e,t){
if(e&&e.includes(QM.sep))throw new Error("`"+t+"` cannot be a path: did not expect `"+QM.sep+"`")
}function KM(e,t){if(!e)throw new Error("`"+t+"` cannot be empty")}
function JM(e,t){
if(!e)throw new Error("Setting `"+t+"` requires `path` to be set too")}
const eN={abandonedHeadElementChild:{
reason:"Unexpected metadata element after head",
description:"Unexpected element after head. Expected the element before `</head>`",
url:!1},abruptClosingOfEmptyComment:{
reason:"Unexpected abruptly closed empty comment",
description:"Unexpected `>` or `->`. Expected `--\x3e` to close comments"},
abruptDoctypePublicIdentifier:{
reason:"Unexpected abruptly closed public identifier",
description:"Unexpected `>`. Expected a closing `\"` or `'` after the public identifier"
},abruptDoctypeSystemIdentifier:{
reason:"Unexpected abruptly closed system identifier",
description:"Unexpected `>`. Expected a closing `\"` or `'` after the identifier identifier"
},absenceOfDigitsInNumericCharacterReference:{
reason:"Unexpected non-digit at start of numeric character reference",
description:"Unexpected `%c`. Expected `[0-9]` for decimal references or `[0-9a-fA-F]` for hexadecimal references"
},cdataInHtmlContent:{reason:"Unexpected CDATA section in HTML",
description:"Unexpected `<![CDATA[` in HTML. Remove it, use a comment, or encode special characters instead"
},characterReferenceOutsideUnicodeRange:{
reason:"Unexpected too big numeric character reference",
description:"Unexpectedly high character reference. Expected character references to be at most hexadecimal 10ffff (or decimal 1114111)"
},closingOfElementWithOpenChildElements:{
reason:"Unexpected closing tag with open child elements",
description:"Unexpectedly closing tag. Expected other tags to be closed first",
url:!1},controlCharacterInInputStream:{reason:"Unexpected control character",
description:"Unexpected control character `%x`. Expected a non-control code point, 0x00, or ASCII whitespace"
},controlCharacterReference:{reason:"Unexpected control character reference",
description:"Unexpectedly control character in reference. Expected a non-control code point, 0x00, or ASCII whitespace"
},disallowedContentInNoscriptInHead:{
reason:"Disallowed content inside `<noscript>` in `<head>`",
description:"Unexpected text character `%c`. Only use text in `<noscript>`s in `<body>`",
url:!1},duplicateAttribute:{reason:"Unexpected duplicate attribute",
description:"Unexpectedly double attribute. Expected attributes to occur only once"
},endTagWithAttributes:{reason:"Unexpected attribute on closing tag",
description:"Unexpected attribute. Expected `>` instead"},
endTagWithTrailingSolidus:{reason:"Unexpected slash at end of closing tag",
description:"Unexpected `%c-1`. Expected `>` instead"},
endTagWithoutMatchingOpenElement:{reason:"Unexpected unopened end tag",
description:"Unexpected end tag. Expected no end tag or another end tag",url:!1
},eofBeforeTagName:{reason:"Unexpected end of file",
description:"Unexpected end of file. Expected tag name instead"},eofInCdata:{
reason:"Unexpected end of file in CDATA",
description:"Unexpected end of file. Expected `]]>` to close the CDATA"},
eofInComment:{reason:"Unexpected end of file in comment",
description:"Unexpected end of file. Expected `--\x3e` to close the comment"},
eofInDoctype:{reason:"Unexpected end of file in doctype",
description:"Unexpected end of file. Expected a valid doctype (such as `<!doctype html>`)"
},eofInElementThatCanContainOnlyText:{
reason:"Unexpected end of file in element that can only contain text",
description:"Unexpected end of file. Expected text or a closing tag",url:!1},
eofInScriptHtmlCommentLikeText:{
reason:"Unexpected end of file in comment inside script",
description:"Unexpected end of file. Expected `--\x3e` to close the comment"},
eofInTag:{reason:"Unexpected end of file in tag",
description:"Unexpected end of file. Expected `>` to close the tag"},
incorrectlyClosedComment:{reason:"Incorrectly closed comment",
description:"Unexpected `%c-1`. Expected `--\x3e` to close the comment"},
incorrectlyOpenedComment:{reason:"Incorrectly opened comment",
description:"Unexpected `%c`. Expected `\x3c!--` to open the comment"},
invalidCharacterSequenceAfterDoctypeName:{
reason:"Invalid sequence after doctype name",
description:"Unexpected sequence at `%c`. Expected `public` or `system`"},
invalidFirstCharacterOfTagName:{reason:"Invalid first character in tag name",
description:"Unexpected `%c`. Expected an ASCII letter instead"},
misplacedDoctype:{reason:"Misplaced doctype",
description:"Unexpected doctype. Expected doctype before head",url:!1},
misplacedStartTagForHeadElement:{reason:"Misplaced `<head>` start tag",
description:"Unexpected start tag `<head>`. Expected `<head>` directly after doctype",
url:!1},missingAttributeValue:{reason:"Missing attribute value",
description:"Unexpected `%c-1`. Expected an attribute value or no `%c-1` instead"
},missingDoctype:{reason:"Missing doctype before other content",
description:"Expected a `<!doctype html>` before anything else",url:!1},
missingDoctypeName:{reason:"Missing doctype name",
description:"Unexpected doctype end at `%c`. Expected `html` instead"},
missingDoctypePublicIdentifier:{reason:"Missing public identifier in doctype",
description:"Unexpected `%c`. Expected identifier for `public` instead"},
missingDoctypeSystemIdentifier:{reason:"Missing system identifier in doctype",
description:'Unexpected `%c`. Expected identifier for `system` instead (suggested: `"about:legacy-compat"`)'
},missingEndTagName:{reason:"Missing name in end tag",
description:"Unexpected `%c`. Expected an ASCII letter instead"},
missingQuoteBeforeDoctypePublicIdentifier:{
reason:"Missing quote before public identifier in doctype",
description:"Unexpected `%c`. Expected `\"` or `'` instead"},
missingQuoteBeforeDoctypeSystemIdentifier:{
reason:"Missing quote before system identifier in doctype",
description:"Unexpected `%c`. Expected `\"` or `'` instead"},
missingSemicolonAfterCharacterReference:{
reason:"Missing semicolon after character reference",
description:"Unexpected `%c`. Expected `;` instead"},
missingWhitespaceAfterDoctypePublicKeyword:{
reason:"Missing whitespace after public identifier in doctype",
description:"Unexpected `%c`. Expected ASCII whitespace instead"},
missingWhitespaceAfterDoctypeSystemKeyword:{
reason:"Missing whitespace after system identifier in doctype",
description:"Unexpected `%c`. Expected ASCII whitespace instead"},
missingWhitespaceBeforeDoctypeName:{
reason:"Missing whitespace before doctype name",
description:"Unexpected `%c`. Expected ASCII whitespace instead"},
missingWhitespaceBetweenAttributes:{
reason:"Missing whitespace between attributes",
description:"Unexpected `%c`. Expected ASCII whitespace instead"},
missingWhitespaceBetweenDoctypePublicAndSystemIdentifiers:{
reason:"Missing whitespace between public and system identifiers in doctype",
description:"Unexpected `%c`. Expected ASCII whitespace instead"},
nestedComment:{reason:"Unexpected nested comment",
description:"Unexpected `\x3c!--`. Expected `--\x3e`"},nestedNoscriptInHead:{
reason:"Unexpected nested `<noscript>` in `<head>`",
description:"Unexpected `<noscript>`. Expected a closing tag or a meta element",
url:!1},nonConformingDoctype:{
reason:"Unexpected non-conforming doctype declaration",
description:'Expected `<!doctype html>` or `<!doctype html system "about:legacy-compat">`',
url:!1},nonVoidHtmlElementStartTagWithTrailingSolidus:{
reason:"Unexpected trailing slash on start tag of non-void element",
description:"Unexpected `/`. Expected `>` instead"},
noncharacterCharacterReference:{
reason:"Unexpected noncharacter code point referenced by character reference",
description:"Unexpected code point. Do not use noncharacters in HTML"},
noncharacterInInputStream:{reason:"Unexpected noncharacter character",
description:"Unexpected code point `%x`. Do not use noncharacters in HTML"},
nullCharacterReference:{
reason:"Unexpected NULL character referenced by character reference",
description:"Unexpected code point. Do not use NULL characters in HTML"},
openElementsLeftAfterEof:{reason:"Unexpected end of file",
description:"Unexpected end of file. Expected closing tag instead",url:!1},
surrogateCharacterReference:{
reason:"Unexpected surrogate character referenced by character reference",
description:"Unexpected code point. Do not use lone surrogate characters in HTML"
},surrogateInInputStream:{reason:"Unexpected surrogate character",
description:"Unexpected code point `%x`. Do not use lone surrogate characters in HTML"
},unexpectedCharacterAfterDoctypeSystemIdentifier:{
reason:"Invalid character after system identifier in doctype",
description:"Unexpected character at `%c`. Expected `>`"},
unexpectedCharacterInAttributeName:{
reason:"Unexpected character in attribute name",
description:"Unexpected `%c`. Expected whitespace, `/`, `>`, `=`, or probably an ASCII letter"
},unexpectedCharacterInUnquotedAttributeValue:{
reason:"Unexpected character in unquoted attribute value",
description:"Unexpected `%c`. Quote the attribute value to include it"},
unexpectedEqualsSignBeforeAttributeName:{
reason:"Unexpected equals sign before attribute name",
description:"Unexpected `%c`. Add an attribute name before it"},
unexpectedNullCharacter:{reason:"Unexpected NULL character",
description:"Unexpected code point `%x`. Do not use NULL characters in HTML"},
unexpectedQuestionMarkInsteadOfTagName:{
reason:"Unexpected question mark instead of tag name",
description:"Unexpected `%c`. Expected an ASCII letter instead"},
unexpectedSolidusInTag:{reason:"Unexpected slash in tag",
description:"Unexpected `%c-1`. Expected it followed by `>` or in a quoted attribute value"
},unknownNamedCharacterReference:{
reason:"Unexpected unknown named character reference",
description:"Unexpected character reference. Expected known named character references"
}
},tN="https://html.spec.whatwg.org/multipage/parsing.html#parse-error-",nN=/-[a-z]/g,rN=/%c(?:([-+])(\d+))?/g,oN=/%x/g,aN={
2:!0,1:!1,0:null},iN={};function sN(e,t){
const n=t||iN,r=n.onerror,o=e instanceof GM?e:new GM(e),a=n.fragment?BM:LM,i=String(o),s=a(i,{
sourceCodeLocationInfo:!0,onParseError:n.onerror?function(e){
const t=e.code,a=function(e){return e.replace(nN,lN)
}(t),s=n[a],l=null==s||s,c="number"==typeof l?l:l?1:0;if(c){
const n=eN[a],i=new ZM(u(n.reason),{place:{start:{line:e.startLine,
column:e.startCol,offset:e.startOffset},end:{line:e.endLine,column:e.endCol,
offset:e.endOffset}},ruleId:t,source:"hast-util-from-html"})
;o.path&&(i.file=o.path,
i.name=o.path+":"+i.name),i.fatal=aN[c],i.note=u(n.description),
i.url=!1===n.url?void 0:tN+t,r(i)}function u(t){
return t.replace(rN,(function(t,n,r){
const o=(r?Number.parseInt(r,10):0)*("-"===n?-1:1);return function(e){
return"`"===e?"` ` `":e}(i.charAt(e.startOffset+o))})).replace(oN,(function(){
return t=i.charCodeAt(e.startOffset),"0x"+t.toString(16).toUpperCase();var t}))}
}:null,scriptingEnabled:!1});return UP(s,{file:o,space:n.space,verbose:n.verbose
})}function lN(e){return e.charAt(1).toUpperCase()}function cN(e){
const{emitParseErrors:t,...n}={...this.data("settings"),...e}
;this.parser=function(e,r){return sN(e,{...n,onerror:t?function(e){
r.path&&(e.name=r.path+":"+e.name,e.file=r.path),r.messages.push(e)}:void 0})}}
const uN=["area","base","basefont","bgsound","br","col","command","embed","frame","hr","image","img","input","keygen","link","meta","param","source","track","wbr"]
;let dN=class{constructor(e,t,n){this.normal=t,this.property=e,n&&(this.space=n)
}};function pN(e,t){const n={},r={}
;for(const o of e)Object.assign(n,o.property),Object.assign(r,o.normal)
;return new dN(n,r,t)}function hN(e){return e.toLowerCase()}
dN.prototype.normal={},dN.prototype.property={},dN.prototype.space=void 0
;class fN{constructor(e,t){this.attribute=t,this.property=e}}
fN.prototype.attribute="",
fN.prototype.booleanish=!1,fN.prototype.boolean=!1,fN.prototype.commaOrSpaceSeparated=!1,
fN.prototype.commaSeparated=!1,
fN.prototype.defined=!1,fN.prototype.mustUseProperty=!1,
fN.prototype.number=!1,fN.prototype.overloadedBoolean=!1,
fN.prototype.property="",
fN.prototype.spaceSeparated=!1,fN.prototype.space=void 0;let mN=0
;const gN=kN(),vN=kN(),bN=kN(),yN=kN(),ON=kN(),wN=kN(),xN=kN();function kN(){
return 2**++mN}const SN=Object.freeze(Object.defineProperty({__proto__:null,
boolean:gN,booleanish:vN,commaOrSpaceSeparated:xN,commaSeparated:wN,number:yN,
overloadedBoolean:bN,spaceSeparated:ON},Symbol.toStringTag,{value:"Module"
})),_N=Object.keys(SN);class TN extends fN{constructor(e,t,n,r){let o=-1
;if(super(e,t),EN(this,"space",r),"number"==typeof n)for(;++o<_N.length;){
const e=_N[o];EN(this,_N[o],(n&SN[e])===SN[e])}}}function EN(e,t,n){n&&(e[t]=n)}
function AN(e){const t={},n={};for(const[r,o]of Object.entries(e.properties)){
const a=new TN(r,e.transform(e.attributes||{},r),o,e.space)
;e.mustUseProperty&&e.mustUseProperty.includes(r)&&(a.mustUseProperty=!0),
t[r]=a,n[hN(r)]=r,n[hN(a.attribute)]=r}return new dN(t,n,e.space)}
TN.prototype.defined=!0;const CN=AN({properties:{ariaActiveDescendant:null,
ariaAtomic:vN,ariaAutoComplete:null,ariaBusy:vN,ariaChecked:vN,ariaColCount:yN,
ariaColIndex:yN,ariaColSpan:yN,ariaControls:ON,ariaCurrent:null,
ariaDescribedBy:ON,ariaDetails:null,ariaDisabled:vN,ariaDropEffect:ON,
ariaErrorMessage:null,ariaExpanded:vN,ariaFlowTo:ON,ariaGrabbed:vN,
ariaHasPopup:null,ariaHidden:vN,ariaInvalid:null,ariaKeyShortcuts:null,
ariaLabel:null,ariaLabelledBy:ON,ariaLevel:yN,ariaLive:null,ariaModal:vN,
ariaMultiLine:vN,ariaMultiSelectable:vN,ariaOrientation:null,ariaOwns:ON,
ariaPlaceholder:null,ariaPosInSet:yN,ariaPressed:vN,ariaReadOnly:vN,
ariaRelevant:null,ariaRequired:vN,ariaRoleDescription:ON,ariaRowCount:yN,
ariaRowIndex:yN,ariaRowSpan:yN,ariaSelected:vN,ariaSetSize:yN,ariaSort:null,
ariaValueMax:yN,ariaValueMin:yN,ariaValueNow:yN,ariaValueText:null,role:null},
transform:(e,t)=>"role"===t?t:"aria-"+t.slice(4).toLowerCase()})
;function $N(e,t){return t in e?e[t]:t}function PN(e,t){
return $N(e,t.toLowerCase())}const DN=AN({attributes:{
acceptcharset:"accept-charset",classname:"class",htmlfor:"for",
httpequiv:"http-equiv"},
mustUseProperty:["checked","multiple","muted","selected"],properties:{abbr:null,
accept:wN,acceptCharset:ON,accessKey:ON,action:null,allow:null,
allowFullScreen:gN,allowPaymentRequest:gN,allowUserMedia:gN,alt:null,as:null,
async:gN,autoCapitalize:null,autoComplete:ON,autoFocus:gN,autoPlay:gN,
blocking:ON,capture:null,charSet:null,checked:gN,cite:null,className:ON,cols:yN,
colSpan:null,content:null,contentEditable:vN,controls:gN,controlsList:ON,
coords:yN|wN,crossOrigin:null,data:null,dateTime:null,decoding:null,default:gN,
defer:gN,dir:null,dirName:null,disabled:gN,download:bN,draggable:vN,
encType:null,enterKeyHint:null,fetchPriority:null,form:null,formAction:null,
formEncType:null,formMethod:null,formNoValidate:gN,formTarget:null,headers:ON,
height:yN,hidden:bN,high:yN,href:null,hrefLang:null,htmlFor:ON,httpEquiv:ON,
id:null,imageSizes:null,imageSrcSet:null,inert:gN,inputMode:null,integrity:null,
is:null,isMap:gN,itemId:null,itemProp:ON,itemRef:ON,itemScope:gN,itemType:ON,
kind:null,label:null,lang:null,language:null,list:null,loading:null,loop:gN,
low:yN,manifest:null,max:null,maxLength:yN,media:null,method:null,min:null,
minLength:yN,multiple:gN,muted:gN,name:null,nonce:null,noModule:gN,
noValidate:gN,onAbort:null,onAfterPrint:null,onAuxClick:null,onBeforeMatch:null,
onBeforePrint:null,onBeforeToggle:null,onBeforeUnload:null,onBlur:null,
onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,
onClose:null,onContextLost:null,onContextMenu:null,onContextRestored:null,
onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,
onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,
onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,
onEmptied:null,onEnded:null,onError:null,onFocus:null,onFormData:null,
onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,
onKeyUp:null,onLanguageChange:null,onLoad:null,onLoadedData:null,
onLoadedMetadata:null,onLoadEnd:null,onLoadStart:null,onMessage:null,
onMessageError:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,
onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onOffline:null,
onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,
onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,
onRejectionHandled:null,onReset:null,onResize:null,onScroll:null,
onScrollEnd:null,onSecurityPolicyViolation:null,onSeeked:null,onSeeking:null,
onSelect:null,onSlotChange:null,onStalled:null,onStorage:null,onSubmit:null,
onSuspend:null,onTimeUpdate:null,onToggle:null,onUnhandledRejection:null,
onUnload:null,onVolumeChange:null,onWaiting:null,onWheel:null,open:gN,
optimum:yN,pattern:null,ping:ON,placeholder:null,playsInline:gN,popover:null,
popoverTarget:null,popoverTargetAction:null,poster:null,preload:null,
readOnly:gN,referrerPolicy:null,rel:ON,required:gN,reversed:gN,rows:yN,
rowSpan:yN,sandbox:ON,scope:null,scoped:gN,seamless:gN,selected:gN,
shadowRootClonable:gN,shadowRootDelegatesFocus:gN,shadowRootMode:null,
shape:null,size:yN,sizes:null,slot:null,span:yN,spellCheck:vN,src:null,
srcDoc:null,srcLang:null,srcSet:null,start:yN,step:null,style:null,tabIndex:yN,
target:null,title:null,translate:null,type:null,typeMustMatch:gN,useMap:null,
value:vN,width:yN,wrap:null,writingSuggestions:null,align:null,aLink:null,
archive:ON,axis:null,background:null,bgColor:null,border:yN,borderColor:null,
bottomMargin:yN,cellPadding:null,cellSpacing:null,char:null,charOff:null,
classId:null,clear:null,code:null,codeBase:null,codeType:null,color:null,
compact:gN,declare:gN,event:null,face:null,frame:null,frameBorder:null,
hSpace:yN,leftMargin:yN,link:null,longDesc:null,lowSrc:null,marginHeight:yN,
marginWidth:yN,noResize:gN,noHref:gN,noShade:gN,noWrap:gN,object:null,
profile:null,prompt:null,rev:null,rightMargin:yN,rules:null,scheme:null,
scrolling:vN,standby:null,summary:null,text:null,topMargin:yN,valueType:null,
version:null,vAlign:null,vLink:null,vSpace:yN,allowTransparency:null,
autoCorrect:null,autoSave:null,disablePictureInPicture:gN,
disableRemotePlayback:gN,prefix:null,property:null,results:yN,security:null,
unselectable:null},space:"html",transform:PN}),IN=AN({attributes:{
accentHeight:"accent-height",alignmentBaseline:"alignment-baseline",
arabicForm:"arabic-form",baselineShift:"baseline-shift",capHeight:"cap-height",
className:"class",clipPath:"clip-path",clipRule:"clip-rule",
colorInterpolation:"color-interpolation",
colorInterpolationFilters:"color-interpolation-filters",
colorProfile:"color-profile",colorRendering:"color-rendering",
crossOrigin:"crossorigin",dataType:"datatype",
dominantBaseline:"dominant-baseline",enableBackground:"enable-background",
fillOpacity:"fill-opacity",fillRule:"fill-rule",floodColor:"flood-color",
floodOpacity:"flood-opacity",fontFamily:"font-family",fontSize:"font-size",
fontSizeAdjust:"font-size-adjust",fontStretch:"font-stretch",
fontStyle:"font-style",fontVariant:"font-variant",fontWeight:"font-weight",
glyphName:"glyph-name",
glyphOrientationHorizontal:"glyph-orientation-horizontal",
glyphOrientationVertical:"glyph-orientation-vertical",hrefLang:"hreflang",
horizAdvX:"horiz-adv-x",horizOriginX:"horiz-origin-x",
horizOriginY:"horiz-origin-y",imageRendering:"image-rendering",
letterSpacing:"letter-spacing",lightingColor:"lighting-color",
markerEnd:"marker-end",markerMid:"marker-mid",markerStart:"marker-start",
navDown:"nav-down",navDownLeft:"nav-down-left",navDownRight:"nav-down-right",
navLeft:"nav-left",navNext:"nav-next",navPrev:"nav-prev",navRight:"nav-right",
navUp:"nav-up",navUpLeft:"nav-up-left",navUpRight:"nav-up-right",
onAbort:"onabort",onActivate:"onactivate",onAfterPrint:"onafterprint",
onBeforePrint:"onbeforeprint",onBegin:"onbegin",onCancel:"oncancel",
onCanPlay:"oncanplay",onCanPlayThrough:"oncanplaythrough",onChange:"onchange",
onClick:"onclick",onClose:"onclose",onCopy:"oncopy",onCueChange:"oncuechange",
onCut:"oncut",onDblClick:"ondblclick",onDrag:"ondrag",onDragEnd:"ondragend",
onDragEnter:"ondragenter",onDragExit:"ondragexit",onDragLeave:"ondragleave",
onDragOver:"ondragover",onDragStart:"ondragstart",onDrop:"ondrop",
onDurationChange:"ondurationchange",onEmptied:"onemptied",onEnd:"onend",
onEnded:"onended",onError:"onerror",onFocus:"onfocus",onFocusIn:"onfocusin",
onFocusOut:"onfocusout",onHashChange:"onhashchange",onInput:"oninput",
onInvalid:"oninvalid",onKeyDown:"onkeydown",onKeyPress:"onkeypress",
onKeyUp:"onkeyup",onLoad:"onload",onLoadedData:"onloadeddata",
onLoadedMetadata:"onloadedmetadata",onLoadStart:"onloadstart",
onMessage:"onmessage",onMouseDown:"onmousedown",onMouseEnter:"onmouseenter",
onMouseLeave:"onmouseleave",onMouseMove:"onmousemove",onMouseOut:"onmouseout",
onMouseOver:"onmouseover",onMouseUp:"onmouseup",onMouseWheel:"onmousewheel",
onOffline:"onoffline",onOnline:"ononline",onPageHide:"onpagehide",
onPageShow:"onpageshow",onPaste:"onpaste",onPause:"onpause",onPlay:"onplay",
onPlaying:"onplaying",onPopState:"onpopstate",onProgress:"onprogress",
onRateChange:"onratechange",onRepeat:"onrepeat",onReset:"onreset",
onResize:"onresize",onScroll:"onscroll",onSeeked:"onseeked",
onSeeking:"onseeking",onSelect:"onselect",onShow:"onshow",onStalled:"onstalled",
onStorage:"onstorage",onSubmit:"onsubmit",onSuspend:"onsuspend",
onTimeUpdate:"ontimeupdate",onToggle:"ontoggle",onUnload:"onunload",
onVolumeChange:"onvolumechange",onWaiting:"onwaiting",onZoom:"onzoom",
overlinePosition:"overline-position",overlineThickness:"overline-thickness",
paintOrder:"paint-order",panose1:"panose-1",pointerEvents:"pointer-events",
referrerPolicy:"referrerpolicy",renderingIntent:"rendering-intent",
shapeRendering:"shape-rendering",stopColor:"stop-color",
stopOpacity:"stop-opacity",strikethroughPosition:"strikethrough-position",
strikethroughThickness:"strikethrough-thickness",
strokeDashArray:"stroke-dasharray",strokeDashOffset:"stroke-dashoffset",
strokeLineCap:"stroke-linecap",strokeLineJoin:"stroke-linejoin",
strokeMiterLimit:"stroke-miterlimit",strokeOpacity:"stroke-opacity",
strokeWidth:"stroke-width",tabIndex:"tabindex",textAnchor:"text-anchor",
textDecoration:"text-decoration",textRendering:"text-rendering",
transformOrigin:"transform-origin",typeOf:"typeof",
underlinePosition:"underline-position",underlineThickness:"underline-thickness",
unicodeBidi:"unicode-bidi",unicodeRange:"unicode-range",
unitsPerEm:"units-per-em",vAlphabetic:"v-alphabetic",vHanging:"v-hanging",
vIdeographic:"v-ideographic",vMathematical:"v-mathematical",
vectorEffect:"vector-effect",vertAdvY:"vert-adv-y",vertOriginX:"vert-origin-x",
vertOriginY:"vert-origin-y",wordSpacing:"word-spacing",
writingMode:"writing-mode",xHeight:"x-height",playbackOrder:"playbackorder",
timelineBegin:"timelinebegin"},properties:{about:xN,accentHeight:yN,
accumulate:null,additive:null,alignmentBaseline:null,alphabetic:yN,amplitude:yN,
arabicForm:null,ascent:yN,attributeName:null,attributeType:null,azimuth:yN,
bandwidth:null,baselineShift:null,baseFrequency:null,baseProfile:null,bbox:null,
begin:null,bias:yN,by:null,calcMode:null,capHeight:yN,className:ON,clip:null,
clipPath:null,clipPathUnits:null,clipRule:null,color:null,
colorInterpolation:null,colorInterpolationFilters:null,colorProfile:null,
colorRendering:null,content:null,contentScriptType:null,contentStyleType:null,
crossOrigin:null,cursor:null,cx:null,cy:null,d:null,dataType:null,
defaultAction:null,descent:yN,diffuseConstant:yN,direction:null,display:null,
dur:null,divisor:yN,dominantBaseline:null,download:gN,dx:null,dy:null,
edgeMode:null,editable:null,elevation:yN,enableBackground:null,end:null,
event:null,exponent:yN,externalResourcesRequired:null,fill:null,fillOpacity:yN,
fillRule:null,filter:null,filterRes:null,filterUnits:null,floodColor:null,
floodOpacity:null,focusable:null,focusHighlight:null,fontFamily:null,
fontSize:null,fontSizeAdjust:null,fontStretch:null,fontStyle:null,
fontVariant:null,fontWeight:null,format:null,fr:null,from:null,fx:null,fy:null,
g1:wN,g2:wN,glyphName:wN,glyphOrientationHorizontal:null,
glyphOrientationVertical:null,glyphRef:null,gradientTransform:null,
gradientUnits:null,handler:null,hanging:yN,hatchContentUnits:null,
hatchUnits:null,height:null,href:null,hrefLang:null,horizAdvX:yN,
horizOriginX:yN,horizOriginY:yN,id:null,ideographic:yN,imageRendering:null,
initialVisibility:null,in:null,in2:null,intercept:yN,k:yN,k1:yN,k2:yN,k3:yN,
k4:yN,kernelMatrix:xN,kernelUnitLength:null,keyPoints:null,keySplines:null,
keyTimes:null,kerning:null,lang:null,lengthAdjust:null,letterSpacing:null,
lightingColor:null,limitingConeAngle:yN,local:null,markerEnd:null,
markerMid:null,markerStart:null,markerHeight:null,markerUnits:null,
markerWidth:null,mask:null,maskContentUnits:null,maskUnits:null,
mathematical:null,max:null,media:null,mediaCharacterEncoding:null,
mediaContentEncodings:null,mediaSize:yN,mediaTime:null,method:null,min:null,
mode:null,name:null,navDown:null,navDownLeft:null,navDownRight:null,
navLeft:null,navNext:null,navPrev:null,navRight:null,navUp:null,navUpLeft:null,
navUpRight:null,numOctaves:null,observer:null,offset:null,onAbort:null,
onActivate:null,onAfterPrint:null,onBeforePrint:null,onBegin:null,onCancel:null,
onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,
onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,
onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,
onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,
onEmptied:null,onEnd:null,onEnded:null,onError:null,onFocus:null,onFocusIn:null,
onFocusOut:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,
onKeyPress:null,onKeyUp:null,onLoad:null,onLoadedData:null,
onLoadedMetadata:null,onLoadStart:null,onMessage:null,onMouseDown:null,
onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,
onMouseOver:null,onMouseUp:null,onMouseWheel:null,onOffline:null,onOnline:null,
onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,
onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRepeat:null,
onReset:null,onResize:null,onScroll:null,onSeeked:null,onSeeking:null,
onSelect:null,onShow:null,onStalled:null,onStorage:null,onSubmit:null,
onSuspend:null,onTimeUpdate:null,onToggle:null,onUnload:null,
onVolumeChange:null,onWaiting:null,onZoom:null,opacity:null,operator:null,
order:null,orient:null,orientation:null,origin:null,overflow:null,overlay:null,
overlinePosition:yN,overlineThickness:yN,paintOrder:null,panose1:null,path:null,
pathLength:yN,patternContentUnits:null,patternTransform:null,patternUnits:null,
phase:null,ping:ON,pitch:null,playbackOrder:null,pointerEvents:null,points:null,
pointsAtX:yN,pointsAtY:yN,pointsAtZ:yN,preserveAlpha:null,
preserveAspectRatio:null,primitiveUnits:null,propagate:null,property:xN,r:null,
radius:null,referrerPolicy:null,refX:null,refY:null,rel:xN,rev:xN,
renderingIntent:null,repeatCount:null,repeatDur:null,requiredExtensions:xN,
requiredFeatures:xN,requiredFonts:xN,requiredFormats:xN,resource:null,
restart:null,result:null,rotate:null,rx:null,ry:null,scale:null,seed:null,
shapeRendering:null,side:null,slope:null,snapshotTime:null,specularConstant:yN,
specularExponent:yN,spreadMethod:null,spacing:null,startOffset:null,
stdDeviation:null,stemh:null,stemv:null,stitchTiles:null,stopColor:null,
stopOpacity:null,strikethroughPosition:yN,strikethroughThickness:yN,string:null,
stroke:null,strokeDashArray:xN,strokeDashOffset:null,strokeLineCap:null,
strokeLineJoin:null,strokeMiterLimit:yN,strokeOpacity:yN,strokeWidth:null,
style:null,surfaceScale:yN,syncBehavior:null,syncBehaviorDefault:null,
syncMaster:null,syncTolerance:null,syncToleranceDefault:null,systemLanguage:xN,
tabIndex:yN,tableValues:null,target:null,targetX:yN,targetY:yN,textAnchor:null,
textDecoration:null,textRendering:null,textLength:null,timelineBegin:null,
title:null,transformBehavior:null,type:null,typeOf:xN,to:null,transform:null,
transformOrigin:null,u1:null,u2:null,underlinePosition:yN,underlineThickness:yN,
unicode:null,unicodeBidi:null,unicodeRange:null,unitsPerEm:yN,values:null,
vAlphabetic:yN,vMathematical:yN,vectorEffect:null,vHanging:yN,vIdeographic:yN,
version:null,vertAdvY:yN,vertOriginX:yN,vertOriginY:yN,viewBox:null,
viewTarget:null,visibility:null,width:null,widths:null,wordSpacing:null,
writingMode:null,x:null,x1:null,x2:null,xChannelSelector:null,xHeight:yN,y:null,
y1:null,y2:null,yChannelSelector:null,z:null,zoomAndPan:null},space:"svg",
transform:$N}),MN=AN({properties:{xLinkActuate:null,xLinkArcRole:null,
xLinkHref:null,xLinkRole:null,xLinkShow:null,xLinkTitle:null,xLinkType:null},
space:"xlink",transform:(e,t)=>"xlink:"+t.slice(5).toLowerCase()}),NN=AN({
attributes:{xmlnsxlink:"xmlns:xlink"},properties:{xmlnsXLink:null,xmlns:null},
space:"xmlns",transform:PN}),RN=AN({properties:{xmlBase:null,xmlLang:null,
xmlSpace:null},space:"xml",transform:(e,t)=>"xml:"+t.slice(3).toLowerCase()
}),LN=/[A-Z]/g,BN=/-[a-z]/g,jN=/^data[-\w.:]+$/i;function UN(e){
return"-"+e.toLowerCase()}function zN(e){return e.charAt(1).toUpperCase()}
const FN=pN([CN,DN,MN,NN,RN],"html"),ZN=pN([CN,IN,MN,NN,RN],"svg"),QN={}.hasOwnProperty
;function HN(e,t){const n=t||{};function r(t,...n){let o=r.invalid
;const a=r.handlers;if(t&&QN.call(t,e)){const n=String(t[e])
;o=QN.call(a,n)?a[n]:r.unknown}if(o)return o.call(this,t,...n)}
return r.handlers=n.handlers||{},r.invalid=n.invalid,r.unknown=n.unknown,r}
const VN=/["&'<>`]/g,qN=/[\uD800-\uDBFF][\uDC00-\uDFFF]/g,WN=/[\x01-\t\v\f\x0E-\x1F\x7F\x81\x8D\x8F\x90\x9D\xA0-\uFFFF]/g,XN=/[|\\{}()[\]^$+*?.]/g,GN=new WeakMap
;function YN(e,t){return e=e.replace(t.subset?function(e){let t=GN.get(e)
;t||(t=function(e){const t=[];let n=-1
;for(;++n<e.length;)t.push(e[n].replace(XN,"\\$&"))
;return new RegExp("(?:"+t.join("|")+")","g")}(e),GN.set(e,t));return t
}(t.subset):VN,n),t.subset||t.escapeOnly?e:e.replace(qN,(function(e,n,r){
return t.format(1024*(e.charCodeAt(0)-55296)+e.charCodeAt(1)-56320+65536,r.charCodeAt(n+2),t)
})).replace(WN,n);function n(e,n,r){
return t.format(e.charCodeAt(0),r.charCodeAt(n+1),t)}}const KN=/[\dA-Fa-f]/
;const JN=/\d/
;const eR=["AElig","AMP","Aacute","Acirc","Agrave","Aring","Atilde","Auml","COPY","Ccedil","ETH","Eacute","Ecirc","Egrave","Euml","GT","Iacute","Icirc","Igrave","Iuml","LT","Ntilde","Oacute","Ocirc","Ograve","Oslash","Otilde","Ouml","QUOT","REG","THORN","Uacute","Ucirc","Ugrave","Uuml","Yacute","aacute","acirc","acute","aelig","agrave","amp","aring","atilde","auml","brvbar","ccedil","cedil","cent","copy","curren","deg","divide","eacute","ecirc","egrave","eth","euml","frac12","frac14","frac34","gt","iacute","icirc","iexcl","igrave","iquest","iuml","laquo","lt","macr","micro","middot","nbsp","not","ntilde","oacute","ocirc","ograve","ordf","ordm","oslash","otilde","ouml","para","plusmn","pound","quot","raquo","reg","sect","shy","sup1","sup2","sup3","szlig","thorn","times","uacute","ucirc","ugrave","uml","uuml","yacute","yen","yuml"],tR={
nbsp:" ",iexcl:"¡",cent:"¢",pound:"£",curren:"¤",yen:"¥",brvbar:"¦",sect:"§",
uml:"¨",copy:"©",ordf:"ª",laquo:"«",not:"¬",shy:"­",reg:"®",macr:"¯",deg:"°",
plusmn:"±",sup2:"²",sup3:"³",acute:"´",micro:"µ",para:"¶",middot:"·",cedil:"¸",
sup1:"¹",ordm:"º",raquo:"»",frac14:"¼",frac12:"½",frac34:"¾",iquest:"¿",
Agrave:"À",Aacute:"Á",Acirc:"Â",Atilde:"Ã",Auml:"Ä",Aring:"Å",AElig:"Æ",
Ccedil:"Ç",Egrave:"È",Eacute:"É",Ecirc:"Ê",Euml:"Ë",Igrave:"Ì",Iacute:"Í",
Icirc:"Î",Iuml:"Ï",ETH:"Ð",Ntilde:"Ñ",Ograve:"Ò",Oacute:"Ó",Ocirc:"Ô",
Otilde:"Õ",Ouml:"Ö",times:"×",Oslash:"Ø",Ugrave:"Ù",Uacute:"Ú",Ucirc:"Û",
Uuml:"Ü",Yacute:"Ý",THORN:"Þ",szlig:"ß",agrave:"à",aacute:"á",acirc:"â",
atilde:"ã",auml:"ä",aring:"å",aelig:"æ",ccedil:"ç",egrave:"è",eacute:"é",
ecirc:"ê",euml:"ë",igrave:"ì",iacute:"í",icirc:"î",iuml:"ï",eth:"ð",ntilde:"ñ",
ograve:"ò",oacute:"ó",ocirc:"ô",otilde:"õ",ouml:"ö",divide:"÷",oslash:"ø",
ugrave:"ù",uacute:"ú",ucirc:"û",uuml:"ü",yacute:"ý",thorn:"þ",yuml:"ÿ",fnof:"ƒ",
Alpha:"Α",Beta:"Β",Gamma:"Γ",Delta:"Δ",Epsilon:"Ε",Zeta:"Ζ",Eta:"Η",Theta:"Θ",
Iota:"Ι",Kappa:"Κ",Lambda:"Λ",Mu:"Μ",Nu:"Ν",Xi:"Ξ",Omicron:"Ο",Pi:"Π",Rho:"Ρ",
Sigma:"Σ",Tau:"Τ",Upsilon:"Υ",Phi:"Φ",Chi:"Χ",Psi:"Ψ",Omega:"Ω",alpha:"α",
beta:"β",gamma:"γ",delta:"δ",epsilon:"ε",zeta:"ζ",eta:"η",theta:"θ",iota:"ι",
kappa:"κ",lambda:"λ",mu:"μ",nu:"ν",xi:"ξ",omicron:"ο",pi:"π",rho:"ρ",sigmaf:"ς",
sigma:"σ",tau:"τ",upsilon:"υ",phi:"φ",chi:"χ",psi:"ψ",omega:"ω",thetasym:"ϑ",
upsih:"ϒ",piv:"ϖ",bull:"•",hellip:"…",prime:"′",Prime:"″",oline:"‾",frasl:"⁄",
weierp:"℘",image:"ℑ",real:"ℜ",trade:"™",alefsym:"ℵ",larr:"←",uarr:"↑",rarr:"→",
darr:"↓",harr:"↔",crarr:"↵",lArr:"⇐",uArr:"⇑",rArr:"⇒",dArr:"⇓",hArr:"⇔",
forall:"∀",part:"∂",exist:"∃",empty:"∅",nabla:"∇",isin:"∈",notin:"∉",ni:"∋",
prod:"∏",sum:"∑",minus:"−",lowast:"∗",radic:"√",prop:"∝",infin:"∞",ang:"∠",
and:"∧",or:"∨",cap:"∩",cup:"∪",int:"∫",there4:"∴",sim:"∼",cong:"≅",asymp:"≈",
ne:"≠",equiv:"≡",le:"≤",ge:"≥",sub:"⊂",sup:"⊃",nsub:"⊄",sube:"⊆",supe:"⊇",
oplus:"⊕",otimes:"⊗",perp:"⊥",sdot:"⋅",lceil:"⌈",rceil:"⌉",lfloor:"⌊",
rfloor:"⌋",lang:"〈",rang:"〉",loz:"◊",spades:"♠",clubs:"♣",hearts:"♥",diams:"♦",
quot:'"',amp:"&",lt:"<",gt:">",OElig:"Œ",oelig:"œ",Scaron:"Š",scaron:"š",
Yuml:"Ÿ",circ:"ˆ",tilde:"˜",ensp:" ",emsp:" ",thinsp:" ",zwnj:"‌",zwj:"‍",
lrm:"‎",rlm:"‏",ndash:"–",mdash:"—",lsquo:"‘",rsquo:"’",sbquo:"‚",ldquo:"“",
rdquo:"”",bdquo:"„",dagger:"†",Dagger:"‡",permil:"‰",lsaquo:"‹",rsaquo:"›",
euro:"€"
},nR=["cent","copy","divide","gt","lt","not","para","times"],rR={}.hasOwnProperty,oR={}
;let aR;for(aR in tR)rR.call(tR,aR)&&(oR[tR[aR]]=aR);const iR=/[^\dA-Za-z]/
;function sR(e,t,n){let r,o=function(e,t,n){
const r="&#x"+e.toString(16).toUpperCase()
;return n&&t&&!KN.test(String.fromCharCode(t))?r:r+";"
}(e,t,n.omitOptionalSemicolons)
;if((n.useNamedReferences||n.useShortestReferences)&&(r=function(e,t,n,r){
const o=String.fromCharCode(e);if(rR.call(oR,o)){const e=oR[o],a="&"+e
;return n&&eR.includes(e)&&!nR.includes(e)&&(!r||t&&61!==t&&iR.test(String.fromCharCode(t)))?a:a+";"
}return""
}(e,t,n.omitOptionalSemicolons,n.attribute)),(n.useShortestReferences||!r)&&n.useShortestReferences){
const r=function(e,t,n){const r="&#"+String(e)
;return n&&t&&!JN.test(String.fromCharCode(t))?r:r+";"
}(e,t,n.omitOptionalSemicolons);r.length<o.length&&(o=r)}
return r&&(!n.useShortestReferences||r.length<o.length)?r:o}function lR(e,t){
return YN(e,Object.assign({format:sR},t))}
const cR=/^>|^->|<!--|-->|--!>|<!-$/g,uR=[">"],dR=["<",">"];function pR(e,t){
const n=String(e)
;if("string"!=typeof t)throw new TypeError("Expected character")
;let r=0,o=n.indexOf(t);for(;-1!==o;)r++,o=n.indexOf(t,o+t.length);return r}
const hR=/[ \t\n\f\r]/g;function fR(e){
return"object"==typeof e?"text"===e.type&&mR(e.value):mR(e)}function mR(e){
return""===e.replace(hR,"")}const gR=yR(1),vR=yR(-1),bR=[];function yR(e){
return function(t,n,r){const o=t?t.children:bR;let a=(n||0)+e,i=o[a]
;if(!r)for(;i&&fR(i);)a+=e,i=o[a];return i}}const OR={}.hasOwnProperty
;function wR(e){return function(t,n,r){
return OR.call(e,t.tagName)&&e[t.tagName](t,n,r)}}const xR=wR({
body:function(e,t,n){const r=gR(n,t);return!r||"comment"!==r.type},caption:kR,
colgroup:kR,dd:function(e,t,n){const r=gR(n,t)
;return!r||"element"===r.type&&("dt"===r.tagName||"dd"===r.tagName)},
dt:function(e,t,n){const r=gR(n,t)
;return Boolean(r&&"element"===r.type&&("dt"===r.tagName||"dd"===r.tagName))},
head:kR,html:function(e,t,n){const r=gR(n,t);return!r||"comment"!==r.type},
li:function(e,t,n){const r=gR(n,t)
;return!r||"element"===r.type&&"li"===r.tagName},optgroup:function(e,t,n){
const r=gR(n,t);return!r||"element"===r.type&&"optgroup"===r.tagName},
option:function(e,t,n){const r=gR(n,t)
;return!r||"element"===r.type&&("option"===r.tagName||"optgroup"===r.tagName)},
p:function(e,t,n){const r=gR(n,t)
;return r?"element"===r.type&&("address"===r.tagName||"article"===r.tagName||"aside"===r.tagName||"blockquote"===r.tagName||"details"===r.tagName||"div"===r.tagName||"dl"===r.tagName||"fieldset"===r.tagName||"figcaption"===r.tagName||"figure"===r.tagName||"footer"===r.tagName||"form"===r.tagName||"h1"===r.tagName||"h2"===r.tagName||"h3"===r.tagName||"h4"===r.tagName||"h5"===r.tagName||"h6"===r.tagName||"header"===r.tagName||"hgroup"===r.tagName||"hr"===r.tagName||"main"===r.tagName||"menu"===r.tagName||"nav"===r.tagName||"ol"===r.tagName||"p"===r.tagName||"pre"===r.tagName||"section"===r.tagName||"table"===r.tagName||"ul"===r.tagName):!n||!("element"===n.type&&("a"===n.tagName||"audio"===n.tagName||"del"===n.tagName||"ins"===n.tagName||"map"===n.tagName||"noscript"===n.tagName||"video"===n.tagName))
},rp:SR,rt:SR,tbody:function(e,t,n){const r=gR(n,t)
;return!r||"element"===r.type&&("tbody"===r.tagName||"tfoot"===r.tagName)},
td:_R,tfoot:function(e,t,n){return!gR(n,t)},th:_R,thead:function(e,t,n){
const r=gR(n,t)
;return Boolean(r&&"element"===r.type&&("tbody"===r.tagName||"tfoot"===r.tagName))
},tr:function(e,t,n){const r=gR(n,t)
;return!r||"element"===r.type&&"tr"===r.tagName}});function kR(e,t,n){
const r=gR(n,t,!0)
;return!r||"comment"!==r.type&&!("text"===r.type&&fR(r.value.charAt(0)))}
function SR(e,t,n){const r=gR(n,t)
;return!r||"element"===r.type&&("rp"===r.tagName||"rt"===r.tagName)}
function _R(e,t,n){const r=gR(n,t)
;return!r||"element"===r.type&&("td"===r.tagName||"th"===r.tagName)}
const TR=wR({body:function(e){const t=gR(e,-1,!0)
;return!(t&&("comment"===t.type||"text"===t.type&&fR(t.value.charAt(0))||"element"===t.type&&("meta"===t.tagName||"link"===t.tagName||"script"===t.tagName||"style"===t.tagName||"template"===t.tagName)))
},colgroup:function(e,t,n){const r=vR(n,t),o=gR(e,-1,!0)
;if(n&&r&&"element"===r.type&&"colgroup"===r.tagName&&xR(r,n.children.indexOf(r),n))return!1
;return Boolean(o&&"element"===o.type&&"col"===o.tagName)},head:function(e){
const t=new Set
;for(const r of e.children)if("element"===r.type&&("base"===r.tagName||"title"===r.tagName)){
if(t.has(r.tagName))return!1;t.add(r.tagName)}const n=e.children[0]
;return!n||"element"===n.type},html:function(e){const t=gR(e,-1)
;return!t||"comment"!==t.type},tbody:function(e,t,n){const r=vR(n,t),o=gR(e,-1)
;if(n&&r&&"element"===r.type&&("thead"===r.tagName||"tbody"===r.tagName)&&xR(r,n.children.indexOf(r),n))return!1
;return Boolean(o&&"element"===o.type&&"tr"===o.tagName)}});const ER={
name:[["\t\n\f\r &/=>".split(""),"\t\n\f\r \"&'/=>`".split("")],["\0\t\n\f\r \"&'/<=>".split(""),"\0\t\n\f\r \"&'/<=>`".split("")]],
unquoted:[["\t\n\f\r &>".split(""),"\0\t\n\f\r \"&'<=>`".split("")],["\0\t\n\f\r \"&'<=>`".split(""),"\0\t\n\f\r \"&'<=>`".split("")]],
single:[["&'".split(""),"\"&'`".split("")],["\0&'".split(""),"\0\"&'`".split("")]],
double:[['"&'.split(""),"\"&'`".split("")],['\0"&'.split(""),"\0\"&'`".split("")]]
};function AR(e,t,n){const r=function(e,t){const n=hN(t);let r=t,o=fN
;if(n in e.normal)return e.property[e.normal[n]]
;if(n.length>4&&"data"===n.slice(0,4)&&jN.test(t)){if("-"===t.charAt(4)){
const e=t.slice(5).replace(BN,zN);r="data"+e.charAt(0).toUpperCase()+e.slice(1)
}else{const e=t.slice(4);if(!BN.test(e)){let n=e.replace(LN,UN)
;"-"!==n.charAt(0)&&(n="-"+n),t="data"+n}}o=TN}return new o(r,t)
}(e.schema,t),o=e.settings.allowParseErrors&&"html"===e.schema.space?0:1,a=e.settings.allowDangerousCharacters?0:1
;let i,s=e.quote
;if(!r.overloadedBoolean||n!==r.attribute&&""!==n?!r.boolean&&!r.overloadedBoolean||"string"==typeof n&&n!==r.attribute&&""!==n||(n=Boolean(n)):n=!0,
null==n||!1===n||"number"==typeof n&&Number.isNaN(n))return""
;const l=lR(r.attribute,Object.assign({},e.settings.characterReferences,{
subset:ER.name[o][a]}))
;return!0===n?l:(n=Array.isArray(n)?(r.commaSeparated?SP:EP)(n,{
padLeft:!e.settings.tightCommaSeparatedLists
}):String(n),e.settings.collapseEmptyAttributes&&!n?l:(e.settings.preferUnquoted&&(i=lR(n,Object.assign({},e.settings.characterReferences,{
attribute:!0,subset:ER.unquoted[o][a]
}))),i!==n&&(e.settings.quoteSmart&&pR(n,s)>pR(n,e.alternative)&&(s=e.alternative),
i=s+lR(n,Object.assign({},e.settings.characterReferences,{
subset:("'"===s?ER.single:ER.double)[o][a],attribute:!0}))+s),l+(i?"="+i:i)))}
const CR=["<","&"];function $R(e,t,n,r){
return!n||"element"!==n.type||"script"!==n.tagName&&"style"!==n.tagName?lR(e.value,Object.assign({},r.settings.characterReferences,{
subset:CR})):e.value}const PR=HN("type",{invalid:function(e){
throw new Error("Expected node, not `"+e+"`")},unknown:function(e){
throw new Error("Cannot compile unknown node `"+e.type+"`")},handlers:{
comment:function(e,t,n,r){
return r.settings.bogusComments?"<?"+lR(e.value,Object.assign({},r.settings.characterReferences,{
subset:uR}))+">":"\x3c!--"+e.value.replace(cR,(function(e){
return lR(e,Object.assign({},r.settings.characterReferences,{subset:dR}))
}))+"--\x3e"},doctype:function(e,t,n,r){
return"<!"+(r.settings.upperDoctype?"DOCTYPE":"doctype")+(r.settings.tightDoctype?"":" ")+"html>"
},element:function(e,t,n,r){
const o=r.schema,a="svg"!==o.space&&r.settings.omitOptionalTags
;let i="svg"===o.space?r.settings.closeEmptyElements:r.settings.voids.includes(e.tagName.toLowerCase())
;const s=[];let l;"html"===o.space&&"svg"===e.tagName&&(r.schema=ZN)
;const c=function(e,t){const n=[];let r,o=-1
;if(t)for(r in t)if(null!==t[r]&&void 0!==t[r]){const o=AR(e,r,t[r])
;o&&n.push(o)}for(;++o<n.length;){
const t=e.settings.tightAttributes?n[o].charAt(n[o].length-1):void 0
;o!==n.length-1&&'"'!==t&&"'"!==t&&(n[o]+=" ")}return n.join("")
}(r,e.properties),u=r.all("html"===o.space&&"template"===e.tagName?e.content:e)
;return r.schema=o,
u&&(i=!1),!c&&a&&TR(e,t,n)||(s.push("<",e.tagName,c?" "+c:""),
i&&("svg"===o.space||r.settings.closeSelfClosing)&&(l=c.charAt(c.length-1),
(!r.settings.tightSelfClosing||"/"===l||l&&'"'!==l&&"'"!==l)&&s.push(" "),
s.push("/")),s.push(">")),s.push(u),i||a&&xR(e,t,n)||s.push("</"+e.tagName+">"),
s.join("")},raw:function(e,t,n,r){
return r.settings.allowDangerousHtml?e.value:$R(e,0,n,r)},
root:function(e,t,n,r){return r.all(e)},text:$R}});const DR={},IR={},MR=[]
;function NR(e,t,n){return PR(e,t,n,this)}function RR(e){
const t=[],n=e&&e.children||MR;let r=-1
;for(;++r<n.length;)t[r]=this.one(n[r],r,e);return t.join("")}function LR(e){
const t={...this.data("settings"),...e};this.compiler=function(e){
return function(e,t){const n=t||DR,r=n.quote||'"',o='"'===r?"'":'"'
;if('"'!==r&&"'"!==r)throw new Error("Invalid quote `"+r+"`, expected `'` or `\"`")
;return{one:NR,all:RR,settings:{omitOptionalTags:n.omitOptionalTags||!1,
allowParseErrors:n.allowParseErrors||!1,
allowDangerousCharacters:n.allowDangerousCharacters||!1,
quoteSmart:n.quoteSmart||!1,preferUnquoted:n.preferUnquoted||!1,
tightAttributes:n.tightAttributes||!1,upperDoctype:n.upperDoctype||!1,
tightDoctype:n.tightDoctype||!1,bogusComments:n.bogusComments||!1,
tightCommaSeparatedLists:n.tightCommaSeparatedLists||!1,
tightSelfClosing:n.tightSelfClosing||!1,
collapseEmptyAttributes:n.collapseEmptyAttributes||!1,
allowDangerousHtml:n.allowDangerousHtml||!1,voids:n.voids||uN,
characterReferences:n.characterReferences||IR,
closeSelfClosing:n.closeSelfClosing||!1,
closeEmptyElements:n.closeEmptyElements||!1},schema:"svg"===n.space?ZN:FN,
quote:r,alternative:o}.one(Array.isArray(e)?{type:"root",children:e
}:e,void 0,void 0)}(e,t)}}function BR(e){if(e)throw e}function jR(e){
return e&&e.__esModule&&Object.prototype.hasOwnProperty.call(e,"default")?e.default:e
}var UR,zR;var FR=function(){if(zR)return UR;zR=1
;var e=Object.prototype.hasOwnProperty,t=Object.prototype.toString,n=Object.defineProperty,r=Object.getOwnPropertyDescriptor,o=function(e){
return"function"==typeof Array.isArray?Array.isArray(e):"[object Array]"===t.call(e)
},a=function(n){if(!n||"[object Object]"!==t.call(n))return!1
;var r,o=e.call(n,"constructor"),a=n.constructor&&n.constructor.prototype&&e.call(n.constructor.prototype,"isPrototypeOf")
;if(n.constructor&&!o&&!a)return!1;for(r in n);return void 0===r||e.call(n,r)
},i=function(e,t){n&&"__proto__"===t.name?n(e,t.name,{enumerable:!0,
configurable:!0,value:t.newValue,writable:!0}):e[t.name]=t.newValue
},s=function(t,n){if("__proto__"===n){if(!e.call(t,n))return
;if(r)return r(t,n).value}return t[n]};return UR=function e(){
var t,n,r,l,c,u,d=arguments[0],p=1,h=arguments.length,f=!1
;for("boolean"==typeof d&&(f=d,
d=arguments[1]||{},p=2),(null==d||"object"!=typeof d&&"function"!=typeof d)&&(d={});p<h;++p)if(null!=(t=arguments[p]))for(n in t)r=s(d,n),
d!==(l=s(t,n))&&(f&&l&&(a(l)||(c=o(l)))?(c?(c=!1,u=r&&o(r)?r:[]):u=r&&a(r)?r:{},
i(d,{name:n,newValue:e(f,u,l)})):void 0!==l&&i(d,{name:n,newValue:l}));return d
},UR}();const ZR=jR(FR);function QR(e){if("object"!=typeof e||null===e)return!1
;const t=Object.getPrototypeOf(e)
;return!(null!==t&&t!==Object.prototype&&null!==Object.getPrototypeOf(t)||Symbol.toStringTag in e||Symbol.iterator in e)
}function HR(){const e=[],t={run:function(...t){let n=-1;const r=t.pop()
;if("function"!=typeof r)throw new TypeError("Expected function as last argument, not "+r)
;!function o(a,...i){const s=e[++n];let l=-1;if(a)r(a);else{
for(;++l<t.length;)null!==i[l]&&void 0!==i[l]||(i[l]=t[l]);t=i,s?function(e,t){
let n;return r;function r(...t){const r=e.length>t.length;let s;r&&t.push(o)
;try{s=e.apply(this,t)}catch(a){if(r&&n)throw a;return o(a)}
r||(s&&s.then&&"function"==typeof s.then?s.then(i,o):s instanceof Error?o(s):i(s))
}function o(e,...r){n||(n=!0,t(e,...r))}function i(e){o(null,e)}
}(s,o)(...i):r(null,...i)}}(null,...t)},use:function(n){
if("function"!=typeof n)throw new TypeError("Expected `middelware` to be a function, not "+n)
;return e.push(n),t}};return t}const VR=function(e){
const t=this.constructor.prototype,n=t[e],r=function(){
return n.apply(r,arguments)};return Object.setPrototypeOf(r,t),r
},qR={}.hasOwnProperty;class WR extends VR{constructor(){
super("copy"),this.Compiler=void 0,
this.Parser=void 0,this.attachers=[],this.compiler=void 0,
this.freezeIndex=-1,this.frozen=void 0,
this.namespace={},this.parser=void 0,this.transformers=HR()}copy(){
const e=new WR;let t=-1;for(;++t<this.attachers.length;){
const n=this.attachers[t];e.use(...n)}return e.data(ZR(!0,{},this.namespace)),e}
data(e,t){return"string"==typeof e?2===arguments.length?(KR("data",this.frozen),
this.namespace[e]=t,
this):qR.call(this.namespace,e)&&this.namespace[e]||void 0:e?(KR("data",this.frozen),
this.namespace=e,this):this.namespace}freeze(){if(this.frozen)return this
;const e=this;for(;++this.freezeIndex<this.attachers.length;){
const[t,...n]=this.attachers[this.freezeIndex];if(!1===n[0])continue
;!0===n[0]&&(n[0]=void 0);const r=t.call(e,...n)
;"function"==typeof r&&this.transformers.use(r)}
return this.frozen=!0,this.freezeIndex=Number.POSITIVE_INFINITY,this}parse(e){
this.freeze();const t=tL(e),n=this.parser||this.Parser
;return GR("parse",n),n(String(t),t)}process(e,t){const n=this
;return this.freeze(),
GR("process",this.parser||this.Parser),YR("process",this.compiler||this.Compiler),
t?r(void 0,t):new Promise(r);function r(r,o){const a=tL(e),i=n.parse(a)
;function s(e,n){e||!n?o(e):r?r(n):t(void 0,n)}n.run(i,a,(function(e,t,r){
if(e||!t||!r)return s(e);const o=t,a=n.stringify(o,r);var i
;"string"==typeof(i=a)||function(e){
return Boolean(e&&"object"==typeof e&&"byteLength"in e&&"byteOffset"in e)
}(i)?r.value=a:r.result=a,s(e,r)}))}}processSync(e){let t,n=!1
;return this.freeze(),
GR("processSync",this.parser||this.Parser),YR("processSync",this.compiler||this.Compiler),
this.process(e,(function(e,r){n=!0,BR(e),t=r})),eL("processSync","process",n),t}
run(e,t,n){JR(e),this.freeze();const r=this.transformers
;return n||"function"!=typeof t||(n=t,t=void 0),n?o(void 0,n):new Promise(o)
;function o(o,a){const i=tL(t);r.run(e,i,(function(t,r,i){const s=r||e
;t?a(t):o?o(s):n(void 0,s,i)}))}}runSync(e,t){let n,r=!1
;return this.run(e,t,(function(e,t){BR(e),n=t,r=!0})),eL("runSync","run",r),n}
stringify(e,t){this.freeze();const n=tL(t),r=this.compiler||this.Compiler
;return YR("stringify",r),JR(e),r(e,n)}use(e,...t){
const n=this.attachers,r=this.namespace
;if(KR("use",this.frozen),null==e);else if("function"==typeof e)s(e,t);else{
if("object"!=typeof e)throw new TypeError("Expected usable value, not `"+e+"`")
;Array.isArray(e)?i(e):a(e)}return this;function o(e){
if("function"==typeof e)s(e,[]);else{
if("object"!=typeof e)throw new TypeError("Expected usable value, not `"+e+"`")
;if(Array.isArray(e)){const[t,...n]=e;s(t,n)}else a(e)}}function a(e){
if(!("plugins"in e)&&!("settings"in e))throw new Error("Expected usable value but received an empty preset, which is probably a mistake: presets typically come with `plugins` and sometimes with `settings`, but this has neither")
;i(e.plugins),e.settings&&(r.settings=ZR(!0,r.settings,e.settings))}
function i(e){let t=-1;if(null==e);else{
if(!Array.isArray(e))throw new TypeError("Expected a list of plugins, not `"+e+"`")
;for(;++t<e.length;){o(e[t])}}}function s(e,t){let r=-1,o=-1
;for(;++r<n.length;)if(n[r][0]===e){o=r;break}
if(-1===o)n.push([e,...t]);else if(t.length>0){let[r,...a]=t;const i=n[o][1]
;QR(i)&&QR(r)&&(r=ZR(!0,i,r)),n[o]=[e,r,...a]}}}}const XR=(new WR).freeze()
;function GR(e,t){
if("function"!=typeof t)throw new TypeError("Cannot `"+e+"` without `parser`")}
function YR(e,t){
if("function"!=typeof t)throw new TypeError("Cannot `"+e+"` without `compiler`")
}function KR(e,t){
if(t)throw new Error("Cannot call `"+e+"` on a frozen processor.\nCreate a new processor first, by calling it: use `processor()` instead of `processor`.")
}function JR(e){
if(!QR(e)||"string"!=typeof e.type)throw new TypeError("Expected node, got `"+e+"`")
}function eL(e,t,n){
if(!n)throw new Error("`"+e+"` finished async. Use `"+t+"` instead")}
function tL(e){return function(e){
return Boolean(e&&"object"==typeof e&&"message"in e&&"messages"in e)
}(e)?e:new GM(e)}const nL=function(e){if(null==e)return oL
;if("function"==typeof e)return rL(e)
;if("object"==typeof e)return Array.isArray(e)?function(e){const t=[];let n=-1
;for(;++n<e.length;)t[n]=nL(e[n]);return rL(r);function r(...e){let n=-1
;for(;++n<t.length;)if(t[n].apply(this,e))return!0;return!1}}(e):function(e){
const t=e;return rL(n);function n(n){const r=n;let o
;for(o in e)if(r[o]!==t[o])return!1;return!0}}(e)
;if("string"==typeof e)return function(e){return rL(t);function t(t){
return t&&t.type===e}}(e)
;throw new Error("Expected function, string, or object as test")}
;function rL(e){return function(t,n,r){return Boolean(function(e){
return null!==e&&"object"==typeof e&&"type"in e
}(t)&&e.call(this,t,"number"==typeof n?n:void 0,r||void 0))}}function oL(){
return!0}const aL=[],iL=!0,sL=!1,lL="skip";function cL(e,t,n,r){let o
;"function"==typeof t&&"function"!=typeof n?(r=n,n=t):o=t;const a=nL(o),i=r?-1:1
;!function e(o,s,l){const c=o&&"object"==typeof o?o:{}
;if("string"==typeof c.type){
const e="string"==typeof c.tagName?c.tagName:"string"==typeof c.name?c.name:void 0
;Object.defineProperty(u,"name",{value:"node ("+o.type+(e?"<"+e+">":"")+")"})}
return u;function u(){let c,u,d,p=aL
;if((!t||a(o,s,l[l.length-1]||void 0))&&(p=function(e){
if(Array.isArray(e))return e;if("number"==typeof e)return[iL,e]
;return null==e?aL:[e]}(n(o,l)),p[0]===sL))return p
;if("children"in o&&o.children){const t=o
;if(t.children&&p[0]!==lL)for(u=(r?t.children.length:-1)+i,
d=l.concat(t);u>-1&&u<t.children.length;){const n=t.children[u];if(c=e(n,u,d)(),
c[0]===sL)return c;u="number"==typeof c[1]?c[1]:u+i}}return p}}(e,void 0,[])()}
function uL(e,t,n,r){let o,a,i
;"function"==typeof t&&"function"!=typeof n?(a=void 0,
i=t,o=n):(a=t,i=n,o=r),cL(e,a,(function(e,t){
const n=t[t.length-1],r=n?n.children.indexOf(e):void 0;return i(e,r,n)}),o)}
const dL={ts:"typescript",js:"javascript",py:"python",py3:"python",
"c#":"csharp","c++":"cpp",node:"javascript"},pL=function(e,t,n){const r=nL(n)
;if(!e||!e.type||!e.children)throw new Error("Expected parent node")
;if("number"==typeof t){
if(t<0||t===Number.POSITIVE_INFINITY)throw new Error("Expected positive finite number as index")
}else if((t=e.children.indexOf(t))<0)throw new Error("Expected child node or index")
;for(;++t<e.children.length;)if(r(e.children[t],t,e))return e.children[t]
},hL=function(e,t,n,r,o){const a=fL(t);return!!vL(e)&&a.call(o,e,n,r)
},fL=function(e){if(null==e)return gL;if("string"==typeof e)return function(e){
return mL(t);function t(t){return t.tagName===e}}(e)
;if("object"==typeof e)return function(e){const t=[];let n=-1
;for(;++n<e.length;)t[n]=fL(e[n]);return mL(r);function r(...e){let n=-1
;for(;++n<t.length;)if(t[n].apply(this,e))return!0;return!1}}(e)
;if("function"==typeof e)return mL(e)
;throw new Error("Expected function, string, or array as `test`")}
;function mL(e){return function(t,n,r){
return Boolean(vL(t)&&e.call(this,t,"number"==typeof n?n:void 0,r||void 0))}}
function gL(e){
return Boolean(e&&"object"==typeof e&&"type"in e&&"element"===e.type&&"tagName"in e&&"string"==typeof e.tagName)
}function vL(e){return null!==e&&"object"==typeof e&&"type"in e&&"tagName"in e}
const bL=/\n/g,yL=/[\t ]+/g,OL=fL("br"),wL=fL((function(e){
return"td"===e.tagName||"th"===e.tagName
})),xL=fL("p"),kL=fL("tr"),SL=fL(["datalist","head","noembed","noframes","noscript","rp","script","style","template","title",function(e){
return Boolean((e.properties||{}).hidden)},function(e){
return"dialog"===e.tagName&&!(e.properties||{}).open
}]),_L=fL(["address","article","aside","blockquote","body","caption","center","dd","dialog","dir","dl","dt","div","figure","figcaption","footer","form,","h1","h2","h3","h4","h5","h6","header","hgroup","hr","html","legend","li","listing","main","menu","nav","ol","p","plaintext","pre","section","ul","xmp"])
;function TL(e,t){const n="children"in e?e.children:[],r=_L(e),o=$L(e,{
whitespace:{}.whitespace||"normal"}),a=[]
;"text"!==e.type&&"comment"!==e.type||a.push(...AL(e,{breakBefore:!0,
breakAfter:!0}));let i=-1;for(;++i<n.length;)a.push(...EL(n[i],e,{whitespace:o,
breakBefore:i?void 0:r,breakAfter:i<n.length-1?OL(n[i+1]):r}));const s=[];let l
;for(i=-1;++i<a.length;){const e=a[i]
;"number"==typeof e?void 0!==l&&e>l&&(l=e):e&&(void 0!==l&&l>-1&&s.push("\n".repeat(l)||" "),
l=-1,s.push(e))}return s.join("")}function EL(e,t,n){
return"element"===e.type?function(e,t,n){const r=$L(e,n),o=e.children||[]
;let a,i,s=-1,l=[];if(SL(e))return l;OL(e)||kL(e)&&pL(t,e,kL)?i="\n":xL(e)?(a=2,
i=2):_L(e)&&(a=1,i=1);for(;++s<o.length;)l=l.concat(EL(o[s],e,{whitespace:r,
breakBefore:s?void 0:a,breakAfter:s<o.length-1?OL(o[s+1]):i}))
;wL(e)&&pL(t,e,wL)&&l.push("\t");a&&l.unshift(a);i&&l.push(i);return l
}(e,t,n):"text"===e.type?"normal"===n.whitespace?AL(e,n):function(e){
return[String(e.value)]}(e):[]}function AL(e,t){
const n=String(e.value),r=[],o=[];let a=0;for(;a<=n.length;){bL.lastIndex=a
;const e=bL.exec(n),o=e&&"index"in e?e.index:n.length
;r.push(CL(n.slice(a,o).replace(/[\u061C\u200E\u200F\u202A-\u202E\u2066-\u2069]/g,""),0!==a||t.breakBefore,o!==n.length||t.breakAfter)),
a=o+1}let i,s=-1
;for(;++s<r.length;)8203===r[s].charCodeAt(r[s].length-1)||s<r.length-1&&8203===r[s+1].charCodeAt(0)?(o.push(r[s]),
i=void 0):r[s]?("number"==typeof i&&o.push(i),
o.push(r[s]),i=0):0!==s&&s!==r.length-1||o.push(0);return o}function CL(e,t,n){
const r=[];let o,a=0;for(;a<e.length;){yL.lastIndex=a;const n=yL.exec(e)
;o=n?n.index:e.length,
a||o||!n||t||r.push(""),a!==o&&r.push(e.slice(a,o)),a=n?o+n[0].length:o}
return a===o||n||r.push(""),r.join(" ")}function $L(e,t){if("element"===e.type){
const n=e.properties||{};switch(e.tagName){case"listing":case"plaintext":
case"xmp":return"pre";case"nobr":return"nowrap";case"pre":
return n.wrap?"pre-wrap":"pre";case"td":case"th":
return n.noWrap?"nowrap":t.whitespace;case"textarea":return"pre-wrap"}}
return t.whitespace}function PL(e){return{name:"Dockerfile",aliases:["docker"],
case_insensitive:!0,
keywords:["from","maintainer","expose","env","arg","user","onbuild","stopsignal"],
contains:[e.HASH_COMMENT_MODE,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,e.NUMBER_MODE,{
beginKeywords:"run cmd entrypoint volume add copy workdir label healthcheck shell",
starts:{end:/[^\\]$/,subLanguage:"bash"}}],illegal:"</"}}function DL(e){
return new RegExp(e.replace(/[-/\\^$*+?.()|[\]{}]/g,"\\$&"),"m")}function IL(e){
return e?"string"==typeof e?e:e.source:null}function ML(e){
return NL("(?=",e,")")}function NL(...e){return e.map((e=>IL(e))).join("")}
function RL(...e){const t=function(e){const t=e[e.length-1]
;return"object"==typeof t&&t.constructor===Object?(e.splice(e.length-1,1),t):{}
}(e);return"("+(t.capture?"":"?:")+e.map((e=>IL(e))).join("|")+")"}
const LL=["a","abbr","address","article","aside","audio","b","blockquote","body","button","canvas","caption","cite","code","dd","del","details","dfn","div","dl","dt","em","fieldset","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","header","hgroup","html","i","iframe","img","input","ins","kbd","label","legend","li","main","mark","menu","nav","object","ol","optgroup","option","p","picture","q","quote","samp","section","select","source","span","strong","summary","sup","table","tbody","td","textarea","tfoot","th","thead","time","tr","ul","var","video","defs","g","marker","mask","pattern","svg","switch","symbol","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feFlood","feGaussianBlur","feImage","feMerge","feMorphology","feOffset","feSpecularLighting","feTile","feTurbulence","linearGradient","radialGradient","stop","circle","ellipse","image","line","path","polygon","polyline","rect","text","use","textPath","tspan","foreignObject","clipPath"],BL=["any-hover","any-pointer","aspect-ratio","color","color-gamut","color-index","device-aspect-ratio","device-height","device-width","display-mode","forced-colors","grid","height","hover","inverted-colors","monochrome","orientation","overflow-block","overflow-inline","pointer","prefers-color-scheme","prefers-contrast","prefers-reduced-motion","prefers-reduced-transparency","resolution","scan","scripting","update","width","min-width","max-width","min-height","max-height"].sort().reverse(),jL=["active","any-link","blank","checked","current","default","defined","dir","disabled","drop","empty","enabled","first","first-child","first-of-type","fullscreen","future","focus","focus-visible","focus-within","has","host","host-context","hover","indeterminate","in-range","invalid","is","lang","last-child","last-of-type","left","link","local-link","not","nth-child","nth-col","nth-last-child","nth-last-col","nth-last-of-type","nth-of-type","only-child","only-of-type","optional","out-of-range","past","placeholder-shown","read-only","read-write","required","right","root","scope","target","target-within","user-invalid","valid","visited","where"].sort().reverse(),UL=["after","backdrop","before","cue","cue-region","first-letter","first-line","grammar-error","marker","part","placeholder","selection","slotted","spelling-error"].sort().reverse(),zL=["accent-color","align-content","align-items","align-self","alignment-baseline","all","anchor-name","animation","animation-composition","animation-delay","animation-direction","animation-duration","animation-fill-mode","animation-iteration-count","animation-name","animation-play-state","animation-range","animation-range-end","animation-range-start","animation-timeline","animation-timing-function","appearance","aspect-ratio","backdrop-filter","backface-visibility","background","background-attachment","background-blend-mode","background-clip","background-color","background-image","background-origin","background-position","background-position-x","background-position-y","background-repeat","background-size","baseline-shift","block-size","border","border-block","border-block-color","border-block-end","border-block-end-color","border-block-end-style","border-block-end-width","border-block-start","border-block-start-color","border-block-start-style","border-block-start-width","border-block-style","border-block-width","border-bottom","border-bottom-color","border-bottom-left-radius","border-bottom-right-radius","border-bottom-style","border-bottom-width","border-collapse","border-color","border-end-end-radius","border-end-start-radius","border-image","border-image-outset","border-image-repeat","border-image-slice","border-image-source","border-image-width","border-inline","border-inline-color","border-inline-end","border-inline-end-color","border-inline-end-style","border-inline-end-width","border-inline-start","border-inline-start-color","border-inline-start-style","border-inline-start-width","border-inline-style","border-inline-width","border-left","border-left-color","border-left-style","border-left-width","border-radius","border-right","border-right-color","border-right-style","border-right-width","border-spacing","border-start-end-radius","border-start-start-radius","border-style","border-top","border-top-color","border-top-left-radius","border-top-right-radius","border-top-style","border-top-width","border-width","bottom","box-align","box-decoration-break","box-direction","box-flex","box-flex-group","box-lines","box-ordinal-group","box-orient","box-pack","box-shadow","box-sizing","break-after","break-before","break-inside","caption-side","caret-color","clear","clip","clip-path","clip-rule","color","color-interpolation","color-interpolation-filters","color-profile","color-rendering","color-scheme","column-count","column-fill","column-gap","column-rule","column-rule-color","column-rule-style","column-rule-width","column-span","column-width","columns","contain","contain-intrinsic-block-size","contain-intrinsic-height","contain-intrinsic-inline-size","contain-intrinsic-size","contain-intrinsic-width","container","container-name","container-type","content","content-visibility","counter-increment","counter-reset","counter-set","cue","cue-after","cue-before","cursor","cx","cy","direction","display","dominant-baseline","empty-cells","enable-background","field-sizing","fill","fill-opacity","fill-rule","filter","flex","flex-basis","flex-direction","flex-flow","flex-grow","flex-shrink","flex-wrap","float","flood-color","flood-opacity","flow","font","font-display","font-family","font-feature-settings","font-kerning","font-language-override","font-optical-sizing","font-palette","font-size","font-size-adjust","font-smooth","font-smoothing","font-stretch","font-style","font-synthesis","font-synthesis-position","font-synthesis-small-caps","font-synthesis-style","font-synthesis-weight","font-variant","font-variant-alternates","font-variant-caps","font-variant-east-asian","font-variant-emoji","font-variant-ligatures","font-variant-numeric","font-variant-position","font-variation-settings","font-weight","forced-color-adjust","gap","glyph-orientation-horizontal","glyph-orientation-vertical","grid","grid-area","grid-auto-columns","grid-auto-flow","grid-auto-rows","grid-column","grid-column-end","grid-column-start","grid-gap","grid-row","grid-row-end","grid-row-start","grid-template","grid-template-areas","grid-template-columns","grid-template-rows","hanging-punctuation","height","hyphenate-character","hyphenate-limit-chars","hyphens","icon","image-orientation","image-rendering","image-resolution","ime-mode","initial-letter","initial-letter-align","inline-size","inset","inset-area","inset-block","inset-block-end","inset-block-start","inset-inline","inset-inline-end","inset-inline-start","isolation","justify-content","justify-items","justify-self","kerning","left","letter-spacing","lighting-color","line-break","line-height","line-height-step","list-style","list-style-image","list-style-position","list-style-type","margin","margin-block","margin-block-end","margin-block-start","margin-bottom","margin-inline","margin-inline-end","margin-inline-start","margin-left","margin-right","margin-top","margin-trim","marker","marker-end","marker-mid","marker-start","marks","mask","mask-border","mask-border-mode","mask-border-outset","mask-border-repeat","mask-border-slice","mask-border-source","mask-border-width","mask-clip","mask-composite","mask-image","mask-mode","mask-origin","mask-position","mask-repeat","mask-size","mask-type","masonry-auto-flow","math-depth","math-shift","math-style","max-block-size","max-height","max-inline-size","max-width","min-block-size","min-height","min-inline-size","min-width","mix-blend-mode","nav-down","nav-index","nav-left","nav-right","nav-up","none","normal","object-fit","object-position","offset","offset-anchor","offset-distance","offset-path","offset-position","offset-rotate","opacity","order","orphans","outline","outline-color","outline-offset","outline-style","outline-width","overflow","overflow-anchor","overflow-block","overflow-clip-margin","overflow-inline","overflow-wrap","overflow-x","overflow-y","overlay","overscroll-behavior","overscroll-behavior-block","overscroll-behavior-inline","overscroll-behavior-x","overscroll-behavior-y","padding","padding-block","padding-block-end","padding-block-start","padding-bottom","padding-inline","padding-inline-end","padding-inline-start","padding-left","padding-right","padding-top","page","page-break-after","page-break-before","page-break-inside","paint-order","pause","pause-after","pause-before","perspective","perspective-origin","place-content","place-items","place-self","pointer-events","position","position-anchor","position-visibility","print-color-adjust","quotes","r","resize","rest","rest-after","rest-before","right","rotate","row-gap","ruby-align","ruby-position","scale","scroll-behavior","scroll-margin","scroll-margin-block","scroll-margin-block-end","scroll-margin-block-start","scroll-margin-bottom","scroll-margin-inline","scroll-margin-inline-end","scroll-margin-inline-start","scroll-margin-left","scroll-margin-right","scroll-margin-top","scroll-padding","scroll-padding-block","scroll-padding-block-end","scroll-padding-block-start","scroll-padding-bottom","scroll-padding-inline","scroll-padding-inline-end","scroll-padding-inline-start","scroll-padding-left","scroll-padding-right","scroll-padding-top","scroll-snap-align","scroll-snap-stop","scroll-snap-type","scroll-timeline","scroll-timeline-axis","scroll-timeline-name","scrollbar-color","scrollbar-gutter","scrollbar-width","shape-image-threshold","shape-margin","shape-outside","shape-rendering","speak","speak-as","src","stop-color","stop-opacity","stroke","stroke-dasharray","stroke-dashoffset","stroke-linecap","stroke-linejoin","stroke-miterlimit","stroke-opacity","stroke-width","tab-size","table-layout","text-align","text-align-all","text-align-last","text-anchor","text-combine-upright","text-decoration","text-decoration-color","text-decoration-line","text-decoration-skip","text-decoration-skip-ink","text-decoration-style","text-decoration-thickness","text-emphasis","text-emphasis-color","text-emphasis-position","text-emphasis-style","text-indent","text-justify","text-orientation","text-overflow","text-rendering","text-shadow","text-size-adjust","text-transform","text-underline-offset","text-underline-position","text-wrap","text-wrap-mode","text-wrap-style","timeline-scope","top","touch-action","transform","transform-box","transform-origin","transform-style","transition","transition-behavior","transition-delay","transition-duration","transition-property","transition-timing-function","translate","unicode-bidi","user-modify","user-select","vector-effect","vertical-align","view-timeline","view-timeline-axis","view-timeline-inset","view-timeline-name","view-transition-name","visibility","voice-balance","voice-duration","voice-family","voice-pitch","voice-range","voice-rate","voice-stress","voice-volume","white-space","white-space-collapse","widows","width","will-change","word-break","word-spacing","word-wrap","writing-mode","x","y","z-index","zoom"].sort().reverse()
;function FL(e){const t=e.regex,n={className:"number",relevance:0,variants:[{
begin:/([+-]+)?[\d]+_[\d_]+/},{begin:e.NUMBER_RE}]},r=e.COMMENT();r.variants=[{
begin:/;/,end:/$/},{begin:/#/,end:/$/}];const o={className:"variable",
variants:[{begin:/\$[\w\d"][\w\d_]*/},{begin:/\$\{(.*?)\}/}]},a={
className:"literal",begin:/\bon|off|true|false|yes|no\b/},i={className:"string",
contains:[e.BACKSLASH_ESCAPE],variants:[{begin:"'''",end:"'''",relevance:10},{
begin:'"""',end:'"""',relevance:10},{begin:'"',end:'"'},{begin:"'",end:"'"}]
},s={begin:/\[/,end:/\]/,contains:[r,a,o,i,n,"self"],relevance:0
},l=t.either(/[A-Za-z0-9_-]+/,/"(\\"|[^"])*"/,/'[^']*'/);return{
name:"TOML, also INI",aliases:["toml"],case_insensitive:!0,illegal:/\S/,
contains:[r,{className:"section",begin:/\[+/,end:/\]+/},{
begin:t.concat(l,"(\\s*\\.\\s*",l,")*",t.lookahead(/\s*=\s*[^#\s]/)),
className:"attr",starts:{end:/$/,contains:[r,s,a,o,i,n]}}]}}
var ZL="[0-9](_*[0-9])*",QL=`\\.(${ZL})`,HL="[0-9a-fA-F](_*[0-9a-fA-F])*",VL={
className:"number",variants:[{
begin:`(\\b(${ZL})((${QL})|\\.)?|(${QL}))[eE][+-]?(${ZL})[fFdD]?\\b`},{
begin:`\\b(${ZL})((${QL})[fFdD]?\\b|\\.([fFdD]\\b)?)`},{
begin:`(${QL})[fFdD]?\\b`},{begin:`\\b(${ZL})[fFdD]\\b`},{
begin:`\\b0[xX]((${HL})\\.?|(${HL})?\\.(${HL}))[pP][+-]?(${ZL})[fFdD]?\\b`},{
begin:"\\b(0|[1-9](_*[0-9])*)[lL]?\\b"},{begin:`\\b0[xX](${HL})[lL]?\\b`},{
begin:"\\b0(_*[0-7])*[lL]?\\b"},{begin:"\\b0[bB][01](_*[01])*[lL]?\\b"}],
relevance:0};function qL(e,t,n){return-1===n?"":e.replace(t,(r=>qL(e,t,n-1)))}
const WL="[A-Za-z$_][0-9A-Za-z$_]*",XL=["as","in","of","if","for","while","finally","var","new","function","do","return","void","else","break","catch","instanceof","with","throw","case","default","try","switch","continue","typeof","delete","let","yield","const","class","debugger","async","await","static","import","from","export","extends","using"],GL=["true","false","null","undefined","NaN","Infinity"],YL=["Object","Function","Boolean","Symbol","Math","Date","Number","BigInt","String","RegExp","Array","Float32Array","Float64Array","Int8Array","Uint8Array","Uint8ClampedArray","Int16Array","Int32Array","Uint16Array","Uint32Array","BigInt64Array","BigUint64Array","Set","Map","WeakSet","WeakMap","ArrayBuffer","SharedArrayBuffer","Atomics","DataView","JSON","Promise","Generator","GeneratorFunction","AsyncFunction","Reflect","Proxy","Intl","WebAssembly"],KL=["Error","EvalError","InternalError","RangeError","ReferenceError","SyntaxError","TypeError","URIError"],JL=["setInterval","setTimeout","clearInterval","clearTimeout","require","exports","eval","isFinite","isNaN","parseFloat","parseInt","decodeURI","decodeURIComponent","encodeURI","encodeURIComponent","escape","unescape"],eB=["arguments","this","super","console","window","document","localStorage","sessionStorage","module","global"],tB=[].concat(JL,YL,KL)
;var nB="[0-9](_*[0-9])*",rB=`\\.(${nB})`,oB="[0-9a-fA-F](_*[0-9a-fA-F])*",aB={
className:"number",variants:[{
begin:`(\\b(${nB})((${rB})|\\.)?|(${rB}))[eE][+-]?(${nB})[fFdD]?\\b`},{
begin:`\\b(${nB})((${rB})[fFdD]?\\b|\\.([fFdD]\\b)?)`},{
begin:`(${rB})[fFdD]?\\b`},{begin:`\\b(${nB})[fFdD]\\b`},{
begin:`\\b0[xX]((${oB})\\.?|(${oB})?\\.(${oB}))[pP][+-]?(${nB})[fFdD]?\\b`},{
begin:"\\b(0|[1-9](_*[0-9])*)[lL]?\\b"},{begin:`\\b0[xX](${oB})[lL]?\\b`},{
begin:"\\b0(_*[0-7])*[lL]?\\b"},{begin:"\\b0[bB][01](_*[01])*[lL]?\\b"}],
relevance:0}
;const iB=["a","abbr","address","article","aside","audio","b","blockquote","body","button","canvas","caption","cite","code","dd","del","details","dfn","div","dl","dt","em","fieldset","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","header","hgroup","html","i","iframe","img","input","ins","kbd","label","legend","li","main","mark","menu","nav","object","ol","optgroup","option","p","picture","q","quote","samp","section","select","source","span","strong","summary","sup","table","tbody","td","textarea","tfoot","th","thead","time","tr","ul","var","video","defs","g","marker","mask","pattern","svg","switch","symbol","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feFlood","feGaussianBlur","feImage","feMerge","feMorphology","feOffset","feSpecularLighting","feTile","feTurbulence","linearGradient","radialGradient","stop","circle","ellipse","image","line","path","polygon","polyline","rect","text","use","textPath","tspan","foreignObject","clipPath"],sB=["any-hover","any-pointer","aspect-ratio","color","color-gamut","color-index","device-aspect-ratio","device-height","device-width","display-mode","forced-colors","grid","height","hover","inverted-colors","monochrome","orientation","overflow-block","overflow-inline","pointer","prefers-color-scheme","prefers-contrast","prefers-reduced-motion","prefers-reduced-transparency","resolution","scan","scripting","update","width","min-width","max-width","min-height","max-height"].sort().reverse(),lB=["active","any-link","blank","checked","current","default","defined","dir","disabled","drop","empty","enabled","first","first-child","first-of-type","fullscreen","future","focus","focus-visible","focus-within","has","host","host-context","hover","indeterminate","in-range","invalid","is","lang","last-child","last-of-type","left","link","local-link","not","nth-child","nth-col","nth-last-child","nth-last-col","nth-last-of-type","nth-of-type","only-child","only-of-type","optional","out-of-range","past","placeholder-shown","read-only","read-write","required","right","root","scope","target","target-within","user-invalid","valid","visited","where"].sort().reverse(),cB=["after","backdrop","before","cue","cue-region","first-letter","first-line","grammar-error","marker","part","placeholder","selection","slotted","spelling-error"].sort().reverse(),uB=["accent-color","align-content","align-items","align-self","alignment-baseline","all","anchor-name","animation","animation-composition","animation-delay","animation-direction","animation-duration","animation-fill-mode","animation-iteration-count","animation-name","animation-play-state","animation-range","animation-range-end","animation-range-start","animation-timeline","animation-timing-function","appearance","aspect-ratio","backdrop-filter","backface-visibility","background","background-attachment","background-blend-mode","background-clip","background-color","background-image","background-origin","background-position","background-position-x","background-position-y","background-repeat","background-size","baseline-shift","block-size","border","border-block","border-block-color","border-block-end","border-block-end-color","border-block-end-style","border-block-end-width","border-block-start","border-block-start-color","border-block-start-style","border-block-start-width","border-block-style","border-block-width","border-bottom","border-bottom-color","border-bottom-left-radius","border-bottom-right-radius","border-bottom-style","border-bottom-width","border-collapse","border-color","border-end-end-radius","border-end-start-radius","border-image","border-image-outset","border-image-repeat","border-image-slice","border-image-source","border-image-width","border-inline","border-inline-color","border-inline-end","border-inline-end-color","border-inline-end-style","border-inline-end-width","border-inline-start","border-inline-start-color","border-inline-start-style","border-inline-start-width","border-inline-style","border-inline-width","border-left","border-left-color","border-left-style","border-left-width","border-radius","border-right","border-right-color","border-right-style","border-right-width","border-spacing","border-start-end-radius","border-start-start-radius","border-style","border-top","border-top-color","border-top-left-radius","border-top-right-radius","border-top-style","border-top-width","border-width","bottom","box-align","box-decoration-break","box-direction","box-flex","box-flex-group","box-lines","box-ordinal-group","box-orient","box-pack","box-shadow","box-sizing","break-after","break-before","break-inside","caption-side","caret-color","clear","clip","clip-path","clip-rule","color","color-interpolation","color-interpolation-filters","color-profile","color-rendering","color-scheme","column-count","column-fill","column-gap","column-rule","column-rule-color","column-rule-style","column-rule-width","column-span","column-width","columns","contain","contain-intrinsic-block-size","contain-intrinsic-height","contain-intrinsic-inline-size","contain-intrinsic-size","contain-intrinsic-width","container","container-name","container-type","content","content-visibility","counter-increment","counter-reset","counter-set","cue","cue-after","cue-before","cursor","cx","cy","direction","display","dominant-baseline","empty-cells","enable-background","field-sizing","fill","fill-opacity","fill-rule","filter","flex","flex-basis","flex-direction","flex-flow","flex-grow","flex-shrink","flex-wrap","float","flood-color","flood-opacity","flow","font","font-display","font-family","font-feature-settings","font-kerning","font-language-override","font-optical-sizing","font-palette","font-size","font-size-adjust","font-smooth","font-smoothing","font-stretch","font-style","font-synthesis","font-synthesis-position","font-synthesis-small-caps","font-synthesis-style","font-synthesis-weight","font-variant","font-variant-alternates","font-variant-caps","font-variant-east-asian","font-variant-emoji","font-variant-ligatures","font-variant-numeric","font-variant-position","font-variation-settings","font-weight","forced-color-adjust","gap","glyph-orientation-horizontal","glyph-orientation-vertical","grid","grid-area","grid-auto-columns","grid-auto-flow","grid-auto-rows","grid-column","grid-column-end","grid-column-start","grid-gap","grid-row","grid-row-end","grid-row-start","grid-template","grid-template-areas","grid-template-columns","grid-template-rows","hanging-punctuation","height","hyphenate-character","hyphenate-limit-chars","hyphens","icon","image-orientation","image-rendering","image-resolution","ime-mode","initial-letter","initial-letter-align","inline-size","inset","inset-area","inset-block","inset-block-end","inset-block-start","inset-inline","inset-inline-end","inset-inline-start","isolation","justify-content","justify-items","justify-self","kerning","left","letter-spacing","lighting-color","line-break","line-height","line-height-step","list-style","list-style-image","list-style-position","list-style-type","margin","margin-block","margin-block-end","margin-block-start","margin-bottom","margin-inline","margin-inline-end","margin-inline-start","margin-left","margin-right","margin-top","margin-trim","marker","marker-end","marker-mid","marker-start","marks","mask","mask-border","mask-border-mode","mask-border-outset","mask-border-repeat","mask-border-slice","mask-border-source","mask-border-width","mask-clip","mask-composite","mask-image","mask-mode","mask-origin","mask-position","mask-repeat","mask-size","mask-type","masonry-auto-flow","math-depth","math-shift","math-style","max-block-size","max-height","max-inline-size","max-width","min-block-size","min-height","min-inline-size","min-width","mix-blend-mode","nav-down","nav-index","nav-left","nav-right","nav-up","none","normal","object-fit","object-position","offset","offset-anchor","offset-distance","offset-path","offset-position","offset-rotate","opacity","order","orphans","outline","outline-color","outline-offset","outline-style","outline-width","overflow","overflow-anchor","overflow-block","overflow-clip-margin","overflow-inline","overflow-wrap","overflow-x","overflow-y","overlay","overscroll-behavior","overscroll-behavior-block","overscroll-behavior-inline","overscroll-behavior-x","overscroll-behavior-y","padding","padding-block","padding-block-end","padding-block-start","padding-bottom","padding-inline","padding-inline-end","padding-inline-start","padding-left","padding-right","padding-top","page","page-break-after","page-break-before","page-break-inside","paint-order","pause","pause-after","pause-before","perspective","perspective-origin","place-content","place-items","place-self","pointer-events","position","position-anchor","position-visibility","print-color-adjust","quotes","r","resize","rest","rest-after","rest-before","right","rotate","row-gap","ruby-align","ruby-position","scale","scroll-behavior","scroll-margin","scroll-margin-block","scroll-margin-block-end","scroll-margin-block-start","scroll-margin-bottom","scroll-margin-inline","scroll-margin-inline-end","scroll-margin-inline-start","scroll-margin-left","scroll-margin-right","scroll-margin-top","scroll-padding","scroll-padding-block","scroll-padding-block-end","scroll-padding-block-start","scroll-padding-bottom","scroll-padding-inline","scroll-padding-inline-end","scroll-padding-inline-start","scroll-padding-left","scroll-padding-right","scroll-padding-top","scroll-snap-align","scroll-snap-stop","scroll-snap-type","scroll-timeline","scroll-timeline-axis","scroll-timeline-name","scrollbar-color","scrollbar-gutter","scrollbar-width","shape-image-threshold","shape-margin","shape-outside","shape-rendering","speak","speak-as","src","stop-color","stop-opacity","stroke","stroke-dasharray","stroke-dashoffset","stroke-linecap","stroke-linejoin","stroke-miterlimit","stroke-opacity","stroke-width","tab-size","table-layout","text-align","text-align-all","text-align-last","text-anchor","text-combine-upright","text-decoration","text-decoration-color","text-decoration-line","text-decoration-skip","text-decoration-skip-ink","text-decoration-style","text-decoration-thickness","text-emphasis","text-emphasis-color","text-emphasis-position","text-emphasis-style","text-indent","text-justify","text-orientation","text-overflow","text-rendering","text-shadow","text-size-adjust","text-transform","text-underline-offset","text-underline-position","text-wrap","text-wrap-mode","text-wrap-style","timeline-scope","top","touch-action","transform","transform-box","transform-origin","transform-style","transition","transition-behavior","transition-delay","transition-duration","transition-property","transition-timing-function","translate","unicode-bidi","user-modify","user-select","vector-effect","vertical-align","view-timeline","view-timeline-axis","view-timeline-inset","view-timeline-name","view-transition-name","visibility","voice-balance","voice-duration","voice-family","voice-pitch","voice-range","voice-rate","voice-stress","voice-volume","white-space","white-space-collapse","widows","width","will-change","word-break","word-spacing","word-wrap","writing-mode","x","y","z-index","zoom"].sort().reverse(),dB=lB.concat(cB).sort().reverse()
;const pB=["a","abbr","address","article","aside","audio","b","blockquote","body","button","canvas","caption","cite","code","dd","del","details","dfn","div","dl","dt","em","fieldset","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","header","hgroup","html","i","iframe","img","input","ins","kbd","label","legend","li","main","mark","menu","nav","object","ol","optgroup","option","p","picture","q","quote","samp","section","select","source","span","strong","summary","sup","table","tbody","td","textarea","tfoot","th","thead","time","tr","ul","var","video","defs","g","marker","mask","pattern","svg","switch","symbol","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feFlood","feGaussianBlur","feImage","feMerge","feMorphology","feOffset","feSpecularLighting","feTile","feTurbulence","linearGradient","radialGradient","stop","circle","ellipse","image","line","path","polygon","polyline","rect","text","use","textPath","tspan","foreignObject","clipPath"],hB=["any-hover","any-pointer","aspect-ratio","color","color-gamut","color-index","device-aspect-ratio","device-height","device-width","display-mode","forced-colors","grid","height","hover","inverted-colors","monochrome","orientation","overflow-block","overflow-inline","pointer","prefers-color-scheme","prefers-contrast","prefers-reduced-motion","prefers-reduced-transparency","resolution","scan","scripting","update","width","min-width","max-width","min-height","max-height"].sort().reverse(),fB=["active","any-link","blank","checked","current","default","defined","dir","disabled","drop","empty","enabled","first","first-child","first-of-type","fullscreen","future","focus","focus-visible","focus-within","has","host","host-context","hover","indeterminate","in-range","invalid","is","lang","last-child","last-of-type","left","link","local-link","not","nth-child","nth-col","nth-last-child","nth-last-col","nth-last-of-type","nth-of-type","only-child","only-of-type","optional","out-of-range","past","placeholder-shown","read-only","read-write","required","right","root","scope","target","target-within","user-invalid","valid","visited","where"].sort().reverse(),mB=["after","backdrop","before","cue","cue-region","first-letter","first-line","grammar-error","marker","part","placeholder","selection","slotted","spelling-error"].sort().reverse(),gB=["accent-color","align-content","align-items","align-self","alignment-baseline","all","anchor-name","animation","animation-composition","animation-delay","animation-direction","animation-duration","animation-fill-mode","animation-iteration-count","animation-name","animation-play-state","animation-range","animation-range-end","animation-range-start","animation-timeline","animation-timing-function","appearance","aspect-ratio","backdrop-filter","backface-visibility","background","background-attachment","background-blend-mode","background-clip","background-color","background-image","background-origin","background-position","background-position-x","background-position-y","background-repeat","background-size","baseline-shift","block-size","border","border-block","border-block-color","border-block-end","border-block-end-color","border-block-end-style","border-block-end-width","border-block-start","border-block-start-color","border-block-start-style","border-block-start-width","border-block-style","border-block-width","border-bottom","border-bottom-color","border-bottom-left-radius","border-bottom-right-radius","border-bottom-style","border-bottom-width","border-collapse","border-color","border-end-end-radius","border-end-start-radius","border-image","border-image-outset","border-image-repeat","border-image-slice","border-image-source","border-image-width","border-inline","border-inline-color","border-inline-end","border-inline-end-color","border-inline-end-style","border-inline-end-width","border-inline-start","border-inline-start-color","border-inline-start-style","border-inline-start-width","border-inline-style","border-inline-width","border-left","border-left-color","border-left-style","border-left-width","border-radius","border-right","border-right-color","border-right-style","border-right-width","border-spacing","border-start-end-radius","border-start-start-radius","border-style","border-top","border-top-color","border-top-left-radius","border-top-right-radius","border-top-style","border-top-width","border-width","bottom","box-align","box-decoration-break","box-direction","box-flex","box-flex-group","box-lines","box-ordinal-group","box-orient","box-pack","box-shadow","box-sizing","break-after","break-before","break-inside","caption-side","caret-color","clear","clip","clip-path","clip-rule","color","color-interpolation","color-interpolation-filters","color-profile","color-rendering","color-scheme","column-count","column-fill","column-gap","column-rule","column-rule-color","column-rule-style","column-rule-width","column-span","column-width","columns","contain","contain-intrinsic-block-size","contain-intrinsic-height","contain-intrinsic-inline-size","contain-intrinsic-size","contain-intrinsic-width","container","container-name","container-type","content","content-visibility","counter-increment","counter-reset","counter-set","cue","cue-after","cue-before","cursor","cx","cy","direction","display","dominant-baseline","empty-cells","enable-background","field-sizing","fill","fill-opacity","fill-rule","filter","flex","flex-basis","flex-direction","flex-flow","flex-grow","flex-shrink","flex-wrap","float","flood-color","flood-opacity","flow","font","font-display","font-family","font-feature-settings","font-kerning","font-language-override","font-optical-sizing","font-palette","font-size","font-size-adjust","font-smooth","font-smoothing","font-stretch","font-style","font-synthesis","font-synthesis-position","font-synthesis-small-caps","font-synthesis-style","font-synthesis-weight","font-variant","font-variant-alternates","font-variant-caps","font-variant-east-asian","font-variant-emoji","font-variant-ligatures","font-variant-numeric","font-variant-position","font-variation-settings","font-weight","forced-color-adjust","gap","glyph-orientation-horizontal","glyph-orientation-vertical","grid","grid-area","grid-auto-columns","grid-auto-flow","grid-auto-rows","grid-column","grid-column-end","grid-column-start","grid-gap","grid-row","grid-row-end","grid-row-start","grid-template","grid-template-areas","grid-template-columns","grid-template-rows","hanging-punctuation","height","hyphenate-character","hyphenate-limit-chars","hyphens","icon","image-orientation","image-rendering","image-resolution","ime-mode","initial-letter","initial-letter-align","inline-size","inset","inset-area","inset-block","inset-block-end","inset-block-start","inset-inline","inset-inline-end","inset-inline-start","isolation","justify-content","justify-items","justify-self","kerning","left","letter-spacing","lighting-color","line-break","line-height","line-height-step","list-style","list-style-image","list-style-position","list-style-type","margin","margin-block","margin-block-end","margin-block-start","margin-bottom","margin-inline","margin-inline-end","margin-inline-start","margin-left","margin-right","margin-top","margin-trim","marker","marker-end","marker-mid","marker-start","marks","mask","mask-border","mask-border-mode","mask-border-outset","mask-border-repeat","mask-border-slice","mask-border-source","mask-border-width","mask-clip","mask-composite","mask-image","mask-mode","mask-origin","mask-position","mask-repeat","mask-size","mask-type","masonry-auto-flow","math-depth","math-shift","math-style","max-block-size","max-height","max-inline-size","max-width","min-block-size","min-height","min-inline-size","min-width","mix-blend-mode","nav-down","nav-index","nav-left","nav-right","nav-up","none","normal","object-fit","object-position","offset","offset-anchor","offset-distance","offset-path","offset-position","offset-rotate","opacity","order","orphans","outline","outline-color","outline-offset","outline-style","outline-width","overflow","overflow-anchor","overflow-block","overflow-clip-margin","overflow-inline","overflow-wrap","overflow-x","overflow-y","overlay","overscroll-behavior","overscroll-behavior-block","overscroll-behavior-inline","overscroll-behavior-x","overscroll-behavior-y","padding","padding-block","padding-block-end","padding-block-start","padding-bottom","padding-inline","padding-inline-end","padding-inline-start","padding-left","padding-right","padding-top","page","page-break-after","page-break-before","page-break-inside","paint-order","pause","pause-after","pause-before","perspective","perspective-origin","place-content","place-items","place-self","pointer-events","position","position-anchor","position-visibility","print-color-adjust","quotes","r","resize","rest","rest-after","rest-before","right","rotate","row-gap","ruby-align","ruby-position","scale","scroll-behavior","scroll-margin","scroll-margin-block","scroll-margin-block-end","scroll-margin-block-start","scroll-margin-bottom","scroll-margin-inline","scroll-margin-inline-end","scroll-margin-inline-start","scroll-margin-left","scroll-margin-right","scroll-margin-top","scroll-padding","scroll-padding-block","scroll-padding-block-end","scroll-padding-block-start","scroll-padding-bottom","scroll-padding-inline","scroll-padding-inline-end","scroll-padding-inline-start","scroll-padding-left","scroll-padding-right","scroll-padding-top","scroll-snap-align","scroll-snap-stop","scroll-snap-type","scroll-timeline","scroll-timeline-axis","scroll-timeline-name","scrollbar-color","scrollbar-gutter","scrollbar-width","shape-image-threshold","shape-margin","shape-outside","shape-rendering","speak","speak-as","src","stop-color","stop-opacity","stroke","stroke-dasharray","stroke-dashoffset","stroke-linecap","stroke-linejoin","stroke-miterlimit","stroke-opacity","stroke-width","tab-size","table-layout","text-align","text-align-all","text-align-last","text-anchor","text-combine-upright","text-decoration","text-decoration-color","text-decoration-line","text-decoration-skip","text-decoration-skip-ink","text-decoration-style","text-decoration-thickness","text-emphasis","text-emphasis-color","text-emphasis-position","text-emphasis-style","text-indent","text-justify","text-orientation","text-overflow","text-rendering","text-shadow","text-size-adjust","text-transform","text-underline-offset","text-underline-position","text-wrap","text-wrap-mode","text-wrap-style","timeline-scope","top","touch-action","transform","transform-box","transform-origin","transform-style","transition","transition-behavior","transition-delay","transition-duration","transition-property","transition-timing-function","translate","unicode-bidi","user-modify","user-select","vector-effect","vertical-align","view-timeline","view-timeline-axis","view-timeline-inset","view-timeline-name","view-transition-name","visibility","voice-balance","voice-duration","voice-family","voice-pitch","voice-range","voice-rate","voice-stress","voice-volume","white-space","white-space-collapse","widows","width","will-change","word-break","word-spacing","word-wrap","writing-mode","x","y","z-index","zoom"].sort().reverse()
;function vB(e){return e?"string"==typeof e?e:e.source:null}function bB(e){
return yB("(?=",e,")")}function yB(...e){return e.map((e=>vB(e))).join("")}
function OB(...e){const t=function(e){const t=e[e.length-1]
;return"object"==typeof t&&t.constructor===Object?(e.splice(e.length-1,1),t):{}
}(e);return"("+(t.capture?"":"?:")+e.map((e=>vB(e))).join("|")+")"}
const wB=e=>yB(/\b/,e,/\w$/.test(e)?/\b/:/\B/),xB=["Protocol","Type"].map(wB),kB=["init","self"].map(wB),SB=["Any","Self"],_B=["actor","any","associatedtype","async","await",/as\?/,/as!/,"as","borrowing","break","case","catch","class","consume","consuming","continue","convenience","copy","default","defer","deinit","didSet","distributed","do","dynamic","each","else","enum","extension","fallthrough",/fileprivate\(set\)/,"fileprivate","final","for","func","get","guard","if","import","indirect","infix",/init\?/,/init!/,"inout",/internal\(set\)/,"internal","in","is","isolated","nonisolated","lazy","let","macro","mutating","nonmutating",/open\(set\)/,"open","operator","optional","override","package","postfix","precedencegroup","prefix",/private\(set\)/,"private","protocol",/public\(set\)/,"public","repeat","required","rethrows","return","set","some","static","struct","subscript","super","switch","throws","throw",/try\?/,/try!/,"try","typealias",/unowned\(safe\)/,/unowned\(unsafe\)/,"unowned","var","weak","where","while","willSet"],TB=["false","nil","true"],EB=["assignment","associativity","higherThan","left","lowerThan","none","right"],AB=["#colorLiteral","#column","#dsohandle","#else","#elseif","#endif","#error","#file","#fileID","#fileLiteral","#filePath","#function","#if","#imageLiteral","#keyPath","#line","#selector","#sourceLocation","#warning"],CB=["abs","all","any","assert","assertionFailure","debugPrint","dump","fatalError","getVaList","isKnownUniquelyReferenced","max","min","numericCast","pointwiseMax","pointwiseMin","precondition","preconditionFailure","print","readLine","repeatElement","sequence","stride","swap","swift_unboxFromSwiftValueWithType","transcode","type","unsafeBitCast","unsafeDowncast","withExtendedLifetime","withUnsafeMutablePointer","withUnsafePointer","withVaList","withoutActuallyEscaping","zip"],$B=OB(/[/=\-+!*%<>&|^~?]/,/[\u00A1-\u00A7]/,/[\u00A9\u00AB]/,/[\u00AC\u00AE]/,/[\u00B0\u00B1]/,/[\u00B6\u00BB\u00BF\u00D7\u00F7]/,/[\u2016-\u2017]/,/[\u2020-\u2027]/,/[\u2030-\u203E]/,/[\u2041-\u2053]/,/[\u2055-\u205E]/,/[\u2190-\u23FF]/,/[\u2500-\u2775]/,/[\u2794-\u2BFF]/,/[\u2E00-\u2E7F]/,/[\u3001-\u3003]/,/[\u3008-\u3020]/,/[\u3030]/),PB=OB($B,/[\u0300-\u036F]/,/[\u1DC0-\u1DFF]/,/[\u20D0-\u20FF]/,/[\uFE00-\uFE0F]/,/[\uFE20-\uFE2F]/),DB=yB($B,PB,"*"),IB=OB(/[a-zA-Z_]/,/[\u00A8\u00AA\u00AD\u00AF\u00B2-\u00B5\u00B7-\u00BA]/,/[\u00BC-\u00BE\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF]/,/[\u0100-\u02FF\u0370-\u167F\u1681-\u180D\u180F-\u1DBF]/,/[\u1E00-\u1FFF]/,/[\u200B-\u200D\u202A-\u202E\u203F-\u2040\u2054\u2060-\u206F]/,/[\u2070-\u20CF\u2100-\u218F\u2460-\u24FF\u2776-\u2793]/,/[\u2C00-\u2DFF\u2E80-\u2FFF]/,/[\u3004-\u3007\u3021-\u302F\u3031-\u303F\u3040-\uD7FF]/,/[\uF900-\uFD3D\uFD40-\uFDCF\uFDF0-\uFE1F\uFE30-\uFE44]/,/[\uFE47-\uFEFE\uFF00-\uFFFD]/),MB=OB(IB,/\d/,/[\u0300-\u036F\u1DC0-\u1DFF\u20D0-\u20FF\uFE20-\uFE2F]/),NB=yB(IB,MB,"*"),RB=yB(/[A-Z]/,MB,"*"),LB=["attached","autoclosure",yB(/convention\(/,OB("swift","block","c"),/\)/),"discardableResult","dynamicCallable","dynamicMemberLookup","escaping","freestanding","frozen","GKInspectable","IBAction","IBDesignable","IBInspectable","IBOutlet","IBSegueAction","inlinable","main","nonobjc","NSApplicationMain","NSCopying","NSManaged",yB(/objc\(/,NB,/\)/),"objc","objcMembers","propertyWrapper","requires_stored_property_inits","resultBuilder","Sendable","testable","UIApplicationMain","unchecked","unknown","usableFromInline","warn_unqualified_access"],BB=["iOS","iOSApplicationExtension","macOS","macOSApplicationExtension","macCatalyst","macCatalystApplicationExtension","watchOS","watchOSApplicationExtension","tvOS","tvOSApplicationExtension","swift"]
;const jB="[A-Za-z$_][0-9A-Za-z$_]*",UB=["as","in","of","if","for","while","finally","var","new","function","do","return","void","else","break","catch","instanceof","with","throw","case","default","try","switch","continue","typeof","delete","let","yield","const","class","debugger","async","await","static","import","from","export","extends","using"],zB=["true","false","null","undefined","NaN","Infinity"],FB=["Object","Function","Boolean","Symbol","Math","Date","Number","BigInt","String","RegExp","Array","Float32Array","Float64Array","Int8Array","Uint8Array","Uint8ClampedArray","Int16Array","Int32Array","Uint16Array","Uint32Array","BigInt64Array","BigUint64Array","Set","Map","WeakSet","WeakMap","ArrayBuffer","SharedArrayBuffer","Atomics","DataView","JSON","Promise","Generator","GeneratorFunction","AsyncFunction","Reflect","Proxy","Intl","WebAssembly"],ZB=["Error","EvalError","InternalError","RangeError","ReferenceError","SyntaxError","TypeError","URIError"],QB=["setInterval","setTimeout","clearInterval","clearTimeout","require","exports","eval","isFinite","isNaN","parseFloat","parseInt","decodeURI","decodeURIComponent","encodeURI","encodeURIComponent","escape","unescape"],HB=["arguments","this","super","console","window","document","localStorage","sessionStorage","module","global"],VB=[].concat(QB,FB,ZB)
;function qB(e){
const t=e.regex,n=t.concat(/[\p{L}_]/u,t.optional(/[\p{L}0-9_.-]*:/u),/[\p{L}0-9_.-]*/u),r={
className:"symbol",begin:/&[a-z]+;|&#[0-9]+;|&#x[a-f0-9]+;/},o={begin:/\s/,
contains:[{className:"keyword",begin:/#?[a-z_][a-z1-9_-]+/,illegal:/\n/}]
},a=e.inherit(o,{begin:/\(/,end:/\)/}),i=e.inherit(e.APOS_STRING_MODE,{
className:"string"}),s=e.inherit(e.QUOTE_STRING_MODE,{className:"string"}),l={
endsWithParent:!0,illegal:/</,relevance:0,contains:[{className:"attr",
begin:/[\p{L}0-9._:-]+/u,relevance:0},{begin:/=\s*/,relevance:0,contains:[{
className:"string",endsParent:!0,variants:[{begin:/"/,end:/"/,contains:[r]},{
begin:/'/,end:/'/,contains:[r]},{begin:/[^\s"'=<>`]+/}]}]}]};return{
name:"HTML, XML",
aliases:["html","xhtml","rss","atom","xjb","xsd","xsl","plist","wsf","svg"],
case_insensitive:!0,unicodeRegex:!0,contains:[{className:"meta",begin:/<![a-z]/,
end:/>/,relevance:10,contains:[o,s,i,a,{begin:/\[/,end:/\]/,contains:[{
className:"meta",begin:/<![a-z]/,end:/>/,contains:[o,a,s,i]}]}]
},e.COMMENT(/<!--/,/-->/,{relevance:10}),{begin:/<!\[CDATA\[/,end:/\]\]>/,
relevance:10},r,{className:"meta",end:/\?>/,variants:[{begin:/<\?xml/,
relevance:10,contains:[s]},{begin:/<\?[a-z][a-z0-9]+/}]},{className:"tag",
begin:/<style(?=\s|>)/,end:/>/,keywords:{name:"style"},contains:[l],starts:{
end:/<\/style>/,returnEnd:!0,subLanguage:["css","xml"]}},{className:"tag",
begin:/<script(?=\s|>)/,end:/>/,keywords:{name:"script"},contains:[l],starts:{
end:/<\/script>/,returnEnd:!0,subLanguage:["javascript","handlebars","xml"]}},{
className:"tag",begin:/<>|<\/>/},{className:"tag",
begin:t.concat(/</,t.lookahead(t.concat(n,t.either(/\/>/,/>/,/\s/)))),
end:/\/?>/,contains:[{className:"name",begin:n,relevance:0,starts:l}]},{
className:"tag",begin:t.concat(/<\//,t.lookahead(t.concat(n,/>/))),contains:[{
className:"name",begin:n,relevance:0},{begin:/>/,relevance:0,endsParent:!0}]}]}}
var WB,XB;function GB(){if(XB)return WB;function e(t){
return t instanceof Map?t.clear=t.delete=t.set=function(){
throw new Error("map is read-only")
}:t instanceof Set&&(t.add=t.clear=t.delete=function(){
throw new Error("set is read-only")
}),Object.freeze(t),Object.getOwnPropertyNames(t).forEach((n=>{
const r=t[n],o=typeof r;"object"!==o&&"function"!==o||Object.isFrozen(r)||e(r)
})),t}XB=1;class t{constructor(e){void 0===e.data&&(e.data={}),this.data=e.data,
this.isMatchIgnored=!1}ignoreMatch(){this.isMatchIgnored=!0}}function n(e){
return e.replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;").replace(/"/g,"&quot;").replace(/'/g,"&#x27;")
}function r(e,...t){const n=Object.create(null);for(const r in e)n[r]=e[r]
;return t.forEach((function(e){for(const t in e)n[t]=e[t]})),n}
const o=e=>!!e.scope;class a{constructor(e,t){
this.buffer="",this.classPrefix=t.classPrefix,e.walk(this)}addText(e){
this.buffer+=n(e)}openNode(e){if(!o(e))return;const t=((e,{prefix:t})=>{
if(e.startsWith("language:"))return e.replace("language:","language-")
;if(e.includes(".")){const n=e.split(".")
;return[`${t}${n.shift()}`,...n.map(((e,t)=>`${e}${"_".repeat(t+1)}`))].join(" ")
}return`${t}${e}`})(e.scope,{prefix:this.classPrefix});this.span(t)}
closeNode(e){o(e)&&(this.buffer+="</span>")}value(){return this.buffer}span(e){
this.buffer+=`<span class="${e}">`}}const i=(e={})=>{const t={children:[]}
;return Object.assign(t,e),t};class s{constructor(){
this.rootNode=i(),this.stack=[this.rootNode]}get top(){
return this.stack[this.stack.length-1]}get root(){return this.rootNode}add(e){
this.top.children.push(e)}openNode(e){const t=i({scope:e})
;this.add(t),this.stack.push(t)}closeNode(){
if(this.stack.length>1)return this.stack.pop()}closeAllNodes(){
for(;this.closeNode(););}toJSON(){return JSON.stringify(this.rootNode,null,4)}
walk(e){return this.constructor._walk(e,this.rootNode)}static _walk(e,t){
return"string"==typeof t?e.addText(t):t.children&&(e.openNode(t),
t.children.forEach((t=>this._walk(e,t))),e.closeNode(t)),e}static _collapse(e){
"string"!=typeof e&&e.children&&(e.children.every((e=>"string"==typeof e))?e.children=[e.children.join("")]:e.children.forEach((e=>{
s._collapse(e)})))}}class l extends s{constructor(e){super(),this.options=e}
addText(e){""!==e&&this.add(e)}startScope(e){this.openNode(e)}endScope(){
this.closeNode()}__addSublanguage(e,t){const n=e.root
;t&&(n.scope=`language:${t}`),this.add(n)}toHTML(){
return new a(this,this.options).value()}finalize(){
return this.closeAllNodes(),!0}}function c(e){
return e?"string"==typeof e?e:e.source:null}function u(e){return h("(?=",e,")")}
function d(e){return h("(?:",e,")*")}function p(e){return h("(?:",e,")?")}
function h(...e){return e.map((e=>c(e))).join("")}function f(...e){
const t=function(e){const t=e[e.length-1]
;return"object"==typeof t&&t.constructor===Object?(e.splice(e.length-1,1),t):{}
}(e);return"("+(t.capture?"":"?:")+e.map((e=>c(e))).join("|")+")"}function m(e){
return new RegExp(e.toString()+"|").exec("").length-1}
const g=/\[(?:[^\\\]]|\\.)*\]|\(\??|\\([1-9][0-9]*)|\\./
;function v(e,{joinWith:t}){let n=0;return e.map((e=>{n+=1;const t=n
;let r=c(e),o="";for(;r.length>0;){const e=g.exec(r);if(!e){o+=r;break}
o+=r.substring(0,e.index),
r=r.substring(e.index+e[0].length),"\\"===e[0][0]&&e[1]?o+="\\"+String(Number(e[1])+t):(o+=e[0],
"("===e[0]&&n++)}return o})).map((e=>`(${e})`)).join(t)}
const b="[a-zA-Z]\\w*",y="[a-zA-Z_]\\w*",O="\\b\\d+(\\.\\d+)?",w="(-?)(\\b0[xX][a-fA-F0-9]+|(\\b\\d+(\\.\\d*)?|\\.\\d+)([eE][-+]?\\d+)?)",x="\\b(0b[01]+)",k={
begin:"\\\\[\\s\\S]",relevance:0},S={scope:"string",begin:"'",end:"'",
illegal:"\\n",contains:[k]},_={scope:"string",begin:'"',end:'"',illegal:"\\n",
contains:[k]},T=function(e,t,n={}){const o=r({scope:"comment",begin:e,end:t,
contains:[]},n);o.contains.push({scope:"doctag",
begin:"[ ]*(?=(TODO|FIXME|NOTE|BUG|OPTIMIZE|HACK|XXX):)",
end:/(TODO|FIXME|NOTE|BUG|OPTIMIZE|HACK|XXX):/,excludeBegin:!0,relevance:0})
;const a=f("I","a","is","so","us","to","at","if","in","it","on",/[A-Za-z]+['](d|ve|re|ll|t|s|n)/,/[A-Za-z]+[-][a-z]+/,/[A-Za-z][a-z]{2,}/)
;return o.contains.push({begin:h(/[ ]+/,"(",a,/[.]?[:]?([.][ ]|[ ])/,"){3}")}),o
},E=T("//","$"),A=T("/\\*","\\*/"),C=T("#","$"),$={scope:"number",begin:O,
relevance:0},P={scope:"number",begin:w,relevance:0},D={scope:"number",begin:x,
relevance:0},I={scope:"regexp",begin:/\/(?=[^/\n]*\/)/,end:/\/[gimuy]*/,
contains:[k,{begin:/\[/,end:/\]/,relevance:0,contains:[k]}]},M={scope:"title",
begin:b,relevance:0},N={scope:"title",begin:y,relevance:0},R={begin:"\\.\\s*"+y,
relevance:0};var L=Object.freeze({__proto__:null,APOS_STRING_MODE:S,
BACKSLASH_ESCAPE:k,BINARY_NUMBER_MODE:D,BINARY_NUMBER_RE:x,COMMENT:T,
C_BLOCK_COMMENT_MODE:A,C_LINE_COMMENT_MODE:E,C_NUMBER_MODE:P,C_NUMBER_RE:w,
END_SAME_AS_BEGIN:function(e){return Object.assign(e,{"on:begin":(e,t)=>{
t.data._beginMatch=e[1]},"on:end":(e,t)=>{
t.data._beginMatch!==e[1]&&t.ignoreMatch()}})},HASH_COMMENT_MODE:C,IDENT_RE:b,
MATCH_NOTHING_RE:/\b\B/,METHOD_GUARD:R,NUMBER_MODE:$,NUMBER_RE:O,
PHRASAL_WORDS_MODE:{
begin:/\b(a|an|the|are|I'm|isn't|don't|doesn't|won't|but|just|should|pretty|simply|enough|gonna|going|wtf|so|such|will|you|your|they|like|more)\b/
},QUOTE_STRING_MODE:_,REGEXP_MODE:I,
RE_STARTERS_RE:"!|!=|!==|%|%=|&|&&|&=|\\*|\\*=|\\+|\\+=|,|-|-=|/=|/|:|;|<<|<<=|<=|<|===|==|=|>>>=|>>=|>=|>>>|>>|>|\\?|\\[|\\{|\\(|\\^|\\^=|\\||\\|=|\\|\\||~",
SHEBANG:(e={})=>{const t=/^#![ ]*\//
;return e.binary&&(e.begin=h(t,/.*\b/,e.binary,/\b.*/)),r({scope:"meta",begin:t,
end:/$/,relevance:0,"on:begin":(e,t)=>{0!==e.index&&t.ignoreMatch()}},e)},
TITLE_MODE:M,UNDERSCORE_IDENT_RE:y,UNDERSCORE_TITLE_MODE:N});function B(e,t){
"."===e.input[e.index-1]&&t.ignoreMatch()}function j(e,t){
void 0!==e.className&&(e.scope=e.className,delete e.className)}function U(e,t){
t&&e.beginKeywords&&(e.begin="\\b("+e.beginKeywords.split(" ").join("|")+")(?!\\.)(?=\\b|\\s)",
e.__beforeBegin=B,e.keywords=e.keywords||e.beginKeywords,delete e.beginKeywords,
void 0===e.relevance&&(e.relevance=0))}function z(e,t){
Array.isArray(e.illegal)&&(e.illegal=f(...e.illegal))}function F(e,t){
if(e.match){
if(e.begin||e.end)throw new Error("begin & end are not supported with match")
;e.begin=e.match,delete e.match}}function Z(e,t){
void 0===e.relevance&&(e.relevance=1)}const Q=(e,t)=>{if(!e.beforeMatch)return
;if(e.starts)throw new Error("beforeMatch cannot be used with starts")
;const n=Object.assign({},e);Object.keys(e).forEach((t=>{delete e[t]
})),e.keywords=n.keywords,e.begin=h(n.beforeMatch,u(n.begin)),e.starts={
relevance:0,contains:[Object.assign(n,{endsParent:!0})]
},e.relevance=0,delete n.beforeMatch
},H=["of","and","for","in","not","or","if","then","parent","list","value"],V="keyword"
;function q(e,t,n=V){const r=Object.create(null)
;return"string"==typeof e?o(n,e.split(" ")):Array.isArray(e)?o(n,e):Object.keys(e).forEach((function(n){
Object.assign(r,q(e[n],t,n))})),r;function o(e,n){
t&&(n=n.map((e=>e.toLowerCase()))),n.forEach((function(t){const n=t.split("|")
;r[n[0]]=[e,W(n[0],n[1])]}))}}function W(e,t){return t?Number(t):function(e){
return H.includes(e.toLowerCase())}(e)?0:1}const X={},G=e=>{console.error(e)
},Y=(e,...t)=>{console.log(`WARN: ${e}`,...t)},K=(e,t)=>{
X[`${e}/${t}`]||(console.log(`Deprecated as of ${e}. ${t}`),X[`${e}/${t}`]=!0)
},J=new Error;function ee(e,t,{key:n}){let r=0;const o=e[n],a={},i={}
;for(let s=1;s<=t.length;s++)i[s+r]=o[s],a[s+r]=!0,r+=m(t[s-1])
;e[n]=i,e[n]._emit=a,e[n]._multi=!0}function te(e){!function(e){
e.scope&&"object"==typeof e.scope&&null!==e.scope&&(e.beginScope=e.scope,
delete e.scope)}(e),"string"==typeof e.beginScope&&(e.beginScope={
_wrap:e.beginScope}),"string"==typeof e.endScope&&(e.endScope={_wrap:e.endScope
}),function(e){if(Array.isArray(e.begin)){
if(e.skip||e.excludeBegin||e.returnBegin)throw G("skip, excludeBegin, returnBegin not compatible with beginScope: {}"),
J
;if("object"!=typeof e.beginScope||null===e.beginScope)throw G("beginScope must be object"),
J;ee(e,e.begin,{key:"beginScope"}),e.begin=v(e.begin,{joinWith:""})}
}(e),function(e){if(Array.isArray(e.end)){
if(e.skip||e.excludeEnd||e.returnEnd)throw G("skip, excludeEnd, returnEnd not compatible with endScope: {}"),
J
;if("object"!=typeof e.endScope||null===e.endScope)throw G("endScope must be object"),
J;ee(e,e.end,{key:"endScope"}),e.end=v(e.end,{joinWith:""})}}(e)}function ne(e){
function t(t,n){
return new RegExp(c(t),"m"+(e.case_insensitive?"i":"")+(e.unicodeRegex?"u":"")+(n?"g":""))
}class n{constructor(){
this.matchIndexes={},this.regexes=[],this.matchAt=1,this.position=0}
addRule(e,t){
t.position=this.position++,this.matchIndexes[this.matchAt]=t,this.regexes.push([t,e]),
this.matchAt+=m(e)+1}compile(){0===this.regexes.length&&(this.exec=()=>null)
;const e=this.regexes.map((e=>e[1]));this.matcherRe=t(v(e,{joinWith:"|"
}),!0),this.lastIndex=0}exec(e){this.matcherRe.lastIndex=this.lastIndex
;const t=this.matcherRe.exec(e);if(!t)return null
;const n=t.findIndex(((e,t)=>t>0&&void 0!==e)),r=this.matchIndexes[n]
;return t.splice(0,n),Object.assign(t,r)}}class o{constructor(){
this.rules=[],this.multiRegexes=[],
this.count=0,this.lastIndex=0,this.regexIndex=0}getMatcher(e){
if(this.multiRegexes[e])return this.multiRegexes[e];const t=new n
;return this.rules.slice(e).forEach((([e,n])=>t.addRule(e,n))),
t.compile(),this.multiRegexes[e]=t,t}resumingScanAtSamePosition(){
return 0!==this.regexIndex}considerAll(){this.regexIndex=0}addRule(e,t){
this.rules.push([e,t]),"begin"===t.type&&this.count++}exec(e){
const t=this.getMatcher(this.regexIndex);t.lastIndex=this.lastIndex
;let n=t.exec(e)
;if(this.resumingScanAtSamePosition())if(n&&n.index===this.lastIndex);else{
const t=this.getMatcher(0);t.lastIndex=this.lastIndex+1,n=t.exec(e)}
return n&&(this.regexIndex+=n.position+1,
this.regexIndex===this.count&&this.considerAll()),n}}
if(e.compilerExtensions||(e.compilerExtensions=[]),
e.contains&&e.contains.includes("self"))throw new Error("ERR: contains `self` is not supported at the top-level of a language.  See documentation.")
;return e.classNameAliases=r(e.classNameAliases||{}),function n(a,i){const s=a
;if(a.isCompiled)return s
;[j,F,te,Q].forEach((e=>e(a,i))),e.compilerExtensions.forEach((e=>e(a,i))),
a.__beforeBegin=null,[U,z,Z].forEach((e=>e(a,i))),a.isCompiled=!0;let l=null
;return"object"==typeof a.keywords&&a.keywords.$pattern&&(a.keywords=Object.assign({},a.keywords),
l=a.keywords.$pattern,
delete a.keywords.$pattern),l=l||/\w+/,a.keywords&&(a.keywords=q(a.keywords,e.case_insensitive)),
s.keywordPatternRe=t(l,!0),
i&&(a.begin||(a.begin=/\B|\b/),s.beginRe=t(s.begin),a.end||a.endsWithParent||(a.end=/\B|\b/),
a.end&&(s.endRe=t(s.end)),
s.terminatorEnd=c(s.end)||"",a.endsWithParent&&i.terminatorEnd&&(s.terminatorEnd+=(a.end?"|":"")+i.terminatorEnd)),
a.illegal&&(s.illegalRe=t(a.illegal)),
a.contains||(a.contains=[]),a.contains=[].concat(...a.contains.map((function(e){
return function(e){
e.variants&&!e.cachedVariants&&(e.cachedVariants=e.variants.map((function(t){
return r(e,{variants:null},t)})));if(e.cachedVariants)return e.cachedVariants
;if(re(e))return r(e,{starts:e.starts?r(e.starts):null})
;if(Object.isFrozen(e))return r(e);return e}("self"===e?a:e)
}))),a.contains.forEach((function(e){n(e,s)
})),a.starts&&n(a.starts,i),s.matcher=function(e){const t=new o
;return e.contains.forEach((e=>t.addRule(e.begin,{rule:e,type:"begin"
}))),e.terminatorEnd&&t.addRule(e.terminatorEnd,{type:"end"
}),e.illegal&&t.addRule(e.illegal,{type:"illegal"}),t}(s),s}(e)}function re(e){
return!!e&&(e.endsWithParent||re(e.starts))}class oe extends Error{
constructor(e,t){super(e),this.name="HTMLInjectionError",this.html=t}}
const ae=n,ie=r,se=Symbol("nomatch"),le=function(n){
const r=Object.create(null),o=Object.create(null),a=[];let i=!0
;const s="Could not find the language '{}', did you forget to load/include a language module?",c={
disableAutodetect:!0,name:"Plain text",contains:[]};let m={
ignoreUnescapedHTML:!1,throwUnescapedHTML:!1,noHighlightRe:/^(no-?highlight)$/i,
languageDetectRe:/\blang(?:uage)?-([\w-]+)\b/i,classPrefix:"hljs-",
cssSelector:"pre code",languages:null,__emitter:l};function g(e){
return m.noHighlightRe.test(e)}function v(e,t,n){let r="",o=""
;"object"==typeof t?(r=e,
n=t.ignoreIllegals,o=t.language):(K("10.7.0","highlight(lang, code, ...args) has been deprecated."),
K("10.7.0","Please use highlight(code, options) instead.\nhttps://github.com/highlightjs/highlight.js/issues/2277"),
o=e,r=t),void 0===n&&(n=!0);const a={code:r,language:o};T("before:highlight",a)
;const i=a.result?a.result:b(a.language,a.code,n)
;return i.code=a.code,T("after:highlight",i),i}function b(e,n,o,a){
const l=Object.create(null);function c(){if(!T.keywords)return void A.addText(C)
;let e=0;T.keywordPatternRe.lastIndex=0;let t=T.keywordPatternRe.exec(C),n=""
;for(;t;){n+=C.substring(e,t.index)
;const o=x.case_insensitive?t[0].toLowerCase():t[0],a=(r=o,T.keywords[r]);if(a){
const[e,r]=a
;if(A.addText(n),n="",l[o]=(l[o]||0)+1,l[o]<=7&&($+=r),e.startsWith("_"))n+=t[0];else{
const n=x.classNameAliases[e]||e;d(t[0],n)}}else n+=t[0]
;e=T.keywordPatternRe.lastIndex,t=T.keywordPatternRe.exec(C)}var r
;n+=C.substring(e),A.addText(n)}function u(){null!=T.subLanguage?function(){
if(""===C)return;let e=null;if("string"==typeof T.subLanguage){
if(!r[T.subLanguage])return void A.addText(C)
;e=b(T.subLanguage,C,!0,E[T.subLanguage]),E[T.subLanguage]=e._top
}else e=y(C,T.subLanguage.length?T.subLanguage:null)
;T.relevance>0&&($+=e.relevance),A.__addSublanguage(e._emitter,e.language)
}():c(),C=""}function d(e,t){""!==e&&(A.startScope(t),A.addText(e),A.endScope())
}function p(e,t){let n=1;const r=t.length-1;for(;n<=r;){if(!e._emit[n]){n++
;continue}const r=x.classNameAliases[e[n]]||e[n],o=t[n];r?d(o,r):(C=o,c(),C=""),
n++}}function h(e,t){
return e.scope&&"string"==typeof e.scope&&A.openNode(x.classNameAliases[e.scope]||e.scope),
e.beginScope&&(e.beginScope._wrap?(d(C,x.classNameAliases[e.beginScope._wrap]||e.beginScope._wrap),
C=""):e.beginScope._multi&&(p(e.beginScope,t),C="")),T=Object.create(e,{parent:{
value:T}}),T}function f(e,n,r){let o=function(e,t){const n=e&&e.exec(t)
;return n&&0===n.index}(e.endRe,r);if(o){if(e["on:end"]){const r=new t(e)
;e["on:end"](n,r),r.isMatchIgnored&&(o=!1)}if(o){
for(;e.endsParent&&e.parent;)e=e.parent;return e}}
if(e.endsWithParent)return f(e.parent,n,r)}function g(e){
return 0===T.matcher.regexIndex?(C+=e[0],1):(I=!0,0)}function v(e){
const t=e[0],r=n.substring(e.index),o=f(T,e,r);if(!o)return se;const a=T
;T.endScope&&T.endScope._wrap?(u(),
d(t,T.endScope._wrap)):T.endScope&&T.endScope._multi?(u(),
p(T.endScope,e)):a.skip?C+=t:(a.returnEnd||a.excludeEnd||(C+=t),
u(),a.excludeEnd&&(C=t));do{
T.scope&&A.closeNode(),T.skip||T.subLanguage||($+=T.relevance),T=T.parent
}while(T!==o.parent);return o.starts&&h(o.starts,e),a.returnEnd?0:t.length}
let O={};function w(r,a){const s=a&&a[0];if(C+=r,null==s)return u(),0
;if("begin"===O.type&&"end"===a.type&&O.index===a.index&&""===s){
if(C+=n.slice(a.index,a.index+1),!i){
const t=new Error(`0 width match regex (${e})`)
;throw t.languageName=e,t.badRule=O.rule,t}return 1}
if(O=a,"begin"===a.type)return function(e){
const n=e[0],r=e.rule,o=new t(r),a=[r.__beforeBegin,r["on:begin"]]
;for(const t of a)if(t&&(t(e,o),o.isMatchIgnored))return g(n)
;return r.skip?C+=n:(r.excludeBegin&&(C+=n),
u(),r.returnBegin||r.excludeBegin||(C=n)),h(r,e),r.returnBegin?0:n.length}(a)
;if("illegal"===a.type&&!o){
const e=new Error('Illegal lexeme "'+s+'" for mode "'+(T.scope||"<unnamed>")+'"')
;throw e.mode=T,e}if("end"===a.type){const e=v(a);if(e!==se)return e}
if("illegal"===a.type&&""===s)return C+="\n",1;if(D>1e5&&D>3*a.index){
throw new Error("potential infinite loop, way more iterations than matches")}
return C+=s,s.length}const x=k(e)
;if(!x)throw G(s.replace("{}",e)),new Error('Unknown language: "'+e+'"')
;const S=ne(x);let _="",T=a||S;const E={},A=new m.__emitter(m);!function(){
const e=[];for(let t=T;t!==x;t=t.parent)t.scope&&e.unshift(t.scope)
;e.forEach((e=>A.openNode(e)))}();let C="",$=0,P=0,D=0,I=!1;try{
if(x.__emitTokens)x.__emitTokens(n,A);else{for(T.matcher.considerAll();;){
D++,I?I=!1:T.matcher.considerAll(),T.matcher.lastIndex=P
;const e=T.matcher.exec(n);if(!e)break;const t=w(n.substring(P,e.index),e)
;P=e.index+t}w(n.substring(P))}return A.finalize(),_=A.toHTML(),{language:e,
value:_,relevance:$,illegal:!1,_emitter:A,_top:T}}catch(M){
if(M.message&&M.message.includes("Illegal"))return{language:e,value:ae(n),
illegal:!0,relevance:0,_illegalBy:{message:M.message,index:P,
context:n.slice(P-100,P+100),mode:M.mode,resultSoFar:_},_emitter:A};if(i)return{
language:e,value:ae(n),illegal:!1,relevance:0,errorRaised:M,_emitter:A,_top:T}
;throw M}}function y(e,t){t=t||m.languages||Object.keys(r);const n=function(e){
const t={value:ae(e),illegal:!1,relevance:0,_top:c,_emitter:new m.__emitter(m)}
;return t._emitter.addText(e),t}(e),o=t.filter(k).filter(_).map((t=>b(t,e,!1)))
;o.unshift(n);const a=o.sort(((e,t)=>{
if(e.relevance!==t.relevance)return t.relevance-e.relevance
;if(e.language&&t.language){if(k(e.language).supersetOf===t.language)return 1
;if(k(t.language).supersetOf===e.language)return-1}return 0})),[i,s]=a,l=i
;return l.secondBest=s,l}function O(e){let t=null;const n=function(e){
let t=e.className+" ";t+=e.parentNode?e.parentNode.className:""
;const n=m.languageDetectRe.exec(t);if(n){const t=k(n[1])
;return t||(Y(s.replace("{}",n[1])),
Y("Falling back to no-highlight mode for this block.",e)),t?n[1]:"no-highlight"}
return t.split(/\s+/).find((e=>g(e)||k(e)))}(e);if(g(n))return
;if(T("before:highlightElement",{el:e,language:n
}),e.dataset.highlighted)return void console.log("Element previously highlighted. To highlight again, first unset `dataset.highlighted`.",e)
;if(e.children.length>0&&(m.ignoreUnescapedHTML||(console.warn("One of your code blocks includes unescaped HTML. This is a potentially serious security risk."),
console.warn("https://github.com/highlightjs/highlight.js/wiki/security"),
console.warn("The element with unescaped HTML:"),
console.warn(e)),m.throwUnescapedHTML)){
throw new oe("One of your code blocks includes unescaped HTML.",e.innerHTML)}t=e
;const r=t.textContent,a=n?v(r,{language:n,ignoreIllegals:!0}):y(r)
;e.innerHTML=a.value,e.dataset.highlighted="yes",function(e,t,n){
const r=t&&o[t]||n;e.classList.add("hljs"),e.classList.add(`language-${r}`)
}(e,n,a.language),e.result={language:a.language,re:a.relevance,
relevance:a.relevance},a.secondBest&&(e.secondBest={
language:a.secondBest.language,relevance:a.secondBest.relevance
}),T("after:highlightElement",{el:e,result:a,text:r})}let w=!1;function x(){
if("loading"===document.readyState)return w||window.addEventListener("DOMContentLoaded",(function(){
x()}),!1),void(w=!0);document.querySelectorAll(m.cssSelector).forEach(O)}
function k(e){return e=(e||"").toLowerCase(),r[e]||r[o[e]]}
function S(e,{languageName:t}){"string"==typeof e&&(e=[e]),e.forEach((e=>{
o[e.toLowerCase()]=t}))}function _(e){const t=k(e)
;return t&&!t.disableAutodetect}function T(e,t){const n=e
;a.forEach((function(e){e[n]&&e[n](t)}))}Object.assign(n,{highlight:v,
highlightAuto:y,highlightAll:x,highlightElement:O,highlightBlock:function(e){
return K("10.7.0","highlightBlock will be removed entirely in v12.0"),
K("10.7.0","Please use highlightElement now."),O(e)},configure:function(e){
m=ie(m,e)},initHighlighting:()=>{
x(),K("10.6.0","initHighlighting() deprecated.  Use highlightAll() now.")},
initHighlightingOnLoad:function(){
x(),K("10.6.0","initHighlightingOnLoad() deprecated.  Use highlightAll() now.")
},registerLanguage:function(e,t){let o=null;try{o=t(n)}catch(a){
if(G("Language definition for '{}' could not be registered.".replace("{}",e)),
!i)throw a;G(a),o=c}
o.name||(o.name=e),r[e]=o,o.rawDefinition=t.bind(null,n),o.aliases&&S(o.aliases,{
languageName:e})},unregisterLanguage:function(e){delete r[e]
;for(const t of Object.keys(o))o[t]===e&&delete o[t]},listLanguages:function(){
return Object.keys(r)},getLanguage:k,registerAliases:S,autoDetection:_,
inherit:ie,addPlugin:function(e){!function(e){
e["before:highlightBlock"]&&!e["before:highlightElement"]&&(e["before:highlightElement"]=t=>{
e["before:highlightBlock"](Object.assign({block:t.el},t))
}),e["after:highlightBlock"]&&!e["after:highlightElement"]&&(e["after:highlightElement"]=t=>{
e["after:highlightBlock"](Object.assign({block:t.el},t))})}(e),a.push(e)},
removePlugin:function(e){const t=a.indexOf(e);-1!==t&&a.splice(t,1)}
}),n.debugMode=function(){i=!1},n.safeMode=function(){i=!0
},n.versionString="11.11.1",n.regex={concat:h,lookahead:u,either:f,optional:p,
anyNumberOfTimes:d};for(const t in L)"object"==typeof L[t]&&e(L[t])
;return Object.assign(n,L),n},ce=le({})
;return ce.newInstance=()=>le({}),WB=ce,ce.HighlightJS=ce,ce.default=ce,WB}
const YB=jR(GB()),KB={},JB="hljs-";class ej{constructor(e){
this.options=e,this.root={type:"root",children:[],data:{language:void 0,
relevance:0}},this.stack=[this.root]}addText(e){if(""===e)return
;const t=this.stack[this.stack.length-1],n=t.children[t.children.length-1]
;n&&"text"===n.type?n.value+=e:t.children.push({type:"text",value:e})}
startScope(e){this.openNode(String(e))}endScope(){this.closeNode()}
__addSublanguage(e,t){const n=this.stack[this.stack.length-1],r=e.root.children
;t?n.children.push({type:"element",tagName:"span",properties:{className:[t]},
children:r}):n.children.push(...r)}openNode(e){
const t=this,n=e.split(".").map((function(e,n){
return n?e+"_".repeat(n):t.options.classPrefix+e})),r={type:"element",
tagName:"span",properties:{className:n},children:[]}
;this.stack[this.stack.length-1].children.push(r),this.stack.push(r)}
closeNode(){this.stack.pop()}finalize(){}toHTML(){return""}}const tj={}
;function nj(e){
const t=e||tj,n=t.aliases,r=e?.detect??!1,o=t.languages,a=t.plainText,i=t.prefix,s=t.subset
;let l="hljs";const c=e?.lowlight??function(e){const t=YB.newInstance()
;return e&&o(e),{highlight:n,highlightAuto:function(e,o){
const a=(o||KB).subset||r();let i,s=-1,l=0;for(;++s<a.length;){const r=a[s]
;if(!t.getLanguage(r))continue;const c=n(r,e,o)
;c.data&&void 0!==c.data.relevance&&c.data.relevance>l&&(l=c.data.relevance,i=c)
}return i||{type:"root",children:[],data:{language:void 0,relevance:l}}},
listLanguages:r,register:o,registerAlias:function(e,n){
if("string"==typeof e)t.registerAliases("string"==typeof n?n:[...n],{
languageName:e});else{let n;for(n in e)if(Object.hasOwn(e,n)){const r=e[n]
;t.registerAliases("string"==typeof r?r:[...r],{languageName:n})}}},
registered:function(e){return Boolean(t.getLanguage(e))}};function n(e,n,r){
const o=r||KB,a="string"==typeof o.prefix?o.prefix:JB
;if(!t.getLanguage(e))throw new Error("Unknown language: `"+e+"` is not registered")
;t.configure({__emitter:ej,classPrefix:a});const i=t.highlight(n,{
ignoreIllegals:!0,language:e})
;if(i.errorRaised)throw new Error("Could not highlight with `Highlight.js`",{
cause:i.errorRaised});const s=i._emitter.root,l=s.data
;return l.language=i.language,l.relevance=i.relevance,s}function r(){
return t.listLanguages()}function o(e,n){
if("string"==typeof e)t.registerLanguage(e,n);else{let n
;for(n in e)Object.hasOwn(e,n)&&t.registerLanguage(n,e[n])}}}(o)
;if(n&&c.registerAlias(n),i){const e=i.indexOf("-");l=e>-1?i.slice(0,e):i}
return(e,t)=>{uL(e,"element",((e,n,o)=>{
if("code"!==e.tagName||!o||"element"!==o.type||"pre"!==o.tagName)return
;const u=function(e){const t=e.properties.className
;if(!Array.isArray(t))return"";const n=t.reduce(((e,t)=>{if(e)return e
;const n=String(t)
;return"no-highlight"===n||"nohighlight"===n?"no-highlight":"lang-"===n.slice(0,5)?n.slice(5):"language-"===n.slice(0,9)?n.slice(9):e
}),"");return dL[n||""]||n}(e)
;if("no-highlight"===u||!u&&!r||u&&a?.includes(u))return;let d
;Array.isArray(e.properties.className)||(e.properties.className=[]),
e.properties.className.includes(l)||e.properties.className.unshift(l);try{
d=u?c.highlight(u,TL(o),{prefix:i}):c.highlightAuto(TL(o),{prefix:i,subset:s})
}catch(p){const n=p
;if(u&&/Unknown language/.test(n.message))return void t.message(`Cannot highlight as \`${u}\`, it's not registered`,{
ancestors:[o,e],cause:n,place:e.position,ruleId:"missing-language",
source:"rehype-highlight"});throw n}
!u&&d.data?.language&&e.properties.className.push("language-"+d.data.language),
d.children.length>0&&(e.children=d.children)}))}}function rj(e){
return"text"===e?.type}function oj(e){return"element"===e?.type}function aj(e){
return{type:"text",value:e}}function ij(){return e=>{uL(e,"element",((e,t,n)=>{
if("element"===n?.type&&"pre"===n.tagName&&"code"===e.tagName){let t=0
;e.children=sj(e),e.children.forEach((e=>{
if("element"===e.type&&"span"===e.tagName){
const n=e.children[e.children.length-1]
;n&&(!rj(n)||rj(n)&&!cj(n))&&(e.children.push({type:"text",value:"\n"}),t++)}
})),
e.properties.style=[`--line-count: ${t};`,`--line-digits: ${t.toString().length};`]
}}))}}function sj(e,t=[],n){
const r=()=>t[t.length-1]??(t.push(lj())&&t[t.length-1]||void 0)
;return e.children.forEach((o=>{if(rj(o)&&cj(o)){const a=o.value.split(/\n/)
;a.forEach(((o,i)=>{n?r()?.children.push({...e,children:[aj(o)]
}):r()?.children.push(aj(o)),i!==a.length-1&&t.push(lj())}))
}else oj(o)&&o.children.some(cj)?sj(o,t,!0):r()?.children.push(o)})),t}
function lj(...e){return{type:"element",tagName:"span",properties:{
class:["line"]},children:e}}function cj(e){
return rj(e)&&/\r?\n/.test(e.value)||oj(e)&&e.children.some(cj)}
function uj(e,t){
const n=("string"==typeof t?.maskCredentials?[t.maskCredentials]:t?.maskCredentials??[]).filter((e=>!(e.length<3))),r=`language-${dL[t.lang]??t.lang}`
;var o;const a=XR().use(cN,{fragment:!0}).use((o=e,()=>e=>{uL(e,"element",(e=>{
"code"===e.tagName&&e.children.push({type:"text",value:o})}))})).use(nj,{
languages:t.languages
}).use(t?.lineNumbers?ij:()=>{}).use(LR).processSync(`<pre><code class="${r}"></code></pre>`).toString()
;return n.length?n.reduce(((e,t)=>e.split(t).join(`<span class="credential"><span class="credential-value">${t}</span></span>`)),a):a
}var dj,pj;const hj={bash:function(e){const t=e.regex,n={},r={begin:/\$\{/,
end:/\}/,contains:["self",{begin:/:-/,contains:[n]}]};Object.assign(n,{
className:"variable",variants:[{
begin:t.concat(/\$[\w\d#@][\w\d_]*/,"(?![\\w\\d])(?![$])")},r]});const o={
className:"subst",begin:/\$\(/,end:/\)/,contains:[e.BACKSLASH_ESCAPE]
},a=e.inherit(e.COMMENT(),{match:[/(^|\s)/,/#.*$/],scope:{2:"comment"}}),i={
begin:/<<-?\s*(?=\w+)/,starts:{contains:[e.END_SAME_AS_BEGIN({begin:/(\w+)/,
end:/(\w+)/,className:"string"})]}},s={className:"string",begin:/"/,end:/"/,
contains:[e.BACKSLASH_ESCAPE,n,o]};o.contains.push(s);const l={begin:/\$?\(\(/,
end:/\)\)/,contains:[{begin:/\d+#[0-9a-f]+/,className:"number"},e.NUMBER_MODE,n]
},c=e.SHEBANG({
binary:`(${["fish","bash","zsh","sh","csh","ksh","tcsh","dash","scsh"].join("|")})`,
relevance:10}),u={className:"function",begin:/\w[\w\d_]*\s*\(\s*\)\s*\{/,
returnBegin:!0,contains:[e.inherit(e.TITLE_MODE,{begin:/\w[\w\d_]*/})],
relevance:0};return{name:"Bash",aliases:["sh","zsh"],keywords:{
$pattern:/\b[a-z][a-z0-9._-]+\b/,
keyword:["if","then","else","elif","fi","time","for","while","until","in","do","done","case","esac","coproc","function","select"],
literal:["true","false"],
built_in:["break","cd","continue","eval","exec","exit","export","getopts","hash","pwd","readonly","return","shift","test","times","trap","umask","unset","alias","bind","builtin","caller","command","declare","echo","enable","help","let","local","logout","mapfile","printf","read","readarray","source","sudo","type","typeset","ulimit","unalias","set","shopt","autoload","bg","bindkey","bye","cap","chdir","clone","comparguments","compcall","compctl","compdescribe","compfiles","compgroups","compquote","comptags","comptry","compvalues","dirs","disable","disown","echotc","echoti","emulate","fc","fg","float","functions","getcap","getln","history","integer","jobs","kill","limit","log","noglob","popd","print","pushd","pushln","rehash","sched","setcap","setopt","stat","suspend","ttyctl","unfunction","unhash","unlimit","unsetopt","vared","wait","whence","where","which","zcompile","zformat","zftp","zle","zmodload","zparseopts","zprof","zpty","zregexparse","zsocket","zstyle","ztcp","chcon","chgrp","chown","chmod","cp","dd","df","dir","dircolors","ln","ls","mkdir","mkfifo","mknod","mktemp","mv","realpath","rm","rmdir","shred","sync","touch","truncate","vdir","b2sum","base32","base64","cat","cksum","comm","csplit","cut","expand","fmt","fold","head","join","md5sum","nl","numfmt","od","paste","ptx","pr","sha1sum","sha224sum","sha256sum","sha384sum","sha512sum","shuf","sort","split","sum","tac","tail","tr","tsort","unexpand","uniq","wc","arch","basename","chroot","date","dirname","du","echo","env","expr","factor","groups","hostid","id","link","logname","nice","nohup","nproc","pathchk","pinky","printenv","printf","pwd","readlink","runcon","seq","sleep","stat","stdbuf","stty","tee","test","timeout","tty","uname","unlink","uptime","users","who","whoami","yes"]
},contains:[c,e.SHEBANG(),u,l,a,i,{match:/(\/[a-z._-]+)+/},s,{match:/\\"/},{
className:"string",begin:/'/,end:/'/},{match:/\\'/},n]}},c:function(e){
const t=e.regex,n=e.COMMENT("//","$",{contains:[{begin:/\\\n/}]
}),r="decltype\\(auto\\)",o="[a-zA-Z_]\\w*::",a="("+r+"|"+t.optional(o)+"[a-zA-Z_]\\w*"+t.optional("<[^<>]+>")+")",i={
className:"type",variants:[{begin:"\\b[a-z\\d_]*_t\\b"},{
match:/\batomic_[a-z]{3,6}\b/}]},s={className:"string",variants:[{
begin:'(u8?|U|L)?"',end:'"',illegal:"\\n",contains:[e.BACKSLASH_ESCAPE]},{
begin:"(u8?|U|L)?'(\\\\(x[0-9A-Fa-f]{2}|u[0-9A-Fa-f]{4,8}|[0-7]{3}|\\S)|.)",
end:"'",illegal:"."},e.END_SAME_AS_BEGIN({
begin:/(?:u8?|U|L)?R"([^()\\ ]{0,16})\(/,end:/\)([^()\\ ]{0,16})"/})]},l={
className:"number",variants:[{match:/\b(0b[01']+)/},{
match:/(-?)\b([\d']+(\.[\d']*)?|\.[\d']+)((ll|LL|l|L)(u|U)?|(u|U)(ll|LL|l|L)?|f|F|b|B)/
},{
match:/(-?)\b(0[xX][a-fA-F0-9]+(?:'[a-fA-F0-9]+)*(?:\.[a-fA-F0-9]*(?:'[a-fA-F0-9]*)*)?(?:[pP][-+]?[0-9]+)?(l|L)?(u|U)?)/
},{match:/(-?)\b\d+(?:'\d+)*(?:\.\d*(?:'\d*)*)?(?:[eE][-+]?\d+)?/}],relevance:0
},c={className:"meta",begin:/#\s*[a-z]+\b/,end:/$/,keywords:{
keyword:"if else elif endif define undef warning error line pragma _Pragma ifdef ifndef elifdef elifndef include"
},contains:[{begin:/\\\n/,relevance:0},e.inherit(s,{className:"string"}),{
className:"string",begin:/<.*?>/},n,e.C_BLOCK_COMMENT_MODE]},u={
className:"title",begin:t.optional(o)+e.IDENT_RE,relevance:0
},d=t.optional(o)+e.IDENT_RE+"\\s*\\(",p={
keyword:["asm","auto","break","case","continue","default","do","else","enum","extern","for","fortran","goto","if","inline","register","restrict","return","sizeof","typeof","typeof_unqual","struct","switch","typedef","union","volatile","while","_Alignas","_Alignof","_Atomic","_Generic","_Noreturn","_Static_assert","_Thread_local","alignas","alignof","noreturn","static_assert","thread_local","_Pragma"],
type:["float","double","signed","unsigned","int","short","long","char","void","_Bool","_BitInt","_Complex","_Imaginary","_Decimal32","_Decimal64","_Decimal96","_Decimal128","_Decimal64x","_Decimal128x","_Float16","_Float32","_Float64","_Float128","_Float32x","_Float64x","_Float128x","const","static","constexpr","complex","bool","imaginary"],
literal:"true false NULL",
built_in:"std string wstring cin cout cerr clog stdin stdout stderr stringstream istringstream ostringstream auto_ptr deque list queue stack vector map set pair bitset multiset multimap unordered_set unordered_map unordered_multiset unordered_multimap priority_queue make_pair array shared_ptr abort terminate abs acos asin atan2 atan calloc ceil cosh cos exit exp fabs floor fmod fprintf fputs free frexp fscanf future isalnum isalpha iscntrl isdigit isgraph islower isprint ispunct isspace isupper isxdigit tolower toupper labs ldexp log10 log malloc realloc memchr memcmp memcpy memset modf pow printf putchar puts scanf sinh sin snprintf sprintf sqrt sscanf strcat strchr strcmp strcpy strcspn strlen strncat strncmp strncpy strpbrk strrchr strspn strstr tanh tan vfprintf vprintf vsprintf endl initializer_list unique_ptr"
},h=[c,i,n,e.C_BLOCK_COMMENT_MODE,l,s],f={variants:[{begin:/=/,end:/;/},{
begin:/\(/,end:/\)/},{beginKeywords:"new throw return else",end:/;/}],
keywords:p,contains:h.concat([{begin:/\(/,end:/\)/,keywords:p,
contains:h.concat(["self"]),relevance:0}]),relevance:0},m={
begin:"("+a+"[\\*&\\s]+)+"+d,returnBegin:!0,end:/[{;=]/,excludeEnd:!0,
keywords:p,illegal:/[^\w\s\*&:<>.]/,contains:[{begin:r,keywords:p,relevance:0},{
begin:d,returnBegin:!0,contains:[e.inherit(u,{className:"title.function"})],
relevance:0},{relevance:0,match:/,/},{className:"params",begin:/\(/,end:/\)/,
keywords:p,relevance:0,contains:[n,e.C_BLOCK_COMMENT_MODE,s,l,i,{begin:/\(/,
end:/\)/,keywords:p,relevance:0,contains:["self",n,e.C_BLOCK_COMMENT_MODE,s,l,i]
}]},i,n,e.C_BLOCK_COMMENT_MODE,c]};return{name:"C",aliases:["h"],keywords:p,
disableAutodetect:!0,illegal:"</",contains:[].concat(f,m,h,[c,{
begin:e.IDENT_RE+"::",keywords:p},{className:"class",
beginKeywords:"enum class struct union",end:/[{;:<>=]/,contains:[{
beginKeywords:"final class struct"},e.TITLE_MODE]}]),exports:{preprocessor:c,
strings:s,keywords:p}}},clojure:function(e){
const t="a-zA-Z_\\-!.?+*=<>&'",n="[#]?["+t+"]["+t+"0-9/;:$#]*",r="def defonce defprotocol defstruct defmulti defmethod defn- defn defmacro deftype defrecord",o={
$pattern:n,
built_in:r+" cond apply if-not if-let if not not= =|0 <|0 >|0 <=|0 >=|0 ==|0 +|0 /|0 *|0 -|0 rem quot neg? pos? delay? symbol? keyword? true? false? integer? empty? coll? list? set? ifn? fn? associative? sequential? sorted? counted? reversible? number? decimal? class? distinct? isa? float? rational? reduced? ratio? odd? even? char? seq? vector? string? map? nil? contains? zero? instance? not-every? not-any? libspec? -> ->> .. . inc compare do dotimes mapcat take remove take-while drop letfn drop-last take-last drop-while while intern condp case reduced cycle split-at split-with repeat replicate iterate range merge zipmap declare line-seq sort comparator sort-by dorun doall nthnext nthrest partition eval doseq await await-for let agent atom send send-off release-pending-sends add-watch mapv filterv remove-watch agent-error restart-agent set-error-handler error-handler set-error-mode! error-mode shutdown-agents quote var fn loop recur throw try monitor-enter monitor-exit macroexpand macroexpand-1 for dosync and or when when-not when-let comp juxt partial sequence memoize constantly complement identity assert peek pop doto proxy first rest cons cast coll last butlast sigs reify second ffirst fnext nfirst nnext meta with-meta ns in-ns create-ns import refer keys select-keys vals key val rseq name namespace promise into transient persistent! conj! assoc! dissoc! pop! disj! use class type num float double short byte boolean bigint biginteger bigdec print-method print-dup throw-if printf format load compile get-in update-in pr pr-on newline flush read slurp read-line subvec with-open memfn time re-find re-groups rand-int rand mod locking assert-valid-fdecl alias resolve ref deref refset swap! reset! set-validator! compare-and-set! alter-meta! reset-meta! commute get-validator alter ref-set ref-history-count ref-min-history ref-max-history ensure sync io! new next conj set! to-array future future-call into-array aset gen-class reduce map filter find empty hash-map hash-set sorted-map sorted-map-by sorted-set sorted-set-by vec vector seq flatten reverse assoc dissoc list disj get union difference intersection extend extend-type extend-protocol int nth delay count concat chunk chunk-buffer chunk-append chunk-first chunk-rest max min dec unchecked-inc-int unchecked-inc unchecked-dec-inc unchecked-dec unchecked-negate unchecked-add-int unchecked-add unchecked-subtract-int unchecked-subtract chunk-next chunk-cons chunked-seq? prn vary-meta lazy-seq spread list* str find-keyword keyword symbol gensym force rationalize"
},a={begin:n,relevance:0},i={scope:"number",relevance:0,variants:[{
match:/[-+]?0[xX][0-9a-fA-F]+N?/},{match:/[-+]?0[0-7]+N?/},{
match:/[-+]?[1-9][0-9]?[rR][0-9a-zA-Z]+N?/},{match:/[-+]?[0-9]+\/[0-9]+N?/},{
match:/[-+]?[0-9]+((\.[0-9]*([eE][+-]?[0-9]+)?M?)|([eE][+-]?[0-9]+M?|M))/},{
match:/[-+]?([1-9][0-9]*|0)N?/}]},s={scope:"character",variants:[{
match:/\\o[0-3]?[0-7]{1,2}/},{match:/\\u[0-9a-fA-F]{4}/},{
match:/\\(newline|space|tab|formfeed|backspace|return)/},{match:/\\\S/,
relevance:0}]},l={scope:"regex",begin:/#"/,end:/"/,contains:[e.BACKSLASH_ESCAPE]
},c=e.inherit(e.QUOTE_STRING_MODE,{illegal:null}),u={scope:"punctuation",
match:/,/,relevance:0},d=e.COMMENT(";","$",{relevance:0}),p={
className:"literal",begin:/\b(true|false|nil)\b/},h={
begin:"\\[|(#::?"+n+")?\\{",end:"[\\]\\}]",relevance:0},f={className:"symbol",
begin:"[:]{1,2}"+n},m={begin:"\\(",end:"\\)"},g={endsWithParent:!0,relevance:0
},v={keywords:o,className:"name",begin:n,relevance:0,starts:g
},b=[u,m,s,l,c,d,f,h,i,p,a],y={beginKeywords:r,keywords:{$pattern:n,keyword:r},
end:'(\\[|#|\\d|"|:|\\{|\\)|\\(|$)',contains:[{className:"title",begin:n,
relevance:0,excludeEnd:!0,endsParent:!0}].concat(b)}
;return m.contains=[y,v,g],g.contains=b,h.contains=b,{name:"Clojure",
aliases:["clj","edn"],illegal:/\S/,contains:[u,m,s,l,c,d,f,h,i,p]}},
cpp:function(e){const t=e.regex,n=e.COMMENT("//","$",{contains:[{begin:/\\\n/}]
}),r="decltype\\(auto\\)",o="[a-zA-Z_]\\w*::",a="(?!struct)("+r+"|"+t.optional(o)+"[a-zA-Z_]\\w*"+t.optional("<[^<>]+>")+")",i={
className:"type",begin:"\\b[a-z\\d_]*_t\\b"},s={className:"string",variants:[{
begin:'(u8?|U|L)?"',end:'"',illegal:"\\n",contains:[e.BACKSLASH_ESCAPE]},{
begin:"(u8?|U|L)?'(\\\\(x[0-9A-Fa-f]{2}|u[0-9A-Fa-f]{4,8}|[0-7]{3}|\\S)|.)",
end:"'",illegal:"."},e.END_SAME_AS_BEGIN({
begin:/(?:u8?|U|L)?R"([^()\\ ]{0,16})\(/,end:/\)([^()\\ ]{0,16})"/})]},l={
className:"number",variants:[{
begin:"[+-]?(?:(?:[0-9](?:'?[0-9])*\\.(?:[0-9](?:'?[0-9])*)?|\\.[0-9](?:'?[0-9])*)(?:[Ee][+-]?[0-9](?:'?[0-9])*)?|[0-9](?:'?[0-9])*[Ee][+-]?[0-9](?:'?[0-9])*|0[Xx](?:[0-9A-Fa-f](?:'?[0-9A-Fa-f])*(?:\\.(?:[0-9A-Fa-f](?:'?[0-9A-Fa-f])*)?)?|\\.[0-9A-Fa-f](?:'?[0-9A-Fa-f])*)[Pp][+-]?[0-9](?:'?[0-9])*)(?:[Ff](?:16|32|64|128)?|(BF|bf)16|[Ll]|)"
},{
begin:"[+-]?\\b(?:0[Bb][01](?:'?[01])*|0[Xx][0-9A-Fa-f](?:'?[0-9A-Fa-f])*|0(?:'?[0-7])*|[1-9](?:'?[0-9])*)(?:[Uu](?:LL?|ll?)|[Uu][Zz]?|(?:LL?|ll?)[Uu]?|[Zz][Uu]|)"
}],relevance:0},c={className:"meta",begin:/#\s*[a-z]+\b/,end:/$/,keywords:{
keyword:"if else elif endif define undef warning error line pragma _Pragma ifdef ifndef include"
},contains:[{begin:/\\\n/,relevance:0},e.inherit(s,{className:"string"}),{
className:"string",begin:/<.*?>/},n,e.C_BLOCK_COMMENT_MODE]},u={
className:"title",begin:t.optional(o)+e.IDENT_RE,relevance:0
},d=t.optional(o)+e.IDENT_RE+"\\s*\\(",p={
type:["bool","char","char16_t","char32_t","char8_t","double","float","int","long","short","void","wchar_t","unsigned","signed","const","static"],
keyword:["alignas","alignof","and","and_eq","asm","atomic_cancel","atomic_commit","atomic_noexcept","auto","bitand","bitor","break","case","catch","class","co_await","co_return","co_yield","compl","concept","const_cast|10","consteval","constexpr","constinit","continue","decltype","default","delete","do","dynamic_cast|10","else","enum","explicit","export","extern","false","final","for","friend","goto","if","import","inline","module","mutable","namespace","new","noexcept","not","not_eq","nullptr","operator","or","or_eq","override","private","protected","public","reflexpr","register","reinterpret_cast|10","requires","return","sizeof","static_assert","static_cast|10","struct","switch","synchronized","template","this","thread_local","throw","transaction_safe","transaction_safe_dynamic","true","try","typedef","typeid","typename","union","using","virtual","volatile","while","xor","xor_eq"],
literal:["NULL","false","nullopt","nullptr","true"],built_in:["_Pragma"],
_type_hints:["any","auto_ptr","barrier","binary_semaphore","bitset","complex","condition_variable","condition_variable_any","counting_semaphore","deque","false_type","flat_map","flat_set","future","imaginary","initializer_list","istringstream","jthread","latch","lock_guard","multimap","multiset","mutex","optional","ostringstream","packaged_task","pair","promise","priority_queue","queue","recursive_mutex","recursive_timed_mutex","scoped_lock","set","shared_future","shared_lock","shared_mutex","shared_timed_mutex","shared_ptr","stack","string_view","stringstream","timed_mutex","thread","true_type","tuple","unique_lock","unique_ptr","unordered_map","unordered_multimap","unordered_multiset","unordered_set","variant","vector","weak_ptr","wstring","wstring_view"]
},h={className:"function.dispatch",relevance:0,keywords:{
_hint:["abort","abs","acos","apply","as_const","asin","atan","atan2","calloc","ceil","cerr","cin","clog","cos","cosh","cout","declval","endl","exchange","exit","exp","fabs","floor","fmod","forward","fprintf","fputs","free","frexp","fscanf","future","invoke","isalnum","isalpha","iscntrl","isdigit","isgraph","islower","isprint","ispunct","isspace","isupper","isxdigit","labs","launder","ldexp","log","log10","make_pair","make_shared","make_shared_for_overwrite","make_tuple","make_unique","malloc","memchr","memcmp","memcpy","memset","modf","move","pow","printf","putchar","puts","realloc","scanf","sin","sinh","snprintf","sprintf","sqrt","sscanf","std","stderr","stdin","stdout","strcat","strchr","strcmp","strcpy","strcspn","strlen","strncat","strncmp","strncpy","strpbrk","strrchr","strspn","strstr","swap","tan","tanh","terminate","to_underlying","tolower","toupper","vfprintf","visit","vprintf","vsprintf"]
},
begin:t.concat(/\b/,/(?!decltype)/,/(?!if)/,/(?!for)/,/(?!switch)/,/(?!while)/,e.IDENT_RE,t.lookahead(/(<[^<>]+>|)\s*\(/))
},f=[h,c,i,n,e.C_BLOCK_COMMENT_MODE,l,s],m={variants:[{begin:/=/,end:/;/},{
begin:/\(/,end:/\)/},{beginKeywords:"new throw return else",end:/;/}],
keywords:p,contains:f.concat([{begin:/\(/,end:/\)/,keywords:p,
contains:f.concat(["self"]),relevance:0}]),relevance:0},g={className:"function",
begin:"("+a+"[\\*&\\s]+)+"+d,returnBegin:!0,end:/[{;=]/,excludeEnd:!0,
keywords:p,illegal:/[^\w\s\*&:<>.]/,contains:[{begin:r,keywords:p,relevance:0},{
begin:d,returnBegin:!0,contains:[u],relevance:0},{begin:/::/,relevance:0},{
begin:/:/,endsWithParent:!0,contains:[s,l]},{relevance:0,match:/,/},{
className:"params",begin:/\(/,end:/\)/,keywords:p,relevance:0,
contains:[n,e.C_BLOCK_COMMENT_MODE,s,l,i,{begin:/\(/,end:/\)/,keywords:p,
relevance:0,contains:["self",n,e.C_BLOCK_COMMENT_MODE,s,l,i]}]
},i,n,e.C_BLOCK_COMMENT_MODE,c]};return{name:"C++",
aliases:["cc","c++","h++","hpp","hh","hxx","cxx"],keywords:p,illegal:"</",
classNameAliases:{"function.dispatch":"built_in"},
contains:[].concat(m,g,h,f,[c,{
begin:"\\b(deque|list|queue|priority_queue|pair|stack|vector|map|set|bitset|multiset|multimap|unordered_map|unordered_set|unordered_multiset|unordered_multimap|array|tuple|optional|variant|function|flat_map|flat_set)\\s*<(?!<)",
end:">",keywords:p,contains:["self",i]},{begin:e.IDENT_RE+"::",keywords:p},{
match:[/\b(?:enum(?:\s+(?:class|struct))?|class|struct|union)/,/\s+/,/\w+/],
className:{1:"keyword",3:"title.class"}}])}},csharp:function(e){const t={
keyword:["abstract","as","base","break","case","catch","class","const","continue","do","else","event","explicit","extern","finally","fixed","for","foreach","goto","if","implicit","in","interface","internal","is","lock","namespace","new","operator","out","override","params","private","protected","public","readonly","record","ref","return","scoped","sealed","sizeof","stackalloc","static","struct","switch","this","throw","try","typeof","unchecked","unsafe","using","virtual","void","volatile","while"].concat(["add","alias","and","ascending","args","async","await","by","descending","dynamic","equals","file","from","get","global","group","init","into","join","let","nameof","not","notnull","on","or","orderby","partial","record","remove","required","scoped","select","set","unmanaged","value|0","var","when","where","with","yield"]),
built_in:["bool","byte","char","decimal","delegate","double","dynamic","enum","float","int","long","nint","nuint","object","sbyte","short","string","ulong","uint","ushort"],
literal:["default","false","null","true"]},n=e.inherit(e.TITLE_MODE,{
begin:"[a-zA-Z](\\.?\\w)*"}),r={className:"number",variants:[{
begin:"\\b(0b[01']+)"},{
begin:"(-?)\\b([\\d']+(\\.[\\d']*)?|\\.[\\d']+)(u|U|l|L|ul|UL|f|F|b|B)"},{
begin:"(-?)(\\b0[xX][a-fA-F0-9']+|(\\b[\\d']+(\\.[\\d']*)?|\\.[\\d']+)([eE][-+]?[\\d']+)?)"
}],relevance:0},o={className:"string",begin:'@"',end:'"',contains:[{begin:'""'}]
},a=e.inherit(o,{illegal:/\n/}),i={className:"subst",begin:/\{/,end:/\}/,
keywords:t},s=e.inherit(i,{illegal:/\n/}),l={className:"string",begin:/\$"/,
end:'"',illegal:/\n/,contains:[{begin:/\{\{/},{begin:/\}\}/
},e.BACKSLASH_ESCAPE,s]},c={className:"string",begin:/\$@"/,end:'"',contains:[{
begin:/\{\{/},{begin:/\}\}/},{begin:'""'},i]},u=e.inherit(c,{illegal:/\n/,
contains:[{begin:/\{\{/},{begin:/\}\}/},{begin:'""'},s]})
;i.contains=[c,l,o,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,r,e.C_BLOCK_COMMENT_MODE],
s.contains=[u,l,a,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,r,e.inherit(e.C_BLOCK_COMMENT_MODE,{
illegal:/\n/})];const d={variants:[{className:"string",
begin:/"""("*)(?!")(.|\n)*?"""\1/,relevance:1
},c,l,o,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE]},p={begin:"<",end:">",
contains:[{beginKeywords:"in out"},n]
},h=e.IDENT_RE+"(<"+e.IDENT_RE+"(\\s*,\\s*"+e.IDENT_RE+")*>)?(\\[\\])?",f={
begin:"@"+e.IDENT_RE,relevance:0};return{name:"C#",aliases:["cs","c#"],
keywords:t,illegal:/::/,contains:[e.COMMENT("///","$",{returnBegin:!0,
contains:[{className:"doctag",variants:[{begin:"///",relevance:0},{
begin:"\x3c!--|--\x3e"},{begin:"</?",end:">"}]}]
}),e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,{className:"meta",begin:"#",
end:"$",keywords:{
keyword:"if else elif endif define undef warning error line region endregion pragma checksum"
}},d,r,{beginKeywords:"class interface",relevance:0,end:/[{;=]/,
illegal:/[^\s:,]/,contains:[{beginKeywords:"where class"
},n,p,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{beginKeywords:"namespace",
relevance:0,end:/[{;=]/,illegal:/[^\s:]/,
contains:[n,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{
beginKeywords:"record",relevance:0,end:/[{;=]/,illegal:/[^\s:]/,
contains:[n,p,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{className:"meta",
begin:"^\\s*\\[(?=[\\w])",excludeBegin:!0,end:"\\]",excludeEnd:!0,contains:[{
className:"string",begin:/"/,end:/"/}]},{
beginKeywords:"new return throw await else",relevance:0},{className:"function",
begin:"("+h+"\\s+)+"+e.IDENT_RE+"\\s*(<[^=]+>\\s*)?\\(",returnBegin:!0,
end:/\s*[{;=]/,excludeEnd:!0,keywords:t,contains:[{
beginKeywords:["public","private","protected","static","internal","protected","abstract","async","extern","override","unsafe","virtual","new","sealed","partial"].join(" "),
relevance:0},{begin:e.IDENT_RE+"\\s*(<[^=]+>\\s*)?\\(",returnBegin:!0,
contains:[e.TITLE_MODE,p],relevance:0},{match:/\(\)/},{className:"params",
begin:/\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:t,relevance:0,
contains:[d,r,e.C_BLOCK_COMMENT_MODE]
},e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},f]}},css:function(e){
const t=e.regex,n=(e=>({IMPORTANT:{scope:"meta",begin:"!important"},
BLOCK_COMMENT:e.C_BLOCK_COMMENT_MODE,HEXCOLOR:{scope:"number",
begin:/#(([0-9a-fA-F]{3,4})|(([0-9a-fA-F]{2}){3,4}))\b/},FUNCTION_DISPATCH:{
className:"built_in",begin:/[\w-]+(?=\()/},ATTRIBUTE_SELECTOR_MODE:{
scope:"selector-attr",begin:/\[/,end:/\]/,illegal:"$",
contains:[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE]},CSS_NUMBER_MODE:{
scope:"number",
begin:e.NUMBER_RE+"(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",
relevance:0},CSS_VARIABLE:{className:"attr",begin:/--[A-Za-z_][A-Za-z0-9_-]*/}
}))(e),r=[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE];return{name:"CSS",
case_insensitive:!0,illegal:/[=|'\$]/,keywords:{keyframePosition:"from to"},
classNameAliases:{keyframePosition:"selector-tag"},contains:[n.BLOCK_COMMENT,{
begin:/-(webkit|moz|ms|o)-(?=[a-z])/},n.CSS_NUMBER_MODE,{
className:"selector-id",begin:/#[A-Za-z0-9_-]+/,relevance:0},{
className:"selector-class",begin:"\\.[a-zA-Z-][a-zA-Z0-9_-]*",relevance:0
},n.ATTRIBUTE_SELECTOR_MODE,{className:"selector-pseudo",variants:[{
begin:":("+jL.join("|")+")"},{begin:":(:)?("+UL.join("|")+")"}]
},n.CSS_VARIABLE,{className:"attribute",begin:"\\b("+zL.join("|")+")\\b"},{
begin:/:/,end:/[;}{]/,
contains:[n.BLOCK_COMMENT,n.HEXCOLOR,n.IMPORTANT,n.CSS_NUMBER_MODE,...r,{
begin:/(url|data-uri)\(/,end:/\)/,relevance:0,keywords:{built_in:"url data-uri"
},contains:[...r,{className:"string",begin:/[^)]/,endsWithParent:!0,
excludeEnd:!0}]},n.FUNCTION_DISPATCH]},{begin:t.lookahead(/@/),end:"[{;]",
relevance:0,illegal:/:/,contains:[{className:"keyword",begin:/@-?\w[\w]*(-\w+)*/
},{begin:/\s/,endsWithParent:!0,excludeEnd:!0,relevance:0,keywords:{
$pattern:/[a-z-]+/,keyword:"and or not only",attribute:BL.join(" ")},contains:[{
begin:/[a-z-]+(?=:)/,className:"attribute"},...r,n.CSS_NUMBER_MODE]}]},{
className:"selector-tag",begin:"\\b("+LL.join("|")+")\\b"}]}},
curl:jR(pj?dj:(pj=1,dj=function(e){const t={className:"string",begin:/"/,
end:/"/,contains:[e.BACKSLASH_ESCAPE,{className:"variable",begin:/\$\(/,
end:/\)/,contains:[e.BACKSLASH_ESCAPE]}],relevance:0},n={className:"number",
variants:[{begin:e.C_NUMBER_RE}],relevance:0};return{name:"curl",
aliases:["curl"],keywords:"curl",case_insensitive:!0,contains:[{
className:"literal",begin:/(--request|-X)\s/,contains:[{className:"symbol",
begin:/(get|post|delete|options|head|put|patch|trace|connect)/,end:/\s/,
returnEnd:!0}],returnEnd:!0,relevance:10},{className:"literal",begin:/--/,
end:/[\s"]/,returnEnd:!0,relevance:0},{className:"literal",begin:/-\w/,
end:/[\s"]/,returnEnd:!0,relevance:0},t,{className:"string",begin:/\\"/,
relevance:0},{className:"string",begin:/'/,end:/'/,relevance:0
},e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,n,{match:/(\/[a-z._-]+)+/}]}})),
dart:function(e){const t={className:"subst",variants:[{begin:"\\$[A-Za-z0-9_]+"
}]},n={className:"subst",variants:[{begin:/\$\{/,end:/\}/}],
keywords:"true false null this is new super"},r={className:"number",relevance:0,
variants:[{match:/\b[0-9][0-9_]*(\.[0-9][0-9_]*)?([eE][+-]?[0-9][0-9_]*)?\b/},{
match:/\b0[xX][0-9A-Fa-f][0-9A-Fa-f_]*\b/}]},o={className:"string",variants:[{
begin:"r'''",end:"'''"},{begin:'r"""',end:'"""'},{begin:"r'",end:"'",
illegal:"\\n"},{begin:'r"',end:'"',illegal:"\\n"},{begin:"'''",end:"'''",
contains:[e.BACKSLASH_ESCAPE,t,n]},{begin:'"""',end:'"""',
contains:[e.BACKSLASH_ESCAPE,t,n]},{begin:"'",end:"'",illegal:"\\n",
contains:[e.BACKSLASH_ESCAPE,t,n]},{begin:'"',end:'"',illegal:"\\n",
contains:[e.BACKSLASH_ESCAPE,t,n]}]};n.contains=[r,o]
;const a=["Comparable","DateTime","Duration","Function","Iterable","Iterator","List","Map","Match","Object","Pattern","RegExp","Set","Stopwatch","String","StringBuffer","StringSink","Symbol","Type","Uri","bool","double","int","num","Element","ElementList"],i=a.map((e=>`${e}?`))
;return{name:"Dart",keywords:{
keyword:["abstract","as","assert","async","await","base","break","case","catch","class","const","continue","covariant","default","deferred","do","dynamic","else","enum","export","extends","extension","external","factory","false","final","finally","for","Function","get","hide","if","implements","import","in","interface","is","late","library","mixin","new","null","on","operator","part","required","rethrow","return","sealed","set","show","static","super","switch","sync","this","throw","true","try","typedef","var","void","when","while","with","yield"],
built_in:a.concat(i).concat(["Never","Null","dynamic","print","document","querySelector","querySelectorAll","window"]),
$pattern:/[A-Za-z][A-Za-z0-9_]*\??/},
contains:[o,e.COMMENT(/\/\*\*(?!\/)/,/\*\//,{subLanguage:"markdown",relevance:0
}),e.COMMENT(/\/{3,} ?/,/$/,{contains:[{subLanguage:"markdown",begin:".",
end:"$",relevance:0}]}),e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,{
className:"class",beginKeywords:"class interface",end:/\{/,excludeEnd:!0,
contains:[{beginKeywords:"extends implements"},e.UNDERSCORE_TITLE_MODE]},r,{
className:"meta",begin:"@[A-Za-z]+"},{begin:"=>"}]}},diff:function(e){
const t=e.regex;return{name:"Diff",aliases:["patch"],contains:[{
className:"meta",relevance:10,
match:t.either(/^@@ +-\d+,\d+ +\+\d+,\d+ +@@/,/^\*\*\* +\d+,\d+ +\*\*\*\*$/,/^--- +\d+,\d+ +----$/)
},{className:"comment",variants:[{
begin:t.either(/Index: /,/^index/,/={3,}/,/^-{3}/,/^\*{3} /,/^\+{3}/,/^diff --git/),
end:/$/},{match:/^\*{15}$/}]},{className:"addition",begin:/^\+/,end:/$/},{
className:"deletion",begin:/^-/,end:/$/},{className:"addition",begin:/^!/,
end:/$/}]}},docker:PL,dockerfile:PL,elixir:function(e){
const t=e.regex,n="[a-zA-Z_][a-zA-Z0-9_.]*(!|\\?)?",r={$pattern:n,
keyword:["after","alias","and","case","catch","cond","defstruct","defguard","do","else","end","fn","for","if","import","in","not","or","quote","raise","receive","require","reraise","rescue","try","unless","unquote","unquote_splicing","use","when","with|0"],
literal:["false","nil","true"]},o={className:"subst",begin:/#\{/,end:/\}/,
keywords:r},a={match:/\\[\s\S]/,scope:"char.escape",relevance:0
},i="[/|([{<\"']",s=[{begin:/"/,end:/"/},{begin:/'/,end:/'/},{begin:/\//,
end:/\//},{begin:/\|/,end:/\|/},{begin:/\(/,end:/\)/},{begin:/\[/,end:/\]/},{
begin:/\{/,end:/\}/},{begin:/</,end:/>/}],l=e=>({scope:"char.escape",
begin:t.concat(/\\/,e),relevance:0}),c={className:"string",
begin:"~[a-z](?="+i+")",contains:s.map((t=>e.inherit(t,{contains:[l(t.end),a,o]
})))},u={className:"string",begin:"~[A-Z](?="+i+")",
contains:s.map((t=>e.inherit(t,{contains:[l(t.end)]})))},d={className:"regex",
variants:[{begin:"~r(?="+i+")",contains:s.map((n=>e.inherit(n,{
end:t.concat(n.end,/[uismxfU]{0,7}/),contains:[l(n.end),a,o]})))},{
begin:"~R(?="+i+")",contains:s.map((n=>e.inherit(n,{
end:t.concat(n.end,/[uismxfU]{0,7}/),contains:[l(n.end)]})))}]},p={
className:"string",contains:[e.BACKSLASH_ESCAPE,o],variants:[{begin:/"""/,
end:/"""/},{begin:/'''/,end:/'''/},{begin:/~S"""/,end:/"""/,contains:[]},{
begin:/~S"/,end:/"/,contains:[]},{begin:/~S'''/,end:/'''/,contains:[]},{
begin:/~S'/,end:/'/,contains:[]},{begin:/'/,end:/'/},{begin:/"/,end:/"/}]},h={
className:"function",beginKeywords:"def defp defmacro defmacrop",end:/\B\b/,
contains:[e.inherit(e.TITLE_MODE,{begin:n,endsParent:!0})]},f=e.inherit(h,{
className:"class",beginKeywords:"defimpl defmodule defprotocol defrecord",
end:/\bdo\b|$|;/}),m=[p,d,u,c,e.HASH_COMMENT_MODE,f,h,{begin:"::"},{
className:"symbol",begin:":(?![\\s:])",contains:[p,{
begin:"[a-zA-Z_]\\w*[!?=]?|[-+~]@|<<|>>|=~|===?|<=>|[<>]=?|\\*\\*|[-/+%^&*~`|]|\\[\\]=?"
}],relevance:0},{className:"symbol",begin:n+":(?!:)",relevance:0},{
className:"title.class",begin:/(\b[A-Z][a-zA-Z0-9_]+)/,relevance:0},{
className:"number",
begin:"(\\b0o[0-7_]+)|(\\b0b[01_]+)|(\\b0x[0-9a-fA-F_]+)|(-?\\b[0-9][0-9_]*(\\.[0-9_]+([eE][-+]?[0-9]+)?)?)",
relevance:0},{className:"variable",begin:"(\\$\\W)|((\\$|@@?)(\\w+))"}]
;return o.contains=m,{name:"Elixir",aliases:["ex","exs"],keywords:r,contains:m}
},fsharp:function(e){const t={scope:"keyword",
match:/\b(yield|return|let|do|match|use)!/
},n=["bool","byte","sbyte","int8","int16","int32","uint8","uint16","uint32","int","uint","int64","uint64","nativeint","unativeint","decimal","float","double","float32","single","char","string","unit","bigint","option","voption","list","array","seq","byref","exn","inref","nativeptr","obj","outref","voidptr","Result"],r={
keyword:["abstract","and","as","assert","base","begin","class","default","delegate","do","done","downcast","downto","elif","else","end","exception","extern","finally","fixed","for","fun","function","global","if","in","inherit","inline","interface","internal","lazy","let","match","member","module","mutable","namespace","new","of","open","or","override","private","public","rec","return","static","struct","then","to","try","type","upcast","use","val","void","when","while","with","yield"],
literal:["true","false","null","Some","None","Ok","Error","infinity","infinityf","nan","nanf"],
built_in:["not","ref","raise","reraise","dict","readOnlyDict","set","get","enum","sizeof","typeof","typedefof","nameof","nullArg","invalidArg","invalidOp","id","fst","snd","ignore","lock","using","box","unbox","tryUnbox","printf","printfn","sprintf","eprintf","eprintfn","fprintf","fprintfn","failwith","failwithf"],
"variable.constant":["__LINE__","__SOURCE_DIRECTORY__","__SOURCE_FILE__"]},o={
variants:[e.COMMENT(/\(\*(?!\))/,/\*\)/,{contains:["self"]
}),e.C_LINE_COMMENT_MODE]},a={scope:"variable",begin:/``/,end:/``/
},i=/\B('|\^)/,s={scope:"symbol",variants:[{match:NL(i,/``.*?``/)},{
match:NL(i,e.UNDERSCORE_IDENT_RE)}],relevance:0},l=function({includeEqual:e}){
let t;t=e?"!%&*+-/<=>@^|~?":"!%&*+-/<>@^|~?"
;const n=NL("[",...Array.from(t).map(DL),"]"),r=RL(n,/\./),o=NL(r,ML(r)),a=RL(NL(o,r,"*"),NL(n,"+"))
;return{scope:"operator",match:RL(a,/:\?>/,/:\?/,/:>/,/:=/,/::?/,/\$/),
relevance:0}},c=l({includeEqual:!0}),u=l({includeEqual:!1}),d=function(t,i){
return{begin:NL(t,ML(NL(/\s*/,RL(/\w/,/'/,/\^/,/#/,/``/,/\(/,/{\|/)))),
beginScope:i,end:ML(RL(/\n/,/=/)),relevance:0,keywords:e.inherit(r,{type:n}),
contains:[o,s,e.inherit(a,{scope:null}),u]}
},p=d(/:/,"operator"),h=d(/\bof\b/,"keyword"),f={
begin:[/(^|\s+)/,/type/,/\s+/,/[a-zA-Z_](\w|')*/],beginScope:{2:"keyword",
4:"title.class"},end:ML(/\(|=|$/),keywords:r,contains:[o,e.inherit(a,{scope:null
}),s,{scope:"operator",match:/<|>/},p]},m={scope:"computation-expression",
match:/\b[_a-z]\w*(?=\s*\{)/},g={
begin:[/^\s*/,NL(/#/,RL("if","else","endif","line","nowarn","light","r","i","I","load","time","help","quit")),/\b/],
beginScope:{2:"meta"},end:ML(/\s|$/)},v={
variants:[e.BINARY_NUMBER_MODE,e.C_NUMBER_MODE]},b={scope:"string",begin:/"/,
end:/"/,contains:[e.BACKSLASH_ESCAPE]},y={scope:"string",begin:/@"/,end:/"/,
contains:[{match:/""/},e.BACKSLASH_ESCAPE]},O={scope:"string",begin:/"""/,
end:/"""/,relevance:2},w={scope:"subst",begin:/\{/,end:/\}/,keywords:r},x={
scope:"string",begin:/\$"/,end:/"/,contains:[{match:/\{\{/},{match:/\}\}/
},e.BACKSLASH_ESCAPE,w]},k={scope:"string",begin:/(\$@|@\$)"/,end:/"/,
contains:[{match:/\{\{/},{match:/\}\}/},{match:/""/},e.BACKSLASH_ESCAPE,w]},S={
scope:"string",begin:/\$"""/,end:/"""/,contains:[{match:/\{\{/},{match:/\}\}/
},w],relevance:2},_={scope:"string",
match:NL(/'/,RL(/[^\\']/,/\\(?:.|\d{3}|x[a-fA-F\d]{2}|u[a-fA-F\d]{4}|U[a-fA-F\d]{8})/),/'/)
};return w.contains=[k,x,y,b,_,t,o,a,p,m,g,v,s,c],{name:"F#",
aliases:["fs","f#"],keywords:r,illegal:/\/\*/,classNameAliases:{
"computation-expression":"keyword"},contains:[t,{variants:[S,k,x,O,y,b,_]
},o,a,f,{scope:"meta",begin:/\[</,end:/>\]/,relevance:2,contains:[a,O,y,b,_,v]
},h,p,m,g,v,s,c]}},go:function(e){const t={
keyword:["break","case","chan","const","continue","default","defer","else","fallthrough","for","func","go","goto","if","import","interface","map","package","range","return","select","struct","switch","type","var"],
type:["bool","byte","complex64","complex128","error","float32","float64","int8","int16","int32","int64","string","uint8","uint16","uint32","uint64","int","uint","uintptr","rune"],
literal:["true","false","iota","nil"],
built_in:["append","cap","close","complex","copy","imag","len","make","new","panic","print","println","real","recover","delete"]
};return{name:"Go",aliases:["golang"],keywords:t,illegal:"</",
contains:[e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,{className:"string",
variants:[e.QUOTE_STRING_MODE,e.APOS_STRING_MODE,{begin:"`",end:"`"}]},{
className:"number",variants:[{
match:/-?\b0[xX]\.[a-fA-F0-9](_?[a-fA-F0-9])*[pP][+-]?\d(_?\d)*i?/,relevance:0
},{
match:/-?\b0[xX](_?[a-fA-F0-9])+((\.([a-fA-F0-9](_?[a-fA-F0-9])*)?)?[pP][+-]?\d(_?\d)*)?i?/,
relevance:0},{match:/-?\b0[oO](_?[0-7])*i?/,relevance:0},{
match:/-?\.\d(_?\d)*([eE][+-]?\d(_?\d)*)?i?/,relevance:0},{
match:/-?\b\d(_?\d)*(\.(\d(_?\d)*)?)?([eE][+-]?\d(_?\d)*)?i?/,relevance:0}]},{
begin:/:=/},{className:"function",beginKeywords:"func",end:"\\s*(\\{|$)",
excludeEnd:!0,contains:[e.TITLE_MODE,{className:"params",begin:/\(/,end:/\)/,
endsParent:!0,keywords:t,illegal:/["']/}]}]}},graphql:function(e){
const t=e.regex;return{name:"GraphQL",aliases:["gql"],case_insensitive:!0,
disableAutodetect:!1,keywords:{
keyword:["query","mutation","subscription","type","input","schema","directive","interface","union","scalar","fragment","enum","on"],
literal:["true","false","null"]},
contains:[e.HASH_COMMENT_MODE,e.QUOTE_STRING_MODE,e.NUMBER_MODE,{
scope:"punctuation",match:/[.]{3}/,relevance:0},{scope:"punctuation",
begin:/[\!\(\)\:\=\[\]\{\|\}]{1}/,relevance:0},{scope:"variable",begin:/\$/,
end:/\W/,excludeEnd:!0,relevance:0},{scope:"meta",match:/@\w+/,excludeEnd:!0},{
scope:"symbol",begin:t.concat(/[_A-Za-z][_0-9A-Za-z]*/,t.lookahead(/\s*:/)),
relevance:0}],illegal:[/[;<']/,/BEGIN/]}},haskell:function(e){
const t="([0-9]_*)+",n="([0-9a-fA-F]_*)+",r="([!#$%&*+.\\/<=>?@\\\\^~-]|(?!([(),;\\[\\]`|{}]|[_:\"']))(\\p{S}|\\p{P}))",o={
variants:[e.COMMENT("--+","$"),e.COMMENT(/\{-/,/-\}/,{contains:["self"]})]},a={
className:"meta",begin:/\{-#/,end:/#-\}/},i={className:"meta",begin:"^#",end:"$"
},s={className:"type",begin:"\\b[A-Z][\\w']*",relevance:0},l={begin:"\\(",
end:"\\)",illegal:'"',contains:[a,i,{className:"type",
begin:"\\b[A-Z][\\w]*(\\((\\.\\.|,|\\w+)\\))?"},e.inherit(e.TITLE_MODE,{
begin:"[_a-z][\\w']*"}),o]},c={className:"number",relevance:0,variants:[{
match:`\\b(${t})(\\.(${t}))?([eE][+-]?(${t}))?\\b`},{
match:`\\b0[xX]_*(${n})(\\.(${n}))?([pP][+-]?(${t}))?\\b`},{
match:"\\b0[oO](([0-7]_*)+)\\b"},{match:"\\b0[bB](([01]_*)+)\\b"}]};return{
name:"Haskell",aliases:["hs"],
keywords:"let in if then else case of where do module import hiding qualified type data newtype deriving class instance as default infix infixl infixr foreign export ccall stdcall cplusplus jvm dotnet safe unsafe family forall mdo proc rec",
unicodeRegex:!0,contains:[{beginKeywords:"module",end:"where",
keywords:"module where",contains:[l,o],illegal:"\\W\\.|;"},{
begin:"\\bimport\\b",end:"$",keywords:"import qualified as hiding",
contains:[l,o],illegal:"\\W\\.|;"},{className:"class",
begin:"^(\\s*)?(class|instance)\\b",end:"where",
keywords:"class family instance where",contains:[s,l,o]},{className:"class",
begin:"\\b(data|(new)?type)\\b",end:"$",
keywords:"data family type newtype deriving",contains:[a,s,l,{begin:/\{/,
end:/\}/,contains:l.contains},o]},{beginKeywords:"default",end:"$",
contains:[s,l,o]},{beginKeywords:"infix infixl infixr",end:"$",
contains:[e.C_NUMBER_MODE,o]},{begin:"\\bforeign\\b",end:"$",
keywords:"foreign import export ccall stdcall cplusplus jvm dotnet safe unsafe",
contains:[s,e.QUOTE_STRING_MODE,o]},{className:"meta",
begin:"#!\\/usr\\/bin\\/env runhaskell",end:"$"},a,i,{scope:"string",
begin:/'(?=\\?.')/,end:/'/,contains:[{scope:"char.escape",match:/\\./}]
},e.QUOTE_STRING_MODE,c,s,e.inherit(e.TITLE_MODE,{begin:"^[_a-z][\\w']*"}),{
begin:`(?!-)${r}--+|--+(?!-)${r}`},o,{begin:"->|<-"}]}},html:qB,
http:function(e){const t="HTTP/([32]|1\\.[01])",n={className:"attribute",
begin:e.regex.concat("^",/[A-Za-z][A-Za-z0-9-]*/,"(?=\\:\\s)"),starts:{
contains:[{className:"punctuation",begin:/: /,relevance:0,starts:{end:"$",
relevance:0}}]}},r=[n,{begin:"\\n\\n",starts:{subLanguage:[],endsWithParent:!0}
}];return{name:"HTTP",aliases:["https"],illegal:/\S/,contains:[{
begin:"^(?="+t+" \\d{3})",end:/$/,contains:[{className:"meta",begin:t},{
className:"number",begin:"\\b\\d{3}\\b"}],starts:{end:/\b\B/,illegal:/\S/,
contains:r}},{begin:"(?=^[A-Z]+ (.*?) "+t+"$)",end:/$/,contains:[{
className:"string",begin:" ",end:" ",excludeBegin:!0,excludeEnd:!0},{
className:"meta",begin:t},{className:"keyword",begin:"[A-Z]+"}],starts:{
end:/\b\B/,illegal:/\S/,contains:r}},e.inherit(n,{relevance:0})]}},ini:FL,
java:function(e){
const t=e.regex,n="[À-ʸa-zA-Z_$][À-ʸa-zA-Z_$0-9]*",r=n+qL("(?:<"+n+"~~~(?:\\s*,\\s*"+n+"~~~)*>)?",/~~~/g,2),o={
keyword:["synchronized","abstract","private","var","static","if","const ","for","while","strictfp","finally","protected","import","native","final","void","enum","else","break","transient","catch","instanceof","volatile","case","assert","package","default","public","try","switch","continue","throws","protected","public","private","module","requires","exports","do","sealed","yield","permits","goto","when"],
literal:["false","true","null"],
type:["char","boolean","long","float","int","byte","short","double"],
built_in:["super","this"]},a={className:"meta",begin:"@"+n,contains:[{
begin:/\(/,end:/\)/,contains:["self"]}]},i={className:"params",begin:/\(/,
end:/\)/,keywords:o,relevance:0,contains:[e.C_BLOCK_COMMENT_MODE],endsParent:!0}
;return{name:"Java",aliases:["jsp"],keywords:o,illegal:/<\/|#/,
contains:[e.COMMENT("/\\*\\*","\\*/",{relevance:0,contains:[{begin:/\w+@/,
relevance:0},{className:"doctag",begin:"@[A-Za-z]+"}]}),{
begin:/import java\.[a-z]+\./,keywords:"import",relevance:2
},e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,{begin:/"""/,end:/"""/,
className:"string",contains:[e.BACKSLASH_ESCAPE]
},e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,{
match:[/\b(?:class|interface|enum|extends|implements|new)/,/\s+/,n],className:{
1:"keyword",3:"title.class"}},{match:/non-sealed/,scope:"keyword"},{
begin:[t.concat(/(?!else)/,n),/\s+/,n,/\s+/,/=(?!=)/],className:{1:"type",
3:"variable",5:"operator"}},{begin:[/record/,/\s+/,n],className:{1:"keyword",
3:"title.class"},contains:[i,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{
beginKeywords:"new throw return else",relevance:0},{
begin:["(?:"+r+"\\s+)",e.UNDERSCORE_IDENT_RE,/\s*(?=\()/],className:{
2:"title.function"},keywords:o,contains:[{className:"params",begin:/\(/,
end:/\)/,keywords:o,relevance:0,
contains:[a,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,VL,e.C_BLOCK_COMMENT_MODE]
},e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},VL,a]}},javascript:function(e){
const t=e.regex,n=WL,r="<>",o="</>",a={begin:/<[A-Za-z0-9\\._:-]+/,
end:/\/[A-Za-z0-9\\._:-]+>|\/>/,isTrulyOpeningTag:(e,t)=>{
const n=e[0].length+e.index,r=e.input[n]
;if("<"===r||","===r)return void t.ignoreMatch();let o
;">"===r&&(((e,{after:t})=>{const n="</"+e[0].slice(1)
;return-1!==e.input.indexOf(n,t)})(e,{after:n})||t.ignoreMatch())
;const a=e.input.substring(n)
;((o=a.match(/^\s*=/))||(o=a.match(/^\s+extends\s+/))&&0===o.index)&&t.ignoreMatch()
}},i={$pattern:WL,keyword:XL,literal:GL,built_in:tB,"variable.language":eB
},s="[0-9](_?[0-9])*",l=`\\.(${s})`,c="0|[1-9](_?[0-9])*|0[0-7]*[89][0-9]*",u={
className:"number",variants:[{
begin:`(\\b(${c})((${l})|\\.)?|(${l}))[eE][+-]?(${s})\\b`},{
begin:`\\b(${c})\\b((${l})\\b|\\.)?|(${l})\\b`},{
begin:"\\b(0|[1-9](_?[0-9])*)n\\b"},{
begin:"\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*n?\\b"},{
begin:"\\b0[bB][0-1](_?[0-1])*n?\\b"},{begin:"\\b0[oO][0-7](_?[0-7])*n?\\b"},{
begin:"\\b0[0-7]+n?\\b"}],relevance:0},d={className:"subst",begin:"\\$\\{",
end:"\\}",keywords:i,contains:[]},p={begin:".?html`",end:"",starts:{end:"`",
returnEnd:!1,contains:[e.BACKSLASH_ESCAPE,d],subLanguage:"xml"}},h={
begin:".?css`",end:"",starts:{end:"`",returnEnd:!1,
contains:[e.BACKSLASH_ESCAPE,d],subLanguage:"css"}},f={begin:".?gql`",end:"",
starts:{end:"`",returnEnd:!1,contains:[e.BACKSLASH_ESCAPE,d],
subLanguage:"graphql"}},m={className:"string",begin:"`",end:"`",
contains:[e.BACKSLASH_ESCAPE,d]},g={className:"comment",
variants:[e.COMMENT(/\/\*\*(?!\/)/,"\\*/",{relevance:0,contains:[{
begin:"(?=@[A-Za-z]+)",relevance:0,contains:[{className:"doctag",
begin:"@[A-Za-z]+"},{className:"type",begin:"\\{",end:"\\}",excludeEnd:!0,
excludeBegin:!0,relevance:0},{className:"variable",begin:n+"(?=\\s*(-)|$)",
endsParent:!0,relevance:0},{begin:/(?=[^\n])\s/,relevance:0}]}]
}),e.C_BLOCK_COMMENT_MODE,e.C_LINE_COMMENT_MODE]
},v=[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,p,h,f,m,{match:/\$\d+/},u]
;d.contains=v.concat({begin:/\{/,end:/\}/,keywords:i,contains:["self"].concat(v)
});const b=[].concat(g,d.contains),y=b.concat([{begin:/(\s*)\(/,end:/\)/,
keywords:i,contains:["self"].concat(b)}]),O={className:"params",begin:/(\s*)\(/,
end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:i,contains:y},w={variants:[{
match:[/class/,/\s+/,n,/\s+/,/extends/,/\s+/,t.concat(n,"(",t.concat(/\./,n),")*")],
scope:{1:"keyword",3:"title.class",5:"keyword",7:"title.class.inherited"}},{
match:[/class/,/\s+/,n],scope:{1:"keyword",3:"title.class"}}]},x={relevance:0,
match:t.either(/\bJSON/,/\b[A-Z][a-z]+([A-Z][a-z]*|\d)*/,/\b[A-Z]{2,}([A-Z][a-z]+|\d)+([A-Z][a-z]*)*/,/\b[A-Z]{2,}[a-z]+([A-Z][a-z]+|\d)*([A-Z][a-z]*)*/),
className:"title.class",keywords:{_:[...YL,...KL]}},k={variants:[{
match:[/function/,/\s+/,n,/(?=\s*\()/]},{match:[/function/,/\s*(?=\()/]}],
className:{1:"keyword",3:"title.function"},label:"func.def",contains:[O],
illegal:/%/},S={
match:t.concat(/\b/,(_=[...JL,"super","import"].map((e=>`${e}\\s*\\(`)),
t.concat("(?!",_.join("|"),")")),n,t.lookahead(/\s*\(/)),
className:"title.function",relevance:0};var _;const T={
begin:t.concat(/\./,t.lookahead(t.concat(n,/(?![0-9A-Za-z$_(])/))),end:n,
excludeBegin:!0,keywords:"prototype",className:"property",relevance:0},E={
match:[/get|set/,/\s+/,n,/(?=\()/],className:{1:"keyword",3:"title.function"},
contains:[{begin:/\(\)/},O]
},A="(\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)|"+e.UNDERSCORE_IDENT_RE+")\\s*=>",C={
match:[/const|var|let/,/\s+/,n,/\s*/,/=\s*/,/(async\s*)?/,t.lookahead(A)],
keywords:"async",className:{1:"keyword",3:"title.function"},contains:[O]}
;return{name:"JavaScript",aliases:["js","jsx","mjs","cjs"],keywords:i,exports:{
PARAMS_CONTAINS:y,CLASS_REFERENCE:x},illegal:/#(?![$_A-z])/,
contains:[e.SHEBANG({label:"shebang",binary:"node",relevance:5}),{
label:"use_strict",className:"meta",relevance:10,
begin:/^\s*['"]use (strict|asm)['"]/
},e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,p,h,f,m,g,{match:/\$\d+/},u,x,{
scope:"attr",match:n+t.lookahead(":"),relevance:0},C,{
begin:"("+e.RE_STARTERS_RE+"|\\b(case|return|throw)\\b)\\s*",
keywords:"return throw case",relevance:0,contains:[g,e.REGEXP_MODE,{
className:"function",begin:A,returnBegin:!0,end:"\\s*=>",contains:[{
className:"params",variants:[{begin:e.UNDERSCORE_IDENT_RE,relevance:0},{
className:null,begin:/\(\s*\)/,skip:!0},{begin:/(\s*)\(/,end:/\)/,
excludeBegin:!0,excludeEnd:!0,keywords:i,contains:y}]}]},{begin:/,/,relevance:0
},{match:/\s+/,relevance:0},{variants:[{begin:r,end:o},{
match:/<[A-Za-z0-9\\._:-]+\s*\/>/},{begin:a.begin,
"on:begin":a.isTrulyOpeningTag,end:a.end}],subLanguage:"xml",contains:[{
begin:a.begin,end:a.end,skip:!0,contains:["self"]}]}]},k,{
beginKeywords:"while if switch catch for"},{
begin:"\\b(?!function)"+e.UNDERSCORE_IDENT_RE+"\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)\\s*\\{",
returnBegin:!0,label:"func.def",contains:[O,e.inherit(e.TITLE_MODE,{begin:n,
className:"title.function"})]},{match:/\.\.\./,relevance:0},T,{match:"\\$"+n,
relevance:0},{match:[/\bconstructor(?=\s*\()/],className:{1:"title.function"},
contains:[O]},S,{relevance:0,match:/\b[A-Z][A-Z_0-9]+\b/,
className:"variable.constant"},w,E,{match:/\$[(.]/}]}},json:function(e){
const t=["true","false","null"],n={scope:"literal",beginKeywords:t.join(" ")}
;return{name:"JSON",aliases:["jsonc"],keywords:{literal:t},contains:[{
className:"attr",begin:/"(\\.|[^\\"\r\n])*"(?=\s*:)/,relevance:1.01},{
match:/[{}[\],:]/,className:"punctuation",relevance:0
},e.QUOTE_STRING_MODE,n,e.C_NUMBER_MODE,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE],
illegal:"\\S"}},kotlin:function(e){const t={
keyword:"abstract as val var vararg get set class object open private protected public noinline crossinline dynamic final enum if else do while for when throw try catch finally import package is in fun override companion reified inline lateinit init interface annotation data sealed internal infix operator out by constructor super tailrec where const inner suspend typealias external expect actual",
built_in:"Byte Short Char Int Long Boolean Float Double Void Unit Nothing",
literal:"true false null"},n={className:"symbol",begin:e.UNDERSCORE_IDENT_RE+"@"
},r={className:"subst",begin:/\$\{/,end:/\}/,contains:[e.C_NUMBER_MODE]},o={
className:"variable",begin:"\\$"+e.UNDERSCORE_IDENT_RE},a={className:"string",
variants:[{begin:'"""',end:'"""(?=[^"])',contains:[o,r]},{begin:"'",end:"'",
illegal:/\n/,contains:[e.BACKSLASH_ESCAPE]},{begin:'"',end:'"',illegal:/\n/,
contains:[e.BACKSLASH_ESCAPE,o,r]}]};r.contains.push(a);const i={
className:"meta",
begin:"@(?:file|property|field|get|set|receiver|param|setparam|delegate)\\s*:(?:\\s*"+e.UNDERSCORE_IDENT_RE+")?"
},s={className:"meta",begin:"@"+e.UNDERSCORE_IDENT_RE,contains:[{begin:/\(/,
end:/\)/,contains:[e.inherit(a,{className:"string"}),"self"]}]
},l=aB,c=e.COMMENT("/\\*","\\*/",{contains:[e.C_BLOCK_COMMENT_MODE]}),u={
variants:[{className:"type",begin:e.UNDERSCORE_IDENT_RE},{begin:/\(/,end:/\)/,
contains:[]}]},d=u;return d.variants[1].contains=[u],u.variants[1].contains=[d],
{name:"Kotlin",aliases:["kt","kts"],keywords:t,
contains:[e.COMMENT("/\\*\\*","\\*/",{relevance:0,contains:[{className:"doctag",
begin:"@[A-Za-z]+"}]}),e.C_LINE_COMMENT_MODE,c,{className:"keyword",
begin:/\b(break|continue|return|this)\b/,starts:{contains:[{className:"symbol",
begin:/@\w+/}]}},n,i,s,{className:"function",beginKeywords:"fun",end:"[(]|$",
returnBegin:!0,excludeEnd:!0,keywords:t,relevance:5,contains:[{
begin:e.UNDERSCORE_IDENT_RE+"\\s*\\(",returnBegin:!0,relevance:0,
contains:[e.UNDERSCORE_TITLE_MODE]},{className:"type",begin:/</,end:/>/,
keywords:"reified",relevance:0},{className:"params",begin:/\(/,end:/\)/,
endsParent:!0,keywords:t,relevance:0,contains:[{begin:/:/,end:/[=,\/]/,
endsWithParent:!0,contains:[u,e.C_LINE_COMMENT_MODE,c],relevance:0
},e.C_LINE_COMMENT_MODE,c,i,s,a,e.C_NUMBER_MODE]},c]},{
begin:[/class|interface|trait/,/\s+/,e.UNDERSCORE_IDENT_RE],beginScope:{
3:"title.class"},keywords:"class interface trait",end:/[:\{(]|$/,excludeEnd:!0,
illegal:"extends implements",contains:[{
beginKeywords:"public protected internal private constructor"
},e.UNDERSCORE_TITLE_MODE,{className:"type",begin:/</,end:/>/,excludeBegin:!0,
excludeEnd:!0,relevance:0},{className:"type",begin:/[,:]\s*/,end:/[<\(,){\s]|$/,
excludeBegin:!0,returnEnd:!0},i,s]},a,{className:"meta",begin:"^#!/usr/bin/env",
end:"$",illegal:"\n"},l]}},less:function(e){const t=(e=>({IMPORTANT:{
scope:"meta",begin:"!important"},BLOCK_COMMENT:e.C_BLOCK_COMMENT_MODE,HEXCOLOR:{
scope:"number",begin:/#(([0-9a-fA-F]{3,4})|(([0-9a-fA-F]{2}){3,4}))\b/},
FUNCTION_DISPATCH:{className:"built_in",begin:/[\w-]+(?=\()/},
ATTRIBUTE_SELECTOR_MODE:{scope:"selector-attr",begin:/\[/,end:/\]/,illegal:"$",
contains:[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE]},CSS_NUMBER_MODE:{
scope:"number",
begin:e.NUMBER_RE+"(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",
relevance:0},CSS_VARIABLE:{className:"attr",begin:/--[A-Za-z_][A-Za-z0-9_-]*/}
}))(e),n=dB,r="[\\w-]+",o="("+r+"|@\\{"+r+"\\})",a=[],i=[],s=function(e){return{
className:"string",begin:"~?"+e+".*?"+e}},l=function(e,t,n){return{className:e,
begin:t,relevance:n}},c={$pattern:/[a-z-]+/,keyword:"and or not only",
attribute:sB.join(" ")},u={begin:"\\(",end:"\\)",contains:i,keywords:c,
relevance:0}
;i.push(e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,s("'"),s('"'),t.CSS_NUMBER_MODE,{
begin:"(url|data-uri)\\(",starts:{className:"string",end:"[\\)\\n]",
excludeEnd:!0}
},t.HEXCOLOR,u,l("variable","@@?"+r,10),l("variable","@\\{"+r+"\\}"),l("built_in","~?`[^`]*?`"),{
className:"attribute",begin:r+"\\s*:",end:":",returnBegin:!0,excludeEnd:!0
},t.IMPORTANT,{beginKeywords:"and not"},t.FUNCTION_DISPATCH);const d=i.concat({
begin:/\{/,end:/\}/,contains:a}),p={beginKeywords:"when",endsWithParent:!0,
contains:[{beginKeywords:"and not"}].concat(i)},h={begin:o+"\\s*:",
returnBegin:!0,end:/[;}]/,relevance:0,contains:[{begin:/-(webkit|moz|ms|o)-/
},t.CSS_VARIABLE,{className:"attribute",begin:"\\b("+uB.join("|")+")\\b",
end:/(?=:)/,starts:{endsWithParent:!0,illegal:"[<=$]",relevance:0,contains:i}}]
},f={className:"keyword",
begin:"@(import|media|charset|font-face|(-[a-z]+-)?keyframes|supports|document|namespace|page|viewport|host)\\b",
starts:{end:"[;{}]",keywords:c,returnEnd:!0,contains:i,relevance:0}},m={
className:"variable",variants:[{begin:"@"+r+"\\s*:",relevance:15},{begin:"@"+r
}],starts:{end:"[;}]",returnEnd:!0,contains:d}},g={variants:[{
begin:"[\\.#:&\\[>]",end:"[;{}]"},{begin:o,end:/\{/}],returnBegin:!0,
returnEnd:!0,illegal:"[<='$\"]",relevance:0,
contains:[e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,p,l("keyword","all\\b"),l("variable","@\\{"+r+"\\}"),{
begin:"\\b("+iB.join("|")+")\\b",className:"selector-tag"
},t.CSS_NUMBER_MODE,l("selector-tag",o,0),l("selector-id","#"+o),l("selector-class","\\."+o,0),l("selector-tag","&",0),t.ATTRIBUTE_SELECTOR_MODE,{
className:"selector-pseudo",begin:":("+lB.join("|")+")"},{
className:"selector-pseudo",begin:":(:)?("+cB.join("|")+")"},{begin:/\(/,
end:/\)/,relevance:0,contains:d},{begin:"!important"},t.FUNCTION_DISPATCH]},v={
begin:r+`:(:)?(${n.join("|")})`,returnBegin:!0,contains:[g]}
;return a.push(e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,f,m,v,h,g,p,t.FUNCTION_DISPATCH),
{name:"Less",case_insensitive:!0,illegal:"[=>'/<($\"]",contains:a}},
lua:function(e){const t="\\[=*\\[",n="\\]=*\\]",r={begin:t,end:n,
contains:["self"]},o=[e.COMMENT("--(?!"+t+")","$"),e.COMMENT("--"+t,n,{
contains:[r],relevance:10})];return{name:"Lua",aliases:["pluto"],keywords:{
$pattern:e.UNDERSCORE_IDENT_RE,literal:"true false nil",
keyword:"and break do else elseif end for goto if in local not or repeat return then until while",
built_in:"_G _ENV _VERSION __index __newindex __mode __call __metatable __tostring __len __gc __add __sub __mul __div __mod __pow __concat __unm __eq __lt __le assert collectgarbage dofile error getfenv getmetatable ipairs load loadfile loadstring module next pairs pcall print rawequal rawget rawset require select setfenv setmetatable tonumber tostring type unpack xpcall arg self coroutine resume yield status wrap create running debug getupvalue debug sethook getmetatable gethook setmetatable setlocal traceback setfenv getinfo setupvalue getlocal getregistry getfenv io lines write close flush open output type read stderr stdin input stdout popen tmpfile math log max acos huge ldexp pi cos tanh pow deg tan cosh sinh random randomseed frexp ceil floor rad abs sqrt modf asin min mod fmod log10 atan2 exp sin atan os exit setlocale date getenv difftime remove time clock tmpname rename execute package preload loadlib loaded loaders cpath config path seeall string sub upper len gfind rep find match char dump gmatch reverse byte format gsub lower table setn insert getn foreachi maxn foreach concat sort remove"
},contains:o.concat([{className:"function",beginKeywords:"function",end:"\\)",
contains:[e.inherit(e.TITLE_MODE,{
begin:"([_a-zA-Z]\\w*\\.)*([_a-zA-Z]\\w*:)?[_a-zA-Z]\\w*"}),{className:"params",
begin:"\\(",endsWithParent:!0,contains:o}].concat(o)
},e.C_NUMBER_MODE,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,{className:"string",
begin:t,end:n,contains:[r],relevance:5}])}},makefile:function(e){const t={
className:"variable",variants:[{begin:"\\$\\("+e.UNDERSCORE_IDENT_RE+"\\)",
contains:[e.BACKSLASH_ESCAPE]},{begin:/\$[@%<?\^\+\*]/}]},n={className:"string",
begin:/"/,end:/"/,contains:[e.BACKSLASH_ESCAPE,t]},r={className:"variable",
begin:/\$\([\w-]+\s/,end:/\)/,keywords:{
built_in:"subst patsubst strip findstring filter filter-out sort word wordlist firstword lastword dir notdir suffix basename addsuffix addprefix join wildcard realpath abspath error warning shell origin flavor foreach if or and call eval file value"
},contains:[t,n]},o={begin:"^"+e.UNDERSCORE_IDENT_RE+"\\s*(?=[:+?]?=)"},a={
className:"section",begin:/^[^\s]+:/,end:/$/,contains:[t]};return{
name:"Makefile",aliases:["mk","mak","make"],keywords:{$pattern:/[\w-]+/,
keyword:"define endef undefine ifdef ifndef ifeq ifneq else endif include -include sinclude override export unexport private vpath"
},contains:[e.HASH_COMMENT_MODE,t,n,r,o,{className:"meta",begin:/^\.PHONY:/,
end:/$/,keywords:{$pattern:/[\.\w]+/,keyword:".PHONY"}},a]}},
markdown:function(e){const t={begin:/<\/?[A-Za-z_]/,end:">",subLanguage:"xml",
relevance:0},n={variants:[{begin:/\[.+?\]\[.*?\]/,relevance:0},{
begin:/\[.+?\]\(((data|javascript|mailto):|(?:http|ftp)s?:\/\/).*?\)/,
relevance:2},{
begin:e.regex.concat(/\[.+?\]\(/,/[A-Za-z][A-Za-z0-9+.-]*/,/:\/\/.*?\)/),
relevance:2},{begin:/\[.+?\]\([./?&#].*?\)/,relevance:1},{
begin:/\[.*?\]\(.*?\)/,relevance:0}],returnBegin:!0,contains:[{match:/\[(?=\])/
},{className:"string",relevance:0,begin:"\\[",end:"\\]",excludeBegin:!0,
returnEnd:!0},{className:"link",relevance:0,begin:"\\]\\(",end:"\\)",
excludeBegin:!0,excludeEnd:!0},{className:"symbol",relevance:0,begin:"\\]\\[",
end:"\\]",excludeBegin:!0,excludeEnd:!0}]},r={className:"strong",contains:[],
variants:[{begin:/_{2}(?!\s)/,end:/_{2}/},{begin:/\*{2}(?!\s)/,end:/\*{2}/}]
},o={className:"emphasis",contains:[],variants:[{begin:/\*(?![*\s])/,end:/\*/},{
begin:/_(?![_\s])/,end:/_/,relevance:0}]},a=e.inherit(r,{contains:[]
}),i=e.inherit(o,{contains:[]});r.contains.push(i),o.contains.push(a)
;let s=[t,n];return[r,o,a,i].forEach((e=>{e.contains=e.contains.concat(s)
})),s=s.concat(r,o),{name:"Markdown",aliases:["md","mkdown","mkd"],contains:[{
className:"section",variants:[{begin:"^#{1,6}",end:"$",contains:s},{
begin:"(?=^.+?\\n[=-]{2,}$)",contains:[{begin:"^[=-]*$"},{begin:"^",end:"\\n",
contains:s}]}]},t,{className:"bullet",begin:"^[ \t]*([*+-]|(\\d+\\.))(?=\\s+)",
end:"\\s+",excludeEnd:!0},r,o,{className:"quote",begin:"^>\\s+",contains:s,
end:"$"},{className:"code",variants:[{begin:"(`{3,})[^`](.|\\n)*?\\1`*[ ]*"},{
begin:"(~{3,})[^~](.|\\n)*?\\1~*[ ]*"},{begin:"```",end:"```+[ ]*$"},{
begin:"~~~",end:"~~~+[ ]*$"},{begin:"`.+?`"},{begin:"(?=^( {4}|\\t))",
contains:[{begin:"^( {4}|\\t)",end:"(\\n)$"}],relevance:0}]},{
begin:"^[-\\*]{3,}",end:"$"},n,{begin:/^\[[^\n]+\]:/,returnBegin:!0,contains:[{
className:"symbol",begin:/\[/,end:/\]/,excludeBegin:!0,excludeEnd:!0},{
className:"link",begin:/:\s*/,end:/$/,excludeBegin:!0}]},{scope:"literal",
match:/&([a-zA-Z0-9]+|#[0-9]{1,7}|#[Xx][0-9a-fA-F]{1,6});/}]}},
matlab:function(e){const t="('|\\.')+",n={relevance:0,contains:[{begin:t}]}
;return{name:"Matlab",keywords:{
keyword:"arguments break case catch classdef continue else elseif end enumeration events for function global if methods otherwise parfor persistent properties return spmd switch try while",
built_in:"sin sind sinh asin asind asinh cos cosd cosh acos acosd acosh tan tand tanh atan atand atan2 atanh sec secd sech asec asecd asech csc cscd csch acsc acscd acsch cot cotd coth acot acotd acoth hypot exp expm1 log log1p log10 log2 pow2 realpow reallog realsqrt sqrt nthroot nextpow2 abs angle complex conj imag real unwrap isreal cplxpair fix floor ceil round mod rem sign airy besselj bessely besselh besseli besselk beta betainc betaln ellipj ellipke erf erfc erfcx erfinv expint gamma gammainc gammaln psi legendre cross dot factor isprime primes gcd lcm rat rats perms nchoosek factorial cart2sph cart2pol pol2cart sph2cart hsv2rgb rgb2hsv zeros ones eye repmat rand randn linspace logspace freqspace meshgrid accumarray size length ndims numel disp isempty isequal isequalwithequalnans cat reshape diag blkdiag tril triu fliplr flipud flipdim rot90 find sub2ind ind2sub bsxfun ndgrid permute ipermute shiftdim circshift squeeze isscalar isvector ans eps realmax realmin pi i|0 inf nan isnan isinf isfinite j|0 why compan gallery hadamard hankel hilb invhilb magic pascal rosser toeplitz vander wilkinson max min nanmax nanmin mean nanmean type table readtable writetable sortrows sort figure plot plot3 scatter scatter3 cellfun legend intersect ismember procrustes hold num2cell "
},illegal:'(//|"|#|/\\*|\\s+/\\w+)',contains:[{className:"function",
beginKeywords:"function",end:"$",contains:[e.UNDERSCORE_TITLE_MODE,{
className:"params",variants:[{begin:"\\(",end:"\\)"},{begin:"\\[",end:"\\]"}]}]
},{className:"built_in",begin:/true|false/,relevance:0,starts:n},{
begin:"[a-zA-Z][a-zA-Z_0-9]*"+t,relevance:0},{className:"number",
begin:e.C_NUMBER_RE,relevance:0,starts:n},{className:"string",begin:"'",end:"'",
contains:[{begin:"''"}]},{begin:/\]|\}|\)/,relevance:0,starts:n},{
className:"string",begin:'"',end:'"',contains:[{begin:'""'}],starts:n
},e.COMMENT("^\\s*%\\{\\s*$","^\\s*%\\}\\s*$"),e.COMMENT("%","$")]}},
nginx:function(e){const t=e.regex,n={className:"variable",variants:[{
begin:/\$\d+/},{begin:/\$\{\w+\}/},{begin:t.concat(/[$@]/,e.UNDERSCORE_IDENT_RE)
}]},r={endsWithParent:!0,keywords:{$pattern:/[a-z_]{2,}|\/dev\/poll/,
literal:["on","off","yes","no","true","false","none","blocked","debug","info","notice","warn","error","crit","select","break","last","permanent","redirect","kqueue","rtsig","epoll","poll","/dev/poll"]
},relevance:0,illegal:"=>",contains:[e.HASH_COMMENT_MODE,{className:"string",
contains:[e.BACKSLASH_ESCAPE,n],variants:[{begin:/"/,end:/"/},{begin:/'/,end:/'/
}]},{begin:"([a-z]+):/",end:"\\s",endsWithParent:!0,excludeEnd:!0,contains:[n]
},{className:"regexp",contains:[e.BACKSLASH_ESCAPE,n],variants:[{begin:"\\s\\^",
end:"\\s|\\{|;",returnEnd:!0},{begin:"~\\*?\\s+",end:"\\s|\\{|;",returnEnd:!0},{
begin:"\\*(\\.[a-z\\-]+)+"},{begin:"([a-z\\-]+\\.)+\\*"}]},{className:"number",
begin:"\\b\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}(:\\d{1,5})?\\b"},{
className:"number",begin:"\\b\\d+[kKmMgGdshdwy]?\\b",relevance:0},n]};return{
name:"Nginx config",aliases:["nginxconf"],contains:[e.HASH_COMMENT_MODE,{
beginKeywords:"upstream location",end:/;|\{/,contains:r.contains,keywords:{
section:"upstream location"}},{className:"section",
begin:t.concat(e.UNDERSCORE_IDENT_RE+t.lookahead(/\s+\{/)),relevance:0},{
begin:t.lookahead(e.UNDERSCORE_IDENT_RE+"\\s"),end:";|\\{",contains:[{
className:"attribute",begin:e.UNDERSCORE_IDENT_RE,starts:r}],relevance:0}],
illegal:"[^\\s\\}\\{]"}},objectivec:function(e){
const t=/[a-zA-Z@][a-zA-Z0-9_]*/,n={$pattern:t,
keyword:["@interface","@class","@protocol","@implementation"]};return{
name:"Objective-C",aliases:["mm","objc","obj-c","obj-c++","objective-c++"],
keywords:{"variable.language":["this","super"],$pattern:t,
keyword:["while","export","sizeof","typedef","const","struct","for","union","volatile","static","mutable","if","do","return","goto","enum","else","break","extern","asm","case","default","register","explicit","typename","switch","continue","inline","readonly","assign","readwrite","self","@synchronized","id","typeof","nonatomic","IBOutlet","IBAction","strong","weak","copy","in","out","inout","bycopy","byref","oneway","__strong","__weak","__block","__autoreleasing","@private","@protected","@public","@try","@property","@end","@throw","@catch","@finally","@autoreleasepool","@synthesize","@dynamic","@selector","@optional","@required","@encode","@package","@import","@defs","@compatibility_alias","__bridge","__bridge_transfer","__bridge_retained","__bridge_retain","__covariant","__contravariant","__kindof","_Nonnull","_Nullable","_Null_unspecified","__FUNCTION__","__PRETTY_FUNCTION__","__attribute__","getter","setter","retain","unsafe_unretained","nonnull","nullable","null_unspecified","null_resettable","class","instancetype","NS_DESIGNATED_INITIALIZER","NS_UNAVAILABLE","NS_REQUIRES_SUPER","NS_RETURNS_INNER_POINTER","NS_INLINE","NS_AVAILABLE","NS_DEPRECATED","NS_ENUM","NS_OPTIONS","NS_SWIFT_UNAVAILABLE","NS_ASSUME_NONNULL_BEGIN","NS_ASSUME_NONNULL_END","NS_REFINED_FOR_SWIFT","NS_SWIFT_NAME","NS_SWIFT_NOTHROW","NS_DURING","NS_HANDLER","NS_ENDHANDLER","NS_VALUERETURN","NS_VOIDRETURN"],
literal:["false","true","FALSE","TRUE","nil","YES","NO","NULL"],
built_in:["dispatch_once_t","dispatch_queue_t","dispatch_sync","dispatch_async","dispatch_once"],
type:["int","float","char","unsigned","signed","short","long","double","wchar_t","unichar","void","bool","BOOL","id|0","_Bool"]
},illegal:"</",contains:[{className:"built_in",
begin:"\\b(AV|CA|CF|CG|CI|CL|CM|CN|CT|MK|MP|MTK|MTL|NS|SCN|SK|UI|WK|XC)\\w+"
},e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,e.C_NUMBER_MODE,e.QUOTE_STRING_MODE,e.APOS_STRING_MODE,{
className:"string",variants:[{begin:'@"',end:'"',illegal:"\\n",
contains:[e.BACKSLASH_ESCAPE]}]},{className:"meta",begin:/#\s*[a-z]+\b/,end:/$/,
keywords:{
keyword:"if else elif endif define undef warning error line pragma ifdef ifndef include"
},contains:[{begin:/\\\n/,relevance:0},e.inherit(e.QUOTE_STRING_MODE,{
className:"string"}),{className:"string",begin:/<.*?>/,end:/$/,illegal:"\\n"
},e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{className:"class",
begin:"("+n.keyword.join("|")+")\\b",end:/(\{|$)/,excludeEnd:!0,keywords:n,
contains:[e.UNDERSCORE_TITLE_MODE]},{begin:"\\."+e.UNDERSCORE_IDENT_RE,
relevance:0}]}},ocaml:function(e){return{name:"OCaml",aliases:["ml"],keywords:{
$pattern:"[a-z_]\\w*!?",
keyword:"and as assert asr begin class constraint do done downto else end exception external for fun function functor if in include inherit! inherit initializer land lazy let lor lsl lsr lxor match method!|10 method mod module mutable new object of open! open or private rec sig struct then to try type val! val virtual when while with parser value",
built_in:"array bool bytes char exn|5 float int int32 int64 list lazy_t|5 nativeint|5 string unit in_channel out_channel ref",
literal:"true false"},illegal:/\/\/|>>/,contains:[{className:"literal",
begin:"\\[(\\|\\|)?\\]|\\(\\)",relevance:0},e.COMMENT("\\(\\*","\\*\\)",{
contains:["self"]}),{className:"symbol",begin:"'[A-Za-z_](?!')[\\w']*"},{
className:"type",begin:"`[A-Z][\\w']*"},{className:"type",
begin:"\\b[A-Z][\\w']*",relevance:0},{begin:"[a-z_]\\w*'[\\w']*",relevance:0
},e.inherit(e.APOS_STRING_MODE,{className:"string",relevance:0
}),e.inherit(e.QUOTE_STRING_MODE,{illegal:null}),{className:"number",
begin:"\\b(0[xX][a-fA-F0-9_]+[Lln]?|0[oO][0-7_]+[Lln]?|0[bB][01_]+[Lln]?|[0-9][0-9_]*([Lln]|(\\.[0-9_]*)?([eE][-+]?[0-9_]+)?)?)",
relevance:0},{begin:/->/}]}},perl:function(e){
const t=e.regex,n=/[dualxmsipngr]{0,12}/,r={$pattern:/[\w.]+/,
keyword:["abs","accept","alarm","and","atan2","bind","binmode","bless","break","caller","chdir","chmod","chomp","chop","chown","chr","chroot","class","close","closedir","connect","continue","cos","crypt","dbmclose","dbmopen","defined","delete","die","do","dump","each","else","elsif","endgrent","endhostent","endnetent","endprotoent","endpwent","endservent","eof","eval","exec","exists","exit","exp","fcntl","field","fileno","flock","for","foreach","fork","format","formline","getc","getgrent","getgrgid","getgrnam","gethostbyaddr","gethostbyname","gethostent","getlogin","getnetbyaddr","getnetbyname","getnetent","getpeername","getpgrp","getpriority","getprotobyname","getprotobynumber","getprotoent","getpwent","getpwnam","getpwuid","getservbyname","getservbyport","getservent","getsockname","getsockopt","given","glob","gmtime","goto","grep","gt","hex","if","index","int","ioctl","join","keys","kill","last","lc","lcfirst","length","link","listen","local","localtime","log","lstat","lt","ma","map","method","mkdir","msgctl","msgget","msgrcv","msgsnd","my","ne","next","no","not","oct","open","opendir","or","ord","our","pack","package","pipe","pop","pos","print","printf","prototype","push","q|0","qq","quotemeta","qw","qx","rand","read","readdir","readline","readlink","readpipe","recv","redo","ref","rename","require","reset","return","reverse","rewinddir","rindex","rmdir","say","scalar","seek","seekdir","select","semctl","semget","semop","send","setgrent","sethostent","setnetent","setpgrp","setpriority","setprotoent","setpwent","setservent","setsockopt","shift","shmctl","shmget","shmread","shmwrite","shutdown","sin","sleep","socket","socketpair","sort","splice","split","sprintf","sqrt","srand","stat","state","study","sub","substr","symlink","syscall","sysopen","sysread","sysseek","system","syswrite","tell","telldir","tie","tied","time","times","tr","truncate","uc","ucfirst","umask","undef","unless","unlink","unpack","unshift","untie","until","use","utime","values","vec","wait","waitpid","wantarray","warn","when","while","write","x|0","xor","y|0"].join(" ")
},o={className:"subst",begin:"[$@]\\{",end:"\\}",keywords:r},a={begin:/->\{/,
end:/\}/},i={scope:"attr",match:/\s+:\s*\w+(\s*\(.*?\))?/},s={scope:"variable",
variants:[{begin:/\$\d/},{
begin:t.concat(/[$%@](?!")(\^\w\b|#\w+(::\w+)*|\{\w+\}|\w+(::\w*)*)/,"(?![A-Za-z])(?![@$%])")
},{begin:/[$%@](?!")[^\s\w{=]|\$=/,relevance:0}],contains:[i]},l={
className:"number",variants:[{match:/0?\.[0-9][0-9_]+\b/},{
match:/\bv?(0|[1-9][0-9_]*(\.[0-9_]+)?|[1-9][0-9_]*)\b/},{
match:/\b0[0-7][0-7_]*\b/},{match:/\b0x[0-9a-fA-F][0-9a-fA-F_]*\b/},{
match:/\b0b[0-1][0-1_]*\b/}],relevance:0
},c=[e.BACKSLASH_ESCAPE,o,s],u=[/!/,/\//,/\|/,/\?/,/'/,/"/,/#/],d=(e,r,o="\\1")=>{
const a="\\1"===o?o:t.concat(o,r)
;return t.concat(t.concat("(?:",e,")"),r,/(?:\\.|[^\\\/])*?/,a,/(?:\\.|[^\\\/])*?/,o,n)
},p=(e,r,o)=>t.concat(t.concat("(?:",e,")"),r,/(?:\\.|[^\\\/])*?/,o,n),h=[s,e.HASH_COMMENT_MODE,e.COMMENT(/^=\w/,/=cut/,{
endsWithParent:!0}),a,{className:"string",contains:c,variants:[{
begin:"q[qwxr]?\\s*\\(",end:"\\)",relevance:5},{begin:"q[qwxr]?\\s*\\[",
end:"\\]",relevance:5},{begin:"q[qwxr]?\\s*\\{",end:"\\}",relevance:5},{
begin:"q[qwxr]?\\s*\\|",end:"\\|",relevance:5},{begin:"q[qwxr]?\\s*<",end:">",
relevance:5},{begin:"qw\\s+q",end:"q",relevance:5},{begin:"'",end:"'",
contains:[e.BACKSLASH_ESCAPE]},{begin:'"',end:'"'},{begin:"`",end:"`",
contains:[e.BACKSLASH_ESCAPE]},{begin:/\{\w+\}/,relevance:0},{
begin:"-?\\w+\\s*=>",relevance:0}]},l,{
begin:"(\\/\\/|"+e.RE_STARTERS_RE+"|\\b(split|return|print|reverse|grep)\\b)\\s*",
keywords:"split return print reverse grep",relevance:0,
contains:[e.HASH_COMMENT_MODE,{className:"regexp",variants:[{
begin:d("s|tr|y",t.either(...u,{capture:!0}))},{begin:d("s|tr|y","\\(","\\)")},{
begin:d("s|tr|y","\\[","\\]")},{begin:d("s|tr|y","\\{","\\}")}],relevance:2},{
className:"regexp",variants:[{begin:/(m|qr)\/\//,relevance:0},{
begin:p("(?:m|qr)?",/\//,/\//)},{begin:p("m|qr",t.either(...u,{capture:!0
}),/\1/)},{begin:p("m|qr",/\(/,/\)/)},{begin:p("m|qr",/\[/,/\]/)},{
begin:p("m|qr",/\{/,/\}/)}]}]},{className:"function",beginKeywords:"sub method",
end:"(\\s*\\(.*?\\))?[;{]",excludeEnd:!0,relevance:5,contains:[e.TITLE_MODE,i]
},{className:"class",beginKeywords:"class",end:"[;{]",excludeEnd:!0,relevance:5,
contains:[e.TITLE_MODE,i,l]},{begin:"-\\w\\b",relevance:0},{begin:"^__DATA__$",
end:"^__END__$",subLanguage:"mojolicious",contains:[{begin:"^@@.*",end:"$",
className:"comment"}]}];return o.contains=h,a.contains=h,{name:"Perl",
aliases:["pl","pm"],keywords:r,contains:h}},php:function(e){
const t=e.regex,n=/(?![A-Za-z0-9])(?![$])/,r=t.concat(/[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*/,n),o=t.concat(/(\\?[A-Z][a-z0-9_\x7f-\xff]+|\\?[A-Z]+(?=[A-Z][a-z0-9_\x7f-\xff])){1,}/,n),a=t.concat(/[A-Z]+/,n),i={
scope:"variable",match:"\\$+"+r},s={scope:"subst",variants:[{begin:/\$\w+/},{
begin:/\{\$/,end:/\}/}]},l=e.inherit(e.APOS_STRING_MODE,{illegal:null
}),c="[ \t\n]",u={scope:"string",variants:[e.inherit(e.QUOTE_STRING_MODE,{
illegal:null,contains:e.QUOTE_STRING_MODE.contains.concat(s)}),l,{
begin:/<<<[ \t]*(?:(\w+)|"(\w+)")\n/,end:/[ \t]*(\w+)\b/,
contains:e.QUOTE_STRING_MODE.contains.concat(s),"on:begin":(e,t)=>{
t.data._beginMatch=e[1]||e[2]},"on:end":(e,t)=>{
t.data._beginMatch!==e[1]&&t.ignoreMatch()}},e.END_SAME_AS_BEGIN({
begin:/<<<[ \t]*'(\w+)'\n/,end:/[ \t]*(\w+)\b/})]},d={scope:"number",variants:[{
begin:"\\b0[bB][01]+(?:_[01]+)*\\b"},{begin:"\\b0[oO][0-7]+(?:_[0-7]+)*\\b"},{
begin:"\\b0[xX][\\da-fA-F]+(?:_[\\da-fA-F]+)*\\b"},{
begin:"(?:\\b\\d+(?:_\\d+)*(\\.(?:\\d+(?:_\\d+)*))?|\\B\\.\\d+)(?:[eE][+-]?\\d+)?"
}],relevance:0
},p=["false","null","true"],h=["__CLASS__","__DIR__","__FILE__","__FUNCTION__","__COMPILER_HALT_OFFSET__","__LINE__","__METHOD__","__NAMESPACE__","__TRAIT__","die","echo","exit","include","include_once","print","require","require_once","array","abstract","and","as","binary","bool","boolean","break","callable","case","catch","class","clone","const","continue","declare","default","do","double","else","elseif","empty","enddeclare","endfor","endforeach","endif","endswitch","endwhile","enum","eval","extends","final","finally","float","for","foreach","from","global","goto","if","implements","instanceof","insteadof","int","integer","interface","isset","iterable","list","match|0","mixed","new","never","object","or","private","protected","public","readonly","real","return","string","switch","throw","trait","try","unset","use","var","void","while","xor","yield"],f=["Error|0","AppendIterator","ArgumentCountError","ArithmeticError","ArrayIterator","ArrayObject","AssertionError","BadFunctionCallException","BadMethodCallException","CachingIterator","CallbackFilterIterator","CompileError","Countable","DirectoryIterator","DivisionByZeroError","DomainException","EmptyIterator","ErrorException","Exception","FilesystemIterator","FilterIterator","GlobIterator","InfiniteIterator","InvalidArgumentException","IteratorIterator","LengthException","LimitIterator","LogicException","MultipleIterator","NoRewindIterator","OutOfBoundsException","OutOfRangeException","OuterIterator","OverflowException","ParentIterator","ParseError","RangeException","RecursiveArrayIterator","RecursiveCachingIterator","RecursiveCallbackFilterIterator","RecursiveDirectoryIterator","RecursiveFilterIterator","RecursiveIterator","RecursiveIteratorIterator","RecursiveRegexIterator","RecursiveTreeIterator","RegexIterator","RuntimeException","SeekableIterator","SplDoublyLinkedList","SplFileInfo","SplFileObject","SplFixedArray","SplHeap","SplMaxHeap","SplMinHeap","SplObjectStorage","SplObserver","SplPriorityQueue","SplQueue","SplStack","SplSubject","SplTempFileObject","TypeError","UnderflowException","UnexpectedValueException","UnhandledMatchError","ArrayAccess","BackedEnum","Closure","Fiber","Generator","Iterator","IteratorAggregate","Serializable","Stringable","Throwable","Traversable","UnitEnum","WeakReference","WeakMap","Directory","__PHP_Incomplete_Class","parent","php_user_filter","self","static","stdClass"],m={
keyword:h,literal:(e=>{const t=[];return e.forEach((e=>{
t.push(e),e.toLowerCase()===e?t.push(e.toUpperCase()):t.push(e.toLowerCase())
})),t})(p),built_in:f},g=e=>e.map((e=>e.replace(/\|\d+$/,""))),v={variants:[{
match:[/new/,t.concat(c,"+"),t.concat("(?!",g(f).join("\\b|"),"\\b)"),o],scope:{
1:"keyword",4:"title.class"}}]},b=t.concat(r,"\\b(?!\\()"),y={variants:[{
match:[t.concat(/::/,t.lookahead(/(?!class\b)/)),b],scope:{2:"variable.constant"
}},{match:[/::/,/class/],scope:{2:"variable.language"}},{
match:[o,t.concat(/::/,t.lookahead(/(?!class\b)/)),b],scope:{1:"title.class",
3:"variable.constant"}},{match:[o,t.concat("::",t.lookahead(/(?!class\b)/))],
scope:{1:"title.class"}},{match:[o,/::/,/class/],scope:{1:"title.class",
3:"variable.language"}}]},O={scope:"attr",
match:t.concat(r,t.lookahead(":"),t.lookahead(/(?!::)/))},w={relevance:0,
begin:/\(/,end:/\)/,keywords:m,contains:[O,i,y,e.C_BLOCK_COMMENT_MODE,u,d,v]
},x={relevance:0,
match:[/\b/,t.concat("(?!fn\\b|function\\b|",g(h).join("\\b|"),"|",g(f).join("\\b|"),"\\b)"),r,t.concat(c,"*"),t.lookahead(/(?=\()/)],
scope:{3:"title.function.invoke"},contains:[w]};w.contains.push(x)
;const k=[O,y,e.C_BLOCK_COMMENT_MODE,u,d,v],S={
begin:t.concat(/#\[\s*\\?/,t.either(o,a)),beginScope:"meta",end:/]/,
endScope:"meta",keywords:{literal:p,keyword:["new","array"]},contains:[{
begin:/\[/,end:/]/,keywords:{literal:p,keyword:["new","array"]},
contains:["self",...k]},...k,{scope:"meta",variants:[{match:o},{match:a}]}]}
;return{case_insensitive:!1,keywords:m,
contains:[S,e.HASH_COMMENT_MODE,e.COMMENT("//","$"),e.COMMENT("/\\*","\\*/",{
contains:[{scope:"doctag",match:"@[A-Za-z]+"}]}),{match:/__halt_compiler\(\);/,
keywords:"__halt_compiler",starts:{scope:"comment",end:e.MATCH_NOTHING_RE,
contains:[{match:/\?>/,scope:"meta",endsParent:!0}]}},{scope:"meta",variants:[{
begin:/<\?php/,relevance:10},{begin:/<\?=/},{begin:/<\?/,relevance:.1},{
begin:/\?>/}]},{scope:"variable.language",match:/\$this\b/},i,x,y,{
match:[/const/,/\s/,r],scope:{1:"keyword",3:"variable.constant"}},v,{
scope:"function",relevance:0,beginKeywords:"fn function",end:/[;{]/,
excludeEnd:!0,illegal:"[$%\\[]",contains:[{beginKeywords:"use"
},e.UNDERSCORE_TITLE_MODE,{begin:"=>",endsParent:!0},{scope:"params",
begin:"\\(",end:"\\)",excludeBegin:!0,excludeEnd:!0,keywords:m,
contains:["self",S,i,y,e.C_BLOCK_COMMENT_MODE,u,d]}]},{scope:"class",variants:[{
beginKeywords:"enum",illegal:/[($"]/},{beginKeywords:"class interface trait",
illegal:/[:($"]/}],relevance:0,end:/\{/,excludeEnd:!0,contains:[{
beginKeywords:"extends implements"},e.UNDERSCORE_TITLE_MODE]},{
beginKeywords:"namespace",relevance:0,end:";",illegal:/[.']/,
contains:[e.inherit(e.UNDERSCORE_TITLE_MODE,{scope:"title.class"})]},{
beginKeywords:"use",relevance:0,end:";",contains:[{
match:/\b(as|const|function)\b/,scope:"keyword"},e.UNDERSCORE_TITLE_MODE]},u,d]}
},plaintext:function(e){return{name:"Plain text",aliases:["text","txt"],
disableAutodetect:!0}},powershell:function(e){const t={
$pattern:/-?[A-z\.\-]+\b/,
keyword:"if else foreach return do while until elseif begin for trap data dynamicparam end break throw param continue finally in switch exit filter try process catch hidden static parameter",
built_in:"ac asnp cat cd CFS chdir clc clear clhy cli clp cls clv cnsn compare copy cp cpi cpp curl cvpa dbp del diff dir dnsn ebp echo|0 epal epcsv epsn erase etsn exsn fc fhx fl ft fw gal gbp gc gcb gci gcm gcs gdr gerr ghy gi gin gjb gl gm gmo gp gps gpv group gsn gsnp gsv gtz gu gv gwmi h history icm iex ihy ii ipal ipcsv ipmo ipsn irm ise iwmi iwr kill lp ls man md measure mi mount move mp mv nal ndr ni nmo npssc nsn nv ogv oh popd ps pushd pwd r rbp rcjb rcsn rd rdr ren ri rjb rm rmdir rmo rni rnp rp rsn rsnp rujb rv rvpa rwmi sajb sal saps sasv sbp sc scb select set shcm si sl sleep sls sort sp spjb spps spsv start stz sujb sv swmi tee trcm type wget where wjb write"
},n={begin:"`[\\s\\S]",relevance:0},r={className:"variable",variants:[{
begin:/\$\B/},{className:"keyword",begin:/\$this/},{begin:/\$[\w\d][\w\d_:]*/}]
},o={className:"string",variants:[{begin:/"/,end:/"/},{begin:/@"/,end:/^"@/}],
contains:[n,r,{className:"variable",begin:/\$[A-z]/,end:/[^A-z]/}]},a={
className:"string",variants:[{begin:/'/,end:/'/},{begin:/@'/,end:/^'@/}]
},i=e.inherit(e.COMMENT(null,null),{variants:[{begin:/#/,end:/$/},{begin:/<#/,
end:/#>/}],contains:[{className:"doctag",variants:[{
begin:/\.(synopsis|description|example|inputs|outputs|notes|link|component|role|functionality)/
},{
begin:/\.(parameter|forwardhelptargetname|forwardhelpcategory|remotehelprunspace|externalhelp)\s+\S+/
}]}]}),s={className:"built_in",variants:[{
begin:"(".concat("Add|Clear|Close|Copy|Enter|Exit|Find|Format|Get|Hide|Join|Lock|Move|New|Open|Optimize|Pop|Push|Redo|Remove|Rename|Reset|Resize|Search|Select|Set|Show|Skip|Split|Step|Switch|Undo|Unlock|Watch|Backup|Checkpoint|Compare|Compress|Convert|ConvertFrom|ConvertTo|Dismount|Edit|Expand|Export|Group|Import|Initialize|Limit|Merge|Mount|Out|Publish|Restore|Save|Sync|Unpublish|Update|Approve|Assert|Build|Complete|Confirm|Deny|Deploy|Disable|Enable|Install|Invoke|Register|Request|Restart|Resume|Start|Stop|Submit|Suspend|Uninstall|Unregister|Wait|Debug|Measure|Ping|Repair|Resolve|Test|Trace|Connect|Disconnect|Read|Receive|Send|Write|Block|Grant|Protect|Revoke|Unblock|Unprotect|Use|ForEach|Sort|Tee|Where",")+(-)[\\w\\d]+")
}]},l={className:"class",beginKeywords:"class enum",end:/\s*[{]/,excludeEnd:!0,
relevance:0,contains:[e.TITLE_MODE]},c={className:"function",
begin:/function\s+/,end:/\s*\{|$/,excludeEnd:!0,returnBegin:!0,relevance:0,
contains:[{begin:"function",relevance:0,className:"keyword"},{className:"title",
begin:/\w[\w\d]*((-)[\w\d]+)*/,relevance:0},{begin:/\(/,end:/\)/,
className:"params",relevance:0,contains:[r]}]},u={begin:/using\s/,end:/$/,
returnBegin:!0,contains:[o,a,{className:"keyword",
begin:/(using|assembly|command|module|namespace|type)/}]},d={variants:[{
className:"operator",
begin:"(".concat("-and|-as|-band|-bnot|-bor|-bxor|-casesensitive|-ccontains|-ceq|-cge|-cgt|-cle|-clike|-clt|-cmatch|-cne|-cnotcontains|-cnotlike|-cnotmatch|-contains|-creplace|-csplit|-eq|-exact|-f|-file|-ge|-gt|-icontains|-ieq|-ige|-igt|-ile|-ilike|-ilt|-imatch|-in|-ine|-inotcontains|-inotlike|-inotmatch|-ireplace|-is|-isnot|-isplit|-join|-le|-like|-lt|-match|-ne|-not|-notcontains|-notin|-notlike|-notmatch|-or|-regex|-replace|-shl|-shr|-split|-wildcard|-xor",")\\b")
},{className:"literal",begin:/(-){1,2}[\w\d-]+/,relevance:0}]},p={
className:"function",begin:/\[.*\]\s*[\w]+[ ]??\(/,end:/$/,returnBegin:!0,
relevance:0,contains:[{className:"keyword",
begin:"(".concat(t.keyword.toString().replace(/\s/g,"|"),")\\b"),endsParent:!0,
relevance:0},e.inherit(e.TITLE_MODE,{endsParent:!0})]
},h=[p,i,n,e.NUMBER_MODE,o,a,s,r,{className:"literal",
begin:/\$(null|true|false)\b/},{className:"selector-tag",begin:/@\B/,relevance:0
}],f={begin:/\[/,end:/\]/,excludeBegin:!0,excludeEnd:!0,relevance:0,
contains:[].concat("self",h,{
begin:"("+["string","char","byte","int","long","bool","decimal","single","double","DateTime","xml","array","hashtable","void"].join("|")+")",
className:"built_in",relevance:0},{className:"type",begin:/[\.\w\d]+/,
relevance:0})};return p.contains.unshift(f),{name:"PowerShell",
aliases:["pwsh","ps","ps1"],case_insensitive:!0,keywords:t,
contains:h.concat(l,c,u,d,f)}},properties:function(e){
const t="[ \\t\\f]*",n=t+"[:=]"+t,r="[ \\t\\f]+",o="([^\\\\:= \\t\\f\\n]|\\\\.)+",a={
end:"("+n+"|"+r+")",relevance:0,starts:{className:"string",end:/$/,relevance:0,
contains:[{begin:"\\\\\\\\"},{begin:"\\\\\\n"}]}};return{name:".properties",
disableAutodetect:!0,case_insensitive:!0,illegal:/\S/,
contains:[e.COMMENT("^\\s*[!#]","$"),{returnBegin:!0,variants:[{begin:o+n},{
begin:o+r}],contains:[{className:"attr",begin:o,endsParent:!0}],starts:a},{
className:"attr",begin:o+t+"$"}]}},python:function(e){
const t=e.regex,n=new RegExp("[\\p{XID_Start}_]\\p{XID_Continue}*","u"),r=["and","as","assert","async","await","break","case","class","continue","def","del","elif","else","except","finally","for","from","global","if","import","in","is","lambda","match","nonlocal|10","not","or","pass","raise","return","try","while","with","yield"],o={
$pattern:/[A-Za-z]\w+|__\w+__/,keyword:r,
built_in:["__import__","abs","all","any","ascii","bin","bool","breakpoint","bytearray","bytes","callable","chr","classmethod","compile","complex","delattr","dict","dir","divmod","enumerate","eval","exec","filter","float","format","frozenset","getattr","globals","hasattr","hash","help","hex","id","input","int","isinstance","issubclass","iter","len","list","locals","map","max","memoryview","min","next","object","oct","open","ord","pow","print","property","range","repr","reversed","round","set","setattr","slice","sorted","staticmethod","str","sum","super","tuple","type","vars","zip"],
literal:["__debug__","Ellipsis","False","None","NotImplemented","True"],
type:["Any","Callable","Coroutine","Dict","List","Literal","Generic","Optional","Sequence","Set","Tuple","Type","Union"]
},a={className:"meta",begin:/^(>>>|\.\.\.) /},i={className:"subst",begin:/\{/,
end:/\}/,keywords:o,illegal:/#/},s={begin:/\{\{/,relevance:0},l={
className:"string",contains:[e.BACKSLASH_ESCAPE],variants:[{
begin:/([uU]|[bB]|[rR]|[bB][rR]|[rR][bB])?'''/,end:/'''/,
contains:[e.BACKSLASH_ESCAPE,a],relevance:10},{
begin:/([uU]|[bB]|[rR]|[bB][rR]|[rR][bB])?"""/,end:/"""/,
contains:[e.BACKSLASH_ESCAPE,a],relevance:10},{
begin:/([fF][rR]|[rR][fF]|[fF])'''/,end:/'''/,
contains:[e.BACKSLASH_ESCAPE,a,s,i]},{begin:/([fF][rR]|[rR][fF]|[fF])"""/,
end:/"""/,contains:[e.BACKSLASH_ESCAPE,a,s,i]},{begin:/([uU]|[rR])'/,end:/'/,
relevance:10},{begin:/([uU]|[rR])"/,end:/"/,relevance:10},{
begin:/([bB]|[bB][rR]|[rR][bB])'/,end:/'/},{begin:/([bB]|[bB][rR]|[rR][bB])"/,
end:/"/},{begin:/([fF][rR]|[rR][fF]|[fF])'/,end:/'/,
contains:[e.BACKSLASH_ESCAPE,s,i]},{begin:/([fF][rR]|[rR][fF]|[fF])"/,end:/"/,
contains:[e.BACKSLASH_ESCAPE,s,i]},e.APOS_STRING_MODE,e.QUOTE_STRING_MODE]
},c="[0-9](_?[0-9])*",u=`(\\b(${c}))?\\.(${c})|\\b(${c})\\.`,d=`\\b|${r.join("|")}`,p={
className:"number",relevance:0,variants:[{
begin:`(\\b(${c})|(${u}))[eE][+-]?(${c})[jJ]?(?=${d})`},{begin:`(${u})[jJ]?`},{
begin:`\\b([1-9](_?[0-9])*|0+(_?0)*)[lLjJ]?(?=${d})`},{
begin:`\\b0[bB](_?[01])+[lL]?(?=${d})`},{begin:`\\b0[oO](_?[0-7])+[lL]?(?=${d})`
},{begin:`\\b0[xX](_?[0-9a-fA-F])+[lL]?(?=${d})`},{begin:`\\b(${c})[jJ](?=${d})`
}]},h={className:"comment",begin:t.lookahead(/# type:/),end:/$/,keywords:o,
contains:[{begin:/# type:/},{begin:/#/,end:/\b\B/,endsWithParent:!0}]},f={
className:"params",variants:[{className:"",begin:/\(\s*\)/,skip:!0},{begin:/\(/,
end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:o,
contains:["self",a,p,l,e.HASH_COMMENT_MODE]}]};return i.contains=[l,p,a],{
name:"Python",aliases:["py","gyp","ipython"],unicodeRegex:!0,keywords:o,
illegal:/(<\/|\?)|=>/,contains:[a,p,{scope:"variable.language",match:/\bself\b/
},{beginKeywords:"if",relevance:0},{match:/\bor\b/,scope:"keyword"
},l,h,e.HASH_COMMENT_MODE,{match:[/\bdef/,/\s+/,n],scope:{1:"keyword",
3:"title.function"},contains:[f]},{variants:[{
match:[/\bclass/,/\s+/,n,/\s*/,/\(\s*/,n,/\s*\)/]},{match:[/\bclass/,/\s+/,n]}],
scope:{1:"keyword",3:"title.class",6:"title.class.inherited"}},{
className:"meta",begin:/^[\t ]*@/,end:/(?=#)|$/,contains:[p,f,l]}]}},
r:function(e){
const t=e.regex,n=/(?:(?:[a-zA-Z]|\.[._a-zA-Z])[._a-zA-Z0-9]*)|\.(?!\d)/,r=t.either(/0[xX][0-9a-fA-F]+\.[0-9a-fA-F]*[pP][+-]?\d+i?/,/0[xX][0-9a-fA-F]+(?:[pP][+-]?\d+)?[Li]?/,/(?:\d+(?:\.\d*)?|\.\d+)(?:[eE][+-]?\d+)?[Li]?/),o=/[=!<>:]=|\|\||&&|:::?|<-|<<-|->>|->|\|>|[-+*\/?!$&|:<=>@^~]|\*\*/,a=t.either(/[()]/,/[{}]/,/\[\[/,/[[\]]/,/\\/,/,/)
;return{name:"R",keywords:{$pattern:n,
keyword:"function if in break next repeat else for while",
literal:"NULL NA TRUE FALSE Inf NaN NA_integer_|10 NA_real_|10 NA_character_|10 NA_complex_|10",
built_in:"LETTERS letters month.abb month.name pi T F abs acos acosh all any anyNA Arg as.call as.character as.complex as.double as.environment as.integer as.logical as.null.default as.numeric as.raw asin asinh atan atanh attr attributes baseenv browser c call ceiling class Conj cos cosh cospi cummax cummin cumprod cumsum digamma dim dimnames emptyenv exp expression floor forceAndCall gamma gc.time globalenv Im interactive invisible is.array is.atomic is.call is.character is.complex is.double is.environment is.expression is.finite is.function is.infinite is.integer is.language is.list is.logical is.matrix is.na is.name is.nan is.null is.numeric is.object is.pairlist is.raw is.recursive is.single is.symbol lazyLoadDBfetch length lgamma list log max min missing Mod names nargs nzchar oldClass on.exit pos.to.env proc.time prod quote range Re rep retracemem return round seq_along seq_len seq.int sign signif sin sinh sinpi sqrt standardGeneric substitute sum switch tan tanh tanpi tracemem trigamma trunc unclass untracemem UseMethod xtfrm"
},contains:[e.COMMENT(/#'/,/$/,{contains:[{scope:"doctag",match:/@examples/,
starts:{end:t.lookahead(t.either(/\n^#'\s*(?=@[a-zA-Z]+)/,/\n^(?!#')/)),
endsParent:!0}},{scope:"doctag",begin:"@param",end:/$/,contains:[{
scope:"variable",variants:[{match:n},{match:/`(?:\\.|[^`\\])+`/}],endsParent:!0
}]},{scope:"doctag",match:/@[a-zA-Z]+/},{scope:"keyword",match:/\\[a-zA-Z]+/}]
}),e.HASH_COMMENT_MODE,{scope:"string",contains:[e.BACKSLASH_ESCAPE],
variants:[e.END_SAME_AS_BEGIN({begin:/[rR]"(-*)\(/,end:/\)(-*)"/
}),e.END_SAME_AS_BEGIN({begin:/[rR]"(-*)\{/,end:/\}(-*)"/
}),e.END_SAME_AS_BEGIN({begin:/[rR]"(-*)\[/,end:/\](-*)"/
}),e.END_SAME_AS_BEGIN({begin:/[rR]'(-*)\(/,end:/\)(-*)'/
}),e.END_SAME_AS_BEGIN({begin:/[rR]'(-*)\{/,end:/\}(-*)'/
}),e.END_SAME_AS_BEGIN({begin:/[rR]'(-*)\[/,end:/\](-*)'/}),{begin:'"',end:'"',
relevance:0},{begin:"'",end:"'",relevance:0}]},{relevance:0,variants:[{scope:{
1:"operator",2:"number"},match:[o,r]},{scope:{1:"operator",2:"number"},
match:[/%[^%]*%/,r]},{scope:{1:"punctuation",2:"number"},match:[a,r]},{scope:{
2:"number"},match:[/[^a-zA-Z0-9._]|^/,r]}]},{scope:{3:"operator"},
match:[n,/\s+/,/<-/,/\s+/]},{scope:"operator",relevance:0,variants:[{match:o},{
match:/%[^%]*%/}]},{scope:"punctuation",relevance:0,match:a},{begin:"`",end:"`",
contains:[{begin:/\\./}]}]}},ruby:function(e){
const t=e.regex,n="([a-zA-Z_]\\w*[!?=]?|[-+~]@|<<|>>|=~|===?|<=>|[<>]=?|\\*\\*|[-/+%^&*~`|]|\\[\\]=?)",r=t.either(/\b([A-Z]+[a-z0-9]+)+/,/\b([A-Z]+[a-z0-9]+)+[A-Z]+/),o=t.concat(r,/(::\w+)*/),a={
"variable.constant":["__FILE__","__LINE__","__ENCODING__"],
"variable.language":["self","super"],
keyword:["alias","and","begin","BEGIN","break","case","class","defined","do","else","elsif","end","END","ensure","for","if","in","module","next","not","or","redo","require","rescue","retry","return","then","undef","unless","until","when","while","yield","include","extend","prepend","public","private","protected","raise","throw"],
built_in:["proc","lambda","attr_accessor","attr_reader","attr_writer","define_method","private_constant","module_function"],
literal:["true","false","nil"]},i={className:"doctag",begin:"@[A-Za-z]+"},s={
begin:"#<",end:">"},l=[e.COMMENT("#","$",{contains:[i]
}),e.COMMENT("^=begin","^=end",{contains:[i],relevance:10
}),e.COMMENT("^__END__",e.MATCH_NOTHING_RE)],c={className:"subst",begin:/#\{/,
end:/\}/,keywords:a},u={className:"string",contains:[e.BACKSLASH_ESCAPE,c],
variants:[{begin:/'/,end:/'/},{begin:/"/,end:/"/},{begin:/`/,end:/`/},{
begin:/%[qQwWx]?\(/,end:/\)/},{begin:/%[qQwWx]?\[/,end:/\]/},{
begin:/%[qQwWx]?\{/,end:/\}/},{begin:/%[qQwWx]?</,end:/>/},{begin:/%[qQwWx]?\//,
end:/\//},{begin:/%[qQwWx]?%/,end:/%/},{begin:/%[qQwWx]?-/,end:/-/},{
begin:/%[qQwWx]?\|/,end:/\|/},{begin:/\B\?(\\\d{1,3})/},{
begin:/\B\?(\\x[A-Fa-f0-9]{1,2})/},{begin:/\B\?(\\u\{?[A-Fa-f0-9]{1,6}\}?)/},{
begin:/\B\?(\\M-\\C-|\\M-\\c|\\c\\M-|\\M-|\\C-\\M-)[\x20-\x7e]/},{
begin:/\B\?\\(c|C-)[\x20-\x7e]/},{begin:/\B\?\\?\S/},{
begin:t.concat(/<<[-~]?'?/,t.lookahead(/(\w+)(?=\W)[^\n]*\n(?:[^\n]*\n)*?\s*\1\b/)),
contains:[e.END_SAME_AS_BEGIN({begin:/(\w+)/,end:/(\w+)/,
contains:[e.BACKSLASH_ESCAPE,c]})]}]},d="[0-9](_?[0-9])*",p={className:"number",
relevance:0,variants:[{
begin:`\\b([1-9](_?[0-9])*|0)(\\.(${d}))?([eE][+-]?(${d})|r)?i?\\b`},{
begin:"\\b0[dD][0-9](_?[0-9])*r?i?\\b"},{begin:"\\b0[bB][0-1](_?[0-1])*r?i?\\b"
},{begin:"\\b0[oO][0-7](_?[0-7])*r?i?\\b"},{
begin:"\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*r?i?\\b"},{
begin:"\\b0(_?[0-7])+r?i?\\b"}]},h={variants:[{match:/\(\)/},{
className:"params",begin:/\(/,end:/(?=\))/,excludeBegin:!0,endsParent:!0,
keywords:a}]},f=[u,{variants:[{match:[/class\s+/,o,/\s+<\s+/,o]},{
match:[/\b(class|module)\s+/,o]}],scope:{2:"title.class",
4:"title.class.inherited"},keywords:a},{match:[/(include|extend)\s+/,o],scope:{
2:"title.class"},keywords:a},{relevance:0,match:[o,/\.new[. (]/],scope:{
1:"title.class"}},{relevance:0,match:/\b[A-Z][A-Z_0-9]+\b/,
className:"variable.constant"},{relevance:0,match:r,scope:"title.class"},{
match:[/def/,/\s+/,n],scope:{1:"keyword",3:"title.function"},contains:[h]},{
begin:e.IDENT_RE+"::"},{className:"symbol",
begin:e.UNDERSCORE_IDENT_RE+"(!|\\?)?:",relevance:0},{className:"symbol",
begin:":(?!\\s)",contains:[u,{begin:n}],relevance:0},p,{className:"variable",
begin:"(\\$\\W)|((\\$|@@?)(\\w+))(?=[^@$?])(?![A-Za-z])(?![@$?'])"},{
className:"params",begin:/\|(?!=)/,end:/\|/,excludeBegin:!0,excludeEnd:!0,
relevance:0,keywords:a},{begin:"("+e.RE_STARTERS_RE+"|unless)\\s*",
keywords:"unless",contains:[{className:"regexp",contains:[e.BACKSLASH_ESCAPE,c],
illegal:/\n/,variants:[{begin:"/",end:"/[a-z]*"},{begin:/%r\{/,end:/\}[a-z]*/},{
begin:"%r\\(",end:"\\)[a-z]*"},{begin:"%r!",end:"![a-z]*"},{begin:"%r\\[",
end:"\\][a-z]*"}]}].concat(s,l),relevance:0}].concat(s,l)
;c.contains=f,h.contains=f;const m=[{begin:/^\s*=>/,starts:{end:"$",contains:f}
},{className:"meta.prompt",
begin:"^([>?]>|[\\w#]+\\(\\w+\\):\\d+:\\d+[>*]|(\\w+-)?\\d+\\.\\d+\\.\\d+(p\\d+)?[^\\d][^>]+>)(?=[ ])",
starts:{end:"$",keywords:a,contains:f}}];return l.unshift(s),{name:"Ruby",
aliases:["rb","gemspec","podspec","thor","irb"],keywords:a,illegal:/\/\*/,
contains:[e.SHEBANG({binary:"ruby"})].concat(m).concat(l).concat(f)}},
rust:function(e){
const t=e.regex,n=/(r#)?/,r=t.concat(n,e.UNDERSCORE_IDENT_RE),o=t.concat(n,e.IDENT_RE),a={
className:"title.function.invoke",relevance:0,
begin:t.concat(/\b/,/(?!let|for|while|if|else|match\b)/,o,t.lookahead(/\s*\(/))
},i="([ui](8|16|32|64|128|size)|f(32|64))?",s=["drop ","Copy","Send","Sized","Sync","Drop","Fn","FnMut","FnOnce","ToOwned","Clone","Debug","PartialEq","PartialOrd","Eq","Ord","AsRef","AsMut","Into","From","Default","Iterator","Extend","IntoIterator","DoubleEndedIterator","ExactSizeIterator","SliceConcatExt","ToString","assert!","assert_eq!","bitflags!","bytes!","cfg!","col!","concat!","concat_idents!","debug_assert!","debug_assert_eq!","env!","eprintln!","panic!","file!","format!","format_args!","include_bytes!","include_str!","line!","local_data_key!","module_path!","option_env!","print!","println!","select!","stringify!","try!","unimplemented!","unreachable!","vec!","write!","writeln!","macro_rules!","assert_ne!","debug_assert_ne!"],l=["i8","i16","i32","i64","i128","isize","u8","u16","u32","u64","u128","usize","f32","f64","str","char","bool","Box","Option","Result","String","Vec"]
;return{name:"Rust",aliases:["rs"],keywords:{$pattern:e.IDENT_RE+"!?",type:l,
keyword:["abstract","as","async","await","become","box","break","const","continue","crate","do","dyn","else","enum","extern","false","final","fn","for","if","impl","in","let","loop","macro","match","mod","move","mut","override","priv","pub","ref","return","self","Self","static","struct","super","trait","true","try","type","typeof","union","unsafe","unsized","use","virtual","where","while","yield"],
literal:["true","false","Some","None","Ok","Err"],built_in:s},illegal:"</",
contains:[e.C_LINE_COMMENT_MODE,e.COMMENT("/\\*","\\*/",{contains:["self"]
}),e.inherit(e.QUOTE_STRING_MODE,{begin:/b?"/,illegal:null}),{
className:"symbol",begin:/'[a-zA-Z_][a-zA-Z0-9_]*(?!')/},{scope:"string",
variants:[{begin:/b?r(#*)"(.|\n)*?"\1(?!#)/},{begin:/b?'/,end:/'/,contains:[{
scope:"char.escape",match:/\\('|\w|x\w{2}|u\w{4}|U\w{8})/}]}]},{
className:"number",variants:[{begin:"\\b0b([01_]+)"+i},{begin:"\\b0o([0-7_]+)"+i
},{begin:"\\b0x([A-Fa-f0-9_]+)"+i},{
begin:"\\b(\\d[\\d_]*(\\.[0-9_]+)?([eE][+-]?[0-9_]+)?)"+i}],relevance:0},{
begin:[/fn/,/\s+/,r],className:{1:"keyword",3:"title.function"}},{
className:"meta",begin:"#!?\\[",end:"\\]",contains:[{className:"string",
begin:/"/,end:/"/,contains:[e.BACKSLASH_ESCAPE]}]},{
begin:[/let/,/\s+/,/(?:mut\s+)?/,r],className:{1:"keyword",3:"keyword",
4:"variable"}},{begin:[/for/,/\s+/,r,/\s+/,/in/],className:{1:"keyword",
3:"variable",5:"keyword"}},{begin:[/type/,/\s+/,r],className:{1:"keyword",
3:"title.class"}},{begin:[/(?:trait|enum|struct|union|impl|for)/,/\s+/,r],
className:{1:"keyword",3:"title.class"}},{begin:e.IDENT_RE+"::",keywords:{
keyword:"Self",built_in:s,type:l}},{className:"punctuation",begin:"->"},a]}},
scala:function(e){const t=e.regex,n={className:"subst",variants:[{
begin:"\\$[A-Za-z0-9_]+"},{begin:/\$\{/,end:/\}/}]},r={className:"string",
variants:[{begin:'"""',end:'"""'},{begin:'"',end:'"',illegal:"\\n",
contains:[e.BACKSLASH_ESCAPE]},{begin:'[a-z]+"',end:'"',illegal:"\\n",
contains:[e.BACKSLASH_ESCAPE,n]},{className:"string",begin:'[a-z]+"""',
end:'"""',contains:[n],relevance:10}]},o={className:"type",
begin:"\\b[A-Z][A-Za-z0-9_]*",relevance:0},a={className:"title",
begin:/[^0-9\n\t "'(),.`{}\[\]:;][^\n\t "'(),.`{}\[\]:;]+|[^0-9\n\t "'(),.`{}\[\]:;=]/,
relevance:0},i={className:"class",beginKeywords:"class object trait type",
end:/[:={\[\n;]/,excludeEnd:!0,
contains:[e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,{
beginKeywords:"extends with",relevance:10},{begin:/\[/,end:/\]/,excludeBegin:!0,
excludeEnd:!0,relevance:0,
contains:[o,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{className:"params",
begin:/\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,relevance:0,
contains:[o,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},a]},s={
className:"function",beginKeywords:"def",end:t.lookahead(/[:={\[(\n;]/),
contains:[a]};return{name:"Scala",keywords:{literal:"true false null",
keyword:"type yield lazy override def with val var sealed abstract private trait object if then forSome for while do throw finally protected extends import final return else break new catch super class case package default try this match continue throws implicit export enum given transparent"
},contains:[{begin:["//>",/\s+/,/using/,/\s+/,/\S+/],beginScope:{1:"comment",
3:"keyword",5:"type"},end:/$/,contains:[{className:"string",begin:/\S+/}]
},e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,r,o,s,i,e.C_NUMBER_MODE,{
begin:[/^\s*/,"extension",/\s+(?=[[(])/],beginScope:{2:"keyword"}},{
begin:[/^\s*/,/end/,/\s+/,/(extension\b)?/],beginScope:{2:"keyword",4:"keyword"}
},{match:/\.inline\b/},{begin:/\binline(?=\s)/,keywords:"inline"},{
begin:[/\(\s*/,/using/,/\s+(?!\))/],beginScope:{2:"keyword"}},{className:"meta",
begin:"@[A-Za-z]+"}]}},scss:function(e){const t=(e=>({IMPORTANT:{scope:"meta",
begin:"!important"},BLOCK_COMMENT:e.C_BLOCK_COMMENT_MODE,HEXCOLOR:{
scope:"number",begin:/#(([0-9a-fA-F]{3,4})|(([0-9a-fA-F]{2}){3,4}))\b/},
FUNCTION_DISPATCH:{className:"built_in",begin:/[\w-]+(?=\()/},
ATTRIBUTE_SELECTOR_MODE:{scope:"selector-attr",begin:/\[/,end:/\]/,illegal:"$",
contains:[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE]},CSS_NUMBER_MODE:{
scope:"number",
begin:e.NUMBER_RE+"(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",
relevance:0},CSS_VARIABLE:{className:"attr",begin:/--[A-Za-z_][A-Za-z0-9_-]*/}
}))(e),n=mB,r=fB,o="@[a-z-]+",a={className:"variable",
begin:"(\\$[a-zA-Z-][a-zA-Z0-9_-]*)\\b",relevance:0};return{name:"SCSS",
case_insensitive:!0,illegal:"[=/|']",
contains:[e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,t.CSS_NUMBER_MODE,{
className:"selector-id",begin:"#[A-Za-z0-9_-]+",relevance:0},{
className:"selector-class",begin:"\\.[A-Za-z0-9_-]+",relevance:0
},t.ATTRIBUTE_SELECTOR_MODE,{className:"selector-tag",
begin:"\\b("+pB.join("|")+")\\b",relevance:0},{className:"selector-pseudo",
begin:":("+r.join("|")+")"},{className:"selector-pseudo",
begin:":(:)?("+n.join("|")+")"},a,{begin:/\(/,end:/\)/,
contains:[t.CSS_NUMBER_MODE]},t.CSS_VARIABLE,{className:"attribute",
begin:"\\b("+gB.join("|")+")\\b"},{
begin:"\\b(whitespace|wait|w-resize|visible|vertical-text|vertical-ideographic|uppercase|upper-roman|upper-alpha|underline|transparent|top|thin|thick|text|text-top|text-bottom|tb-rl|table-header-group|table-footer-group|sw-resize|super|strict|static|square|solid|small-caps|separate|se-resize|scroll|s-resize|rtl|row-resize|ridge|right|repeat|repeat-y|repeat-x|relative|progress|pointer|overline|outside|outset|oblique|nowrap|not-allowed|normal|none|nw-resize|no-repeat|no-drop|newspaper|ne-resize|n-resize|move|middle|medium|ltr|lr-tb|lowercase|lower-roman|lower-alpha|loose|list-item|line|line-through|line-edge|lighter|left|keep-all|justify|italic|inter-word|inter-ideograph|inside|inset|inline|inline-block|inherit|inactive|ideograph-space|ideograph-parenthesis|ideograph-numeric|ideograph-alpha|horizontal|hidden|help|hand|groove|fixed|ellipsis|e-resize|double|dotted|distribute|distribute-space|distribute-letter|distribute-all-lines|disc|disabled|default|decimal|dashed|crosshair|collapse|col-resize|circle|char|center|capitalize|break-word|break-all|bottom|both|bolder|bold|block|bidi-override|below|baseline|auto|always|all-scroll|absolute|table|table-cell)\\b"
},{begin:/:/,end:/[;}{]/,relevance:0,
contains:[t.BLOCK_COMMENT,a,t.HEXCOLOR,t.CSS_NUMBER_MODE,e.QUOTE_STRING_MODE,e.APOS_STRING_MODE,t.IMPORTANT,t.FUNCTION_DISPATCH]
},{begin:"@(page|font-face)",keywords:{$pattern:o,keyword:"@page @font-face"}},{
begin:"@",end:"[{;]",returnBegin:!0,keywords:{$pattern:/[a-z-]+/,
keyword:"and or not only",attribute:hB.join(" ")},contains:[{begin:o,
className:"keyword"},{begin:/[a-z-]+(?=:)/,className:"attribute"
},a,e.QUOTE_STRING_MODE,e.APOS_STRING_MODE,t.HEXCOLOR,t.CSS_NUMBER_MODE]
},t.FUNCTION_DISPATCH]}},shell:function(e){return{name:"Shell Session",
aliases:["console","shellsession"],contains:[{className:"meta.prompt",
begin:/^\s{0,3}[/~\w\d[\]()@-]*[>%$#][ ]?/,starts:{end:/[^\\](?=\s*$)/,
subLanguage:"bash"}}]}},sql:function(e){
const t=e.regex,n=e.COMMENT("--","$"),r=["abs","acos","array_agg","asin","atan","avg","cast","ceil","ceiling","coalesce","corr","cos","cosh","count","covar_pop","covar_samp","cume_dist","dense_rank","deref","element","exp","extract","first_value","floor","json_array","json_arrayagg","json_exists","json_object","json_objectagg","json_query","json_table","json_table_primitive","json_value","lag","last_value","lead","listagg","ln","log","log10","lower","max","min","mod","nth_value","ntile","nullif","percent_rank","percentile_cont","percentile_disc","position","position_regex","power","rank","regr_avgx","regr_avgy","regr_count","regr_intercept","regr_r2","regr_slope","regr_sxx","regr_sxy","regr_syy","row_number","sin","sinh","sqrt","stddev_pop","stddev_samp","substring","substring_regex","sum","tan","tanh","translate","translate_regex","treat","trim","trim_array","unnest","upper","value_of","var_pop","var_samp","width_bucket"],o=r,a=["abs","acos","all","allocate","alter","and","any","are","array","array_agg","array_max_cardinality","as","asensitive","asin","asymmetric","at","atan","atomic","authorization","avg","begin","begin_frame","begin_partition","between","bigint","binary","blob","boolean","both","by","call","called","cardinality","cascaded","case","cast","ceil","ceiling","char","char_length","character","character_length","check","classifier","clob","close","coalesce","collate","collect","column","commit","condition","connect","constraint","contains","convert","copy","corr","corresponding","cos","cosh","count","covar_pop","covar_samp","create","cross","cube","cume_dist","current","current_catalog","current_date","current_default_transform_group","current_path","current_role","current_row","current_schema","current_time","current_timestamp","current_path","current_role","current_transform_group_for_type","current_user","cursor","cycle","date","day","deallocate","dec","decimal","decfloat","declare","default","define","delete","dense_rank","deref","describe","deterministic","disconnect","distinct","double","drop","dynamic","each","element","else","empty","end","end_frame","end_partition","end-exec","equals","escape","every","except","exec","execute","exists","exp","external","extract","false","fetch","filter","first_value","float","floor","for","foreign","frame_row","free","from","full","function","fusion","get","global","grant","group","grouping","groups","having","hold","hour","identity","in","indicator","initial","inner","inout","insensitive","insert","int","integer","intersect","intersection","interval","into","is","join","json_array","json_arrayagg","json_exists","json_object","json_objectagg","json_query","json_table","json_table_primitive","json_value","lag","language","large","last_value","lateral","lead","leading","left","like","like_regex","listagg","ln","local","localtime","localtimestamp","log","log10","lower","match","match_number","match_recognize","matches","max","member","merge","method","min","minute","mod","modifies","module","month","multiset","national","natural","nchar","nclob","new","no","none","normalize","not","nth_value","ntile","null","nullif","numeric","octet_length","occurrences_regex","of","offset","old","omit","on","one","only","open","or","order","out","outer","over","overlaps","overlay","parameter","partition","pattern","per","percent","percent_rank","percentile_cont","percentile_disc","period","portion","position","position_regex","power","precedes","precision","prepare","primary","procedure","ptf","range","rank","reads","real","recursive","ref","references","referencing","regr_avgx","regr_avgy","regr_count","regr_intercept","regr_r2","regr_slope","regr_sxx","regr_sxy","regr_syy","release","result","return","returns","revoke","right","rollback","rollup","row","row_number","rows","running","savepoint","scope","scroll","search","second","seek","select","sensitive","session_user","set","show","similar","sin","sinh","skip","smallint","some","specific","specifictype","sql","sqlexception","sqlstate","sqlwarning","sqrt","start","static","stddev_pop","stddev_samp","submultiset","subset","substring","substring_regex","succeeds","sum","symmetric","system","system_time","system_user","table","tablesample","tan","tanh","then","time","timestamp","timezone_hour","timezone_minute","to","trailing","translate","translate_regex","translation","treat","trigger","trim","trim_array","true","truncate","uescape","union","unique","unknown","unnest","update","upper","user","using","value","values","value_of","var_pop","var_samp","varbinary","varchar","varying","versioning","when","whenever","where","width_bucket","window","with","within","without","year","add","asc","collation","desc","final","first","last","view"].filter((e=>!r.includes(e))),i={
match:t.concat(/\b/,t.either(...o),/\s*\(/),relevance:0,keywords:{built_in:o}}
;function s(e){
return t.concat(/\b/,t.either(...e.map((e=>e.replace(/\s+/,"\\s+")))),/\b/)}
const l={scope:"keyword",
match:s(["create table","insert into","primary key","foreign key","not null","alter table","add constraint","grouping sets","on overflow","character set","respect nulls","ignore nulls","nulls first","nulls last","depth first","breadth first"]),
relevance:0};return{name:"SQL",case_insensitive:!0,illegal:/[{}]|<\//,keywords:{
$pattern:/\b[\w\.]+/,keyword:function(e,{exceptions:t,when:n}={}){const r=n
;return t=t||[],e.map((e=>e.match(/\|\d+$/)||t.includes(e)?e:r(e)?`${e}|0`:e))
}(a,{when:e=>e.length<3}),literal:["true","false","unknown"],
type:["bigint","binary","blob","boolean","char","character","clob","date","dec","decfloat","decimal","float","int","integer","interval","nchar","nclob","national","numeric","real","row","smallint","time","timestamp","varchar","varying","varbinary"],
built_in:["current_catalog","current_date","current_default_transform_group","current_path","current_role","current_schema","current_transform_group_for_type","current_user","session_user","system_time","system_user","current_time","localtime","current_timestamp","localtimestamp"]
},contains:[{scope:"type",
match:s(["double precision","large object","with timezone","without timezone"])
},l,i,{scope:"variable",match:/@[a-z0-9][a-z0-9_]*/},{scope:"string",variants:[{
begin:/'/,end:/'/,contains:[{match:/''/}]}]},{begin:/"/,end:/"/,contains:[{
match:/""/}]},e.C_NUMBER_MODE,e.C_BLOCK_COMMENT_MODE,n,{scope:"operator",
match:/[-+*/=%^~]|&&?|\|\|?|!=?|<(?:=>?|<|>)?|>[>=]?/,relevance:0}]}},
swift:function(e){const t={match:/\s+/,relevance:0},n=e.COMMENT("/\\*","\\*/",{
contains:["self"]}),r=[e.C_LINE_COMMENT_MODE,n],o={match:[/\./,OB(...xB,...kB)],
className:{2:"keyword"}},a={match:yB(/\./,OB(..._B)),relevance:0
},i=_B.filter((e=>"string"==typeof e)).concat(["_|0"]),s={variants:[{
className:"keyword",
match:OB(..._B.filter((e=>"string"!=typeof e)).concat(SB).map(wB),...kB)}]},l={
$pattern:OB(/\b\w+/,/#\w+/),keyword:i.concat(AB),literal:TB},c=[o,a,s],u=[{
match:yB(/\./,OB(...CB)),relevance:0},{className:"built_in",
match:yB(/\b/,OB(...CB),/(?=\()/)}],d={match:/->/,relevance:0},p=[d,{
className:"operator",relevance:0,variants:[{match:DB},{match:`\\.(\\.|${PB})+`}]
}],h="([0-9]_*)+",f="([0-9a-fA-F]_*)+",m={className:"number",relevance:0,
variants:[{match:`\\b(${h})(\\.(${h}))?([eE][+-]?(${h}))?\\b`},{
match:`\\b0x(${f})(\\.(${f}))?([pP][+-]?(${h}))?\\b`},{match:/\b0o([0-7]_*)+\b/
},{match:/\b0b([01]_*)+\b/}]},g=(e="")=>({className:"subst",variants:[{
match:yB(/\\/,e,/[0\\tnr"']/)},{match:yB(/\\/,e,/u\{[0-9a-fA-F]{1,8}\}/)}]
}),v=(e="")=>({className:"subst",match:yB(/\\/,e,/[\t ]*(?:[\r\n]|\r\n)/)
}),b=(e="")=>({className:"subst",label:"interpol",begin:yB(/\\/,e,/\(/),end:/\)/
}),y=(e="")=>({begin:yB(e,/"""/),end:yB(/"""/,e),contains:[g(e),v(e),b(e)]
}),O=(e="")=>({begin:yB(e,/"/),end:yB(/"/,e),contains:[g(e),b(e)]}),w={
className:"string",
variants:[y(),y("#"),y("##"),y("###"),O(),O("#"),O("##"),O("###")]
},x=[e.BACKSLASH_ESCAPE,{begin:/\[/,end:/\]/,relevance:0,
contains:[e.BACKSLASH_ESCAPE]}],k={begin:/\/[^\s](?=[^/\n]*\/)/,end:/\//,
contains:x},S=e=>{const t=yB(e,/\//),n=yB(/\//,e);return{begin:t,end:n,
contains:[...x,{scope:"comment",begin:`#(?!.*${n})`,end:/$/}]}},_={
scope:"regexp",variants:[S("###"),S("##"),S("#"),k]},T={match:yB(/`/,NB,/`/)
},E=[T,{className:"variable",match:/\$\d+/},{className:"variable",
match:`\\$${MB}+`}],A=[{match:/(@|#(un)?)available/,scope:"keyword",starts:{
contains:[{begin:/\(/,end:/\)/,keywords:BB,contains:[...p,m,w]}]}},{
scope:"keyword",match:yB(/@/,OB(...LB),bB(OB(/\(/,/\s+/)))},{scope:"meta",
match:yB(/@/,NB)}],C={match:bB(/\b[A-Z]/),relevance:0,contains:[{
className:"type",
match:yB(/(AV|CA|CF|CG|CI|CL|CM|CN|CT|MK|MP|MTK|MTL|NS|SCN|SK|UI|WK|XC)/,MB,"+")
},{className:"type",match:RB,relevance:0},{match:/[?!]+/,relevance:0},{
match:/\.\.\./,relevance:0},{match:yB(/\s+&\s+/,bB(RB)),relevance:0}]},$={
begin:/</,end:/>/,keywords:l,contains:[...r,...c,...A,d,C]};C.contains.push($)
;const P={begin:/\(/,end:/\)/,relevance:0,keywords:l,contains:["self",{
match:yB(NB,/\s*:/),keywords:"_|0",relevance:0
},...r,_,...c,...u,...p,m,w,...E,...A,C]},D={begin:/</,end:/>/,
keywords:"repeat each",contains:[...r,C]},I={begin:/\(/,end:/\)/,keywords:l,
contains:[{begin:OB(bB(yB(NB,/\s*:/)),bB(yB(NB,/\s+/,NB,/\s*:/))),end:/:/,
relevance:0,contains:[{className:"keyword",match:/\b_\b/},{className:"params",
match:NB}]},...r,...c,...p,m,w,...A,C,P],endsParent:!0,illegal:/["']/},M={
match:[/(func|macro)/,/\s+/,OB(T.match,NB,DB)],className:{1:"keyword",
3:"title.function"},contains:[D,I,t],illegal:[/\[/,/%/]},N={
match:[/\b(?:subscript|init[?!]?)/,/\s*(?=[<(])/],className:{1:"keyword"},
contains:[D,I,t],illegal:/\[|%/},R={match:[/operator/,/\s+/,DB],className:{
1:"keyword",3:"title"}},L={begin:[/precedencegroup/,/\s+/,RB],className:{
1:"keyword",3:"title"},contains:[C],keywords:[...EB,...TB],end:/}/},B={
begin:[/(struct|protocol|class|extension|enum|actor)/,/\s+/,NB,/\s*/],
beginScope:{1:"keyword",3:"title.class"},keywords:l,contains:[D,...c,{begin:/:/,
end:/\{/,keywords:l,contains:[{scope:"title.class.inherited",match:RB},...c],
relevance:0}]};for(const j of w.variants){
const e=j.contains.find((e=>"interpol"===e.label));e.keywords=l
;const t=[...c,...u,...p,m,w,...E];e.contains=[...t,{begin:/\(/,end:/\)/,
contains:["self",...t]}]}return{name:"Swift",keywords:l,contains:[...r,M,N,{
match:[/class\b/,/\s+/,/func\b/,/\s+/,/\b[A-Za-z_][A-Za-z0-9_]*\b/],scope:{
1:"keyword",3:"keyword",5:"title.function"}},{match:[/class\b/,/\s+/,/var\b/],
scope:{1:"keyword",3:"keyword"}},B,R,L,{beginKeywords:"import",end:/$/,
contains:[...r],relevance:0},_,...c,...u,...p,m,w,...E,...A,C,P]}},toml:FL,
typescript:function(e){const t=e.regex,n=function(e){
const t=e.regex,n=jB,r="<>",o="</>",a={begin:/<[A-Za-z0-9\\._:-]+/,
end:/\/[A-Za-z0-9\\._:-]+>|\/>/,isTrulyOpeningTag:(e,t)=>{
const n=e[0].length+e.index,r=e.input[n]
;if("<"===r||","===r)return void t.ignoreMatch();let o
;">"===r&&(((e,{after:t})=>{const n="</"+e[0].slice(1)
;return-1!==e.input.indexOf(n,t)})(e,{after:n})||t.ignoreMatch())
;const a=e.input.substring(n)
;((o=a.match(/^\s*=/))||(o=a.match(/^\s+extends\s+/))&&0===o.index)&&t.ignoreMatch()
}},i={$pattern:jB,keyword:UB,literal:zB,built_in:VB,"variable.language":HB
},s="[0-9](_?[0-9])*",l=`\\.(${s})`,c="0|[1-9](_?[0-9])*|0[0-7]*[89][0-9]*",u={
className:"number",variants:[{
begin:`(\\b(${c})((${l})|\\.)?|(${l}))[eE][+-]?(${s})\\b`},{
begin:`\\b(${c})\\b((${l})\\b|\\.)?|(${l})\\b`},{
begin:"\\b(0|[1-9](_?[0-9])*)n\\b"},{
begin:"\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*n?\\b"},{
begin:"\\b0[bB][0-1](_?[0-1])*n?\\b"},{begin:"\\b0[oO][0-7](_?[0-7])*n?\\b"},{
begin:"\\b0[0-7]+n?\\b"}],relevance:0},d={className:"subst",begin:"\\$\\{",
end:"\\}",keywords:i,contains:[]},p={begin:".?html`",end:"",starts:{end:"`",
returnEnd:!1,contains:[e.BACKSLASH_ESCAPE,d],subLanguage:"xml"}},h={
begin:".?css`",end:"",starts:{end:"`",returnEnd:!1,
contains:[e.BACKSLASH_ESCAPE,d],subLanguage:"css"}},f={begin:".?gql`",end:"",
starts:{end:"`",returnEnd:!1,contains:[e.BACKSLASH_ESCAPE,d],
subLanguage:"graphql"}},m={className:"string",begin:"`",end:"`",
contains:[e.BACKSLASH_ESCAPE,d]},g={className:"comment",
variants:[e.COMMENT(/\/\*\*(?!\/)/,"\\*/",{relevance:0,contains:[{
begin:"(?=@[A-Za-z]+)",relevance:0,contains:[{className:"doctag",
begin:"@[A-Za-z]+"},{className:"type",begin:"\\{",end:"\\}",excludeEnd:!0,
excludeBegin:!0,relevance:0},{className:"variable",begin:n+"(?=\\s*(-)|$)",
endsParent:!0,relevance:0},{begin:/(?=[^\n])\s/,relevance:0}]}]
}),e.C_BLOCK_COMMENT_MODE,e.C_LINE_COMMENT_MODE]
},v=[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,p,h,f,m,{match:/\$\d+/},u]
;d.contains=v.concat({begin:/\{/,end:/\}/,keywords:i,contains:["self"].concat(v)
});const b=[].concat(g,d.contains),y=b.concat([{begin:/(\s*)\(/,end:/\)/,
keywords:i,contains:["self"].concat(b)}]),O={className:"params",begin:/(\s*)\(/,
end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:i,contains:y},w={variants:[{
match:[/class/,/\s+/,n,/\s+/,/extends/,/\s+/,t.concat(n,"(",t.concat(/\./,n),")*")],
scope:{1:"keyword",3:"title.class",5:"keyword",7:"title.class.inherited"}},{
match:[/class/,/\s+/,n],scope:{1:"keyword",3:"title.class"}}]},x={relevance:0,
match:t.either(/\bJSON/,/\b[A-Z][a-z]+([A-Z][a-z]*|\d)*/,/\b[A-Z]{2,}([A-Z][a-z]+|\d)+([A-Z][a-z]*)*/,/\b[A-Z]{2,}[a-z]+([A-Z][a-z]+|\d)*([A-Z][a-z]*)*/),
className:"title.class",keywords:{_:[...FB,...ZB]}},k={variants:[{
match:[/function/,/\s+/,n,/(?=\s*\()/]},{match:[/function/,/\s*(?=\()/]}],
className:{1:"keyword",3:"title.function"},label:"func.def",contains:[O],
illegal:/%/},S={
match:t.concat(/\b/,(_=[...QB,"super","import"].map((e=>`${e}\\s*\\(`)),
t.concat("(?!",_.join("|"),")")),n,t.lookahead(/\s*\(/)),
className:"title.function",relevance:0};var _;const T={
begin:t.concat(/\./,t.lookahead(t.concat(n,/(?![0-9A-Za-z$_(])/))),end:n,
excludeBegin:!0,keywords:"prototype",className:"property",relevance:0},E={
match:[/get|set/,/\s+/,n,/(?=\()/],className:{1:"keyword",3:"title.function"},
contains:[{begin:/\(\)/},O]
},A="(\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)|"+e.UNDERSCORE_IDENT_RE+")\\s*=>",C={
match:[/const|var|let/,/\s+/,n,/\s*/,/=\s*/,/(async\s*)?/,t.lookahead(A)],
keywords:"async",className:{1:"keyword",3:"title.function"},contains:[O]}
;return{name:"JavaScript",aliases:["js","jsx","mjs","cjs"],keywords:i,exports:{
PARAMS_CONTAINS:y,CLASS_REFERENCE:x},illegal:/#(?![$_A-z])/,
contains:[e.SHEBANG({label:"shebang",binary:"node",relevance:5}),{
label:"use_strict",className:"meta",relevance:10,
begin:/^\s*['"]use (strict|asm)['"]/
},e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,p,h,f,m,g,{match:/\$\d+/},u,x,{
scope:"attr",match:n+t.lookahead(":"),relevance:0},C,{
begin:"("+e.RE_STARTERS_RE+"|\\b(case|return|throw)\\b)\\s*",
keywords:"return throw case",relevance:0,contains:[g,e.REGEXP_MODE,{
className:"function",begin:A,returnBegin:!0,end:"\\s*=>",contains:[{
className:"params",variants:[{begin:e.UNDERSCORE_IDENT_RE,relevance:0},{
className:null,begin:/\(\s*\)/,skip:!0},{begin:/(\s*)\(/,end:/\)/,
excludeBegin:!0,excludeEnd:!0,keywords:i,contains:y}]}]},{begin:/,/,relevance:0
},{match:/\s+/,relevance:0},{variants:[{begin:r,end:o},{
match:/<[A-Za-z0-9\\._:-]+\s*\/>/},{begin:a.begin,
"on:begin":a.isTrulyOpeningTag,end:a.end}],subLanguage:"xml",contains:[{
begin:a.begin,end:a.end,skip:!0,contains:["self"]}]}]},k,{
beginKeywords:"while if switch catch for"},{
begin:"\\b(?!function)"+e.UNDERSCORE_IDENT_RE+"\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)\\s*\\{",
returnBegin:!0,label:"func.def",contains:[O,e.inherit(e.TITLE_MODE,{begin:n,
className:"title.function"})]},{match:/\.\.\./,relevance:0},T,{match:"\\$"+n,
relevance:0},{match:[/\bconstructor(?=\s*\()/],className:{1:"title.function"},
contains:[O]},S,{relevance:0,match:/\b[A-Z][A-Z_0-9]+\b/,
className:"variable.constant"},w,E,{match:/\$[(.]/}]}
}(e),r=jB,o=["any","void","number","boolean","string","object","never","symbol","bigint","unknown"],a={
begin:[/namespace/,/\s+/,e.IDENT_RE],beginScope:{1:"keyword",3:"title.class"}
},i={beginKeywords:"interface",end:/\{/,excludeEnd:!0,keywords:{
keyword:"interface extends",built_in:o},contains:[n.exports.CLASS_REFERENCE]
},s={$pattern:jB,
keyword:UB.concat(["type","interface","public","private","protected","implements","declare","abstract","readonly","enum","override","satisfies"]),
literal:zB,built_in:VB.concat(o),"variable.language":HB},l={className:"meta",
begin:"@"+r},c=(e,t,n)=>{const r=e.contains.findIndex((e=>e.label===t))
;if(-1===r)throw new Error("can not find mode to replace")
;e.contains.splice(r,1,n)}
;Object.assign(n.keywords,s),n.exports.PARAMS_CONTAINS.push(l)
;const u=n.contains.find((e=>"attr"===e.scope)),d=Object.assign({},u,{
match:t.concat(r,t.lookahead(/\s*\?:/))})
;return n.exports.PARAMS_CONTAINS.push([n.exports.CLASS_REFERENCE,u,d]),
n.contains=n.contains.concat([l,a,i,d]),
c(n,"shebang",e.SHEBANG()),c(n,"use_strict",{className:"meta",relevance:10,
begin:/^\s*['"]use strict['"]/
}),n.contains.find((e=>"func.def"===e.label)).relevance=0,Object.assign(n,{
name:"TypeScript",aliases:["ts","tsx","mts","cts"]}),n},xml:qB,yaml:function(e){
const t="true false yes no null",n="[\\w#;/?:@&=+$,.~*'()[\\]]+",r={
className:"string",relevance:0,variants:[{begin:/"/,end:/"/},{begin:/\S+/}],
contains:[e.BACKSLASH_ESCAPE,{className:"template-variable",variants:[{
begin:/\{\{/,end:/\}\}/},{begin:/%\{/,end:/\}/}]}]},o=e.inherit(r,{variants:[{
begin:/'/,end:/'/,contains:[{begin:/''/,relevance:0}]},{begin:/"/,end:/"/},{
begin:/[^\s,{}[\]]+/}]}),a={className:"number",
begin:"\\b[0-9]{4}(-[0-9][0-9]){0,2}([Tt \\t][0-9][0-9]?(:[0-9][0-9]){2})?(\\.[0-9]*)?([ \\t])*(Z|[-+][0-9][0-9]?(:[0-9][0-9])?)?\\b"
},i={end:",",endsWithParent:!0,excludeEnd:!0,keywords:t,relevance:0},s={
begin:/\{/,end:/\}/,contains:[i],illegal:"\\n",relevance:0},l={begin:"\\[",
end:"\\]",contains:[i],illegal:"\\n",relevance:0},c=[{className:"attr",
variants:[{begin:/[\w*@][\w*@ :()\./-]*:(?=[ \t]|$)/},{
begin:/"[\w*@][\w*@ :()\./-]*":(?=[ \t]|$)/},{
begin:/'[\w*@][\w*@ :()\./-]*':(?=[ \t]|$)/}]},{className:"meta",
begin:"^---\\s*$",relevance:10},{className:"string",
begin:"[\\|>]([1-9]?[+-])?[ ]*\\n( +)[^ ][^\\n]*\\n(\\2[^\\n]+\\n?)*"},{
begin:"<%[%=-]?",end:"[%-]?%>",subLanguage:"ruby",excludeBegin:!0,excludeEnd:!0,
relevance:0},{className:"type",begin:"!\\w+!"+n},{className:"type",
begin:"!<"+n+">"},{className:"type",begin:"!"+n},{className:"type",begin:"!!"+n
},{className:"meta",begin:"&"+e.UNDERSCORE_IDENT_RE+"$"},{className:"meta",
begin:"\\*"+e.UNDERSCORE_IDENT_RE+"$"},{className:"bullet",begin:"-(?=[ ]|$)",
relevance:0},e.HASH_COMMENT_MODE,{beginKeywords:t,keywords:{literal:t}},a,{
className:"number",begin:e.C_NUMBER_RE+"\\b",relevance:0},s,l,{
className:"string",relevance:0,begin:/'/,end:/'/,contains:[{match:/''/,
scope:"char.escape",relevance:0}]},r],u=[...c]
;return u.pop(),u.push(o),i.contains=u,{name:"YAML",case_insensitive:!0,
aliases:["yml"],contains:c}}
},fj="object"==typeof self?self:globalThis,mj=e=>((e,t)=>{
const n=(t,n)=>(e.set(n,t),t),r=o=>{if(e.has(o))return e.get(o);const[a,i]=t[o]
;switch(a){case 0:case-1:return n(i,o);case 1:{const e=n([],o)
;for(const t of i)e.push(r(t));return e}case 2:{const e=n({},o)
;for(const[t,n]of i)e[r(t)]=r(n);return e}case 3:return n(new Date(i),o);case 4:
{const{source:e,flags:t}=i;return n(new RegExp(e,t),o)}case 5:{
const e=n(new Map,o);for(const[t,n]of i)e.set(r(t),r(n));return e}case 6:{
const e=n(new Set,o);for(const t of i)e.add(r(t));return e}case 7:{
const{name:e,message:t}=i;return n(new fj[e](t),o)}case 8:return n(BigInt(i),o)
;case"BigInt":return n(Object(BigInt(i)),o)}return n(new fj[a](i),o)};return r
})(new Map,e)(0),gj="",{toString:vj}={},{keys:bj}=Object,yj=e=>{const t=typeof e
;if("object"!==t||!e)return[0,t];const n=vj.call(e).slice(8,-1);switch(n){
case"Array":return[1,gj];case"Object":return[2,gj];case"Date":return[3,gj]
;case"RegExp":return[4,gj];case"Map":return[5,gj];case"Set":return[6,gj]}
return n.includes("Array")?[1,n]:n.includes("Error")?[7,n]:[2,n]
},Oj=([e,t])=>0===e&&("function"===t||"symbol"===t),wj=(e,{json:t,lossy:n}={})=>{
const r=[];return((e,t,n,r)=>{const o=(e,t)=>{const o=r.push(e)-1
;return n.set(t,o),o},a=r=>{if(n.has(r))return n.get(r);let[i,s]=yj(r)
;switch(i){case 0:{let t=r;switch(s){case"bigint":i=8,t=r.toString();break
;case"function":case"symbol":if(e)throw new TypeError("unable to serialize "+s)
;t=null;break;case"undefined":return o([-1],r)}return o([i,t],r)}case 1:{
if(s)return o([s,[...r]],r);const e=[],t=o([i,e],r)
;for(const n of r)e.push(a(n));return t}case 2:{if(s)switch(s){case"BigInt":
return o([s,r.toString()],r);case"Boolean":case"Number":case"String":
return o([s,r.valueOf()],r)}if(t&&"toJSON"in r)return a(r.toJSON())
;const n=[],l=o([i,n],r)
;for(const t of bj(r))!e&&Oj(yj(r[t]))||n.push([a(t),a(r[t])]);return l}case 3:
return o([i,r.toISOString()],r);case 4:{const{source:e,flags:t}=r;return o([i,{
source:e,flags:t}],r)}case 5:{const t=[],n=o([i,t],r)
;for(const[o,i]of r)(e||!Oj(yj(o))&&!Oj(yj(i)))&&t.push([a(o),a(i)]);return n}
case 6:{const t=[],n=o([i,t],r);for(const o of r)!e&&Oj(yj(o))||t.push(a(o))
;return n}}const{message:l}=r;return o([i,{name:s,message:l}],r)};return a
})(!(t||n),!!t,new Map,r)(e),r
},xj="function"==typeof structuredClone?(e,t)=>t&&("json"in t||"lossy"in t)?mj(wj(e,t)):structuredClone(e):(e,t)=>mj(wj(e,t)),kj=/^[a-zA-Z][a-zA-Z\d+\-.]*?:/,Sj=/^[a-zA-Z]:\\/
;const _j=["http","https"],Tj=["nofollow"],Ej={};function Aj(e){
const t=e||Ej,n=t.protocols||_j,r=fL(t.test);return function(e){
uL(e,"element",(function(e,o,a){
if("a"===e.tagName&&"string"==typeof e.properties.href&&r(e,o,a)){
const r=e.properties.href;if(function(e){
if("string"!=typeof e)throw new TypeError(`Expected a \`string\`, got \`${typeof e}\``)
;return!Sj.test(e)&&kj.test(e)
}(r)?n.includes(r.slice(0,r.indexOf(":"))):r.startsWith("//")){
const n=Cj(t.content,e),r=n&&!Array.isArray(n)?[n]:n,o=Cj(t.rel,e)||Tj,a="string"==typeof o?TP(o):o,i=Cj(t.target,e),s=Cj(t.properties,e)
;if(s&&Object.assign(e.properties,xj(s)),
a.length>0&&(e.properties.rel=[...a]),i&&(e.properties.target=i),r){
const n=Cj(t.contentProperties,e)||{};e.children.push({type:"element",
tagName:"span",properties:xj(n),children:xj(r)})}}}}))}}function Cj(e,t){
return"function"==typeof e?e(t):e}const $j=fL((function(e){
return"audio"===e.tagName||"canvas"===e.tagName||"embed"===e.tagName||"iframe"===e.tagName||"img"===e.tagName||"math"===e.tagName||"object"===e.tagName||"picture"===e.tagName||"svg"===e.tagName||"video"===e.tagName
})),Pj=["address","article","aside","blockquote","body","br","caption","center","col","colgroup","dd","dialog","dir","div","dl","dt","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","head","header","hgroup","hr","html","legend","li","li","listing","main","menu","nav","ol","optgroup","option","p","plaintext","pre","section","summary","table","tbody","td","td","tfoot","th","th","thead","tr","ul","wbr","xmp"],Dj=["button","input","select","textarea"],Ij=["area","base","basefont","dialog","datalist","head","link","meta","noembed","noframes","param","rp","script","source","style","template","track","title"],Mj={},Nj=nL(["comment","doctype"])
;function Rj(e,t){if("children"in e){const n={...t}
;return("root"===e.type||Uj(e))&&(n.before=!0,
n.after=!0),n.whitespace=function(e,t){
if("tagName"in e&&e.properties)switch(e.tagName){case"listing":case"plaintext":
case"script":case"style":case"xmp":return"pre";case"nobr":return"nowrap"
;case"pre":return e.properties.wrap?"pre-wrap":"pre";case"td":case"th":
return e.properties.noWrap?"nowrap":t.whitespace;case"textarea":return"pre-wrap"
}return t.whitespace}(e,t),function(e,t){let n=t.before
;const r=t.after,o=e.children;let a=o.length,i=-1;for(;++i<a;){const e=Rj(o[i],{
...t,after:Lj(o,i,r),before:n})
;e.remove?(o.splice(i,1),i--,a--):e.ignore||(n=e.stripAtStart),jj(o[i])&&(n=!1)}
return{ignore:!1,stripAtStart:Boolean(n||r),remove:!1}}(e,n)}
if("text"===e.type){if("normal"===t.whitespace)return function(e,t){
const n=t.collapse(e.value),r={ignore:!1,stripAtStart:!1,remove:!1}
;let o=0,a=n.length;t.before&&Fj(n.charAt(0))&&o++
;o!==a&&Fj(n.charAt(a-1))&&(t.after?a--:r.stripAtStart=!0)
;o===a?r.remove=!0:e.value=n.slice(o,a);return r}(e,t)
;"nowrap"===t.whitespace&&(e.value=t.collapse(e.value))}return{ignore:Nj(e),
stripAtStart:!1,remove:!1}}function Lj(e,t,n){for(;++t<e.length;){const n=e[t]
;let r=Bj(n)
;if(void 0===r&&"children"in n&&!zj(n)&&(r=Lj(n.children,-1)),"boolean"==typeof r)return r
}return n}function Bj(e){if("element"===e.type){if(jj(e))return!1
;if(Uj(e))return!0}else if("text"===e.type){if(!fR(e))return!1
}else if(!Nj(e))return!1}function jj(e){return $j(e)||hL(e,Dj)}function Uj(e){
return hL(e,Pj)}function zj(e){
return Boolean("element"===e.type&&e.properties.hidden)||Nj(e)||hL(e,Ij)}
function Fj(e){return" "===e||"\n"===e}function Zj(e){const t=/\r?\n|\r/.exec(e)
;return t?t[0]:" "}function Qj(){return" "}function Hj(e){return function(t){
return String(t).replace(/[\t\n\v\f\r ]+/g,e)}}const Vj={}.hasOwnProperty
;const qj=new Set(["pingback","prefetch","stylesheet"])
;const Wj=fL(["a","abbr","area","b","bdi","bdo","br","button","cite","code","data","datalist","del","dfn","em","i","input","ins","kbd","keygen","label","map","mark","meter","noscript","output","progress","q","ruby","s","samp","script","select","small","span","strong","sub","sup","template","textarea","time","u","var","wbr"]),Xj=fL("meta")
;function Gj(e){return Boolean("text"===e.type||Wj(e)||$j(e)||function(e){
if("element"!==e.type||"link"!==e.tagName)return!1
;if(e.properties.itemProp)return!0;const t=e.properties.rel;let n=-1
;if(!Array.isArray(t)||0===t.length)return!1
;for(;++n<t.length;)if(!qj.has(String(t[n])))return!1;return!0
}(e)||Xj(e)&&function(e,t){
const n="element"===e.type&&Vj.call(e.properties,t)&&e.properties[t]
;return null!=n&&!1!==n}(e,"itemProp"))}
const Yj=["pre","script","style","textarea"],Kj={};function Jj(e,t){
const n=t||Kj,r={blanks:n.blanks||[],head:!1,indentInitial:!1!==n.indentInitial,
indent:"number"==typeof n.indent?" ".repeat(n.indent):"string"==typeof n.indent?n.indent:"  "
};function o(e,t,n){
const o=e[e.length-1],a=o&&fR(o)?e[e.length-2]:o,i=(eU(r,a)&&eU(r,n)?"\n\n":"\n")+r.indent.repeat(Math.max(t,0))
;o&&"text"===o.type?o.value=fR(o)?i:o.value+i:e.push({type:"text",value:i})}
!function(e,t){Rj(e,{collapse:Hj((t||Mj).newlines?Zj:Qj),whitespace:"normal"})
}(e,{newlines:!0}),cL(e,(function(e,t){if(!("children"in e))return
;"element"===e.type&&"head"===e.tagName&&(r.head=!0)
;r.head&&"element"===e.type&&"body"===e.tagName&&(r.head=!1)
;if("element"===e.type&&Yj.includes(e.tagName))return lL
;if(0===e.children.length||!tU(r,e))return;let n=t.length;r.indentInitial||n--
;let a=!1
;for(const o of e.children)"comment"!==o.type&&"text"!==o.type||(o.value.includes("\n")&&(a=!0),
o.value=o.value.replace(/ *\n/g,"$&"+r.indent.repeat(n)));const i=[];let s
;for(const l of e.children)(tU(r,l)||a&&!s)&&(o(i,n,l),a=!0),s=l,i.push(l)
;s&&(a||tU(r,s))&&(fR(s)&&(i.pop(),s=i[i.length-1]),o(i,n-1));e.children=i}))}
function eU(e,t){
return Boolean(t&&"element"===t.type&&e.blanks.length>0&&e.blanks.includes(t.tagName))
}function tU(e,t){
return"root"===t.type||"element"===t.type&&(e.head||"script"===t.tagName||$j(t)||!Gj(t))
}function nU(e){return function(t){Jj(t,e)}}
const rU={},oU={}.hasOwnProperty,aU=HN("type",{handlers:{root:function(e,t){
const n={nodeName:"#document",mode:(e.data||{}).quirksMode?"quirks":"no-quirks",
childNodes:[]};return n.childNodes=sU(e.children,n,t),lU(e,n),n},
element:function(e,t){const n=t;let r=n
;"element"===e.type&&"svg"===e.tagName.toLowerCase()&&"html"===n.space&&(r=xP)
;const o=[];let a
;if(e.properties)for(a in e.properties)if("children"!==a&&oU.call(e.properties,a)){
const t=iU(r,a,e.properties[a]);t&&o.push(t)}const i=r.space,s={
nodeName:e.tagName,tagName:e.tagName,attrs:o,namespaceURI:LP[i],childNodes:[],
parentNode:null}
;s.childNodes=sU(e.children,s,r),lU(e,s),"template"===e.tagName&&e.content&&(s.content=function(e,t){
const n={nodeName:"#document-fragment",childNodes:[]}
;return n.childNodes=sU(e.children,n,t),lU(e,n),n}(e.content,r));return s},
text:function(e){const t={nodeName:"#text",value:e.value,parentNode:null}
;return lU(e,t),t},comment:function(e){const t={nodeName:"#comment",
data:e.value,parentNode:null};return lU(e,t),t},doctype:function(e){const t={
nodeName:"#documentType",name:"html",publicId:"",systemId:"",parentNode:null}
;return lU(e,t),t}}});function iU(e,t,n){const r=bP(e,t)
;if(!1===n||null==n||"number"==typeof n&&Number.isNaN(n)||!n&&r.boolean)return
;Array.isArray(n)&&(n=r.commaSeparated?SP(n):EP(n));const o={name:r.attribute,
value:!0===n?"":String(n)};if(r.space&&"html"!==r.space&&"svg"!==r.space){
const e=o.name.indexOf(":")
;e<0?o.prefix="":(o.name=o.name.slice(e+1),o.prefix=r.attribute.slice(0,e)),
o.namespace=LP[r.space]}return o}function sU(e,t,n){let r=-1;const o=[]
;if(e)for(;++r<e.length;){const a=aU(e[r],n);a.parentNode=t,o.push(a)}return o}
function lU(e,t){const n=e.position
;n&&n.start&&n.end&&(n.start.offset,n.end.offset,t.sourceCodeLocation={
startLine:n.start.line,startCol:n.start.column,startOffset:n.start.offset,
endLine:n.end.line,endCol:n.end.column,endOffset:n.end.offset})}
const cU=dU("end"),uU=dU("start");function dU(e){return function(t){
const n=t&&t.position&&t.position[e]||{}
;if("number"==typeof n.line&&n.line>0&&"number"==typeof n.column&&n.column>0)return{
line:n.line,column:n.column,
offset:"number"==typeof n.offset&&n.offset>-1?n.offset:void 0}}}function pU(e){
const t=uU(e),n=cU(e);if(t&&n)return{start:t,end:n}}
const hU=new Set(["mdxFlowExpression","mdxJsxFlowElement","mdxJsxTextElement","mdxTextExpression","mdxjsEsm"]),fU={
sourceCodeLocationInfo:!0,scriptingEnabled:!1};function mU(e,t){
const n=function(e){const t="root"===e.type?e.children[0]:e
;return Boolean(t&&("doctype"===t.type||"element"===t.type&&"html"===t.tagName.toLowerCase()))
}(e),r=HN("type",{handlers:{root:vU,element:bU,text:yU,comment:xU,doctype:OU,
raw:kU},unknown:SU}),o={parser:n?new zI(fU):zI.getFragmentParser(void 0,fU),
handle(e){r(e,o)},stitches:!1,options:t||{}};r(e,o),_U(o,uU())
;const a=UP(n?o.parser.document:o.parser.getFragment(),{file:o.options.file})
;return o.stitches&&uL(a,"comment",(function(e,t,n){const r=e
;if(r.value.stitch&&n&&void 0!==t){return n.children[t]=r.value.stitch,t}
})),"root"===a.type&&1===a.children.length&&a.children[0].type===e.type?a.children[0]:a
}function gU(e,t){let n=-1;if(e)for(;++n<e.length;)t.handle(e[n])}
function vU(e,t){gU(e.children,t)}function bU(e,t){!function(e,t){
const n=e.tagName.toLowerCase()
;if(t.parser.tokenizer.state===FD.PLAINTEXT)return;_U(t,uU(e))
;const r=t.parser.openElements.current
;let o="namespaceURI"in r?r.namespaceURI:LP.html
;o===LP.html&&"svg"===n&&(o=LP.svg);const a=function(e,t){const n=(t||rU).space
;return aU(e,"svg"===n?xP:wP)}({...e,children:[]},{space:o===LP.svg?"svg":"html"
}),i={type:lD.START_TAG,tagName:n,tagID:RD(n),selfClosing:!1,ackSelfClosing:!1,
attrs:"attrs"in a?a.attrs:[],location:EU(e)}
;t.parser.currentToken=i,t.parser._processToken(t.parser.currentToken),
t.parser.tokenizer.lastStartTagName=n}(e,t),gU(e.children,t),function(e,t){
const n=e.tagName.toLowerCase()
;if(!t.parser.tokenizer.inForeignNode&&uN.includes(n))return
;if(t.parser.tokenizer.state===FD.PLAINTEXT)return;_U(t,cU(e));const r={
type:lD.END_TAG,tagName:n,tagID:RD(n),selfClosing:!1,ackSelfClosing:!1,attrs:[],
location:EU(e)}
;t.parser.currentToken=r,t.parser._processToken(t.parser.currentToken),
n!==t.parser.tokenizer.lastStartTagName||t.parser.tokenizer.state!==FD.RCDATA&&t.parser.tokenizer.state!==FD.RAWTEXT&&t.parser.tokenizer.state!==FD.SCRIPT_DATA||(t.parser.tokenizer.state=FD.DATA)
}(e,t)}function yU(e,t){const n={type:lD.CHARACTER,chars:e.value,location:EU(e)}
;_U(t,uU(e)),
t.parser.currentToken=n,t.parser._processToken(t.parser.currentToken)}
function OU(e,t){const n={type:lD.DOCTYPE,name:"html",forceQuirks:!1,
publicId:"",systemId:"",location:EU(e)}
;_U(t,uU(e)),t.parser.currentToken=n,t.parser._processToken(t.parser.currentToken)
}function wU(e,t){t.stitches=!0;const n=function(e){return xj("children"in e?{
...e,children:[]}:e)}(e);if("children"in e&&"children"in n){const r=mU({
type:"root",children:e.children},t.options);n.children=r.children}xU({
type:"comment",value:{stitch:n}},t)}function xU(e,t){const n=e.value,r={
type:lD.COMMENT,data:n,location:EU(e)}
;_U(t,uU(e)),t.parser.currentToken=r,t.parser._processToken(t.parser.currentToken)
}function kU(e,t){
if(t.parser.tokenizer.preprocessor.html="",t.parser.tokenizer.preprocessor.pos=-1,
t.parser.tokenizer.preprocessor.lastGapPos=-2,
t.parser.tokenizer.preprocessor.gapStack=[],
t.parser.tokenizer.preprocessor.skipNextNewLine=!1,
t.parser.tokenizer.preprocessor.lastChunkWritten=!1,
t.parser.tokenizer.preprocessor.endOfChunkHit=!1,
t.parser.tokenizer.preprocessor.isEol=!1,
TU(t,uU(e)),t.parser.tokenizer.write(e.value,!1),
t.parser.tokenizer._runParsingLoop(),
72===t.parser.tokenizer.state||78===t.parser.tokenizer.state){
t.parser.tokenizer.preprocessor.lastChunkWritten=!0
;const e=t.parser.tokenizer._consume();t.parser.tokenizer._callState(e)}}
function SU(e,t){const n=e
;if(!t.options.passThrough||!t.options.passThrough.includes(n.type)){let e=""
;throw hU.has(n.type)&&(e=". It looks like you are using MDX nodes with `hast-util-raw` (or `rehype-raw`). If you use this because you are using remark or rehype plugins that inject `'html'` nodes, then please raise an issue with that plugin, as its a bad and slow idea. If you use this because you are using markdown syntax, then you have to configure this utility (or plugin) to pass through these nodes (see `passThrough` in docs), but you can also migrate to use the MDX syntax"),
new Error("Cannot compile `"+n.type+"` node"+e)}wU(n,t)}function _U(e,t){TU(e,t)
;const n=e.parser.tokenizer.currentCharacterToken
;n&&n.location&&(n.location.endLine=e.parser.tokenizer.preprocessor.line,
n.location.endCol=e.parser.tokenizer.preprocessor.col+1,
n.location.endOffset=e.parser.tokenizer.preprocessor.offset+1,
e.parser.currentToken=n,
e.parser._processToken(e.parser.currentToken)),e.parser.tokenizer.paused=!1,
e.parser.tokenizer.inLoop=!1,
e.parser.tokenizer.active=!1,e.parser.tokenizer.returnState=FD.DATA,
e.parser.tokenizer.charRefCode=-1,
e.parser.tokenizer.consumedAfterSnapshot=-1,e.parser.tokenizer.currentLocation=null,
e.parser.tokenizer.currentCharacterToken=null,
e.parser.tokenizer.currentToken=null,e.parser.tokenizer.currentAttr={name:"",
value:""}}function TU(e,t){if(t&&void 0!==t.offset){const n={startLine:t.line,
startCol:t.column,startOffset:t.offset,endLine:-1,endCol:-1,endOffset:-1}
;e.parser.tokenizer.preprocessor.lineStartPos=1-t.column,
e.parser.tokenizer.preprocessor.droppedBufferSize=t.offset,
e.parser.tokenizer.preprocessor.line=t.line,e.parser.tokenizer.currentLocation=n
}}function EU(e){const t=uU(e)||{line:void 0,column:void 0,offset:void 0
},n=cU(e)||{line:void 0,column:void 0,offset:void 0};return{startLine:t.line,
startCol:t.column,startOffset:t.offset,endLine:n.line,endCol:n.column,
endOffset:n.offset}}function AU(e){return function(t,n){return mU(t,{...e,file:n
})}}const CU=["ariaDescribedBy","ariaLabel","ariaLabelledBy"],$U={ancestors:{
tbody:["table"],td:["table"],th:["table"],thead:["table"],tfoot:["table"],
tr:["table"]},attributes:{
a:[...CU,"dataFootnoteBackref","dataFootnoteRef",["className","data-footnote-backref"],"href"],
blockquote:["cite"],code:[["className",/^language-./]],del:["cite"],
div:["itemScope","itemType"],dl:[...CU],h2:[["className","sr-only"]],
img:[...CU,"longDesc","src"],input:[["disabled",!0],["type","checkbox"]],
ins:["cite"],li:[["className","task-list-item"]],
ol:[...CU,["className","contains-task-list"]],q:["cite"],
section:["dataFootnotes",["className","footnotes"]],source:["srcSet"],
summary:[...CU],table:[...CU],ul:[...CU,["className","contains-task-list"]],
"*":["abbr","accept","acceptCharset","accessKey","action","align","alt","axis","border","cellPadding","cellSpacing","char","charOff","charSet","checked","clear","colSpan","color","cols","compact","coords","dateTime","dir","encType","frame","hSpace","headers","height","hrefLang","htmlFor","id","isMap","itemProp","label","lang","maxLength","media","method","multiple","name","noHref","noShade","noWrap","open","prompt","readOnly","rev","rowSpan","rows","rules","scope","selected","shape","size","span","start","summary","tabIndex","title","useMap","vAlign","value","width"]
},clobber:["ariaDescribedBy","ariaLabelledBy","id","name"],
clobberPrefix:"user-content-",protocols:{cite:["http","https"],
href:["http","https","irc","ircs","mailto","xmpp"],longDesc:["http","https"],
src:["http","https"]},required:{input:{disabled:!0,type:"checkbox"}},
strip:["script"],
tagNames:["a","b","blockquote","br","code","dd","del","details","div","dl","dt","em","h1","h2","h3","h4","h5","h6","hr","i","img","input","ins","kbd","li","ol","p","picture","pre","q","rp","rt","ruby","s","samp","section","source","span","strike","strong","sub","summary","sup","table","tbody","td","tfoot","th","thead","tr","tt","ul","var"]
},PU={}.hasOwnProperty;function DU(e,t){if(t&&"object"==typeof t){const n=t
;switch("string"==typeof n.type?n.type:""){case"comment":return function(e,t){
if(e.schema.allowComments){
const e="string"==typeof t.value?t.value:"",n=e.indexOf("--\x3e"),r={
type:"comment",value:n<0?e:e.slice(0,n)};return RU(r,t),r}}(e,n);case"doctype":
return function(e,t){if(e.schema.allowDoctypes){const e={type:"doctype"}
;return RU(e,t),e}}(e,n);case"element":return function(e,t){
const n="string"==typeof t.tagName?t.tagName:"";e.stack.push(n)
;const r=IU(e,t.children),o=function(e,t){
const n=e.stack[e.stack.length-1],r=e.schema.attributes,o=e.schema.required,a=r&&PU.call(r,n)?r[n]:void 0,i=r&&PU.call(r,"*")?r["*"]:void 0,s=t&&"object"==typeof t?t:{},l={}
;let c;for(c in s)if(PU.call(s,c)){const t=s[c];let n=MU(e,LU(a,c),c,t)
;null==n&&(n=MU(e,LU(i,c),c,t)),null!=n&&(l[c]=n)}if(o&&PU.call(o,n)){
const e=o[n];for(c in e)PU.call(e,c)&&!PU.call(l,c)&&(l[c]=e[c])}return l
}(e,t.properties);e.stack.pop();let a=!1
;if(n&&"*"!==n&&(!e.schema.tagNames||e.schema.tagNames.includes(n))&&(a=!0,
e.schema.ancestors&&PU.call(e.schema.ancestors,n))){
const t=e.schema.ancestors[n];let r=-1
;for(a=!1;++r<t.length;)e.stack.includes(t[r])&&(a=!0)}
if(!a)return e.schema.strip&&!e.schema.strip.includes(n)?r:void 0;const i={
type:"element",tagName:n,properties:o,children:r};return RU(i,t),i}(e,n)
;case"root":return function(e,t){const n=IU(e,t.children),r={type:"root",
children:n};return RU(r,t),r}(e,n);case"text":return function(e,t){
const n="string"==typeof t.value?t.value:"",r={type:"text",value:n}
;return RU(r,t),r}(0,n)}}}function IU(e,t){const n=[];if(Array.isArray(t)){
const r=t;let o=-1;for(;++o<r.length;){const t=DU(e,r[o])
;t&&(Array.isArray(t)?n.push(...t):n.push(t))}}return n}function MU(e,t,n,r){
return t?Array.isArray(r)?function(e,t,n,r){let o=-1;const a=[]
;for(;++o<r.length;){const i=NU(e,t,n,r[o])
;"number"!=typeof i&&"string"!=typeof i||a.push(i)}return a
}(e,t,n,r):NU(e,t,n,r):void 0}function NU(e,t,n,r){
if(("boolean"==typeof r||"number"==typeof r||"string"==typeof r)&&function(e,t,n){
const r=e.schema.protocols&&PU.call(e.schema.protocols,t)?e.schema.protocols[t]:void 0
;if(!r||0===r.length)return!0
;const o=String(n),a=o.indexOf(":"),i=o.indexOf("?"),s=o.indexOf("#"),l=o.indexOf("/")
;if(a<0||l>-1&&a>l||i>-1&&a>i||s>-1&&a>s)return!0;let c=-1;for(;++c<r.length;){
const e=r[c];if(a===e.length&&o.slice(0,e.length)===e)return!0}return!1
}(e,n,r)){if("object"==typeof t&&t.length>1){let e=!1,n=0;for(;++n<t.length;){
const o=t[n];if(o&&"object"==typeof o&&"flags"in o){if(o.test(String(r))){e=!0
;break}}else if(o===r){e=!0;break}}if(!e)return}
return e.schema.clobber&&e.schema.clobberPrefix&&e.schema.clobber.includes(n)?e.schema.clobberPrefix+r:r
}}function RU(e,t){const n=pU(t);t.data&&(e.data=xj(t.data)),n&&(e.position=n)}
function LU(e,t){let n,r=-1;if(e)for(;++r<e.length;){
const o=e[r],a="string"==typeof o?o:o[0];if(a===t)return o;"data*"===a&&(n=o)}
if(t.length>4&&"data"===t.slice(0,4).toLowerCase())return n}function BU(e){
return function(t){const n=function(e,t){let n={type:"root",children:[]}
;const r=DU({schema:t?{...$U,...t}:$U,stack:[]},e)
;return r&&(Array.isArray(r)?1===r.length?n=r[0]:n.children=r:n=r),n}(t,e)
;return n}}
const jU=YU(/[A-Za-z]/),UU=YU(/[\dA-Za-z]/),zU=YU(/[#-'*+\--9=?A-Z^-~]/)
;function FU(e){return null!==e&&(e<32||127===e)}
const ZU=YU(/\d/),QU=YU(/[\dA-Fa-f]/),HU=YU(/[!-/:-@[-`{-~]/);function VU(e){
return null!==e&&e<-2}function qU(e){return null!==e&&(e<0||32===e)}
function WU(e){return-2===e||-1===e||32===e}
const XU=YU(new RegExp("\\p{P}|\\p{S}","u")),GU=YU(/\s/);function YU(e){
return function(t){return null!==t&&t>-1&&e.test(String.fromCharCode(t))}}
function KU(e,t,n){const r=nL((n||{}).ignore||[]),o=function(e){const t=[]
;if(!Array.isArray(e))throw new TypeError("Expected find and replace tuple or list of tuples")
;const n=!e[0]||Array.isArray(e[0])?e:[e];let r=-1;for(;++r<n.length;){
const e=n[r];t.push([JU(e[0]),ez(e[1])])}return t}(t);let a=-1
;for(;++a<o.length;)cL(e,"text",i);function i(e,t){let n,i=-1
;for(;++i<t.length;){const e=t[i],o=n?n.children:void 0
;if(r(e,o?o.indexOf(e):void 0,n))return;n=e}if(n)return function(e,t){
const n=t[t.length-1],r=o[a][0],i=o[a][1];let s=0;const l=n.children.indexOf(e)
;let c=!1,u=[];r.lastIndex=0;let d=r.exec(e.value);for(;d;){const n=d.index,o={
index:d.index,input:d.input,stack:[...t,e]};let a=i(...d,o)
;if("string"==typeof a&&(a=a.length>0?{type:"text",value:a
}:void 0),!1===a?r.lastIndex=n+1:(s!==n&&u.push({type:"text",
value:e.value.slice(s,n)
}),Array.isArray(a)?u.push(...a):a&&u.push(a),s=n+d[0].length,
c=!0),!r.global)break;d=r.exec(e.value)}c?(s<e.value.length&&u.push({
type:"text",value:e.value.slice(s)}),n.children.splice(l,1,...u)):u=[e]
;return l+u.length}(e,t)}}function JU(e){
return"string"==typeof e?new RegExp(function(e){
if("string"!=typeof e)throw new TypeError("Expected a string")
;return e.replace(/[|\\{}()[\]^$+*?.]/g,"\\$&").replace(/-/g,"\\x2d")}(e),"g"):e
}function ez(e){return"function"==typeof e?e:function(){return e}}
const tz="phrasing",nz=["autolink","link","image","label"];function rz(e){
this.enter({type:"link",title:null,url:"",children:[]},e)}function oz(e){
this.config.enter.autolinkProtocol.call(this,e)}function az(e){
this.config.exit.autolinkProtocol.call(this,e)}function iz(e){
this.config.exit.data.call(this,e);const t=this.stack[this.stack.length-1]
;t.type,t.url="http://"+this.sliceSerialize(e)}function sz(e){
this.config.exit.autolinkEmail.call(this,e)}function lz(e){this.exit(e)}
function cz(e){
KU(e,[[/(https?:\/\/|www(?=\.))([-.\w]+)([^ \t\r\n]*)/gi,uz],[/([-.\w+]+)@([-\w]+(?:\.[-\w]+)+)/g,dz]],{
ignore:["link","linkReference"]})}function uz(e,t,n,r,o){let a=""
;if(!pz(o))return!1;if(/^w/i.test(t)&&(n=t+n,t="",a="http://"),!function(e){
const t=e.split(".")
;if(t.length<2||t[t.length-1]&&(/_/.test(t[t.length-1])||!/[a-zA-Z\d]/.test(t[t.length-1]))||t[t.length-2]&&(/_/.test(t[t.length-2])||!/[a-zA-Z\d]/.test(t[t.length-2])))return!1
;return!0}(n))return!1;const i=function(e){const t=/[!"&'),.:;<>?\]}]+$/.exec(e)
;if(!t)return[e,void 0];e=e.slice(0,t.index);let n=t[0],r=n.indexOf(")")
;const o=pR(e,"(");let a=pR(e,")")
;for(;-1!==r&&o>a;)e+=n.slice(0,r+1),n=n.slice(r+1),r=n.indexOf(")"),a++
;return[e,n]}(n+r);if(!i[0])return!1;const s={type:"link",title:null,
url:a+t+i[0],children:[{type:"text",value:t+i[0]}]};return i[1]?[s,{type:"text",
value:i[1]}]:s}function dz(e,t,n,r){return!(!pz(r,!0)||/[-\d_]$/.test(n))&&{
type:"link",title:null,url:"mailto:"+t+"@"+n,children:[{type:"text",
value:t+"@"+n}]}}function pz(e,t){const n=e.input.charCodeAt(e.index-1)
;return(0===e.index||GU(n)||XU(n))&&(!t||47!==n)}function hz(e){
return e.replace(/[\t\n\r ]+/g," ").replace(/^ | $/g,"").toLowerCase().toUpperCase()
}function fz(e){this.enter({type:"footnoteDefinition",identifier:"",label:"",
children:[]},e)}function mz(){this.buffer()}function gz(e){
const t=this.resume(),n=this.stack[this.stack.length-1]
;n.type,n.label=t,n.identifier=hz(this.sliceSerialize(e)).toLowerCase()}
function vz(e){this.exit(e)}function bz(e){this.enter({type:"footnoteReference",
identifier:"",label:""},e)}function yz(){this.buffer()}function Oz(e){
const t=this.resume(),n=this.stack[this.stack.length-1]
;n.type,n.label=t,n.identifier=hz(this.sliceSerialize(e)).toLowerCase()}
function wz(e){this.exit(e)}function xz(e,t,n,r){const o=n.createTracker(r)
;let a=o.move("[^");const i=n.enter("footnoteReference"),s=n.enter("reference")
;return a+=o.move(n.safe(n.associationId(e),{...o.current(),before:a,after:"]"
})),s(),i(),a+=o.move("]"),a}function kz(e,t,n,r){const o=n.createTracker(r)
;let a=o.move("[^");const i=n.enter("footnoteDefinition"),s=n.enter("label")
;return a+=o.move(n.safe(n.associationId(e),{...o.current(),before:a,after:"]"
})),
s(),a+=o.move("]:"+(e.children&&e.children.length>0?" ":"")),o.shift(4),a+=o.move(n.indentLines(n.containerFlow(e,o.current()),Sz)),
i(),a}function Sz(e,t,n){return 0===t?e:(n?"":"    ")+e}xz.peek=function(){
return"["}
;const _z=["autolink","destinationLiteral","destinationRaw","reference","titleQuote","titleApostrophe"]
;function Tz(e){this.enter({type:"delete",children:[]},e)}function Ez(e){
this.exit(e)}function Az(e,t,n,r){
const o=n.createTracker(r),a=n.enter("strikethrough");let i=o.move("~~")
;return i+=n.containerPhrasing(e,{...o.current(),before:i,after:"~"
}),i+=o.move("~~"),a(),i}function Cz(e){return e.length}function $z(e){
const t="string"==typeof e?e.codePointAt(0):0
;return 67===t||99===t?99:76===t||108===t?108:82===t||114===t?114:0}
Az.peek=function(){return"~"};const Pz={}.hasOwnProperty;function Dz(e,t){
let n,r=-1;if(t.extensions)for(;++r<t.extensions.length;)Dz(e,t.extensions[r])
;for(n in t)if(Pz.call(t,n))switch(n){case"extensions":break;case"unsafe":
case"join":Iz(e[n],t[n]);break;case"handlers":Mz(e[n],t[n]);break;default:
e.options[n]=t[n]}return e}function Iz(e,t){t&&e.push(...t)}function Mz(e,t){
t&&Object.assign(e,t)}function Nz(e,t,n){return">"+(n?"":" ")+e}
function Rz(e,t){return Lz(e,t.inConstruct,!0)&&!Lz(e,t.notInConstruct,!1)}
function Lz(e,t,n){if("string"==typeof t&&(t=[t]),!t||0===t.length)return n
;let r=-1;for(;++r<t.length;)if(e.includes(t[r]))return!0;return!1}
function Bz(e,t,n,r){let o=-1
;for(;++o<n.unsafe.length;)if("\n"===n.unsafe[o].character&&Rz(n.stack,n.unsafe[o]))return/[ \t]/.test(r.before)?"":" "
;return"\\\n"}function jz(e,t){
return Boolean(!1===t.options.fences&&e.value&&!e.lang&&/[^ \r\n]/.test(e.value)&&!/^[\t ]*(?:[\r\n]|$)|(?:^|[\r\n])[\t ]*$/.test(e.value))
}function Uz(e,t,n){return(n?"":"    ")+e}function zz(e){
const t=e.options.quote||'"'
;if('"'!==t&&"'"!==t)throw new Error("Cannot serialize title with `"+t+"` for `options.quote`, expected `\"`, or `'`")
;return t}function Fz(e,t,n,r){const o=function(e){
const t=e.options.emphasis||"*"
;if("*"!==t&&"_"!==t)throw new Error("Cannot serialize emphasis with `"+t+"` for `options.emphasis`, expected `*`, or `_`")
;return t}(n),a=n.enter("emphasis"),i=n.createTracker(r);let s=i.move(o)
;return s+=i.move(n.containerPhrasing(e,{before:s,after:o,...i.current()
})),s+=i.move(o),a(),s}Fz.peek=function(e,t,n){return n.options.emphasis||"*"}
;const Zz={};function Qz(e,t){const n=Zz
;return Hz(e,"boolean"!=typeof n.includeImageAlt||n.includeImageAlt,"boolean"!=typeof n.includeHtml||n.includeHtml)
}function Hz(e,t,n){if(function(e){return Boolean(e&&"object"==typeof e)}(e)){
if("value"in e)return"html"!==e.type||n?e.value:""
;if(t&&"alt"in e&&e.alt)return e.alt;if("children"in e)return Vz(e.children,t,n)
}return Array.isArray(e)?Vz(e,t,n):""}function Vz(e,t,n){const r=[];let o=-1
;for(;++o<e.length;)r[o]=Hz(e[o],t,n);return r.join("")}function qz(e,t){
let n=!1;return uL(e,(function(e){
if("value"in e&&/\r?\n|\r/.test(e.value)||"break"===e.type)return n=!0,sL
})),Boolean((!e.depth||e.depth<3)&&Qz(e)&&(t.options.setext||n))}function Wz(e){
return e.value||""}function Xz(e,t,n,r){
const o=zz(n),a='"'===o?"Quote":"Apostrophe",i=n.enter("image")
;let s=n.enter("label");const l=n.createTracker(r);let c=l.move("![")
;return c+=l.move(n.safe(e.alt,{before:c,after:"]",...l.current()
})),c+=l.move("]("),
s(),!e.url&&e.title||/[\0- \u007F]/.test(e.url)?(s=n.enter("destinationLiteral"),
c+=l.move("<"),c+=l.move(n.safe(e.url,{before:c,after:">",...l.current()
})),c+=l.move(">")):(s=n.enter("destinationRaw"),c+=l.move(n.safe(e.url,{
before:c,after:e.title?" ":")",...l.current()
}))),s(),e.title&&(s=n.enter(`title${a}`),
c+=l.move(" "+o),c+=l.move(n.safe(e.title,{before:c,after:o,...l.current()
})),c+=l.move(o),s()),c+=l.move(")"),i(),c}function Gz(e,t,n,r){
const o=e.referenceType,a=n.enter("imageReference");let i=n.enter("label")
;const s=n.createTracker(r);let l=s.move("![");const c=n.safe(e.alt,{before:l,
after:"]",...s.current()});l+=s.move(c+"]["),i();const u=n.stack
;n.stack=[],i=n.enter("reference");const d=n.safe(n.associationId(e),{before:l,
after:"]",...s.current()})
;return i(),n.stack=u,a(),"full"!==o&&c&&c===d?"shortcut"===o?l=l.slice(0,-1):l+=s.move("]"):l+=s.move(d+"]"),
l}function Yz(e,t,n){let r=e.value||"",o="`",a=-1
;for(;new RegExp("(^|[^`])"+o+"([^`]|$)").test(r);)o+="`"
;for(/[^ \r\n]/.test(r)&&(/^[ \r\n]/.test(r)&&/[ \r\n]$/.test(r)||/^`|`$/.test(r))&&(r=" "+r+" ");++a<n.unsafe.length;){
const e=n.unsafe[a],t=n.compilePattern(e);let o;if(e.atBreak)for(;o=t.exec(r);){
let e=o.index
;10===r.charCodeAt(e)&&13===r.charCodeAt(e-1)&&e--,r=r.slice(0,e)+" "+r.slice(o.index+1)
}}return o+r+o}function Kz(e,t){const n=Qz(e)
;return Boolean(!t.options.resourceLink&&e.url&&!e.title&&e.children&&1===e.children.length&&"text"===e.children[0].type&&(n===e.url||"mailto:"+n===e.url)&&/^[a-z][a-z+.-]+:/i.test(e.url)&&!/[\0- <>\u007F]/.test(e.url))
}function Jz(e,t,n,r){
const o=zz(n),a='"'===o?"Quote":"Apostrophe",i=n.createTracker(r);let s,l
;if(Kz(e,n)){const t=n.stack;n.stack=[],s=n.enter("autolink");let r=i.move("<")
;return r+=i.move(n.containerPhrasing(e,{before:r,after:">",...i.current()
})),r+=i.move(">"),s(),n.stack=t,r}s=n.enter("link"),l=n.enter("label")
;let c=i.move("[");return c+=i.move(n.containerPhrasing(e,{before:c,after:"](",
...i.current()
})),c+=i.move("]("),l(),!e.url&&e.title||/[\0- \u007F]/.test(e.url)?(l=n.enter("destinationLiteral"),
c+=i.move("<"),c+=i.move(n.safe(e.url,{before:c,after:">",...i.current()
})),c+=i.move(">")):(l=n.enter("destinationRaw"),c+=i.move(n.safe(e.url,{
before:c,after:e.title?" ":")",...i.current()
}))),l(),e.title&&(l=n.enter(`title${a}`),
c+=i.move(" "+o),c+=i.move(n.safe(e.title,{before:c,after:o,...i.current()
})),c+=i.move(o),l()),c+=i.move(")"),s(),c}function eF(e,t,n,r){
const o=e.referenceType,a=n.enter("linkReference");let i=n.enter("label")
;const s=n.createTracker(r);let l=s.move("[");const c=n.containerPhrasing(e,{
before:l,after:"]",...s.current()});l+=s.move(c+"]["),i();const u=n.stack
;n.stack=[],i=n.enter("reference");const d=n.safe(n.associationId(e),{before:l,
after:"]",...s.current()})
;return i(),n.stack=u,a(),"full"!==o&&c&&c===d?"shortcut"===o?l=l.slice(0,-1):l+=s.move("]"):l+=s.move(d+"]"),
l}function tF(e){const t=e.options.bullet||"*"
;if("*"!==t&&"+"!==t&&"-"!==t)throw new Error("Cannot serialize items with `"+t+"` for `options.bullet`, expected `*`, `+`, or `-`")
;return t}function nF(e){const t=e.options.rule||"*"
;if("*"!==t&&"-"!==t&&"_"!==t)throw new Error("Cannot serialize rules with `"+t+"` for `options.rule`, expected `*`, `-`, or `_`")
;return t}Wz.peek=function(){return"<"},Xz.peek=function(){return"!"
},Gz.peek=function(){return"!"},Yz.peek=function(){return"`"
},Jz.peek=function(e,t,n){return Kz(e,n)?"<":"["},eF.peek=function(){return"["}
;const rF=nL(["break","delete","emphasis","footnote","footnoteReference","image","imageReference","inlineCode","inlineMath","link","linkReference","mdxJsxTextElement","mdxTextExpression","strong","text","textDirective"])
;function oF(e,t,n,r){const o=function(e){const t=e.options.strong||"*"
;if("*"!==t&&"_"!==t)throw new Error("Cannot serialize strong with `"+t+"` for `options.strong`, expected `*`, or `_`")
;return t}(n),a=n.enter("strong"),i=n.createTracker(r);let s=i.move(o+o)
;return s+=i.move(n.containerPhrasing(e,{before:s,after:o,...i.current()
})),s+=i.move(o+o),a(),s}oF.peek=function(e,t,n){return n.options.strong||"*"}
;const aF={blockquote:function(e,t,n,r){
const o=n.enter("blockquote"),a=n.createTracker(r);a.move("> "),a.shift(2)
;const i=n.indentLines(n.containerFlow(e,a.current()),Nz);return o(),i},
break:Bz,code:function(e,t,n,r){const o=function(e){const t=e.options.fence||"`"
;if("`"!==t&&"~"!==t)throw new Error("Cannot serialize code with `"+t+"` for `options.fence`, expected `` ` `` or `~`")
;return t}(n),a=e.value||"",i="`"===o?"GraveAccent":"Tilde";if(jz(e,n)){
const e=n.enter("codeIndented"),t=n.indentLines(a,Uz);return e(),t}
const s=n.createTracker(r),l=o.repeat(Math.max(function(e,t){const n=String(e)
;let r=n.indexOf(t),o=r,a=0,i=0
;if("string"!=typeof t)throw new TypeError("Expected substring")
;for(;-1!==r;)r===o?++a>i&&(i=a):a=1,o=r+t.length,r=n.indexOf(t,o);return i
}(a,o)+1,3)),c=n.enter("codeFenced");let u=s.move(l);if(e.lang){
const t=n.enter(`codeFencedLang${i}`);u+=s.move(n.safe(e.lang,{before:u,
after:" ",encode:["`"],...s.current()})),t()}if(e.lang&&e.meta){
const t=n.enter(`codeFencedMeta${i}`);u+=s.move(" "),u+=s.move(n.safe(e.meta,{
before:u,after:"\n",encode:["`"],...s.current()})),t()}
return u+=s.move("\n"),a&&(u+=s.move(a+"\n")),u+=s.move(l),c(),u},
definition:function(e,t,n,r){
const o=zz(n),a='"'===o?"Quote":"Apostrophe",i=n.enter("definition")
;let s=n.enter("label");const l=n.createTracker(r);let c=l.move("[")
;return c+=l.move(n.safe(n.associationId(e),{before:c,after:"]",...l.current()
})),
c+=l.move("]: "),s(),!e.url||/[\0- \u007F]/.test(e.url)?(s=n.enter("destinationLiteral"),
c+=l.move("<"),c+=l.move(n.safe(e.url,{before:c,after:">",...l.current()
})),c+=l.move(">")):(s=n.enter("destinationRaw"),c+=l.move(n.safe(e.url,{
before:c,after:e.title?" ":"\n",...l.current()
}))),s(),e.title&&(s=n.enter(`title${a}`),
c+=l.move(" "+o),c+=l.move(n.safe(e.title,{before:c,after:o,...l.current()
})),c+=l.move(o),s()),i(),c},emphasis:Fz,hardBreak:Bz,heading:function(e,t,n,r){
const o=Math.max(Math.min(6,e.depth||1),1),a=n.createTracker(r);if(qz(e,n)){
const t=n.enter("headingSetext"),r=n.enter("phrasing"),i=n.containerPhrasing(e,{
...a.current(),before:"\n",after:"\n"})
;return r(),t(),i+"\n"+(1===o?"=":"-").repeat(i.length-(Math.max(i.lastIndexOf("\r"),i.lastIndexOf("\n"))+1))
}const i="#".repeat(o),s=n.enter("headingAtx"),l=n.enter("phrasing")
;a.move(i+" ");let c=n.containerPhrasing(e,{before:"# ",after:"\n",
...a.current()})
;return/^[\t ]/.test(c)&&(c="&#x"+c.charCodeAt(0).toString(16).toUpperCase()+";"+c.slice(1)),
c=c?i+" "+c:i,n.options.closeAtx&&(c+=" "+i),l(),s(),c},html:Wz,image:Xz,
imageReference:Gz,inlineCode:Yz,link:Jz,linkReference:eF,list:function(e,t,n,r){
const o=n.enter("list"),a=n.bulletCurrent;let i=e.ordered?function(e){
const t=e.options.bulletOrdered||"."
;if("."!==t&&")"!==t)throw new Error("Cannot serialize items with `"+t+"` for `options.bulletOrdered`, expected `.` or `)`")
;return t}(n):tF(n);const s=e.ordered?"."===i?")":".":function(e){
const t=tF(e),n=e.options.bulletOther;if(!n)return"*"===t?"-":"*"
;if("*"!==n&&"+"!==n&&"-"!==n)throw new Error("Cannot serialize items with `"+n+"` for `options.bulletOther`, expected `*`, `+`, or `-`")
;if(n===t)throw new Error("Expected `bullet` (`"+t+"`) and `bulletOther` (`"+n+"`) to be different")
;return n}(n);let l=!(!t||!n.bulletLastUsed)&&i===n.bulletLastUsed
;if(!e.ordered){const t=e.children?e.children[0]:void 0
;if("*"!==i&&"-"!==i||!t||t.children&&t.children[0]||"list"!==n.stack[n.stack.length-1]||"listItem"!==n.stack[n.stack.length-2]||"list"!==n.stack[n.stack.length-3]||"listItem"!==n.stack[n.stack.length-4]||0!==n.indexStack[n.indexStack.length-1]||0!==n.indexStack[n.indexStack.length-2]||0!==n.indexStack[n.indexStack.length-3]||(l=!0),
nF(n)===i&&t){let t=-1;for(;++t<e.children.length;){const n=e.children[t]
;if(n&&"listItem"===n.type&&n.children&&n.children[0]&&"thematicBreak"===n.children[0].type){
l=!0;break}}}}l&&(i=s),n.bulletCurrent=i;const c=n.containerFlow(e,r)
;return n.bulletLastUsed=i,n.bulletCurrent=a,o(),c},listItem:function(e,t,n,r){
const o=function(e){const t=e.options.listItemIndent||"one"
;if("tab"!==t&&"one"!==t&&"mixed"!==t)throw new Error("Cannot serialize items with `"+t+"` for `options.listItemIndent`, expected `tab`, `one`, or `mixed`")
;return t}(n);let a=n.bulletCurrent||tF(n)
;t&&"list"===t.type&&t.ordered&&(a=("number"==typeof t.start&&t.start>-1?t.start:1)+(!1===n.options.incrementListMarker?0:t.children.indexOf(e))+a)
;let i=a.length+1
;("tab"===o||"mixed"===o&&(t&&"list"===t.type&&t.spread||e.spread))&&(i=4*Math.ceil(i/4))
;const s=n.createTracker(r);s.move(a+" ".repeat(i-a.length)),s.shift(i)
;const l=n.enter("listItem"),c=n.indentLines(n.containerFlow(e,s.current()),(function(e,t,n){
if(t)return(n?"":" ".repeat(i))+e;return(n?a:a+" ".repeat(i-a.length))+e}))
;return l(),c},paragraph:function(e,t,n,r){
const o=n.enter("paragraph"),a=n.enter("phrasing"),i=n.containerPhrasing(e,r)
;return a(),o(),i},root:function(e,t,n,r){const o=e.children.some((function(e){
return rF(e)}));return(o?n.containerPhrasing:n.containerFlow).call(n,e,r)},
strong:oF,text:function(e,t,n,r){return n.safe(e.value,r)},
thematicBreak:function(e,t,n){
const r=(nF(n)+(n.options.ruleSpaces?" ":"")).repeat(function(e){
const t=e.options.ruleRepetition||3
;if(t<3)throw new Error("Cannot serialize rules with repetition `"+t+"` for `options.ruleRepetition`, expected `3` or more")
;return t}(n));return n.options.ruleSpaces?r.slice(0,-1):r}
},iF=[function(e,t,n,r){
if("code"===t.type&&jz(t,r)&&("list"===e.type||e.type===t.type&&jz(e,r)))return!1
;if("spread"in n&&"boolean"==typeof n.spread){
if("paragraph"===e.type&&(e.type===t.type||"definition"===t.type||"heading"===t.type&&qz(t,r)))return
;return n.spread?1:0}}]
;const sF=["autolink","destinationLiteral","destinationRaw","reference","titleQuote","titleApostrophe"],lF=[{
character:"\t",after:"[\\r\\n]",inConstruct:"phrasing"},{character:"\t",
before:"[\\r\\n]",inConstruct:"phrasing"},{character:"\t",
inConstruct:["codeFencedLangGraveAccent","codeFencedLangTilde"]},{
character:"\r",
inConstruct:["codeFencedLangGraveAccent","codeFencedLangTilde","codeFencedMetaGraveAccent","codeFencedMetaTilde","destinationLiteral","headingAtx"]
},{character:"\n",
inConstruct:["codeFencedLangGraveAccent","codeFencedLangTilde","codeFencedMetaGraveAccent","codeFencedMetaTilde","destinationLiteral","headingAtx"]
},{character:" ",after:"[\\r\\n]",inConstruct:"phrasing"},{character:" ",
before:"[\\r\\n]",inConstruct:"phrasing"},{character:" ",
inConstruct:["codeFencedLangGraveAccent","codeFencedLangTilde"]},{character:"!",
after:"\\[",inConstruct:"phrasing",notInConstruct:sF},{character:'"',
inConstruct:"titleQuote"},{atBreak:!0,character:"#"},{character:"#",
inConstruct:"headingAtx",after:"(?:[\r\n]|$)"},{character:"&",after:"[#A-Za-z]",
inConstruct:"phrasing"},{character:"'",inConstruct:"titleApostrophe"},{
character:"(",inConstruct:"destinationRaw"},{before:"\\]",character:"(",
inConstruct:"phrasing",notInConstruct:sF},{atBreak:!0,before:"\\d+",
character:")"},{character:")",inConstruct:"destinationRaw"},{atBreak:!0,
character:"*",after:"(?:[ \t\r\n*])"},{character:"*",inConstruct:"phrasing",
notInConstruct:sF},{atBreak:!0,character:"+",after:"(?:[ \t\r\n])"},{atBreak:!0,
character:"-",after:"(?:[ \t\r\n-])"},{atBreak:!0,before:"\\d+",character:".",
after:"(?:[ \t\r\n]|$)"},{atBreak:!0,character:"<",after:"[!/?A-Za-z]"},{
character:"<",after:"[!/?A-Za-z]",inConstruct:"phrasing",notInConstruct:sF},{
character:"<",inConstruct:"destinationLiteral"},{atBreak:!0,character:"="},{
atBreak:!0,character:">"},{character:">",inConstruct:"destinationLiteral"},{
atBreak:!0,character:"["},{character:"[",inConstruct:"phrasing",
notInConstruct:sF},{character:"[",inConstruct:["label","reference"]},{
character:"\\",after:"[\\r\\n]",inConstruct:"phrasing"},{character:"]",
inConstruct:["label","reference"]},{atBreak:!0,character:"_"},{character:"_",
inConstruct:"phrasing",notInConstruct:sF},{atBreak:!0,character:"`"},{
character:"`",
inConstruct:["codeFencedLangGraveAccent","codeFencedMetaGraveAccent"]},{
character:"`",inConstruct:"phrasing",notInConstruct:sF},{atBreak:!0,
character:"~"}],cF=document.createElement("i");function uF(e){const t="&"+e+";"
;cF.innerHTML=t;const n=cF.textContent
;return(59!==n.charCodeAt(n.length-1)||"semi"===e)&&(n!==t&&n)}function dF(e,t){
const n=Number.parseInt(e,t)
;return n<9||11===n||n>13&&n<32||n>126&&n<160||n>55295&&n<57344||n>64975&&n<65008||!(65535&~n)||65534==(65535&n)||n>1114111?"�":String.fromCodePoint(n)
}const pF=/\\([!-/:-@[-`{-~])|&(#(?:\d{1,7}|x[\da-f]{1,6})|[\da-z]{1,31});/gi
;function hF(e){return e.replace(pF,fF)}function fF(e,t,n){if(t)return t
;if(35===n.charCodeAt(0)){const e=n.charCodeAt(1),t=120===e||88===e
;return dF(n.slice(t?2:1),t?16:10)}return uF(n)||e}function mF(e){
return e.label||!e.identifier?e.label||"":hF(e.identifier)}function gF(e){
if(!e._compiled){
const t=(e.atBreak?"[\\r\\n][\\t ]*":"")+(e.before?"(?:"+e.before+")":"")
;e._compiled=new RegExp((t?"("+t+")":"")+(/[|\\{}()[\]^$+*?.-]/.test(e.character)?"\\":"")+e.character+(e.after?"(?:"+e.after+")":""),"g")
}return e._compiled}function vF(e,t,n,r){let o=r.join.length;for(;o--;){
const a=r.join[o](e,t,n,r);if(!0===a||1===a)break
;if("number"==typeof a)return"\n".repeat(1+a)
;if(!1===a)return"\n\n\x3c!----\x3e\n\n"}return"\n\n"}const bF=/\r?\n|\r/g
;function yF(e,t){const n=[];let r,o=0,a=0
;for(;r=bF.exec(e);)i(e.slice(o,r.index)),n.push(r[0]),o=r.index+r[0].length,a++
;return i(e.slice(o)),n.join("");function i(e){n.push(t(e,a,!e))}}
function OF(e,t){return e-t}function wF(e,t){
const n=/\\(?=[!-/:-@[-`{-~])/g,r=[],o=[],a=e+t;let i,s=-1,l=0
;for(;i=n.exec(a);)r.push(i.index)
;for(;++s<r.length;)l!==r[s]&&o.push(e.slice(l,r[s])),o.push("\\"),l=r[s]
;return o.push(e.slice(l)),o.join("")}function xF(e){const t=e||{},n=t.now||{}
;let r=t.lineShift||0,o=n.line||1,a=n.column||1;return{move:function(e){
const t=e||"",n=t.split(/\r?\n|\r/g),i=n[n.length-1]
;return o+=n.length-1,a=1===n.length?a+i.length:1+i.length+r,t},
current:function(){return{now:{line:o,column:a},lineShift:r}},shift:function(e){
r+=e}}}function kF(e,t={}){const n={enter:function(e){
return n.stack.push(e),function(){n.stack.pop()}},indentLines:yF,
associationId:mF,containerPhrasing:EF,containerFlow:AF,createTracker:xF,
compilePattern:gF,safe:CF,stack:[],unsafe:[...lF],join:[...iF],handlers:{...aF},
options:{},indexStack:[],handle:void 0}
;Dz(n,t),n.options.tightDefinitions&&n.join.push(TF),n.handle=HN("type",{
invalid:SF,unknown:_F,handlers:n.handlers});let r=n.handle(e,void 0,n,{
before:"\n",after:"\n",now:{line:1,column:1},lineShift:0})
;return r&&10!==r.charCodeAt(r.length-1)&&13!==r.charCodeAt(r.length-1)&&(r+="\n"),
r}function SF(e){throw new Error("Cannot handle value `"+e+"`, expected node")}
function _F(e){throw new Error("Cannot handle unknown node `"+e.type+"`")}
function TF(e,t){if("definition"===e.type&&e.type===t.type)return 0}
function EF(e,t){return function(e,t,n){
const r=t.indexStack,o=e.children||[],a=[];let i=-1,s=n.before;r.push(-1)
;let l=t.createTracker(n);for(;++i<o.length;){const c=o[i];let u
;if(r[r.length-1]=i,i+1<o.length){let n=t.handle.handlers[o[i+1].type]
;n&&n.peek&&(n=n.peek),u=n?n(o[i+1],e,t,{before:"",after:"",...l.current()
}).charAt(0):""}else u=n.after
;a.length>0&&("\r"===s||"\n"===s)&&"html"===c.type&&(a[a.length-1]=a[a.length-1].replace(/(\r?\n|\r)$/," "),
s=" ",l=t.createTracker(n),l.move(a.join(""))),a.push(l.move(t.handle(c,e,t,{
...l.current(),before:s,after:u}))),s=a[a.length-1].slice(-1)}
return r.pop(),a.join("")}(e,this,t)}function AF(e,t){return function(e,t,n){
const r=t.indexStack,o=e.children||[],a=t.createTracker(n),i=[];let s=-1
;for(r.push(-1);++s<o.length;){const n=o[s]
;r[r.length-1]=s,i.push(a.move(t.handle(n,e,t,{before:"\n",after:"\n",
...a.current()
}))),"list"!==n.type&&(t.bulletLastUsed=void 0),s<o.length-1&&i.push(a.move(vF(n,o[s+1],e,t)))
}return r.pop(),i.join("")}(e,this,t)}function CF(e,t){return function(e,t,n){
const r=(n.before||"")+(t||"")+(n.after||""),o=[],a=[],i={};let s=-1
;for(;++s<e.unsafe.length;){const t=e.unsafe[s];if(!Rz(e.stack,t))continue
;const n=e.compilePattern(t);let a;for(;a=n.exec(r);){
const e="before"in t||Boolean(t.atBreak),n="after"in t,r=a.index+(e?a[1].length:0)
;o.includes(r)?(i[r].before&&!e&&(i[r].before=!1),
i[r].after&&!n&&(i[r].after=!1)):(o.push(r),i[r]={before:e,after:n})}}o.sort(OF)
;let l=n.before?n.before.length:0;const c=r.length-(n.after?n.after.length:0)
;for(s=-1;++s<o.length;){const e=o[s]
;e<l||e>=c||e+1<c&&o[s+1]===e+1&&i[e].after&&!i[e+1].before&&!i[e+1].after||o[s-1]===e-1&&i[e].before&&!i[e-1].before&&!i[e-1].after||(l!==e&&a.push(wF(r.slice(l,e),"\\")),
l=e,
!/[!-/:-@[-`{-~]/.test(r.charAt(e))||n.encode&&n.encode.includes(r.charAt(e))?(a.push("&#x"+r.charCodeAt(e).toString(16).toUpperCase()+";"),
l++):a.push("\\"))}return a.push(wF(r.slice(l,c),n.after)),a.join("")}(this,e,t)
}function $F(e){const t=e._align;this.enter({type:"table",
align:t.map((function(e){return"none"===e?null:e})),children:[]
},e),this.data.inTable=!0}function PF(e){this.exit(e),this.data.inTable=void 0}
function DF(e){this.enter({type:"tableRow",children:[]},e)}function IF(e){
this.exit(e)}function MF(e){this.enter({type:"tableCell",children:[]},e)}
function NF(e){let t=this.resume()
;this.data.inTable&&(t=t.replace(/\\([\\|])/g,RF))
;const n=this.stack[this.stack.length-1];n.type,n.value=t,this.exit(e)}
function RF(e,t){return"|"===t?t:e}function LF(e){
const t=e||{},n=t.tableCellPadding,r=t.tablePipeAlign,o=t.stringLength,a=n?" ":"|"
;return{unsafe:[{character:"\r",inConstruct:"tableCell"},{character:"\n",
inConstruct:"tableCell"},{atBreak:!0,character:"|",after:"[\t :-]"},{
character:"|",inConstruct:"tableCell"},{atBreak:!0,character:":",after:"-"},{
atBreak:!0,character:"-",after:"[:|-]"}],handlers:{inlineCode:function(e,t,n){
let r=aF.inlineCode(e,t,n)
;n.stack.includes("tableCell")&&(r=r.replace(/\|/g,"\\$&"));return r},
table:function(e,t,n,r){return s(function(e,t,n){const r=e.children;let o=-1
;const a=[],i=t.enter("table");for(;++o<r.length;)a[o]=l(r[o],t,n);return i(),a
}(e,n,r),e.align)},tableCell:i,tableRow:function(e,t,n,r){const o=s([l(e,n,r)])
;return o.slice(0,o.indexOf("\n"))}}};function i(e,t,n,r){
const o=n.enter("tableCell"),i=n.enter("phrasing"),s=n.containerPhrasing(e,{
...r,before:a,after:a});return i(),o(),s}function s(e,t){
return function(e,t={}){
const n=(t.align||[]).concat(),r=t.stringLength||Cz,o=[],a=[],i=[],s=[]
;let l=0,c=-1;for(;++c<e.length;){const n=[],o=[];let d=-1
;for(e[c].length>l&&(l=e[c].length);++d<e[c].length;){
const a=null==(u=e[c][d])?"":String(u);if(!1!==t.alignDelimiters){const e=r(a)
;o[d]=e,(void 0===s[d]||e>s[d])&&(s[d]=e)}n.push(a)}a[c]=n,i[c]=o}var u;let d=-1
;if("object"==typeof n&&"length"in n)for(;++d<l;)o[d]=$z(n[d]);else{
const e=$z(n);for(;++d<l;)o[d]=e}d=-1;const p=[],h=[];for(;++d<l;){const e=o[d]
;let n="",r="";99===e?(n=":",r=":"):108===e?n=":":114===e&&(r=":")
;let a=!1===t.alignDelimiters?1:Math.max(1,s[d]-n.length-r.length)
;const i=n+"-".repeat(a)+r
;!1!==t.alignDelimiters&&(a=n.length+a+r.length,a>s[d]&&(s[d]=a),h[d]=a),p[d]=i}
a.splice(1,0,p),i.splice(1,0,h),c=-1;const f=[];for(;++c<a.length;){
const e=a[c],n=i[c];d=-1;const r=[];for(;++d<l;){const a=e[d]||"";let i="",c=""
;if(!1!==t.alignDelimiters){const e=s[d]-(n[d]||0),t=o[d]
;114===t?i=" ".repeat(e):99===t?e%2?(i=" ".repeat(e/2+.5),
c=" ".repeat(e/2-.5)):(i=" ".repeat(e/2),c=i):c=" ".repeat(e)}
!1===t.delimiterStart||d||r.push("|"),
!1===t.padding||!1===t.alignDelimiters&&""===a||!1===t.delimiterStart&&!d||r.push(" "),
!1!==t.alignDelimiters&&r.push(i),
r.push(a),!1!==t.alignDelimiters&&r.push(c),!1!==t.padding&&r.push(" "),
!1===t.delimiterEnd&&d===l-1||r.push("|")}
f.push(!1===t.delimiterEnd?r.join("").replace(/ +$/,""):r.join(""))}
return f.join("\n")}(e,{align:t,alignDelimiters:r,padding:n,stringLength:o})}
function l(e,t,n){const r=e.children;let o=-1;const a=[],s=t.enter("tableRow")
;for(;++o<r.length;)a[o]=i(r[o],0,t,n);return s(),a}}function BF(e){
const t=this.stack[this.stack.length-2]
;t.type,t.checked="taskListCheckValueChecked"===e.type}function jF(e){
const t=this.stack[this.stack.length-2]
;if(t&&"listItem"===t.type&&"boolean"==typeof t.checked){
const e=this.stack[this.stack.length-1];e.type;const n=e.children[0]
;if(n&&"text"===n.type){const r=t.children;let o,a=-1;for(;++a<r.length;){
const e=r[a];if("paragraph"===e.type){o=e;break}}
o===e&&(n.value=n.value.slice(1),
0===n.value.length?e.children.shift():e.position&&n.position&&"number"==typeof n.position.start.offset&&(n.position.start.column++,
n.position.start.offset++,e.position.start=Object.assign({},n.position.start)))}
}this.exit(e)}function UF(e,t,n,r){
const o=e.children[0],a="boolean"==typeof e.checked&&o&&"paragraph"===o.type,i="["+(e.checked?"x":" ")+"] ",s=n.createTracker(r)
;a&&s.move(i);let l=aF.listItem(e,t,n,{...r,...s.current()})
;return a&&(l=l.replace(/^(?:[*+-]|\d+\.)([\r\n]| {1,3})/,(function(e){
return e+i}))),l}function zF(e,t,n,r){const o=e.length;let a,i=0
;if(t=t<0?-t>o?0:o+t:t>o?o:t,
n=n>0?n:0,r.length<1e4)a=Array.from(r),a.unshift(t,n),
e.splice(...a);else for(n&&e.splice(t,n);i<r.length;)a=r.slice(i,i+1e4),
a.unshift(t,0),e.splice(...a),i+=1e4,t+=1e4}function FF(e,t){
return e.length>0?(zF(e,e.length,0,t),e):t}const ZF={}.hasOwnProperty
;function QF(e){const t={};let n=-1;for(;++n<e.length;)HF(t,e[n]);return t}
function HF(e,t){let n;for(n in t){
const r=(ZF.call(e,n)?e[n]:void 0)||(e[n]={}),o=t[n];let a;if(o)for(a in o){
ZF.call(r,a)||(r[a]=[]);const e=o[a];VF(r[a],Array.isArray(e)?e:e?[e]:[])}}}
function VF(e,t){let n=-1;const r=[]
;for(;++n<t.length;)("after"===t[n].add?e:r).push(t[n]);zF(e,0,0,r)}const qF={
tokenize:function(e,t,n){let r=0;return function t(a){
if((87===a||119===a)&&r<3)return r++,e.consume(a),t
;if(46===a&&3===r)return e.consume(a),o;return n(a)};function o(e){
return null===e?n(e):t(e)}},partial:!0},WF={tokenize:function(e,t,n){let r,o,a
;return i;function i(t){
return 46===t||95===t?e.check(GF,l,s)(t):null===t||qU(t)||GU(t)||45!==t&&XU(t)?l(t):(a=!0,
e.consume(t),i)}function s(t){return 95===t?r=!0:(o=r,r=void 0),e.consume(t),i}
function l(e){return o||r||!a?n(e):t(e)}},partial:!0},XF={
tokenize:function(e,t){let n=0,r=0;return o;function o(i){
return 40===i?(n++,e.consume(i),
o):41===i&&r<n?a(i):33===i||34===i||38===i||39===i||41===i||42===i||44===i||46===i||58===i||59===i||60===i||63===i||93===i||95===i||126===i?e.check(GF,t,a)(i):null===i||qU(i)||GU(i)?t(i):(e.consume(i),
o)}function a(t){return 41===t&&r++,e.consume(t),o}},partial:!0},GF={
tokenize:function(e,t,n){return r;function r(i){
return 33===i||34===i||39===i||41===i||42===i||44===i||46===i||58===i||59===i||63===i||95===i||126===i?(e.consume(i),
r):38===i?(e.consume(i),
a):93===i?(e.consume(i),o):60===i||null===i||qU(i)||GU(i)?t(i):n(i)}
function o(e){return null===e||40===e||91===e||qU(e)||GU(e)?t(e):r(e)}
function a(e){return jU(e)?i(e):n(e)}function i(t){
return 59===t?(e.consume(t),r):jU(t)?(e.consume(t),i):n(t)}},partial:!0},YF={
tokenize:function(e,t,n){return function(t){return e.consume(t),r}
;function r(e){return UU(e)?n(e):t(e)}},partial:!0},KF={
tokenize:function(e,t,n){const r=this;return function(t){
if(87!==t&&119!==t||!rZ.call(r,r.previous)||sZ(r.events))return n(t)
;return e.enter("literalAutolink"),
e.enter("literalAutolinkWww"),e.check(qF,e.attempt(WF,e.attempt(XF,o),n),n)(t)}
;function o(n){
return e.exit("literalAutolinkWww"),e.exit("literalAutolink"),t(n)}},previous:rZ
},JF={tokenize:function(e,t,n){const r=this;let o="",a=!1;return function(t){
if((72===t||104===t)&&oZ.call(r,r.previous)&&!sZ(r.events))return e.enter("literalAutolink"),
e.enter("literalAutolinkHttp"),o+=String.fromCodePoint(t),e.consume(t),i
;return n(t)};function i(t){
if(jU(t)&&o.length<5)return o+=String.fromCodePoint(t),e.consume(t),i
;if(58===t){const n=o.toLowerCase()
;if("http"===n||"https"===n)return e.consume(t),s}return n(t)}function s(t){
return 47===t?(e.consume(t),a?l:(a=!0,s)):n(t)}function l(t){
return null===t||FU(t)||qU(t)||GU(t)||XU(t)?n(t):e.attempt(WF,e.attempt(XF,c),n)(t)
}function c(n){
return e.exit("literalAutolinkHttp"),e.exit("literalAutolink"),t(n)}},
previous:oZ},eZ={tokenize:function(e,t,n){const r=this;let o,a
;return function(t){if(!iZ(t)||!aZ.call(r,r.previous)||sZ(r.events))return n(t)
;return e.enter("literalAutolink"),e.enter("literalAutolinkEmail"),i(t)}
;function i(t){return iZ(t)?(e.consume(t),i):64===t?(e.consume(t),s):n(t)}
function s(t){
return 46===t?e.check(YF,c,l)(t):45===t||95===t||UU(t)?(a=!0,e.consume(t),
s):c(t)}function l(t){return e.consume(t),o=!0,s}function c(i){
return a&&o&&jU(r.previous)?(e.exit("literalAutolinkEmail"),
e.exit("literalAutolink"),t(i)):n(i)}},previous:aZ},tZ={};let nZ=48
;for(;nZ<123;)tZ[nZ]=eZ,nZ++,58===nZ?nZ=65:91===nZ&&(nZ=97);function rZ(e){
return null===e||40===e||42===e||95===e||91===e||93===e||126===e||qU(e)}
function oZ(e){return!jU(e)}function aZ(e){return!(47===e||iZ(e))}
function iZ(e){return 43===e||45===e||46===e||95===e||UU(e)}function sZ(e){
let t=e.length,n=!1;for(;t--;){const r=e[t][1]
;if(("labelLink"===r.type||"labelImage"===r.type)&&!r._balanced){n=!0;break}
if(r._gfmAutolinkLiteralWalkedInto){n=!1;break}}
return e.length>0&&!n&&(e[e.length-1][1]._gfmAutolinkLiteralWalkedInto=!0),n}
function lZ(e){const t=[];let n=-1,r=0,o=0;for(;++n<e.length;){
const a=e.charCodeAt(n);let i=""
;if(37===a&&UU(e.charCodeAt(n+1))&&UU(e.charCodeAt(n+2)))o=2;else if(a<128)/[!#$&-;=?-Z_a-z~]/.test(String.fromCharCode(a))||(i=String.fromCharCode(a));else if(a>55295&&a<57344){
const t=e.charCodeAt(n+1);a<56320&&t>56319&&t<57344?(i=String.fromCharCode(a,t),
o=1):i="�"}else i=String.fromCharCode(a)
;i&&(t.push(e.slice(r,n),encodeURIComponent(i)),r=n+o+1,i=""),o&&(n+=o,o=0)}
return t.join("")+e.slice(r)}function cZ(e){
return null===e||qU(e)||GU(e)?1:XU(e)?2:void 0}function uZ(e,t,n){const r=[]
;let o=-1;for(;++o<e.length;){const a=e[o].resolveAll
;a&&!r.includes(a)&&(t=a(t,n),r.push(a))}return t}tZ[43]=eZ,tZ[45]=eZ,tZ[46]=eZ,
tZ[95]=eZ,tZ[72]=[eZ,JF],tZ[104]=[eZ,JF],tZ[87]=[eZ,KF],tZ[119]=[eZ,KF]
;const dZ={name:"attention",tokenize:function(e,t){
const n=this.parser.constructs.attentionMarkers.null,r=this.previous,o=cZ(r)
;let a;return function(t){return a=t,e.enter("attentionSequence"),i(t)}
;function i(s){if(s===a)return e.consume(s),i
;const l=e.exit("attentionSequence"),c=cZ(s),u=!c||2===c&&o||n.includes(s),d=!o||2===o&&c||n.includes(r)
;return l._open=Boolean(42===a?u:u&&(o||!d)),
l._close=Boolean(42===a?d:d&&(c||!u)),t(s)}},resolveAll:function(e,t){
let n,r,o,a,i,s,l,c,u=-1
;for(;++u<e.length;)if("enter"===e[u][0]&&"attentionSequence"===e[u][1].type&&e[u][1]._close)for(n=u;n--;)if("exit"===e[n][0]&&"attentionSequence"===e[n][1].type&&e[n][1]._open&&t.sliceSerialize(e[n][1]).charCodeAt(0)===t.sliceSerialize(e[u][1]).charCodeAt(0)){
if((e[n][1]._close||e[u][1]._open)&&(e[u][1].end.offset-e[u][1].start.offset)%3&&!((e[n][1].end.offset-e[n][1].start.offset+e[u][1].end.offset-e[u][1].start.offset)%3))continue
;s=e[n][1].end.offset-e[n][1].start.offset>1&&e[u][1].end.offset-e[u][1].start.offset>1?2:1
;const d=Object.assign({},e[n][1].end),p=Object.assign({},e[u][1].start)
;pZ(d,-s),pZ(p,s),a={type:s>1?"strongSequence":"emphasisSequence",start:d,
end:Object.assign({},e[n][1].end)},i={
type:s>1?"strongSequence":"emphasisSequence",
start:Object.assign({},e[u][1].start),end:p},o={
type:s>1?"strongText":"emphasisText",start:Object.assign({},e[n][1].end),
end:Object.assign({},e[u][1].start)},r={type:s>1?"strong":"emphasis",
start:Object.assign({},a.start),end:Object.assign({},i.end)
},e[n][1].end=Object.assign({},a.start),
e[u][1].start=Object.assign({},i.end),l=[],
e[n][1].end.offset-e[n][1].start.offset&&(l=FF(l,[["enter",e[n][1],t],["exit",e[n][1],t]])),
l=FF(l,[["enter",r,t],["enter",a,t],["exit",a,t],["enter",o,t]]),
l=FF(l,uZ(t.parser.constructs.insideSpan.null,e.slice(n+1,u),t)),
l=FF(l,[["exit",o,t],["enter",i,t],["exit",i,t],["exit",r,t]]),
e[u][1].end.offset-e[u][1].start.offset?(c=2,
l=FF(l,[["enter",e[u][1],t],["exit",e[u][1],t]])):c=0,
zF(e,n-1,u-n+3,l),u=n+l.length-c-2;break}u=-1
;for(;++u<e.length;)"attentionSequence"===e[u][1].type&&(e[u][1].type="data")
;return e}};function pZ(e,t){e.column+=t,e.offset+=t,e._bufferIndex+=t}
const hZ={name:"autolink",tokenize:function(e,t,n){let r=0;return function(t){
return e.enter("autolink"),
e.enter("autolinkMarker"),e.consume(t),e.exit("autolinkMarker"),
e.enter("autolinkProtocol"),o};function o(t){
return jU(t)?(e.consume(t),a):64===t?n(t):l(t)}function a(e){
return 43===e||45===e||46===e||UU(e)?(r=1,i(e)):l(e)}function i(t){
return 58===t?(e.consume(t),
r=0,s):(43===t||45===t||46===t||UU(t))&&r++<32?(e.consume(t),i):(r=0,l(t))}
function s(r){
return 62===r?(e.exit("autolinkProtocol"),e.enter("autolinkMarker"),
e.consume(r),
e.exit("autolinkMarker"),e.exit("autolink"),t):null===r||32===r||60===r||FU(r)?n(r):(e.consume(r),
s)}function l(t){return 64===t?(e.consume(t),c):zU(t)?(e.consume(t),l):n(t)}
function c(e){return UU(e)?u(e):n(e)}function u(n){
return 46===n?(e.consume(n),r=0,
c):62===n?(e.exit("autolinkProtocol").type="autolinkEmail",
e.enter("autolinkMarker"),
e.consume(n),e.exit("autolinkMarker"),e.exit("autolink"),t):d(n)}function d(t){
if((45===t||UU(t))&&r++<63){const n=45===t?d:u;return e.consume(t),n}return n(t)
}}};function fZ(e,t,n,r){const o=r?r-1:Number.POSITIVE_INFINITY;let a=0
;return function(r){if(WU(r))return e.enter(n),i(r);return t(r)};function i(r){
return WU(r)&&a++<o?(e.consume(r),i):(e.exit(n),t(r))}}const mZ={
tokenize:function(e,t,n){return function(t){
return WU(t)?fZ(e,r,"linePrefix")(t):r(t)};function r(e){
return null===e||VU(e)?t(e):n(e)}},partial:!0};const gZ={name:"blockQuote",
tokenize:function(e,t,n){const r=this;return function(t){if(62===t){
const n=r.containerState;return n.open||(e.enter("blockQuote",{_container:!0
}),n.open=!0),
e.enter("blockQuotePrefix"),e.enter("blockQuoteMarker"),e.consume(t),
e.exit("blockQuoteMarker"),o}return n(t)};function o(n){
return WU(n)?(e.enter("blockQuotePrefixWhitespace"),
e.consume(n),e.exit("blockQuotePrefixWhitespace"),
e.exit("blockQuotePrefix"),t):(e.exit("blockQuotePrefix"),t(n))}},continuation:{
tokenize:function(e,t,n){const r=this;return function(t){
if(WU(t))return fZ(e,o,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(t)
;return o(t)};function o(r){return e.attempt(gZ,t,n)(r)}}},exit:function(e){
e.exit("blockQuote")}};const vZ={name:"characterEscape",
tokenize:function(e,t,n){return function(t){
return e.enter("characterEscape"),e.enter("escapeMarker"),
e.consume(t),e.exit("escapeMarker"),r};function r(r){
return HU(r)?(e.enter("characterEscapeValue"),
e.consume(r),e.exit("characterEscapeValue"),e.exit("characterEscape"),t):n(r)}}}
;const bZ={name:"characterReference",tokenize:function(e,t,n){const r=this
;let o,a,i=0;return function(t){
return e.enter("characterReference"),e.enter("characterReferenceMarker"),
e.consume(t),e.exit("characterReferenceMarker"),s};function s(t){
return 35===t?(e.enter("characterReferenceMarkerNumeric"),
e.consume(t),e.exit("characterReferenceMarkerNumeric"),
l):(e.enter("characterReferenceValue"),o=31,a=UU,c(t))}function l(t){
return 88===t||120===t?(e.enter("characterReferenceMarkerHexadecimal"),
e.consume(t),
e.exit("characterReferenceMarkerHexadecimal"),e.enter("characterReferenceValue"),
o=6,a=QU,c):(e.enter("characterReferenceValue"),o=7,a=ZU,c(t))}function c(s){
if(59===s&&i){const o=e.exit("characterReferenceValue")
;return a!==UU||uF(r.sliceSerialize(o))?(e.enter("characterReferenceMarker"),
e.consume(s),
e.exit("characterReferenceMarker"),e.exit("characterReference"),t):n(s)}
return a(s)&&i++<o?(e.consume(s),c):n(s)}}};const yZ={tokenize:function(e,t,n){
const r=this;return function(t){if(null===t)return n(t)
;return e.enter("lineEnding"),e.consume(t),e.exit("lineEnding"),o}
;function o(e){return r.parser.lazy[r.now().line]?n(e):t(e)}},partial:!0},OZ={
name:"codeFenced",tokenize:function(e,t,n){const r=this,o={
tokenize:function(e,t,n){let o=0;return i;function i(t){
return e.enter("lineEnding"),e.consume(t),e.exit("lineEnding"),l}function l(t){
return e.enter("codeFencedFence"),
WU(t)?fZ(e,c,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(t):c(t)
}function c(t){return t===a?(e.enter("codeFencedFenceSequence"),u(t)):n(t)}
function u(t){
return t===a?(o++,e.consume(t),u):o>=s?(e.exit("codeFencedFenceSequence"),
WU(t)?fZ(e,d,"whitespace")(t):d(t)):n(t)}function d(r){
return null===r||VU(r)?(e.exit("codeFencedFence"),t(r)):n(r)}},partial:!0}
;let a,i=0,s=0;return function(t){return function(t){
const n=r.events[r.events.length-1]
;return i=n&&"linePrefix"===n[1].type?n[2].sliceSerialize(n[1],!0).length:0,a=t,
e.enter("codeFenced"),
e.enter("codeFencedFence"),e.enter("codeFencedFenceSequence"),l(t)}(t)}
;function l(t){
return t===a?(s++,e.consume(t),l):s<3?n(t):(e.exit("codeFencedFenceSequence"),
WU(t)?fZ(e,c,"whitespace")(t):c(t))}function c(n){
return null===n||VU(n)?(e.exit("codeFencedFence"),
r.interrupt?t(n):e.check(yZ,h,b)(n)):(e.enter("codeFencedFenceInfo"),
e.enter("chunkString",{contentType:"string"}),u(n))}function u(t){
return null===t||VU(t)?(e.exit("chunkString"),
e.exit("codeFencedFenceInfo"),c(t)):WU(t)?(e.exit("chunkString"),
e.exit("codeFencedFenceInfo"),
fZ(e,d,"whitespace")(t)):96===t&&t===a?n(t):(e.consume(t),u)}function d(t){
return null===t||VU(t)?c(t):(e.enter("codeFencedFenceMeta"),
e.enter("chunkString",{contentType:"string"}),p(t))}function p(t){
return null===t||VU(t)?(e.exit("chunkString"),
e.exit("codeFencedFenceMeta"),c(t)):96===t&&t===a?n(t):(e.consume(t),p)}
function h(t){return e.attempt(o,b,f)(t)}function f(t){
return e.enter("lineEnding"),e.consume(t),e.exit("lineEnding"),m}function m(t){
return i>0&&WU(t)?fZ(e,g,"linePrefix",i+1)(t):g(t)}function g(t){
return null===t||VU(t)?e.check(yZ,h,b)(t):(e.enter("codeFlowValue"),v(t))}
function v(t){
return null===t||VU(t)?(e.exit("codeFlowValue"),g(t)):(e.consume(t),v)}
function b(n){return e.exit("codeFenced"),t(n)}},concrete:!0};const wZ={
name:"codeIndented",tokenize:function(e,t,n){const r=this;return function(t){
return e.enter("codeIndented"),fZ(e,o,"linePrefix",5)(t)};function o(e){
const t=r.events[r.events.length-1]
;return t&&"linePrefix"===t[1].type&&t[2].sliceSerialize(t[1],!0).length>=4?a(e):n(e)
}function a(t){
return null===t?s(t):VU(t)?e.attempt(xZ,a,s)(t):(e.enter("codeFlowValue"),i(t))}
function i(t){
return null===t||VU(t)?(e.exit("codeFlowValue"),a(t)):(e.consume(t),i)}
function s(n){return e.exit("codeIndented"),t(n)}}},xZ={
tokenize:function(e,t,n){const r=this;return o;function o(t){
return r.parser.lazy[r.now().line]?n(t):VU(t)?(e.enter("lineEnding"),
e.consume(t),e.exit("lineEnding"),o):fZ(e,a,"linePrefix",5)(t)}function a(e){
const a=r.events[r.events.length-1]
;return a&&"linePrefix"===a[1].type&&a[2].sliceSerialize(a[1],!0).length>=4?t(e):VU(e)?o(e):n(e)
}},partial:!0};const kZ={name:"codeText",tokenize:function(e,t,n){let r,o,a=0
;return function(t){return e.enter("codeText"),e.enter("codeTextSequence"),i(t)}
;function i(t){
return 96===t?(e.consume(t),a++,i):(e.exit("codeTextSequence"),s(t))}
function s(t){
return null===t?n(t):32===t?(e.enter("space"),e.consume(t),e.exit("space"),
s):96===t?(o=e.enter("codeTextSequence"),r=0,c(t)):VU(t)?(e.enter("lineEnding"),
e.consume(t),e.exit("lineEnding"),s):(e.enter("codeTextData"),l(t))}
function l(t){
return null===t||32===t||96===t||VU(t)?(e.exit("codeTextData"),s(t)):(e.consume(t),
l)}function c(n){
return 96===n?(e.consume(n),r++,c):r===a?(e.exit("codeTextSequence"),
e.exit("codeText"),t(n)):(o.type="codeTextData",l(n))}},resolve:function(e){
let t,n,r=e.length-4,o=3
;if(!("lineEnding"!==e[o][1].type&&"space"!==e[o][1].type||"lineEnding"!==e[r][1].type&&"space"!==e[r][1].type))for(t=o;++t<r;)if("codeTextData"===e[t][1].type){
e[o][1].type="codeTextPadding",e[r][1].type="codeTextPadding",o+=2,r-=2;break}
t=o-1,r++
;for(;++t<=r;)void 0===n?t!==r&&"lineEnding"!==e[t][1].type&&(n=t):t!==r&&"lineEnding"!==e[t][1].type||(e[n][1].type="codeTextData",
t!==n+2&&(e[n][1].end=e[t-1][1].end,
e.splice(n+2,t-n-2),r-=t-n-2,t=n+2),n=void 0);return e},previous:function(e){
return 96!==e||"characterEscape"===this.events[this.events.length-1][1].type}}
;class SZ{constructor(e){this.left=e?[...e]:[],this.right=[]}get(e){
if(e<0||e>=this.left.length+this.right.length)throw new RangeError("Cannot access index `"+e+"` in a splice buffer of size `"+(this.left.length+this.right.length)+"`")
;return e<this.left.length?this.left[e]:this.right[this.right.length-e+this.left.length-1]
}get length(){return this.left.length+this.right.length}shift(){
return this.setCursor(0),this.right.pop()}slice(e,t){
const n=null==t?Number.POSITIVE_INFINITY:t
;return n<this.left.length?this.left.slice(e,n):e>this.left.length?this.right.slice(this.right.length-n+this.left.length,this.right.length-e+this.left.length).reverse():this.left.slice(e).concat(this.right.slice(this.right.length-n+this.left.length).reverse())
}splice(e,t,n){const r=t||0;this.setCursor(Math.trunc(e))
;const o=this.right.splice(this.right.length-r,Number.POSITIVE_INFINITY)
;return n&&_Z(this.left,n),o.reverse()}pop(){
return this.setCursor(Number.POSITIVE_INFINITY),this.left.pop()}push(e){
this.setCursor(Number.POSITIVE_INFINITY),this.left.push(e)}pushMany(e){
this.setCursor(Number.POSITIVE_INFINITY),_Z(this.left,e)}unshift(e){
this.setCursor(0),this.right.push(e)}unshiftMany(e){
this.setCursor(0),_Z(this.right,e.reverse())}setCursor(e){
if(!(e===this.left.length||e>this.left.length&&0===this.right.length||e<0&&0===this.left.length))if(e<this.left.length){
const t=this.left.splice(e,Number.POSITIVE_INFINITY);_Z(this.right,t.reverse())
}else{
const t=this.right.splice(this.left.length+this.right.length-e,Number.POSITIVE_INFINITY)
;_Z(this.left,t.reverse())}}}function _Z(e,t){let n=0
;if(t.length<1e4)e.push(...t);else for(;n<t.length;)e.push(...t.slice(n,n+1e4)),
n+=1e4}function TZ(e){const t={};let n,r,o,a,i,s,l,c=-1;const u=new SZ(e)
;for(;++c<u.length;){for(;c in t;)c=t[c]
;if(n=u.get(c),c&&"chunkFlow"===n[1].type&&"listItemPrefix"===u.get(c-1)[1].type&&(s=n[1]._tokenizer.events,
o=0,
o<s.length&&"lineEndingBlank"===s[o][1].type&&(o+=2),o<s.length&&"content"===s[o][1].type))for(;++o<s.length&&"content"!==s[o][1].type;)"chunkText"===s[o][1].type&&(s[o][1]._isInFirstContentOfListItem=!0,
o++)
;if("enter"===n[0])n[1].contentType&&(Object.assign(t,EZ(u,c)),c=t[c],l=!0);else if(n[1]._container){
for(o=c,
r=void 0;o--&&(a=u.get(o),"lineEnding"===a[1].type||"lineEndingBlank"===a[1].type);)"enter"===a[0]&&(r&&(u.get(r)[1].type="lineEndingBlank"),
a[1].type="lineEnding",r=o)
;r&&(n[1].end=Object.assign({},u.get(r)[1].start),i=u.slice(r,c),
i.unshift(n),u.splice(r,c-r+1,i))}}
return zF(e,0,Number.POSITIVE_INFINITY,u.slice(0)),!l}function EZ(e,t){
const n=e.get(t)[1],r=e.get(t)[2];let o=t-1
;const a=[],i=n._tokenizer||r.parser[n.contentType](n.start),s=i.events,l=[],c={}
;let u,d,p=-1,h=n,f=0,m=0;const g=[m];for(;h;){for(;e.get(++o)[1]!==h;);
a.push(o),
h._tokenizer||(u=r.sliceStream(h),h.next||u.push(null),d&&i.defineSkip(h.start),
h._isInFirstContentOfListItem&&(i._gfmTasklistFirstContentOfListItem=!0),
i.write(u),
h._isInFirstContentOfListItem&&(i._gfmTasklistFirstContentOfListItem=void 0)),
d=h,h=h.next}
for(h=n;++p<s.length;)"exit"===s[p][0]&&"enter"===s[p-1][0]&&s[p][1].type===s[p-1][1].type&&s[p][1].start.line!==s[p][1].end.line&&(m=p+1,
g.push(m),h._tokenizer=void 0,h.previous=void 0,h=h.next)
;for(i.events=[],h?(h._tokenizer=void 0,
h.previous=void 0):g.pop(),p=g.length;p--;){
const t=s.slice(g[p],g[p+1]),n=a.pop();l.push([n,n+t.length-1]),e.splice(n,2,t)}
for(l.reverse(),p=-1;++p<l.length;)c[f+l[p][0]]=f+l[p][1],f+=l[p][1]-l[p][0]-1
;return c}const AZ={tokenize:function(e,t){let n;return function(t){
return e.enter("content"),n=e.enter("chunkContent",{contentType:"content"}),r(t)
};function r(t){return null===t?o(t):VU(t)?e.check(CZ,a,o)(t):(e.consume(t),r)}
function o(n){return e.exit("chunkContent"),e.exit("content"),t(n)}
function a(t){
return e.consume(t),e.exit("chunkContent"),n.next=e.enter("chunkContent",{
contentType:"content",previous:n}),n=n.next,r}},resolve:function(e){
return TZ(e),e}},CZ={tokenize:function(e,t,n){const r=this;return function(t){
return e.exit("chunkContent"),
e.enter("lineEnding"),e.consume(t),e.exit("lineEnding"),fZ(e,o,"linePrefix")}
;function o(o){if(null===o||VU(o))return n(o)
;const a=r.events[r.events.length-1]
;return!r.parser.constructs.disable.null.includes("codeIndented")&&a&&"linePrefix"===a[1].type&&a[2].sliceSerialize(a[1],!0).length>=4?t(o):e.interrupt(r.parser.constructs.flow,n,t)(o)
}},partial:!0};function $Z(e,t,n,r,o,a,i,s,l){
const c=l||Number.POSITIVE_INFINITY;let u=0;return function(t){
if(60===t)return e.enter(r),e.enter(o),e.enter(a),e.consume(t),e.exit(a),d
;if(null===t||32===t||41===t||FU(t))return n(t)
;return e.enter(r),e.enter(i),e.enter(s),e.enter("chunkString",{
contentType:"string"}),f(t)};function d(n){
return 62===n?(e.enter(a),e.consume(n),
e.exit(a),e.exit(o),e.exit(r),t):(e.enter(s),e.enter("chunkString",{
contentType:"string"}),p(n))}function p(t){return 62===t?(e.exit("chunkString"),
e.exit(s),d(t)):null===t||60===t||VU(t)?n(t):(e.consume(t),92===t?h:p)}
function h(t){return 60===t||62===t||92===t?(e.consume(t),p):p(t)}function f(o){
return u||null!==o&&41!==o&&!qU(o)?u<c&&40===o?(e.consume(o),
u++,f):41===o?(e.consume(o),
u--,f):null===o||32===o||40===o||FU(o)?n(o):(e.consume(o),
92===o?m:f):(e.exit("chunkString"),e.exit(s),e.exit(i),e.exit(r),t(o))}
function m(t){return 40===t||41===t||92===t?(e.consume(t),f):f(t)}}
function PZ(e,t,n,r,o,a){const i=this;let s,l=0;return function(t){
return e.enter(r),e.enter(o),e.consume(t),e.exit(o),e.enter(a),c};function c(d){
return l>999||null===d||91===d||93===d&&!s||94===d&&!l&&"_hiddenFootnoteSupport"in i.parser.constructs?n(d):93===d?(e.exit(a),
e.enter(o),
e.consume(d),e.exit(o),e.exit(r),t):VU(d)?(e.enter("lineEnding"),e.consume(d),
e.exit("lineEnding"),c):(e.enter("chunkString",{contentType:"string"}),u(d))}
function u(t){
return null===t||91===t||93===t||VU(t)||l++>999?(e.exit("chunkString"),
c(t)):(e.consume(t),s||(s=!WU(t)),92===t?d:u)}function d(t){
return 91===t||92===t||93===t?(e.consume(t),l++,u):u(t)}}
function DZ(e,t,n,r,o,a){let i;return function(t){
if(34===t||39===t||40===t)return e.enter(r),
e.enter(o),e.consume(t),e.exit(o),i=40===t?41:t,s;return n(t)};function s(n){
return n===i?(e.enter(o),e.consume(n),e.exit(o),e.exit(r),t):(e.enter(a),l(n))}
function l(t){
return t===i?(e.exit(a),s(i)):null===t?n(t):VU(t)?(e.enter("lineEnding"),
e.consume(t),e.exit("lineEnding"),fZ(e,l,"linePrefix")):(e.enter("chunkString",{
contentType:"string"}),c(t))}function c(t){
return t===i||null===t||VU(t)?(e.exit("chunkString"),
l(t)):(e.consume(t),92===t?u:c)}function u(t){
return t===i||92===t?(e.consume(t),c):c(t)}}function IZ(e,t){let n
;return function r(o){
if(VU(o))return e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),n=!0,r
;if(WU(o))return fZ(e,r,n?"linePrefix":"lineSuffix")(o);return t(o)}}const MZ={
name:"definition",tokenize:function(e,t,n){const r=this;let o
;return function(t){return e.enter("definition"),function(t){
return PZ.call(r,e,a,n,"definitionLabel","definitionLabelMarker","definitionLabelString")(t)
}(t)};function a(t){
return o=hz(r.sliceSerialize(r.events[r.events.length-1][1]).slice(1,-1)),
58===t?(e.enter("definitionMarker"),
e.consume(t),e.exit("definitionMarker"),i):n(t)}function i(t){
return qU(t)?IZ(e,s)(t):s(t)}function s(t){
return $Z(e,l,n,"definitionDestination","definitionDestinationLiteral","definitionDestinationLiteralMarker","definitionDestinationRaw","definitionDestinationString")(t)
}function l(t){return e.attempt(NZ,c,c)(t)}function c(t){
return WU(t)?fZ(e,u,"whitespace")(t):u(t)}function u(a){
return null===a||VU(a)?(e.exit("definition"),r.parser.defined.push(o),t(a)):n(a)
}}},NZ={tokenize:function(e,t,n){return function(t){return qU(t)?IZ(e,r)(t):n(t)
};function r(t){
return DZ(e,o,n,"definitionTitle","definitionTitleMarker","definitionTitleString")(t)
}function o(t){return WU(t)?fZ(e,a,"whitespace")(t):a(t)}function a(e){
return null===e||VU(e)?t(e):n(e)}},partial:!0};const RZ={name:"hardBreakEscape",
tokenize:function(e,t,n){return function(t){
return e.enter("hardBreakEscape"),e.consume(t),r};function r(r){
return VU(r)?(e.exit("hardBreakEscape"),t(r)):n(r)}}};const LZ={
name:"headingAtx",tokenize:function(e,t,n){let r=0;return function(t){
return e.enter("atxHeading"),function(t){
return e.enter("atxHeadingSequence"),o(t)}(t)};function o(t){
return 35===t&&r++<6?(e.consume(t),
o):null===t||qU(t)?(e.exit("atxHeadingSequence"),a(t)):n(t)}function a(n){
return 35===n?(e.enter("atxHeadingSequence"),
i(n)):null===n||VU(n)?(e.exit("atxHeading"),
t(n)):WU(n)?fZ(e,a,"whitespace")(n):(e.enter("atxHeadingText"),s(n))}
function i(t){return 35===t?(e.consume(t),i):(e.exit("atxHeadingSequence"),a(t))
}function s(t){
return null===t||35===t||qU(t)?(e.exit("atxHeadingText"),a(t)):(e.consume(t),s)}
},resolve:function(e,t){let n,r,o=e.length-2,a=3
;"whitespace"===e[a][1].type&&(a+=2);o-2>a&&"whitespace"===e[o][1].type&&(o-=2)
;"atxHeadingSequence"===e[o][1].type&&(a===o-1||o-4>a&&"whitespace"===e[o-2][1].type)&&(o-=a+1===o?2:4)
;o>a&&(n={type:"atxHeadingText",start:e[a][1].start,end:e[o][1].end},r={
type:"chunkText",start:e[a][1].start,end:e[o][1].end,contentType:"text"
},zF(e,a,o-a+1,[["enter",n,t],["enter",r,t],["exit",r,t],["exit",n,t]]))
;return e}}
;const BZ=["address","article","aside","base","basefont","blockquote","body","caption","center","col","colgroup","dd","details","dialog","dir","div","dl","dt","fieldset","figcaption","figure","footer","form","frame","frameset","h1","h2","h3","h4","h5","h6","head","header","hr","html","iframe","legend","li","link","main","menu","menuitem","nav","noframes","ol","optgroup","option","p","param","search","section","summary","table","tbody","td","tfoot","th","thead","title","tr","track","ul"],jZ=["pre","script","style","textarea"],UZ={
name:"htmlFlow",tokenize:function(e,t,n){const r=this;let o,a,i,s,l
;return function(t){return function(t){
return e.enter("htmlFlow"),e.enter("htmlFlowData"),e.consume(t),c}(t)}
;function c(s){
return 33===s?(e.consume(s),u):47===s?(e.consume(s),a=!0,h):63===s?(e.consume(s),
o=3,r.interrupt?t:M):jU(s)?(e.consume(s),i=String.fromCharCode(s),f):n(s)}
function u(a){
return 45===a?(e.consume(a),o=2,d):91===a?(e.consume(a),o=5,s=0,p):jU(a)?(e.consume(a),
o=4,r.interrupt?t:M):n(a)}function d(o){
return 45===o?(e.consume(o),r.interrupt?t:M):n(o)}function p(o){const a="CDATA["
;return o===a.charCodeAt(s++)?(e.consume(o),6===s?r.interrupt?t:T:p):n(o)}
function h(t){return jU(t)?(e.consume(t),i=String.fromCharCode(t),f):n(t)}
function f(s){if(null===s||47===s||62===s||qU(s)){
const l=47===s,c=i.toLowerCase()
;return l||a||!jZ.includes(c)?BZ.includes(i.toLowerCase())?(o=6,l?(e.consume(s),
m):r.interrupt?t(s):T(s)):(o=7,
r.interrupt&&!r.parser.lazy[r.now().line]?n(s):a?g(s):v(s)):(o=1,
r.interrupt?t(s):T(s))}
return 45===s||UU(s)?(e.consume(s),i+=String.fromCharCode(s),f):n(s)}
function m(o){return 62===o?(e.consume(o),r.interrupt?t:T):n(o)}function g(t){
return WU(t)?(e.consume(t),g):S(t)}function v(t){
return 47===t?(e.consume(t),S):58===t||95===t||jU(t)?(e.consume(t),
b):WU(t)?(e.consume(t),v):S(t)}function b(t){
return 45===t||46===t||58===t||95===t||UU(t)?(e.consume(t),b):y(t)}
function y(t){return 61===t?(e.consume(t),O):WU(t)?(e.consume(t),y):v(t)}
function O(t){
return null===t||60===t||61===t||62===t||96===t?n(t):34===t||39===t?(e.consume(t),
l=t,w):WU(t)?(e.consume(t),O):x(t)}function w(t){
return t===l?(e.consume(t),l=null,k):null===t||VU(t)?n(t):(e.consume(t),w)}
function x(t){
return null===t||34===t||39===t||47===t||60===t||61===t||62===t||96===t||qU(t)?y(t):(e.consume(t),
x)}function k(e){return 47===e||62===e||WU(e)?v(e):n(e)}function S(t){
return 62===t?(e.consume(t),_):n(t)}function _(t){
return null===t||VU(t)?T(t):WU(t)?(e.consume(t),_):n(t)}function T(t){
return 45===t&&2===o?(e.consume(t),
$):60===t&&1===o?(e.consume(t),P):62===t&&4===o?(e.consume(t),
N):63===t&&3===o?(e.consume(t),
M):93===t&&5===o?(e.consume(t),I):!VU(t)||6!==o&&7!==o?null===t||VU(t)?(e.exit("htmlFlowData"),
E(t)):(e.consume(t),T):(e.exit("htmlFlowData"),e.check(zZ,R,E)(t))}
function E(t){return e.check(FZ,A,R)(t)}function A(t){
return e.enter("lineEnding"),e.consume(t),e.exit("lineEnding"),C}function C(t){
return null===t||VU(t)?E(t):(e.enter("htmlFlowData"),T(t))}function $(t){
return 45===t?(e.consume(t),M):T(t)}function P(t){
return 47===t?(e.consume(t),i="",D):T(t)}function D(t){if(62===t){
const n=i.toLowerCase();return jZ.includes(n)?(e.consume(t),N):T(t)}
return jU(t)&&i.length<8?(e.consume(t),i+=String.fromCharCode(t),D):T(t)}
function I(t){return 93===t?(e.consume(t),M):T(t)}function M(t){
return 62===t?(e.consume(t),N):45===t&&2===o?(e.consume(t),M):T(t)}
function N(t){
return null===t||VU(t)?(e.exit("htmlFlowData"),R(t)):(e.consume(t),N)}
function R(n){return e.exit("htmlFlow"),t(n)}},resolveTo:function(e){
let t=e.length;for(;t--&&("enter"!==e[t][0]||"htmlFlow"!==e[t][1].type););
t>1&&"linePrefix"===e[t-2][1].type&&(e[t][1].start=e[t-2][1].start,
e[t+1][1].start=e[t-2][1].start,e.splice(t-2,2));return e},concrete:!0},zZ={
tokenize:function(e,t,n){return function(r){
return e.enter("lineEnding"),e.consume(r),e.exit("lineEnding"),e.attempt(mZ,t,n)
}},partial:!0},FZ={tokenize:function(e,t,n){const r=this;return function(t){
if(VU(t))return e.enter("lineEnding"),e.consume(t),e.exit("lineEnding"),o
;return n(t)};function o(e){return r.parser.lazy[r.now().line]?n(e):t(e)}},
partial:!0};const ZZ={name:"htmlText",tokenize:function(e,t,n){const r=this
;let o,a,i;return function(t){
return e.enter("htmlText"),e.enter("htmlTextData"),e.consume(t),s}
;function s(t){
return 33===t?(e.consume(t),l):47===t?(e.consume(t),O):63===t?(e.consume(t),
b):jU(t)?(e.consume(t),k):n(t)}function l(t){
return 45===t?(e.consume(t),c):91===t?(e.consume(t),
a=0,h):jU(t)?(e.consume(t),v):n(t)}function c(t){
return 45===t?(e.consume(t),p):n(t)}function u(t){
return null===t?n(t):45===t?(e.consume(t),d):VU(t)?(i=u,D(t)):(e.consume(t),u)}
function d(t){return 45===t?(e.consume(t),p):u(t)}function p(e){
return 62===e?P(e):45===e?d(e):u(e)}function h(t){const r="CDATA["
;return t===r.charCodeAt(a++)?(e.consume(t),6===a?f:h):n(t)}function f(t){
return null===t?n(t):93===t?(e.consume(t),m):VU(t)?(i=f,D(t)):(e.consume(t),f)}
function m(t){return 93===t?(e.consume(t),g):f(t)}function g(t){
return 62===t?P(t):93===t?(e.consume(t),g):f(t)}function v(t){
return null===t||62===t?P(t):VU(t)?(i=v,D(t)):(e.consume(t),v)}function b(t){
return null===t?n(t):63===t?(e.consume(t),y):VU(t)?(i=b,D(t)):(e.consume(t),b)}
function y(e){return 62===e?P(e):b(e)}function O(t){
return jU(t)?(e.consume(t),w):n(t)}function w(t){
return 45===t||UU(t)?(e.consume(t),w):x(t)}function x(t){
return VU(t)?(i=x,D(t)):WU(t)?(e.consume(t),x):P(t)}function k(t){
return 45===t||UU(t)?(e.consume(t),k):47===t||62===t||qU(t)?S(t):n(t)}
function S(t){
return 47===t?(e.consume(t),P):58===t||95===t||jU(t)?(e.consume(t),
_):VU(t)?(i=S,D(t)):WU(t)?(e.consume(t),S):P(t)}function _(t){
return 45===t||46===t||58===t||95===t||UU(t)?(e.consume(t),_):T(t)}
function T(t){
return 61===t?(e.consume(t),E):VU(t)?(i=T,D(t)):WU(t)?(e.consume(t),T):S(t)}
function E(t){
return null===t||60===t||61===t||62===t||96===t?n(t):34===t||39===t?(e.consume(t),
o=t,A):VU(t)?(i=E,D(t)):WU(t)?(e.consume(t),E):(e.consume(t),C)}function A(t){
return t===o?(e.consume(t),
o=void 0,$):null===t?n(t):VU(t)?(i=A,D(t)):(e.consume(t),A)}function C(t){
return null===t||34===t||39===t||60===t||61===t||96===t?n(t):47===t||62===t||qU(t)?S(t):(e.consume(t),
C)}function $(e){return 47===e||62===e||qU(e)?S(e):n(e)}function P(r){
return 62===r?(e.consume(r),e.exit("htmlTextData"),e.exit("htmlText"),t):n(r)}
function D(t){
return e.exit("htmlTextData"),e.enter("lineEnding"),e.consume(t),e.exit("lineEnding"),
I}function I(t){
return WU(t)?fZ(e,M,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(t):M(t)
}function M(t){return e.enter("htmlTextData"),i(t)}}};const QZ={name:"labelEnd",
tokenize:function(e,t,n){const r=this;let o,a,i=r.events.length
;for(;i--;)if(("labelImage"===r.events[i][1].type||"labelLink"===r.events[i][1].type)&&!r.events[i][1]._balanced){
o=r.events[i][1];break}return function(t){if(!o)return n(t)
;if(o._inactive)return u(t)
;return a=r.parser.defined.includes(hz(r.sliceSerialize({start:o.end,end:r.now()
}))),
e.enter("labelEnd"),e.enter("labelMarker"),e.consume(t),e.exit("labelMarker"),
e.exit("labelEnd"),s};function s(t){
return 40===t?e.attempt(HZ,c,a?c:u)(t):91===t?e.attempt(VZ,c,a?l:u)(t):a?c(t):u(t)
}function l(t){return e.attempt(qZ,c,u)(t)}function c(e){return t(e)}
function u(e){return o._balanced=!0,n(e)}},resolveTo:function(e,t){
let n,r,o,a,i=e.length,s=0;for(;i--;)if(n=e[i][1],r){
if("link"===n.type||"labelLink"===n.type&&n._inactive)break
;"enter"===e[i][0]&&"labelLink"===n.type&&(n._inactive=!0)}else if(o){
if("enter"===e[i][0]&&("labelImage"===n.type||"labelLink"===n.type)&&!n._balanced&&(r=i,
"labelLink"!==n.type)){s=2;break}}else"labelEnd"===n.type&&(o=i);const l={
type:"labelLink"===e[r][1].type?"link":"image",
start:Object.assign({},e[r][1].start),end:Object.assign({},e[e.length-1][1].end)
},c={type:"label",start:Object.assign({},e[r][1].start),
end:Object.assign({},e[o][1].end)},u={type:"labelText",
start:Object.assign({},e[r+s+2][1].end),end:Object.assign({},e[o-2][1].start)}
;return a=[["enter",l,t],["enter",c,t]],
a=FF(a,e.slice(r+1,r+s+3)),a=FF(a,[["enter",u,t]]),
a=FF(a,uZ(t.parser.constructs.insideSpan.null,e.slice(r+s+4,o-3),t)),
a=FF(a,[["exit",u,t],e[o-2],e[o-1],["exit",c,t]]),
a=FF(a,e.slice(o+1)),a=FF(a,[["exit",l,t]]),zF(e,r,e.length,a),e},
resolveAll:function(e){let t=-1;for(;++t<e.length;){const n=e[t][1]
;"labelImage"!==n.type&&"labelLink"!==n.type&&"labelEnd"!==n.type||(e.splice(t+1,"labelImage"===n.type?4:2),
n.type="data",t++)}return e}},HZ={tokenize:function(e,t,n){return function(t){
return e.enter("resource"),
e.enter("resourceMarker"),e.consume(t),e.exit("resourceMarker"),r}
;function r(t){return qU(t)?IZ(e,o)(t):o(t)}function o(t){
return 41===t?c(t):$Z(e,a,i,"resourceDestination","resourceDestinationLiteral","resourceDestinationLiteralMarker","resourceDestinationRaw","resourceDestinationString",32)(t)
}function a(t){return qU(t)?IZ(e,s)(t):c(t)}function i(e){return n(e)}
function s(t){
return 34===t||39===t||40===t?DZ(e,l,n,"resourceTitle","resourceTitleMarker","resourceTitleString")(t):c(t)
}function l(t){return qU(t)?IZ(e,c)(t):c(t)}function c(r){
return 41===r?(e.enter("resourceMarker"),
e.consume(r),e.exit("resourceMarker"),e.exit("resource"),t):n(r)}}},VZ={
tokenize:function(e,t,n){const r=this;return function(t){
return PZ.call(r,e,o,a,"reference","referenceMarker","referenceString")(t)}
;function o(e){
return r.parser.defined.includes(hz(r.sliceSerialize(r.events[r.events.length-1][1]).slice(1,-1)))?t(e):n(e)
}function a(e){return n(e)}}},qZ={tokenize:function(e,t,n){return function(t){
return e.enter("reference"),
e.enter("referenceMarker"),e.consume(t),e.exit("referenceMarker"),r}
;function r(r){
return 93===r?(e.enter("referenceMarker"),e.consume(r),e.exit("referenceMarker"),
e.exit("reference"),t):n(r)}}};const WZ={name:"labelStartImage",
tokenize:function(e,t,n){const r=this;return function(t){
return e.enter("labelImage"),
e.enter("labelImageMarker"),e.consume(t),e.exit("labelImageMarker"),o}
;function o(t){
return 91===t?(e.enter("labelMarker"),e.consume(t),e.exit("labelMarker"),
e.exit("labelImage"),a):n(t)}function a(e){
return 94===e&&"_hiddenFootnoteSupport"in r.parser.constructs?n(e):t(e)}},
resolveAll:QZ.resolveAll};const XZ={name:"labelStartLink",
tokenize:function(e,t,n){const r=this;return function(t){
return e.enter("labelLink"),
e.enter("labelMarker"),e.consume(t),e.exit("labelMarker"),e.exit("labelLink"),o}
;function o(e){
return 94===e&&"_hiddenFootnoteSupport"in r.parser.constructs?n(e):t(e)}},
resolveAll:QZ.resolveAll};const GZ={name:"lineEnding",tokenize:function(e,t){
return function(n){
return e.enter("lineEnding"),e.consume(n),e.exit("lineEnding"),
fZ(e,t,"linePrefix")}}};const YZ={name:"thematicBreak",tokenize:function(e,t,n){
let r,o=0;return function(t){return e.enter("thematicBreak"),function(e){
return r=e,a(e)}(t)};function a(a){
return a===r?(e.enter("thematicBreakSequence"),
i(a)):o>=3&&(null===a||VU(a))?(e.exit("thematicBreak"),t(a)):n(a)}function i(t){
return t===r?(e.consume(t),
o++,i):(e.exit("thematicBreakSequence"),WU(t)?fZ(e,a,"whitespace")(t):a(t))}}}
;const KZ={name:"list",tokenize:function(e,t,n){
const r=this,o=r.events[r.events.length-1]
;let a=o&&"linePrefix"===o[1].type?o[2].sliceSerialize(o[1],!0).length:0,i=0
;return function(t){
const o=r.containerState.type||(42===t||43===t||45===t?"listUnordered":"listOrdered")
;if("listUnordered"===o?!r.containerState.marker||t===r.containerState.marker:ZU(t)){
if(r.containerState.type||(r.containerState.type=o,e.enter(o,{_container:!0
})),"listUnordered"===o)return e.enter("listItemPrefix"),
42===t||45===t?e.check(YZ,n,l)(t):l(t)
;if(!r.interrupt||49===t)return e.enter("listItemPrefix"),
e.enter("listItemValue"),s(t)}return n(t)};function s(t){
return ZU(t)&&++i<10?(e.consume(t),
s):(!r.interrupt||i<2)&&(r.containerState.marker?t===r.containerState.marker:41===t||46===t)?(e.exit("listItemValue"),
l(t)):n(t)}function l(t){
return e.enter("listItemMarker"),e.consume(t),e.exit("listItemMarker"),
r.containerState.marker=r.containerState.marker||t,
e.check(mZ,r.interrupt?n:c,e.attempt(JZ,d,u))}function c(e){
return r.containerState.initialBlankLine=!0,a++,d(e)}function u(t){
return WU(t)?(e.enter("listItemPrefixWhitespace"),
e.consume(t),e.exit("listItemPrefixWhitespace"),d):n(t)}function d(n){
return r.containerState.size=a+r.sliceSerialize(e.exit("listItemPrefix"),!0).length,
t(n)}},continuation:{tokenize:function(e,t,n){const r=this
;return r.containerState._closeFlow=void 0,e.check(mZ,(function(n){
return r.containerState.furtherBlankLines=r.containerState.furtherBlankLines||r.containerState.initialBlankLine,
fZ(e,t,"listItemIndent",r.containerState.size+1)(n)}),(function(n){
if(r.containerState.furtherBlankLines||!WU(n))return r.containerState.furtherBlankLines=void 0,
r.containerState.initialBlankLine=void 0,o(n)
;return r.containerState.furtherBlankLines=void 0,
r.containerState.initialBlankLine=void 0,e.attempt(eQ,t,o)(n)}));function o(o){
return r.containerState._closeFlow=!0,
r.interrupt=void 0,fZ(e,e.attempt(KZ,t,n),"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(o)
}}},exit:function(e){e.exit(this.containerState.type)}},JZ={
tokenize:function(e,t,n){const r=this;return fZ(e,(function(e){
const o=r.events[r.events.length-1]
;return!WU(e)&&o&&"listItemPrefixWhitespace"===o[1].type?t(e):n(e)
}),"listItemPrefixWhitespace",r.parser.constructs.disable.null.includes("codeIndented")?void 0:5)
},partial:!0},eQ={tokenize:function(e,t,n){const r=this
;return fZ(e,(function(e){const o=r.events[r.events.length-1]
;return o&&"listItemIndent"===o[1].type&&o[2].sliceSerialize(o[1],!0).length===r.containerState.size?t(e):n(e)
}),"listItemIndent",r.containerState.size+1)},partial:!0};const tQ={
name:"setextUnderline",tokenize:function(e,t,n){const r=this;let o
;return function(t){let i,s=r.events.length
;for(;s--;)if("lineEnding"!==r.events[s][1].type&&"linePrefix"!==r.events[s][1].type&&"content"!==r.events[s][1].type){
i="paragraph"===r.events[s][1].type;break}
if(!r.parser.lazy[r.now().line]&&(r.interrupt||i))return e.enter("setextHeadingLine"),
o=t,function(t){return e.enter("setextHeadingLineSequence"),a(t)}(t);return n(t)
};function a(t){
return t===o?(e.consume(t),a):(e.exit("setextHeadingLineSequence"),
WU(t)?fZ(e,i,"lineSuffix")(t):i(t))}function i(r){
return null===r||VU(r)?(e.exit("setextHeadingLine"),t(r)):n(r)}},
resolveTo:function(e,t){let n,r,o,a=e.length;for(;a--;)if("enter"===e[a][0]){
if("content"===e[a][1].type){n=a;break}"paragraph"===e[a][1].type&&(r=a)
}else"content"===e[a][1].type&&e.splice(a,1),
o||"definition"!==e[a][1].type||(o=a);const i={type:"setextHeading",
start:Object.assign({},e[r][1].start),end:Object.assign({},e[e.length-1][1].end)
}
;e[r][1].type="setextHeadingText",o?(e.splice(r,0,["enter",i,t]),e.splice(o+1,0,["exit",e[n][1],t]),
e[n][1].end=Object.assign({},e[o][1].end)):e[n][1]=i
;return e.push(["exit",i,t]),e}};const nQ={tokenize:function(e,t,n){const r=this
;return fZ(e,(function(e){const o=r.events[r.events.length-1]
;return o&&"gfmFootnoteDefinitionIndent"===o[1].type&&4===o[2].sliceSerialize(o[1],!0).length?t(e):n(e)
}),"gfmFootnoteDefinitionIndent",5)},partial:!0};function rQ(e,t,n){const r=this
;let o=r.events.length;const a=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[])
;let i;for(;o--;){const e=r.events[o][1];if("labelImage"===e.type){i=e;break}
if("gfmFootnoteCall"===e.type||"labelLink"===e.type||"label"===e.type||"image"===e.type||"link"===e.type)break
}return function(o){if(!i||!i._balanced)return n(o)
;const s=hz(r.sliceSerialize({start:i.end,end:r.now()}))
;if(94!==s.codePointAt(0)||!a.includes(s.slice(1)))return n(o)
;return e.enter("gfmFootnoteCallLabelMarker"),
e.consume(o),e.exit("gfmFootnoteCallLabelMarker"),t(o)}}function oQ(e,t){
let n=e.length;for(;n--;)if("labelImage"===e[n][1].type&&"enter"===e[n][0]){
e[n][1];break}e[n+1][1].type="data",e[n+3][1].type="gfmFootnoteCallLabelMarker"
;const r={type:"gfmFootnoteCall",start:Object.assign({},e[n+3][1].start),
end:Object.assign({},e[e.length-1][1].end)},o={type:"gfmFootnoteCallMarker",
start:Object.assign({},e[n+3][1].end),end:Object.assign({},e[n+3][1].end)}
;o.end.column++,o.end.offset++,o.end._bufferIndex++;const a={
type:"gfmFootnoteCallString",start:Object.assign({},o.end),
end:Object.assign({},e[e.length-1][1].start)},i={type:"chunkString",
contentType:"string",start:Object.assign({},a.start),end:Object.assign({},a.end)
},s=[e[n+1],e[n+2],["enter",r,t],e[n+3],e[n+4],["enter",o,t],["exit",o,t],["enter",a,t],["enter",i,t],["exit",i,t],["exit",a,t],e[e.length-2],e[e.length-1],["exit",r,t]]
;return e.splice(n,e.length-n+1,...s),e}function aQ(e,t,n){
const r=this,o=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let a,i=0
;return function(t){
return e.enter("gfmFootnoteCall"),e.enter("gfmFootnoteCallLabelMarker"),
e.consume(t),e.exit("gfmFootnoteCallLabelMarker"),s};function s(t){
return 94!==t?n(t):(e.enter("gfmFootnoteCallMarker"),
e.consume(t),e.exit("gfmFootnoteCallMarker"),
e.enter("gfmFootnoteCallString"),e.enter("chunkString").contentType="string",l)}
function l(s){if(i>999||93===s&&!a||null===s||91===s||qU(s))return n(s)
;if(93===s){e.exit("chunkString");const a=e.exit("gfmFootnoteCallString")
;return o.includes(hz(r.sliceSerialize(a)))?(e.enter("gfmFootnoteCallLabelMarker"),
e.consume(s),
e.exit("gfmFootnoteCallLabelMarker"),e.exit("gfmFootnoteCall"),t):n(s)}
return qU(s)||(a=!0),i++,e.consume(s),92===s?c:l}function c(t){
return 91===t||92===t||93===t?(e.consume(t),i++,l):l(t)}}function iQ(e,t,n){
const r=this,o=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let a,i,s=0
;return function(t){
return e.enter("gfmFootnoteDefinition")._container=!0,e.enter("gfmFootnoteDefinitionLabel"),
e.enter("gfmFootnoteDefinitionLabelMarker"),
e.consume(t),e.exit("gfmFootnoteDefinitionLabelMarker"),l};function l(t){
return 94===t?(e.enter("gfmFootnoteDefinitionMarker"),
e.consume(t),e.exit("gfmFootnoteDefinitionMarker"),
e.enter("gfmFootnoteDefinitionLabelString"),
e.enter("chunkString").contentType="string",c):n(t)}function c(t){
if(s>999||93===t&&!i||null===t||91===t||qU(t))return n(t);if(93===t){
e.exit("chunkString");const n=e.exit("gfmFootnoteDefinitionLabelString")
;return a=hz(r.sliceSerialize(n)),
e.enter("gfmFootnoteDefinitionLabelMarker"),e.consume(t),
e.exit("gfmFootnoteDefinitionLabelMarker"),e.exit("gfmFootnoteDefinitionLabel"),
d}return qU(t)||(i=!0),s++,e.consume(t),92===t?u:c}function u(t){
return 91===t||92===t||93===t?(e.consume(t),s++,c):c(t)}function d(t){
return 58===t?(e.enter("definitionMarker"),
e.consume(t),e.exit("definitionMarker"),
o.includes(a)||o.push(a),fZ(e,p,"gfmFootnoteDefinitionWhitespace")):n(t)}
function p(e){return t(e)}}function sQ(e,t,n){
return e.check(mZ,t,e.attempt(nQ,t,n))}function lQ(e){
e.exit("gfmFootnoteDefinition")}function cQ(e){let t=(e||{}).singleTilde
;const n={tokenize:function(e,n,r){const o=this.previous,a=this.events;let i=0
;return function(t){
if(126===o&&"characterEscape"!==a[a.length-1][1].type)return r(t)
;return e.enter("strikethroughSequenceTemporary"),s(t)};function s(a){
const l=cZ(o);if(126===a)return i>1?r(a):(e.consume(a),i++,s)
;if(i<2&&!t)return r(a);const c=e.exit("strikethroughSequenceTemporary"),u=cZ(a)
;return c._open=!u||2===u&&Boolean(l),c._close=!l||2===l&&Boolean(u),n(a)}},
resolveAll:function(e,t){let n=-1
;for(;++n<e.length;)if("enter"===e[n][0]&&"strikethroughSequenceTemporary"===e[n][1].type&&e[n][1]._close){
let r=n
;for(;r--;)if("exit"===e[r][0]&&"strikethroughSequenceTemporary"===e[r][1].type&&e[r][1]._open&&e[n][1].end.offset-e[n][1].start.offset==e[r][1].end.offset-e[r][1].start.offset){
e[n][1].type="strikethroughSequence",e[r][1].type="strikethroughSequence"
;const o={type:"strikethrough",start:Object.assign({},e[r][1].start),
end:Object.assign({},e[n][1].end)},a={type:"strikethroughText",
start:Object.assign({},e[r][1].end),end:Object.assign({},e[n][1].start)
},i=[["enter",o,t],["enter",e[r][1],t],["exit",e[r][1],t],["enter",a,t]],s=t.parser.constructs.insideSpan.null
;s&&zF(i,i.length,0,uZ(s,e.slice(r+1,n),t)),
zF(i,i.length,0,[["exit",a,t],["enter",e[n][1],t],["exit",e[n][1],t],["exit",o,t]]),
zF(e,r-1,n-r+3,i),n=r+i.length-2;break}}n=-1
;for(;++n<e.length;)"strikethroughSequenceTemporary"===e[n][1].type&&(e[n][1].type="data")
;return e}};return null==t&&(t=!0),{text:{126:n},insideSpan:{null:[n]},
attentionMarkers:{null:[126]}}}class uQ{constructor(){this.map=[]}add(e,t,n){
!function(e,t,n,r){let o=0;if(0===n&&0===r.length)return;for(;o<e.map.length;){
if(e.map[o][0]===t)return e.map[o][1]+=n,void e.map[o][2].push(...r);o+=1}
e.map.push([t,n,r])}(this,e,t,n)}consume(e){if(this.map.sort((function(e,t){
return e[0]-t[0]})),0===this.map.length)return;let t=this.map.length;const n=[]
;for(;t>0;)t-=1,
n.push(e.slice(this.map[t][0]+this.map[t][1]),this.map[t][2]),e.length=this.map[t][0]
;n.push([...e]),e.length=0;let r=n.pop();for(;r;)e.push(...r),r=n.pop()
;this.map.length=0}}function dQ(e,t){let n=!1;const r=[];for(;t<e.length;){
const o=e[t];if(n){
if("enter"===o[0])"tableContent"===o[1].type&&r.push("tableDelimiterMarker"===e[t+1][1].type?"left":"none");else if("tableContent"===o[1].type){
if("tableDelimiterMarker"===e[t-1][1].type){const e=r.length-1
;r[e]="left"===r[e]?"center":"right"}
}else if("tableDelimiterRow"===o[1].type)break
}else"enter"===o[0]&&"tableDelimiterRow"===o[1].type&&(n=!0);t+=1}return r}
function pQ(e,t,n){const r=this;let o,a=0,i=0;return function(e){
let t=r.events.length-1;for(;t>-1;){const e=r.events[t][1].type
;if("lineEnding"!==e&&"linePrefix"!==e)break;t--}
const o=t>-1?r.events[t][1].type:null,a="tableHead"===o||"tableRow"===o?O:s
;if(a===O&&r.parser.lazy[r.now().line])return n(e);return a(e)};function s(t){
return e.enter("tableHead"),e.enter("tableRow"),function(e){
if(124===e)return l(e);return o=!0,i+=1,l(e)}(t)}function l(t){
return null===t?n(t):VU(t)?i>1?(i=0,
r.interrupt=!0,e.exit("tableRow"),e.enter("lineEnding"),
e.consume(t),e.exit("lineEnding"),
d):n(t):WU(t)?fZ(e,l,"whitespace")(t):(i+=1,o&&(o=!1,
a+=1),124===t?(e.enter("tableCellDivider"),
e.consume(t),e.exit("tableCellDivider"),o=!0,l):(e.enter("data"),c(t)))}
function c(t){
return null===t||124===t||qU(t)?(e.exit("data"),l(t)):(e.consume(t),92===t?u:c)}
function u(t){return 92===t||124===t?(e.consume(t),c):c(t)}function d(t){
return r.interrupt=!1,
r.parser.lazy[r.now().line]?n(t):(e.enter("tableDelimiterRow"),
o=!1,WU(t)?fZ(e,p,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(t):p(t))
}function p(t){
return 45===t||58===t?f(t):124===t?(o=!0,e.enter("tableCellDivider"),
e.consume(t),e.exit("tableCellDivider"),h):y(t)}function h(t){
return WU(t)?fZ(e,f,"whitespace")(t):f(t)}function f(t){
return 58===t?(i+=1,o=!0,
e.enter("tableDelimiterMarker"),e.consume(t),e.exit("tableDelimiterMarker"),
m):45===t?(i+=1,m(t)):null===t||VU(t)?b(t):y(t)}function m(t){
return 45===t?(e.enter("tableDelimiterFiller"),g(t)):y(t)}function g(t){
return 45===t?(e.consume(t),
g):58===t?(o=!0,e.exit("tableDelimiterFiller"),e.enter("tableDelimiterMarker"),
e.consume(t),
e.exit("tableDelimiterMarker"),v):(e.exit("tableDelimiterFiller"),v(t))}
function v(t){return WU(t)?fZ(e,b,"whitespace")(t):b(t)}function b(n){
return 124===n?p(n):(null===n||VU(n))&&o&&a===i?(e.exit("tableDelimiterRow"),
e.exit("tableHead"),t(n)):y(n)}function y(e){return n(e)}function O(t){
return e.enter("tableRow"),w(t)}function w(n){
return 124===n?(e.enter("tableCellDivider"),
e.consume(n),e.exit("tableCellDivider"),
w):null===n||VU(n)?(e.exit("tableRow"),t(n)):WU(n)?fZ(e,w,"whitespace")(n):(e.enter("data"),
x(n))}function x(t){
return null===t||124===t||qU(t)?(e.exit("data"),w(t)):(e.consume(t),92===t?k:x)}
function k(t){return 92===t||124===t?(e.consume(t),x):x(t)}}function hQ(e,t){
let n,r,o,a=-1,i=!0,s=0,l=[0,0,0,0],c=[0,0,0,0],u=!1,d=0;const p=new uQ
;for(;++a<e.length;){const h=e[a],f=h[1]
;"enter"===h[0]?"tableHead"===f.type?(u=!1,
0!==d&&(mQ(p,t,d,n,r),r=void 0,d=0),n={type:"table",
start:Object.assign({},f.start),end:Object.assign({},f.end)
},p.add(a,0,[["enter",n,t]])):"tableRow"===f.type||"tableDelimiterRow"===f.type?(i=!0,
o=void 0,l=[0,0,0,0],c=[0,a+1,0,0],u&&(u=!1,r={type:"tableBody",
start:Object.assign({},f.start),end:Object.assign({},f.end)
},p.add(a,0,[["enter",r,t]])),
s="tableDelimiterRow"===f.type?2:r?3:1):!s||"data"!==f.type&&"tableDelimiterMarker"!==f.type&&"tableDelimiterFiller"!==f.type?"tableCellDivider"===f.type&&(i?i=!1:(0!==l[1]&&(c[0]=c[1],
o=fQ(p,t,l,s,void 0,o)),
l=c,c=[l[1],a,0,0])):(i=!1,0===c[2]&&(0!==l[1]&&(c[0]=c[1],
o=fQ(p,t,l,s,void 0,o),
l=[0,0,0,0]),c[2]=a)):"tableHead"===f.type?(u=!0,d=a):"tableRow"===f.type||"tableDelimiterRow"===f.type?(d=a,
0!==l[1]?(c[0]=c[1],
o=fQ(p,t,l,s,a,o)):0!==c[1]&&(o=fQ(p,t,c,s,a,o)),s=0):!s||"data"!==f.type&&"tableDelimiterMarker"!==f.type&&"tableDelimiterFiller"!==f.type||(c[3]=a)
}for(0!==d&&mQ(p,t,d,n,r),p.consume(t.events),a=-1;++a<t.events.length;){
const e=t.events[a]
;"enter"===e[0]&&"table"===e[1].type&&(e[1]._align=dQ(t.events,a))}return e}
function fQ(e,t,n,r,o,a){
const i=1===r?"tableHeader":2===r?"tableDelimiter":"tableData"
;0!==n[0]&&(a.end=Object.assign({},gQ(t.events,n[0])),
e.add(n[0],0,[["exit",a,t]]));const s=gQ(t.events,n[1]);if(a={type:i,
start:Object.assign({},s),end:Object.assign({},s)
},e.add(n[1],0,[["enter",a,t]]),0!==n[2]){
const o=gQ(t.events,n[2]),a=gQ(t.events,n[3]),i={type:"tableContent",
start:Object.assign({},o),end:Object.assign({},a)}
;if(e.add(n[2],0,[["enter",i,t]]),2!==r){const r=t.events[n[2]],o=t.events[n[3]]
;if(r[1].end=Object.assign({},o[1].end),
r[1].type="chunkText",r[1].contentType="text",n[3]>n[2]+1){
const t=n[2]+1,r=n[3]-n[2]-1;e.add(t,r,[])}}e.add(n[3]+1,0,[["exit",i,t]])}
return void 0!==o&&(a.end=Object.assign({},gQ(t.events,o)),
e.add(o,0,[["exit",a,t]]),a=void 0),a}function mQ(e,t,n,r,o){
const a=[],i=gQ(t.events,n);o&&(o.end=Object.assign({},i),a.push(["exit",o,t])),
r.end=Object.assign({},i),a.push(["exit",r,t]),e.add(n+1,0,a)}function gQ(e,t){
const n=e[t],r="enter"===n[0]?"start":"end";return n[1][r]}const vQ={
tokenize:function(e,t,n){const r=this;return function(t){
if(null!==r.previous||!r._gfmTasklistFirstContentOfListItem)return n(t)
;return e.enter("taskListCheck"),
e.enter("taskListCheckMarker"),e.consume(t),e.exit("taskListCheckMarker"),o}
;function o(t){
return qU(t)?(e.enter("taskListCheckValueUnchecked"),e.consume(t),
e.exit("taskListCheckValueUnchecked"),
a):88===t||120===t?(e.enter("taskListCheckValueChecked"),
e.consume(t),e.exit("taskListCheckValueChecked"),a):n(t)}function a(t){
return 93===t?(e.enter("taskListCheckMarker"),
e.consume(t),e.exit("taskListCheckMarker"),e.exit("taskListCheck"),i):n(t)}
function i(r){return VU(r)?t(r):WU(r)?e.check({tokenize:bQ},t,n)(r):n(r)}}}
;function bQ(e,t,n){return fZ(e,(function(e){return null===e?n(e):t(e)
}),"whitespace")}const yQ={};function OQ(e){
const t=e||yQ,n=this.data(),r=n.micromarkExtensions||(n.micromarkExtensions=[]),o=n.fromMarkdownExtensions||(n.fromMarkdownExtensions=[]),a=n.toMarkdownExtensions||(n.toMarkdownExtensions=[])
;r.push(function(e){return QF([{text:tZ},{document:{91:{tokenize:iQ,
continuation:{tokenize:sQ},exit:lQ}},text:{91:{tokenize:aQ},93:{add:"after",
tokenize:rQ,resolveTo:oQ}}},cQ(e),{flow:{null:{tokenize:pQ,resolveAll:hQ}}},{
text:{91:vQ}}])}(t)),o.push([{transforms:[cz],enter:{literalAutolink:rz,
literalAutolinkEmail:oz,literalAutolinkHttp:oz,literalAutolinkWww:oz},exit:{
literalAutolink:lz,literalAutolinkEmail:sz,literalAutolinkHttp:az,
literalAutolinkWww:iz}},{enter:{gfmFootnoteDefinition:fz,
gfmFootnoteDefinitionLabelString:mz,gfmFootnoteCall:bz,gfmFootnoteCallString:yz
},exit:{gfmFootnoteDefinition:vz,gfmFootnoteDefinitionLabelString:gz,
gfmFootnoteCall:wz,gfmFootnoteCallString:Oz}},{canContainEols:["delete"],enter:{
strikethrough:Tz},exit:{strikethrough:Ez}},{enter:{table:$F,tableData:MF,
tableHeader:MF,tableRow:DF},exit:{codeText:NF,table:PF,tableData:IF,
tableHeader:IF,tableRow:IF}},{exit:{taskListCheckValueChecked:BF,
taskListCheckValueUnchecked:BF,paragraph:jF}}]),a.push(function(e){return{
extensions:[{unsafe:[{character:"@",before:"[+\\-.\\w]",after:"[\\-.\\w]",
inConstruct:tz,notInConstruct:nz},{character:".",before:"[Ww]",
after:"[\\-.\\w]",inConstruct:tz,notInConstruct:nz},{character:":",
before:"[ps]",after:"\\/",inConstruct:tz,notInConstruct:nz}]},{unsafe:[{
character:"[",inConstruct:["phrasing","label","reference"]}],handlers:{
footnoteDefinition:kz,footnoteReference:xz}},{unsafe:[{character:"~",
inConstruct:"phrasing",notInConstruct:_z}],handlers:{delete:Az}},LF(e),{
unsafe:[{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{listItem:UF}}]}}(t))
}const wQ={tokenize:function(e){
const t=e.attempt(this.parser.constructs.contentInitial,(function(n){
if(null===n)return void e.consume(n)
;return e.enter("lineEnding"),e.consume(n),e.exit("lineEnding"),
fZ(e,t,"linePrefix")}),(function(t){return e.enter("paragraph"),r(t)}));let n
;return t;function r(t){const r=e.enter("chunkText",{contentType:"text",
previous:n});return n&&(n.next=r),n=r,o(t)}function o(t){
return null===t?(e.exit("chunkText"),
e.exit("paragraph"),void e.consume(t)):VU(t)?(e.consume(t),
e.exit("chunkText"),r):(e.consume(t),o)}}};const xQ={tokenize:function(e){
const t=this,n=[];let r,o,a,i=0;return s;function s(r){if(i<n.length){
const o=n[i];return t.containerState=o[1],e.attempt(o[0].continuation,l,c)(r)}
return c(r)}function l(e){if(i++,t.containerState._closeFlow){
t.containerState._closeFlow=void 0,r&&b();const n=t.events.length;let o,a=n
;for(;a--;)if("exit"===t.events[a][0]&&"chunkFlow"===t.events[a][1].type){
o=t.events[a][1].end;break}v(i);let s=n
;for(;s<t.events.length;)t.events[s][1].end=Object.assign({},o),s++
;return zF(t.events,a+1,0,t.events.slice(n)),t.events.length=s,c(e)}return s(e)}
function c(o){if(i===n.length){if(!r)return p(o)
;if(r.currentConstruct&&r.currentConstruct.concrete)return f(o)
;t.interrupt=Boolean(r.currentConstruct&&!r._gfmTableDynamicInterruptHack)}
return t.containerState={},e.check(kQ,u,d)(o)}function u(e){
return r&&b(),v(i),p(e)}function d(e){
return t.parser.lazy[t.now().line]=i!==n.length,a=t.now().offset,f(e)}
function p(n){return t.containerState={},e.attempt(kQ,h,f)(n)}function h(e){
return i++,n.push([t.currentConstruct,t.containerState]),p(e)}function f(n){
return null===n?(r&&b(),
v(0),void e.consume(n)):(r=r||t.parser.flow(t.now()),e.enter("chunkFlow",{
contentType:"flow",previous:o,_tokenizer:r}),m(n))}function m(n){
return null===n?(g(e.exit("chunkFlow"),!0),
v(0),void e.consume(n)):VU(n)?(e.consume(n),
g(e.exit("chunkFlow")),i=0,t.interrupt=void 0,s):(e.consume(n),m)}
function g(e,n){const s=t.sliceStream(e)
;if(n&&s.push(null),e.previous=o,o&&(o.next=e),
o=e,r.defineSkip(e.start),r.write(s),t.parser.lazy[e.start.line]){
let e=r.events.length
;for(;e--;)if(r.events[e][1].start.offset<a&&(!r.events[e][1].end||r.events[e][1].end.offset>a))return
;const n=t.events.length;let o,s,l=n
;for(;l--;)if("exit"===t.events[l][0]&&"chunkFlow"===t.events[l][1].type){if(o){
s=t.events[l][1].end;break}o=!0}
for(v(i),e=n;e<t.events.length;)t.events[e][1].end=Object.assign({},s),e++
;zF(t.events,l+1,0,t.events.slice(n)),t.events.length=e}}function v(r){
let o=n.length;for(;o-- >r;){const r=n[o]
;t.containerState=r[1],r[0].exit.call(t,e)}n.length=r}function b(){
r.write([null]),o=void 0,r=void 0,t.containerState._closeFlow=void 0}}},kQ={
tokenize:function(e,t,n){
return fZ(e,e.attempt(this.parser.constructs.document,t,n),"linePrefix",this.parser.constructs.disable.null.includes("codeIndented")?void 0:4)
}};const SQ={tokenize:function(e){const t=this,n=e.attempt(mZ,(function(r){
if(null===r)return void e.consume(r)
;return e.enter("lineEndingBlank"),e.consume(r),
e.exit("lineEndingBlank"),t.currentConstruct=void 0,n
}),e.attempt(this.parser.constructs.flowInitial,r,fZ(e,e.attempt(this.parser.constructs.flow,r,e.attempt(AZ,r)),"linePrefix")))
;return n;function r(r){
if(null!==r)return e.enter("lineEnding"),e.consume(r),e.exit("lineEnding"),
t.currentConstruct=void 0,n;e.consume(r)}}};const _Q={resolveAll:CQ()
},TQ=AQ("string"),EQ=AQ("text");function AQ(e){return{tokenize:function(t){
const n=this,r=this.parser.constructs[e],o=t.attempt(r,a,i);return a
;function a(e){return l(e)?o(e):i(e)}function i(e){
if(null!==e)return t.enter("data"),t.consume(e),s;t.consume(e)}function s(e){
return l(e)?(t.exit("data"),o(e)):(t.consume(e),s)}function l(e){
if(null===e)return!0;const t=r[e];let o=-1;if(t)for(;++o<t.length;){const e=t[o]
;if(!e.previous||e.previous.call(n,n.previous))return!0}return!1}},
resolveAll:CQ("text"===e?$Q:void 0)}}function CQ(e){return function(t,n){
let r,o=-1
;for(;++o<=t.length;)void 0===r?t[o]&&"data"===t[o][1].type&&(r=o,o++):t[o]&&"data"===t[o][1].type||(o!==r+2&&(t[r][1].end=t[o-1][1].end,
t.splice(r+2,o-r-2),o=r+2),r=void 0);return e?e(t,n):t}}function $Q(e,t){let n=0
;for(;++n<=e.length;)if((n===e.length||"lineEnding"===e[n][1].type)&&"data"===e[n-1][1].type){
const r=e[n-1][1],o=t.sliceStream(r);let a,i=o.length,s=-1,l=0;for(;i--;){
const e=o[i];if("string"==typeof e){
for(s=e.length;32===e.charCodeAt(s-1);)l++,s--;if(s)break;s=-1
}else if(-2===e)a=!0,l++;else if(-1!==e){i++;break}}if(l){const o={
type:n===e.length||a||l<2?"lineSuffix":"hardBreakTrailing",start:{
line:r.end.line,column:r.end.column-l,offset:r.end.offset-l,
_index:r.start._index+i,_bufferIndex:i?s:r.start._bufferIndex+s},
end:Object.assign({},r.end)}
;r.end=Object.assign({},o.start),r.start.offset===r.end.offset?Object.assign(r,o):(e.splice(n,0,["enter",o,t],["exit",o,t]),
n+=2)}n++}return e}function PQ(e,t,n){
let r=Object.assign(n?Object.assign({},n):{line:1,column:1,offset:0},{_index:0,
_bufferIndex:-1});const o={},a=[];let i=[],s=[];const l={consume:function(e){
VU(e)?(r.line++,
r.column=1,r.offset+=-3===e?2:1,b()):-1!==e&&(r.column++,r.offset++)
;r._bufferIndex<0?r._index++:(r._bufferIndex++,
r._bufferIndex===i[r._index].length&&(r._bufferIndex=-1,r._index++))
;c.previous=e},enter:function(e,t){const n=t||{}
;return n.type=e,n.start=p(),c.events.push(["enter",n,c]),s.push(n),n},
exit:function(e){const t=s.pop();return t.end=p(),c.events.push(["exit",t,c]),t
},attempt:g((function(e,t){v(e,t.from)})),check:g(m),interrupt:g(m,{interrupt:!0
})},c={previous:null,code:null,containerState:{},events:[],parser:e,
sliceStream:d,sliceSerialize:function(e,t){return function(e,t){let n=-1
;const r=[];let o;for(;++n<e.length;){const a=e[n];let i
;if("string"==typeof a)i=a;else switch(a){case-5:i="\r";break;case-4:i="\n"
;break;case-3:i="\r\n";break;case-2:i=t?" ":"\t";break;case-1:if(!t&&o)continue
;i=" ";break;default:i=String.fromCharCode(a)}o=-2===a,r.push(i)}
return r.join("")}(d(e),t)},now:p,defineSkip:function(e){o[e.line]=e.column,b()
},write:function(e){if(i=FF(i,e),h(),null!==i[i.length-1])return[]
;return v(t,0),c.events=uZ(a,c.events,c),c.events}};let u=t.tokenize.call(c,l)
;return t.resolveAll&&a.push(t),c;function d(e){return function(e,t){
const n=t.start._index,r=t.start._bufferIndex,o=t.end._index,a=t.end._bufferIndex
;let i;if(n===o)i=[e[n].slice(r,a)];else{if(i=e.slice(n,o),r>-1){const e=i[0]
;"string"==typeof e?i[0]=e.slice(r):i.shift()}a>0&&i.push(e[o].slice(0,a))}
return i}(i,e)}function p(){
const{line:e,column:t,offset:n,_index:o,_bufferIndex:a}=r;return{line:e,
column:t,offset:n,_index:o,_bufferIndex:a}}function h(){let e
;for(;r._index<i.length;){const t=i[r._index]
;if("string"==typeof t)for(e=r._index,
r._bufferIndex<0&&(r._bufferIndex=0);r._index===e&&r._bufferIndex<t.length;)f(t.charCodeAt(r._bufferIndex));else f(t)
}}function f(e){u=u(e)}function m(e,t){t.restore()}function g(e,t){
return function(n,o,a){let i,u,d,h
;return Array.isArray(n)?f(n):"tokenize"in n?f([n]):function(e){return t
;function t(t){const n=null!==t&&e[t],r=null!==t&&e.null
;return f([...Array.isArray(n)?n:n?[n]:[],...Array.isArray(r)?r:r?[r]:[]])(t)}
}(n);function f(e){return i=e,u=0,0===e.length?a:m(e[u])}function m(e){
return function(n){h=function(){
const e=p(),t=c.previous,n=c.currentConstruct,o=c.events.length,a=Array.from(s)
;return{restore:i,from:o};function i(){
r=e,c.previous=t,c.currentConstruct=n,c.events.length=o,s=a,b()}
}(),d=e,e.partial||(c.currentConstruct=e)
;if(e.name&&c.parser.constructs.disable.null.includes(e.name))return v()
;return e.tokenize.call(t?Object.assign(Object.create(c),t):c,l,g,v)(n)}}
function g(t){return e(d,h),o}function v(e){
return h.restore(),++u<i.length?m(i[u]):a}}}function v(e,t){
e.resolveAll&&!a.includes(e)&&a.push(e),
e.resolve&&zF(c.events,t,c.events.length-t,e.resolve(c.events.slice(t),c)),
e.resolveTo&&(c.events=e.resolveTo(c.events,c))}function b(){
r.line in o&&r.column<2&&(r.column=o[r.line],r.offset+=o[r.line]-1)}}const DQ={
42:KZ,43:KZ,45:KZ,48:KZ,49:KZ,50:KZ,51:KZ,52:KZ,53:KZ,54:KZ,55:KZ,56:KZ,57:KZ,
62:gZ},IQ={91:MZ},MQ={[-2]:wZ,[-1]:wZ,32:wZ},NQ={35:LZ,42:YZ,45:[tQ,YZ],60:UZ,
61:tQ,95:YZ,96:OZ,126:OZ},RQ={38:bZ,92:vZ},LQ={[-5]:GZ,[-4]:GZ,[-3]:GZ,33:WZ,
38:bZ,42:dZ,60:[hZ,ZZ],91:XZ,92:[RZ,vZ],93:QZ,95:dZ,96:kZ},BQ={null:[dZ,_Q]
},jQ=Object.freeze(Object.defineProperty({__proto__:null,attentionMarkers:{
null:[42,95]},contentInitial:IQ,disable:{null:[]},document:DQ,flow:NQ,
flowInitial:MQ,insideSpan:BQ,string:RQ,text:LQ},Symbol.toStringTag,{
value:"Module"}));const UQ=/[\0\t\n\r]/g;const zQ={}.hasOwnProperty
;function FQ(e,t,n){return"string"!=typeof t&&(n=t,t=void 0),function(e){
const t={transforms:[],
canContainEols:["emphasis","fragment","heading","paragraph","strong"],enter:{
autolink:a(te),autolinkProtocol:_,autolinkEmail:_,atxHeading:a(Y),
blockQuote:a(V),characterEscape:_,characterReference:_,codeFenced:a(q),
codeFencedFenceInfo:i,codeFencedFenceMeta:i,codeIndented:a(q,i),codeText:a(W,i),
codeTextData:_,data:_,codeFlowValue:_,definition:a(X),
definitionDestinationString:i,definitionLabelString:i,definitionTitleString:i,
emphasis:a(G),hardBreakEscape:a(K),hardBreakTrailing:a(K),htmlFlow:a(J,i),
htmlFlowData:_,htmlText:a(J,i),htmlTextData:_,image:a(ee),label:i,link:a(te),
listItem:a(re),listItemValue:p,listOrdered:a(ne,d),listUnordered:a(ne),
paragraph:a(oe),reference:j,referenceString:i,resourceDestinationString:i,
resourceTitleString:i,setextHeading:a(Y),strong:a(ae),thematicBreak:a(se)},
exit:{atxHeading:l(),atxHeadingSequence:w,autolink:l(),autolinkEmail:H,
autolinkProtocol:Q,blockQuote:l(),characterEscapeValue:T,
characterReferenceMarkerHexadecimal:z,characterReferenceMarkerNumeric:z,
characterReferenceValue:F,characterReference:Z,codeFenced:l(g),
codeFencedFence:m,codeFencedFenceInfo:h,codeFencedFenceMeta:f,codeFlowValue:T,
codeIndented:l(v),codeText:l(P),codeTextData:T,data:T,definition:l(),
definitionDestinationString:O,definitionLabelString:b,definitionTitleString:y,
emphasis:l(),hardBreakEscape:l(A),hardBreakTrailing:l(A),htmlFlow:l(C),
htmlFlowData:T,htmlText:l($),htmlTextData:T,image:l(I),label:N,labelText:M,
lineEnding:E,link:l(D),listItem:l(),listOrdered:l(),listUnordered:l(),
paragraph:l(),referenceString:U,resourceDestinationString:R,
resourceTitleString:L,resource:B,setextHeading:l(S),setextHeadingLineSequence:k,
setextHeadingText:x,strong:l(),thematicBreak:l()}}
;QQ(t,(e||{}).mdastExtensions||[]);const n={};return r;function r(e){let r={
type:"root",children:[]};const a={stack:[r],tokenStack:[],config:t,enter:s,
exit:c,buffer:i,resume:u,data:n},l=[];let d=-1
;for(;++d<e.length;)if("listOrdered"===e[d][1].type||"listUnordered"===e[d][1].type)if("enter"===e[d][0])l.push(d);else{
d=o(e,l.pop(),d)}for(d=-1;++d<e.length;){const n=t[e[d][0]]
;zQ.call(n,e[d][1].type)&&n[e[d][1].type].call(Object.assign({
sliceSerialize:e[d][2].sliceSerialize},a),e[d][1])}if(a.tokenStack.length>0){
const e=a.tokenStack[a.tokenStack.length-1];(e[1]||VQ).call(a,void 0,e[0])}
for(r.position={start:ZQ(e.length>0?e[0][1].start:{line:1,column:1,offset:0}),
end:ZQ(e.length>0?e[e.length-2][1].end:{line:1,column:1,offset:0})
},d=-1;++d<t.transforms.length;)r=t.transforms[d](r)||r;return r}
function o(e,t,n){let r,o,a,i,s=t-1,l=-1,c=!1;for(;++s<=n;){const t=e[s]
;switch(t[1].type){case"listUnordered":case"listOrdered":case"blockQuote":
"enter"===t[0]?l++:l--,i=void 0;break;case"lineEndingBlank":
"enter"===t[0]&&(!r||i||l||a||(a=s),i=void 0);break;case"linePrefix":
case"listItemValue":case"listItemMarker":case"listItemPrefix":
case"listItemPrefixWhitespace":break;default:i=void 0}
if(!l&&"enter"===t[0]&&"listItemPrefix"===t[1].type||-1===l&&"exit"===t[0]&&("listUnordered"===t[1].type||"listOrdered"===t[1].type)){
if(r){let i=s;for(o=void 0;i--;){const t=e[i]
;if("lineEnding"===t[1].type||"lineEndingBlank"===t[1].type){
if("exit"===t[0])continue
;o&&(e[o][1].type="lineEndingBlank",c=!0),t[1].type="lineEnding",o=i
}else if("linePrefix"!==t[1].type&&"blockQuotePrefix"!==t[1].type&&"blockQuotePrefixWhitespace"!==t[1].type&&"blockQuoteMarker"!==t[1].type&&"listItemIndent"!==t[1].type)break
}
a&&(!o||a<o)&&(r._spread=!0),r.end=Object.assign({},o?e[o][1].start:t[1].end),e.splice(o||s,0,["exit",r,t[2]]),
s++,n++}if("listItemPrefix"===t[1].type){const o={type:"listItem",_spread:!1,
start:Object.assign({},t[1].start),end:void 0}
;r=o,e.splice(s,0,["enter",o,t[2]]),s++,n++,a=void 0,i=!0}}}
return e[t][1]._spread=c,n}function a(e,t){return n;function n(n){
s.call(this,e(n),n),t&&t.call(this,n)}}function i(){this.stack.push({
type:"fragment",children:[]})}function s(e,t,n){
this.stack[this.stack.length-1].children.push(e),
this.stack.push(e),this.tokenStack.push([t,n]),e.position={start:ZQ(t.start),
end:void 0}}function l(e){return t;function t(t){
e&&e.call(this,t),c.call(this,t)}}function c(e,t){
const n=this.stack.pop(),r=this.tokenStack.pop()
;if(!r)throw new Error("Cannot close `"+e.type+"` ("+jM({start:e.start,end:e.end
})+"): it’s not open");if(r[0].type!==e.type)if(t)t.call(this,e,r[0]);else{
(r[1]||VQ).call(this,e,r[0])}n.position.end=ZQ(e.end)}function u(){
return Qz(this.stack.pop())}function d(){
this.data.expectingFirstListItemValue=!0}function p(e){
if(this.data.expectingFirstListItemValue){
this.stack[this.stack.length-2].start=Number.parseInt(this.sliceSerialize(e),10),
this.data.expectingFirstListItemValue=void 0}}function h(){const e=this.resume()
;this.stack[this.stack.length-1].lang=e}function f(){const e=this.resume()
;this.stack[this.stack.length-1].meta=e}function m(){
this.data.flowCodeInside||(this.buffer(),this.data.flowCodeInside=!0)}
function g(){const e=this.resume()
;this.stack[this.stack.length-1].value=e.replace(/^(\r?\n|\r)|(\r?\n|\r)$/g,""),
this.data.flowCodeInside=void 0}function v(){const e=this.resume()
;this.stack[this.stack.length-1].value=e.replace(/(\r?\n|\r)$/g,"")}
function b(e){const t=this.resume(),n=this.stack[this.stack.length-1];n.label=t,
n.identifier=hz(this.sliceSerialize(e)).toLowerCase()}function y(){
const e=this.resume();this.stack[this.stack.length-1].title=e}function O(){
const e=this.resume();this.stack[this.stack.length-1].url=e}function w(e){
const t=this.stack[this.stack.length-1];if(!t.depth){
const n=this.sliceSerialize(e).length;t.depth=n}}function x(){
this.data.setextHeadingSlurpLineEnding=!0}function k(e){
this.stack[this.stack.length-1].depth=61===this.sliceSerialize(e).codePointAt(0)?1:2
}function S(){this.data.setextHeadingSlurpLineEnding=void 0}function _(e){
const t=this.stack[this.stack.length-1].children;let n=t[t.length-1]
;n&&"text"===n.type||(n=ie(),n.position={start:ZQ(e.start),end:void 0
},t.push(n)),this.stack.push(n)}function T(e){const t=this.stack.pop()
;t.value+=this.sliceSerialize(e),t.position.end=ZQ(e.end)}function E(e){
const n=this.stack[this.stack.length-1];if(this.data.atHardBreak){
return n.children[n.children.length-1].position.end=ZQ(e.end),
void(this.data.atHardBreak=void 0)}
!this.data.setextHeadingSlurpLineEnding&&t.canContainEols.includes(n.type)&&(_.call(this,e),
T.call(this,e))}function A(){this.data.atHardBreak=!0}function C(){
const e=this.resume();this.stack[this.stack.length-1].value=e}function $(){
const e=this.resume();this.stack[this.stack.length-1].value=e}function P(){
const e=this.resume();this.stack[this.stack.length-1].value=e}function D(){
const e=this.stack[this.stack.length-1];if(this.data.inReference){
const t=this.data.referenceType||"shortcut"
;e.type+="Reference",e.referenceType=t,delete e.url,delete e.title
}else delete e.identifier,delete e.label;this.data.referenceType=void 0}
function I(){const e=this.stack[this.stack.length-1];if(this.data.inReference){
const t=this.data.referenceType||"shortcut"
;e.type+="Reference",e.referenceType=t,delete e.url,delete e.title
}else delete e.identifier,delete e.label;this.data.referenceType=void 0}
function M(e){const t=this.sliceSerialize(e),n=this.stack[this.stack.length-2]
;n.label=hF(t),n.identifier=hz(t).toLowerCase()}function N(){
const e=this.stack[this.stack.length-1],t=this.resume(),n=this.stack[this.stack.length-1]
;if(this.data.inReference=!0,"link"===n.type){const t=e.children;n.children=t
}else n.alt=t}function R(){const e=this.resume()
;this.stack[this.stack.length-1].url=e}function L(){const e=this.resume()
;this.stack[this.stack.length-1].title=e}function B(){
this.data.inReference=void 0}function j(){this.data.referenceType="collapsed"}
function U(e){const t=this.resume(),n=this.stack[this.stack.length-1];n.label=t,
n.identifier=hz(this.sliceSerialize(e)).toLowerCase(),
this.data.referenceType="full"}function z(e){
this.data.characterReferenceType=e.type}function F(e){
const t=this.sliceSerialize(e),n=this.data.characterReferenceType;let r
;if(n)r=dF(t,"characterReferenceMarkerNumeric"===n?10:16),
this.data.characterReferenceType=void 0;else{r=uF(t)}
this.stack[this.stack.length-1].value+=r}function Z(e){
this.stack.pop().position.end=ZQ(e.end)}function Q(e){T.call(this,e)
;this.stack[this.stack.length-1].url=this.sliceSerialize(e)}function H(e){
T.call(this,e)
;this.stack[this.stack.length-1].url="mailto:"+this.sliceSerialize(e)}
function V(){return{type:"blockquote",children:[]}}function q(){return{
type:"code",lang:null,meta:null,value:""}}function W(){return{type:"inlineCode",
value:""}}function X(){return{type:"definition",identifier:"",label:null,
title:null,url:""}}function G(){return{type:"emphasis",children:[]}}
function Y(){return{type:"heading",depth:0,children:[]}}function K(){return{
type:"break"}}function J(){return{type:"html",value:""}}function ee(){return{
type:"image",title:null,url:"",alt:null}}function te(){return{type:"link",
title:null,url:"",children:[]}}function ne(e){return{type:"list",
ordered:"listOrdered"===e.type,start:null,spread:e._spread,children:[]}}
function re(e){return{type:"listItem",spread:e._spread,checked:null,children:[]}
}function oe(){return{type:"paragraph",children:[]}}function ae(){return{
type:"strong",children:[]}}function ie(){return{type:"text",value:""}}
function se(){return{type:"thematicBreak"}}}(n)(function(e){for(;!TZ(e););
return e}(function(e){const t={defined:[],lazy:{},
constructs:QF([jQ,...(e||{}).extensions||[]]),content:n(wQ),document:n(xQ),
flow:n(SQ),string:n(TQ),text:n(EQ)};return t;function n(e){return function(n){
return PQ(t,e,n)}}}(n).document().write(function(){let e,t=1,n="",r=!0
;return function(o,a,i){const s=[];let l,c,u,d,p
;for(o=n+("string"==typeof o?o.toString():new TextDecoder(a||void 0).decode(o)),
u=0,n="",r&&(65279===o.charCodeAt(0)&&u++,r=void 0);u<o.length;){
if(UQ.lastIndex=u,
l=UQ.exec(o),d=l&&void 0!==l.index?l.index:o.length,p=o.charCodeAt(d),!l){
n=o.slice(u);break}
if(10===p&&u===d&&e)s.push(-3),e=void 0;else switch(e&&(s.push(-5),
e=void 0),u<d&&(s.push(o.slice(u,d)),t+=d-u),p){case 0:s.push(65533),t++;break
;case 9:for(c=4*Math.ceil(t/4),s.push(-2);t++<c;)s.push(-1);break;case 10:
s.push(-4),t=1;break;default:e=!0,t=1}u=d+1}
return i&&(e&&s.push(-5),n&&s.push(n),s.push(null)),s}}()(e,t,!0))))}
function ZQ(e){return{line:e.line,column:e.column,offset:e.offset}}
function QQ(e,t){let n=-1;for(;++n<t.length;){const r=t[n]
;Array.isArray(r)?QQ(e,r):HQ(e,r)}}function HQ(e,t){let n
;for(n in t)if(zQ.call(t,n))switch(n){case"canContainEols":{const r=t[n]
;r&&e[n].push(...r);break}case"transforms":{const r=t[n];r&&e[n].push(...r)
;break}case"enter":case"exit":{const r=t[n];r&&Object.assign(e[n],r);break}}}
function VQ(e,t){throw e?new Error("Cannot close `"+e.type+"` ("+jM({
start:e.start,end:e.end})+"): a different token (`"+t.type+"`, "+jM({
start:t.start,end:t.end
})+") is open"):new Error("Cannot close document, a token (`"+t.type+"`, "+jM({
start:t.start,end:t.end})+") is still open")}function qQ(e){const t=this
;t.parser=function(n){return FQ(n,{...t.data("settings"),...e,
extensions:t.data("micromarkExtensions")||[],
mdastExtensions:t.data("fromMarkdownExtensions")||[]})}}function WQ(e,t){
const n=t.referenceType;let r="]"
;if("collapsed"===n?r+="[]":"full"===n&&(r+="["+(t.label||t.identifier)+"]"),
"imageReference"===t.type)return[{type:"text",value:"!["+t.alt+r}]
;const o=e.all(t),a=o[0];a&&"text"===a.type?a.value="["+a.value:o.unshift({
type:"text",value:"["});const i=o[o.length-1]
;return i&&"text"===i.type?i.value+=r:o.push({type:"text",value:r}),o}
function XQ(e){const t=e.spread;return null==t?e.children.length>1:t}
const GQ=9,YQ=32;function KQ(e){const t=String(e),n=/\r?\n|\r/g
;let r=n.exec(t),o=0;const a=[]
;for(;r;)a.push(JQ(t.slice(o,r.index),o>0,!0),r[0]),
o=r.index+r[0].length,r=n.exec(t)
;return a.push(JQ(t.slice(o),o>0,!1)),a.join("")}function JQ(e,t,n){
let r=0,o=e.length;if(t){let t=e.codePointAt(r)
;for(;t===GQ||t===YQ;)r++,t=e.codePointAt(r)}if(n){let t=e.codePointAt(o-1)
;for(;t===GQ||t===YQ;)o--,t=e.codePointAt(o-1)}return o>r?e.slice(r,o):""}
const eH={blockquote:function(e,t){const n={type:"element",tagName:"blockquote",
properties:{},children:e.wrap(e.all(t),!0)};return e.patch(t,n),e.applyData(t,n)
},break:function(e,t){const n={type:"element",tagName:"br",properties:{},
children:[]};return e.patch(t,n),[e.applyData(t,n),{type:"text",value:"\n"}]},
code:function(e,t){const n=t.value?t.value+"\n":"",r={}
;t.lang&&(r.className=["language-"+t.lang]);let o={type:"element",
tagName:"code",properties:r,children:[{type:"text",value:n}]}
;return t.meta&&(o.data={meta:t.meta}),e.patch(t,o),o=e.applyData(t,o),o={
type:"element",tagName:"pre",properties:{},children:[o]},e.patch(t,o),o},
delete:function(e,t){const n={type:"element",tagName:"del",properties:{},
children:e.all(t)};return e.patch(t,n),e.applyData(t,n)},emphasis:function(e,t){
const n={type:"element",tagName:"em",properties:{},children:e.all(t)}
;return e.patch(t,n),e.applyData(t,n)},footnoteReference:function(e,t){
const n="string"==typeof e.options.clobberPrefix?e.options.clobberPrefix:"user-content-",r=String(t.identifier).toUpperCase(),o=lZ(r.toLowerCase()),a=e.footnoteOrder.indexOf(r)
;let i,s=e.footnoteCounts.get(r)
;void 0===s?(s=0,e.footnoteOrder.push(r),i=e.footnoteOrder.length):i=a+1,
s+=1,e.footnoteCounts.set(r,s);const l={type:"element",tagName:"a",properties:{
href:"#"+n+"fn-"+o,id:n+"fnref-"+o+(s>1?"-"+s:""),dataFootnoteRef:!0,
ariaDescribedBy:["footnote-label"]},children:[{type:"text",value:String(i)}]}
;e.patch(t,l);const c={type:"element",tagName:"sup",properties:{},children:[l]}
;return e.patch(t,c),e.applyData(t,c)},heading:function(e,t){const n={
type:"element",tagName:"h"+t.depth,properties:{},children:e.all(t)}
;return e.patch(t,n),e.applyData(t,n)},html:function(e,t){
if(e.options.allowDangerousHtml){const n={type:"raw",value:t.value}
;return e.patch(t,n),e.applyData(t,n)}},imageReference:function(e,t){
const n=String(t.identifier).toUpperCase(),r=e.definitionById.get(n)
;if(!r)return WQ(e,t);const o={src:lZ(r.url||""),alt:t.alt}
;null!==r.title&&void 0!==r.title&&(o.title=r.title);const a={type:"element",
tagName:"img",properties:o,children:[]};return e.patch(t,a),e.applyData(t,a)},
image:function(e,t){const n={src:lZ(t.url)}
;null!==t.alt&&void 0!==t.alt&&(n.alt=t.alt),
null!==t.title&&void 0!==t.title&&(n.title=t.title);const r={type:"element",
tagName:"img",properties:n,children:[]};return e.patch(t,r),e.applyData(t,r)},
inlineCode:function(e,t){const n={type:"text",
value:t.value.replace(/\r?\n|\r/g," ")};e.patch(t,n);const r={type:"element",
tagName:"code",properties:{},children:[n]};return e.patch(t,r),e.applyData(t,r)
},linkReference:function(e,t){
const n=String(t.identifier).toUpperCase(),r=e.definitionById.get(n)
;if(!r)return WQ(e,t);const o={href:lZ(r.url||"")}
;null!==r.title&&void 0!==r.title&&(o.title=r.title);const a={type:"element",
tagName:"a",properties:o,children:e.all(t)};return e.patch(t,a),e.applyData(t,a)
},link:function(e,t){const n={href:lZ(t.url)}
;null!==t.title&&void 0!==t.title&&(n.title=t.title);const r={type:"element",
tagName:"a",properties:n,children:e.all(t)};return e.patch(t,r),e.applyData(t,r)
},listItem:function(e,t,n){const r=e.all(t),o=n?function(e){let t=!1
;if("list"===e.type){t=e.spread||!1;const n=e.children;let r=-1
;for(;!t&&++r<n.length;)t=XQ(n[r])}return t}(n):XQ(t),a={},i=[]
;if("boolean"==typeof t.checked){const e=r[0];let n
;e&&"element"===e.type&&"p"===e.tagName?n=e:(n={type:"element",tagName:"p",
properties:{},children:[]
},r.unshift(n)),n.children.length>0&&n.children.unshift({type:"text",value:" "
}),n.children.unshift({type:"element",tagName:"input",properties:{
type:"checkbox",checked:t.checked,disabled:!0},children:[]
}),a.className=["task-list-item"]}let s=-1;for(;++s<r.length;){const e=r[s]
;(o||0!==s||"element"!==e.type||"p"!==e.tagName)&&i.push({type:"text",value:"\n"
}),"element"!==e.type||"p"!==e.tagName||o?i.push(e):i.push(...e.children)}
const l=r[r.length-1];l&&(o||"element"!==l.type||"p"!==l.tagName)&&i.push({
type:"text",value:"\n"});const c={type:"element",tagName:"li",properties:a,
children:i};return e.patch(t,c),e.applyData(t,c)},list:function(e,t){
const n={},r=e.all(t);let o=-1
;for("number"==typeof t.start&&1!==t.start&&(n.start=t.start);++o<r.length;){
const e=r[o]
;if("element"===e.type&&"li"===e.tagName&&e.properties&&Array.isArray(e.properties.className)&&e.properties.className.includes("task-list-item")){
n.className=["contains-task-list"];break}}const a={type:"element",
tagName:t.ordered?"ol":"ul",properties:n,children:e.wrap(r,!0)}
;return e.patch(t,a),e.applyData(t,a)},paragraph:function(e,t){const n={
type:"element",tagName:"p",properties:{},children:e.all(t)};return e.patch(t,n),
e.applyData(t,n)},root:function(e,t){const n={type:"root",
children:e.wrap(e.all(t))};return e.patch(t,n),e.applyData(t,n)},
strong:function(e,t){const n={type:"element",tagName:"strong",properties:{},
children:e.all(t)};return e.patch(t,n),e.applyData(t,n)},table:function(e,t){
const n=e.all(t),r=n.shift(),o=[];if(r){const n={type:"element",tagName:"thead",
properties:{},children:e.wrap([r],!0)};e.patch(t.children[0],n),o.push(n)}
if(n.length>0){const r={type:"element",tagName:"tbody",properties:{},
children:e.wrap(n,!0)},a=uU(t.children[1]),i=cU(t.children[t.children.length-1])
;a&&i&&(r.position={start:a,end:i}),o.push(r)}const a={type:"element",
tagName:"table",properties:{},children:e.wrap(o,!0)}
;return e.patch(t,a),e.applyData(t,a)},tableCell:function(e,t){const n={
type:"element",tagName:"td",properties:{},children:e.all(t)}
;return e.patch(t,n),e.applyData(t,n)},tableRow:function(e,t,n){
const r=n?n.children:void 0,o=0===(r?r.indexOf(t):1)?"th":"td",a=n&&"table"===n.type?n.align:void 0,i=a?a.length:t.children.length
;let s=-1;const l=[];for(;++s<i;){const n=t.children[s],r={},i=a?a[s]:void 0
;i&&(r.align=i);let c={type:"element",tagName:o,properties:r,children:[]}
;n&&(c.children=e.all(n),e.patch(n,c),c=e.applyData(n,c)),l.push(c)}const c={
type:"element",tagName:"tr",properties:{},children:e.wrap(l,!0)}
;return e.patch(t,c),e.applyData(t,c)},text:function(e,t){const n={type:"text",
value:KQ(String(t.value))};return e.patch(t,n),e.applyData(t,n)},
thematicBreak:function(e,t){const n={type:"element",tagName:"hr",properties:{},
children:[]};return e.patch(t,n),e.applyData(t,n)},toml:tH,yaml:tH,
definition:tH,footnoteDefinition:tH};function tH(){}function nH(e,t){const n=[{
type:"text",value:"↩"}];return t>1&&n.push({type:"element",tagName:"sup",
properties:{},children:[{type:"text",value:String(t)}]}),n}function rH(e,t){
return"Back to reference "+(e+1)+(t>1?"-"+t:"")}const oH={}.hasOwnProperty,aH={}
;function iH(e,t){e.position&&(t.position=pU(e))}function sH(e,t){let n=t
;if(e&&e.data){const t=e.data.hName,r=e.data.hChildren,o=e.data.hProperties
;if("string"==typeof t)if("element"===n.type)n.tagName=t;else{n={type:"element",
tagName:t,properties:{},children:"children"in n?n.children:[n]}}
"element"===n.type&&o&&Object.assign(n.properties,xj(o)),
"children"in n&&n.children&&null!=r&&(n.children=r)}return n}function lH(e,t){
const n=t.data||{},r=!("value"in t)||oH.call(n,"hProperties")||oH.call(n,"hChildren")?{
type:"element",tagName:"div",properties:{},children:e.all(t)}:{type:"text",
value:t.value};return e.patch(t,r),e.applyData(t,r)}function cH(e,t){const n=[]
;let r=-1;for(t&&n.push({type:"text",value:"\n"});++r<e.length;)r&&n.push({
type:"text",value:"\n"}),n.push(e[r]);return t&&e.length>0&&n.push({type:"text",
value:"\n"}),n}function uH(e){let t=0,n=e.charCodeAt(t);for(;9===n||32===n;)t++,
n=e.charCodeAt(t);return e.slice(t)}function dH(e,t){const n=function(e,t){
const n=t||aH,r=new Map,o=new Map,a=new Map,i={...eH,...n.handlers},s={
all:function(e){const t=[];if("children"in e){const n=e.children;let r=-1
;for(;++r<n.length;){const o=s.one(n[r],e);if(o){
if(r&&"break"===n[r-1].type&&(Array.isArray(o)||"text"!==o.type||(o.value=uH(o.value)),
!Array.isArray(o)&&"element"===o.type)){const e=o.children[0]
;e&&"text"===e.type&&(e.value=uH(e.value))}
Array.isArray(o)?t.push(...o):t.push(o)}}}return t},applyData:sH,
definitionById:r,footnoteById:o,footnoteCounts:a,footnoteOrder:[],handlers:i,
one:function(e,t){const n=e.type,r=s.handlers[n]
;if(oH.call(s.handlers,n)&&r)return r(s,e,t)
;if(s.options.passThrough&&s.options.passThrough.includes(n)){
if("children"in e){const{children:t,...n}=e,r=xj(n);return r.children=s.all(e),r
}return xj(e)}return(s.options.unknownHandler||lH)(s,e,t)},options:n,patch:iH,
wrap:cH};return uL(e,(function(e){
if("definition"===e.type||"footnoteDefinition"===e.type){
const t="definition"===e.type?r:o,n=String(e.identifier).toUpperCase()
;t.has(n)||t.set(n,e)}})),s}(e,t),r=n.one(e,void 0),o=function(e){
const t="string"==typeof e.options.clobberPrefix?e.options.clobberPrefix:"user-content-",n=e.options.footnoteBackContent||nH,r=e.options.footnoteBackLabel||rH,o=e.options.footnoteLabel||"Footnotes",a=e.options.footnoteLabelTagName||"h2",i=e.options.footnoteLabelProperties||{
className:["sr-only"]},s=[];let l=-1;for(;++l<e.footnoteOrder.length;){
const o=e.footnoteById.get(e.footnoteOrder[l]);if(!o)continue
;const a=e.all(o),i=String(o.identifier).toUpperCase(),c=lZ(i.toLowerCase())
;let u=0;const d=[],p=e.footnoteCounts.get(i);for(;void 0!==p&&++u<=p;){
d.length>0&&d.push({type:"text",value:" "});let e="string"==typeof n?n:n(l,u)
;"string"==typeof e&&(e={type:"text",value:e}),d.push({type:"element",
tagName:"a",properties:{href:"#"+t+"fnref-"+c+(u>1?"-"+u:""),
dataFootnoteBackref:"",ariaLabel:"string"==typeof r?r:r(l,u),
className:["data-footnote-backref"]},children:Array.isArray(e)?e:[e]})}
const h=a[a.length-1];if(h&&"element"===h.type&&"p"===h.tagName){
const e=h.children[h.children.length-1]
;e&&"text"===e.type?e.value+=" ":h.children.push({type:"text",value:" "
}),h.children.push(...d)}else a.push(...d);const f={type:"element",tagName:"li",
properties:{id:t+"fn-"+c},children:e.wrap(a,!0)};e.patch(o,f),s.push(f)}
if(0!==s.length)return{type:"element",tagName:"section",properties:{
dataFootnotes:!0,className:["footnotes"]},children:[{type:"element",tagName:a,
properties:{...xj(i),id:"footnote-label"},children:[{type:"text",value:o}]},{
type:"text",value:"\n"},{type:"element",tagName:"ol",properties:{},
children:e.wrap(s,!0)},{type:"text",value:"\n"}]}}(n),a=Array.isArray(r)?{
type:"root",children:r}:r||{type:"root",children:[]};return o&&a.children.push({
type:"text",value:"\n"},o),a}function pH(e,t){
return e&&"run"in e?async function(n,r){const o=dH(n,{file:r,...t})
;await e.run(o,r)}:function(n,r){return dH(n,{file:r,...e||t})}}function hH(e){
const t=this;t.compiler=function(n){return kF(n,{...t.data("settings"),...e,
extensions:t.data("toMarkdownExtensions")||[]})}}
const fH=["note","tip","important","warning","caution","success"]
;function mH(e){
return"text"===e.type&&"string"==typeof e.value&&/^\s*$/.test(e.value)}
function gH(){return e=>{uL(e,"element",((e,t,n)=>{
if("blockquote"!==e.tagName||"number"!=typeof t||!n||"root"!==n.type)return
;const r=e.children.findIndex((e=>!mH(e)));if(-1===r)return
;const o=e.children[r];if(!o||"element"!==o.type||"p"!==o.tagName)return
;const a=o.children[0];if(!a||"text"!==a.type||!a.value.startsWith("[!"))return
;const i=a.value.indexOf("]");if(-1===i)return
;const s=a.value.slice(2,i).toLowerCase();if(!fH.includes(s))return
;if(i+1===a.value.length){const t=o.children[1];if(t){
if("element"!==t.type||"br"!==t.tagName)return;if(!o.children[2])return
;o.children=o.children.slice(2);const e=o.children[0]
;e&&"text"===e.type&&"\n"===e.value.charAt(0)&&(e.value=e.value.slice(1))}else{
const t=r+1<e.children.length&&mH(e.children[r+1])?r+2:r+1
;if(t>=e.children.length||"element"!==e.children[t]?.type)return
;e.children=e.children.slice(t)}
}else"\n"!==a.value.charAt(i+1)||i+2!==a.value.length&&/^\s*$/.test(a.value.slice(i+2))?a.value=a.value.replace(/^\s*\[!.*?\]\s*/,""):a.value=a.value.slice(i+2)
;const l=[];for(let c=r;c<e.children.length;c++){const t=e.children[c]
;"element"===t?.type&&"p"===t.tagName&&t.children?l.push(...t.children):l.push(t)
}n.children[t]={type:"element",tagName:"div",properties:{
className:["markdown-alert",`markdown-alert-${s}`]},children:[{type:"element",
tagName:"div",properties:{className:["markdown-alert-icon"]},children:[]},{
type:"element",tagName:"div",properties:{className:["markdown-alert-content"]},
children:[{type:"text",value:" "},...l]}]}}))}}const vH=(e,...t)=>t=>{
e?.transform&&e?.type&&uL(t,e?.type,(t=>(e?.transform&&e?.transform(t),lL)))}
;function bH(e){return XR().use(qQ).use(OQ).parse(e)}function yH(e,t=1){
const n=bH(e),r=[];return uL(n,"heading",(e=>{const n=OH(e);n&&r.push({
depth:e.depth??t,value:n.value})})),r}function OH(e){if("text"===e.type)return e
;if("children"in e&&e.children)for(const t of e.children){const e=OH(t)
;if(e)return e}return null}function wH(e){const t=bH(e),n=[];let r=[]
;return t.children?.forEach((e=>{
"heading"===e.type?(r.length&&n.push(r),n.push([e]),r=[]):r.push(e)
})),r.length&&n.push(r),n.map((e=>function(e){
const t=XR().use(hH).use(OQ).stringify({type:"root",children:e});return t.trim()
}(e)))}const xH=e=>null!=e,kH={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;",
"'":"&apos;"};function SH(e){return e.replace(/[&<>"']/g,(e=>kH[e]??e))}
function _H(e,t={}){
const{indent:n="  ",format:r=!0,xmlDeclaration:o=!0}=t,a=(e,t,r)=>{let o=""
;if(Array.isArray(e))for(let n=0,i=e.length;n<i;n++)o+=a(e[n],t,r);else if("object"==typeof e&&null!==e){
let i=!1,s="",l=""
;for(const t in e)"@"===t.charAt(0)&&(s+=" "+t.substr(1)+'="'+SH(e[t].toString())+'"')
;for(const t in e)if("#text"===t)l+=SH(e[t]?.toString()??"");else if("#cdata"===t){
l+="<![CDATA["+(e[t]?.toString()??"").replace(/]]>/g,"]]]]><![CDATA[>")+"]]>"
}else"@"!==t.charAt(0)&&(i=!0,l+=a(e[t],t,r+n))
;i||l?(o+=r+"<"+t+s+">\n",o+=l,o+=r+"</"+t+">\n"):o+=r+"<"+t+s+"/>\n"
}else o+=r+"<"+t+">"+SH(e?.toString()||"")+"</"+t+">\n";return o};let i=""
;o&&(i+='<?xml version="1.0" encoding="UTF-8"?>',r&&(i+="\n"))
;for(const s in e)Object.hasOwn(e,s)&&(i+=a(e[s],s,""))
;return r?i.trim():i.replace(/\n/g,"").replace(/>\s+</g,"><").trim()}
const TH=["post","put","patch","delete"],EH=e=>TH.includes(e.toLowerCase()),AH={
get:{short:"GET",colorClass:"text-blue",colorVar:"var(--scalar-color-blue)",
backgroundColor:"bg-blue/10"},post:{short:"POST",colorClass:"text-green",
colorVar:"var(--scalar-color-green)",backgroundColor:"bg-green/10"},put:{
short:"PUT",colorClass:"text-orange",colorVar:"var(--scalar-color-orange)",
backgroundColor:"bg-orange/10"},patch:{short:"PATCH",colorClass:"text-yellow",
colorVar:"var(--scalar-color-yellow)",backgroundColor:"bg-yellow/10"},delete:{
short:"DEL",colorClass:"text-red",colorVar:"var(--scalar-color-red)",
backgroundColor:"bg-red/10"},options:{short:"OPTS",colorClass:"text-purple",
colorVar:"var(--scalar-color-purple)",backgroundColor:"bg-purple/10"},head:{
short:"HEAD",colorClass:"text-c-2",colorVar:"var(--scalar-color-2)",
backgroundColor:"bg-c-2/10"},trace:{short:"TRACE",colorClass:"text-c-2",
colorVar:"var(--scalar-color-2)",backgroundColor:"bg-c-2/10"}},CH=e=>{
const t=e.trim().toLowerCase();return AH[t]??{short:t,color:"text-c-2",
backgroundColor:"bg-c-2"}},$H={100:{name:"Continue",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/100",
color:"var(--scalar-color-blue)"},101:{name:"Switching Protocols",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/101",
color:"var(--scalar-color-blue)"},102:{name:"Processing",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/102",
color:"var(--scalar-color-blue)"},103:{name:"Early Hints",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/103",
color:"var(--scalar-color-blue)"},200:{name:"OK",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/200",
color:"var(--scalar-color-green)"},201:{name:"Created",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/201",
color:"var(--scalar-color-green)"},202:{name:"Accepted",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/202",
color:"var(--scalar-color-green)"},203:{name:"Non-Authoritative Information",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/203",
color:"var(--scalar-color-green)"},204:{name:"No Content",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/204",
color:"var(--scalar-color-green)"},205:{name:"Reset Content",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/205",
color:"var(--scalar-color-green)"},206:{name:"Partial Content",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/206",
color:"var(--scalar-color-green)"},207:{name:"Multi-Status",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/207",
color:"var(--scalar-color-green)"},208:{name:"Already Reported",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/208",
color:"var(--scalar-color-green)"},226:{name:"IM Used",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/226",
color:"var(--scalar-color-green)"},300:{name:"Multiple Choices",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/300",
color:"var(--scalar-color-yellow)"},301:{name:"Moved Permanently",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/301",
color:"var(--scalar-color-yellow)"},302:{name:"Found",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/302",
color:"var(--scalar-color-yellow)"},303:{name:"See Other",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/303",
color:"var(--scalar-color-yellow)"},304:{name:"Not Modified",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/304",
color:"var(--scalar-color-yellow)"},305:{name:"Use Proxy",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/305",
color:"var(--scalar-color-yellow)"},306:{name:"(Unused)",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/306",
color:"var(--scalar-color-yellow)"},307:{name:"Temporary Redirect",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/307",
color:"var(--scalar-color-yellow)"},308:{name:"Permanent Redirect",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/308",
color:"var(--scalar-color-yellow)"},400:{name:"Bad Request",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/400",
color:"var(--scalar-color-red)"},401:{name:"Unauthorized",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/401",
color:"var(--scalar-color-red)"},402:{name:"Payment Required",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/402",
color:"var(--scalar-color-red)"},403:{name:"Forbidden",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/403",
color:"var(--scalar-color-red)"},404:{name:"Not Found",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/404",
color:"var(--scalar-color-red)"},405:{name:"Method Not Allowed",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/405",
color:"var(--scalar-color-red)"},406:{name:"Not Acceptable",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/406",
color:"var(--scalar-color-red)"},407:{name:"Proxy Authentication Required",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/407",
color:"var(--scalar-color-red)"},408:{name:"Request Timeout",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/408",
color:"var(--scalar-color-red)"},409:{name:"Conflict",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/409",
color:"var(--scalar-color-red)"},410:{name:"Gone",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/410",
color:"var(--scalar-color-red)"},411:{name:"Length Required",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/411",
color:"var(--scalar-color-red)"},412:{name:"Precondition Failed",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/412",
color:"var(--scalar-color-red)"},413:{name:"Content Too Large",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/413",
color:"var(--scalar-color-red)"},414:{name:"URI Too Long",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/414",
color:"var(--scalar-color-red)"},415:{name:"Unsupported Media Type",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/415",
color:"var(--scalar-color-red)"},416:{name:"Range Not Satisfiable",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/416",
color:"var(--scalar-color-red)"},417:{name:"Expectation Failed",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/417",
color:"var(--scalar-color-red)"},418:{name:"I'm a teapot",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/418",
color:"var(--scalar-color-red)"},421:{name:"Misdirected Request",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/421",
color:"var(--scalar-color-red)"},422:{name:"Unprocessable Content",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/422",
color:"var(--scalar-color-red)"},423:{name:"Locked",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/423",
color:"var(--scalar-color-red)"},424:{name:"Failed Dependency",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/424",
color:"var(--scalar-color-red)"},425:{name:"Too Early",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/425",
color:"var(--scalar-color-red)"},426:{name:"Upgrade Required",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/426",
color:"var(--scalar-color-red)"},428:{name:"Precondition Required",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/428",
color:"var(--scalar-color-red)"},429:{name:"Too Many Requests",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/429",
color:"var(--scalar-color-red)"},431:{name:"Request Header Fields Too Large",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/431",
color:"var(--scalar-color-red)"},451:{name:"Unavailable For Legal Reasons",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/451",
color:"var(--scalar-color-red)"},500:{name:"Internal Server Error",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/500",
color:"var(--scalar-color-red)"},501:{name:"Not Implemented",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/501",
color:"var(--scalar-color-red)"},502:{name:"Bad Gateway",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/502",
color:"var(--scalar-color-red)"},503:{name:"Service Unavailable",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/503",
color:"var(--scalar-color-red)"},504:{name:"Gateway Timeout",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/504",
color:"var(--scalar-color-red)"},505:{name:"HTTP Version Not Supported",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/505",
color:"var(--scalar-color-red)"},506:{name:"Variant Also Negotiates",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/506",
color:"var(--scalar-color-red)"},507:{name:"Insufficient Storage",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/507",
color:"var(--scalar-color-red)"},508:{name:"Loop Detected",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/508",
color:"var(--scalar-color-red)"},510:{name:"Not Extended",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/510",
color:"var(--scalar-color-red)"},511:{name:"Network Authentication Required",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Status/511",
color:"var(--scalar-color-red)"}
},PH=["delete","get","head","options","patch","post","put","trace"],DH=Object.freeze(new Set(PH)),IH=e=>!(!e||"string"!=typeof e)&&DH.has(e.toLowerCase()),MH=e=>Object.keys(e),NH={
PROTOCOL:/^(?:https?|ftp|file|mailto|tel|data|wss?)*:\/\//,
MULTIPLE_SLASHES:new RegExp("(?<!:)\\/{2,}","g"),
VARIABLES:/{{((?:[^{}]|{[^{}]*})*)}}/g,PATH:/(?:{)([^{}]+)}(?!})/g,
REF_NAME:/\/([^\/]+)$/
},RH=(e,{includePath:t=!0,includeEnv:n=!0}={})=>[t&&NH.PATH,n&&NH.VARIABLES].flatMap((t=>t?[...e.matchAll(t)].map((e=>e[1]?.trim())).filter((e=>void 0!==e)):[]))
;function LH(e,t){
const n=(e,n)=>"function"==typeof t?t(n):t[n]?.toString()||`{${n}}`
;return e.replace(/{{\s*([\w.-]+)\s*}}/g,n).replace(/{\s*([\w.-]+)\s*}/g,n)}
const BH=(e,t={})=>e.replace(NH.VARIABLES,((e,n)=>t[n]??e))
;const jH=["localhost","127.0.0.1","[::1]","0.0.0.0"],UH=["test","example","invalid","localhost"]
;function zH(e){try{const{hostname:t}=new URL(e);if(jH.includes(t))return!0
;const n=t.split(".").pop();return!(!n||!UH.includes(n))}catch{return!0}}
const FH=e=>!NH.PROTOCOL.test(e)&&!/^[a-zA-Z0-9-]+\.[a-zA-Z0-9-.]+(\/|$)/.test(e),ZH=(e,t)=>t&&e!==t?e?`${e.trim()}/${t.trim()}`.replace(NH.MULTIPLE_SLASHES,"/"):t.trim():e.trim(),QH=(e,t,n=new URLSearchParams,r=!1)=>{
if(e&&(!FH(e)||"undefined"!=typeof window)){
const o=r?e:FH(e)?ZH(window.location.origin,e):function(e){
return NH.PROTOCOL.test(e)?e:`http://${e.replace(/^\//,"")}`
}(e),[a="",i]=o.split("?"),s=new URLSearchParams(i||""),[l="",c]=t.split("?"),u=new URLSearchParams(c||""),d=e===t?a:ZH(a,l),p=((...e)=>{
const t={};e.forEach((e=>{const n=Array.from(e.keys());new Set(n).forEach((n=>{
const r=e.getAll(n),o=r.length>1?r:r[0]??"";t[n]=o}))}))
;const n=new URLSearchParams;return Object.entries(t).forEach((([e,t])=>{
Array.isArray(t)?t.forEach((t=>n.append(e,t))):n.append(e,t)})),n
})(s,u,n).toString();return p?`${d}?${p}`:d}return t?ZH(e,t):""
},HH=(e,{baseUrl:t,basePath:n}={})=>{if("undefined"==typeof window&&!t)return e
;try{return new URL(e),e}catch{}try{let r=t||window.location.href;if(n){
const e=t?new URL(t).origin:window.location.origin;r=ZH(e,n+"/")}
return new URL(e,r).toString()}catch{return e}},VH=(e,t)=>{try{
if(!qH(e,t))return t??"";const n=new URL(t),r=FH(e)?`http://localhost${e}`:e
;n.href=r,n.searchParams.append("scalar_url",t)
;return FH(e)?n.toString().replace(/^http:\/\/localhost/,""):n.toString()}catch{
return t??""}},qH=(e,t)=>{try{
return!(!e||!t)&&(!FH(t)&&(!!FH(e)||(!!zH(e)||!zH(t))))}catch{return!1}
},WH=Symbol.for("yaml.alias"),XH=Symbol.for("yaml.document"),GH=Symbol.for("yaml.map"),YH=Symbol.for("yaml.pair"),KH=Symbol.for("yaml.scalar"),JH=Symbol.for("yaml.seq"),eV=Symbol.for("yaml.node.type"),tV=e=>!!e&&"object"==typeof e&&e[eV]===WH,nV=e=>!!e&&"object"==typeof e&&e[eV]===XH,rV=e=>!!e&&"object"==typeof e&&e[eV]===GH,oV=e=>!!e&&"object"==typeof e&&e[eV]===YH,aV=e=>!!e&&"object"==typeof e&&e[eV]===KH,iV=e=>!!e&&"object"==typeof e&&e[eV]===JH
;function sV(e){if(e&&"object"==typeof e)switch(e[eV]){case GH:case JH:return!0}
return!1}function lV(e){if(e&&"object"==typeof e)switch(e[eV]){case WH:case GH:
case KH:case JH:return!0}return!1}
const cV=e=>(aV(e)||sV(e))&&!!e.anchor,uV=Symbol("break visit"),dV=Symbol("skip children"),pV=Symbol("remove node")
;function hV(e,t){const n=vV(t);if(nV(e)){
fV(null,e.contents,n,Object.freeze([e]))===pV&&(e.contents=null)
}else fV(null,e,n,Object.freeze([]))}function fV(e,t,n,r){const o=bV(e,t,n,r)
;if(lV(o)||oV(o))return yV(e,r,o),fV(e,o,n,r);if("symbol"!=typeof o)if(sV(t)){
r=Object.freeze(r.concat(t));for(let e=0;e<t.items.length;++e){
const o=fV(e,t.items[e],n,r);if("number"==typeof o)e=o-1;else{
if(o===uV)return uV;o===pV&&(t.items.splice(e,1),e-=1)}}}else if(oV(t)){
r=Object.freeze(r.concat(t));const e=fV("key",t.key,n,r);if(e===uV)return uV
;e===pV&&(t.key=null);const o=fV("value",t.value,n,r);if(o===uV)return uV
;o===pV&&(t.value=null)}return o}async function mV(e,t){const n=vV(t);if(nV(e)){
await gV(null,e.contents,n,Object.freeze([e]))===pV&&(e.contents=null)
}else await gV(null,e,n,Object.freeze([]))}async function gV(e,t,n,r){
const o=await bV(e,t,n,r);if(lV(o)||oV(o))return yV(e,r,o),gV(e,o,n,r)
;if("symbol"!=typeof o)if(sV(t)){r=Object.freeze(r.concat(t))
;for(let e=0;e<t.items.length;++e){const o=await gV(e,t.items[e],n,r)
;if("number"==typeof o)e=o-1;else{if(o===uV)return uV
;o===pV&&(t.items.splice(e,1),e-=1)}}}else if(oV(t)){
r=Object.freeze(r.concat(t));const e=await gV("key",t.key,n,r)
;if(e===uV)return uV;e===pV&&(t.key=null);const o=await gV("value",t.value,n,r)
;if(o===uV)return uV;o===pV&&(t.value=null)}return o}function vV(e){
return"object"==typeof e&&(e.Collection||e.Node||e.Value)?Object.assign({
Alias:e.Node,Map:e.Node,Scalar:e.Node,Seq:e.Node},e.Value&&{Map:e.Value,
Scalar:e.Value,Seq:e.Value},e.Collection&&{Map:e.Collection,Seq:e.Collection
},e):e}function bV(e,t,n,r){
return"function"==typeof n?n(e,t,r):rV(t)?n.Map?.(e,t,r):iV(t)?n.Seq?.(e,t,r):oV(t)?n.Pair?.(e,t,r):aV(t)?n.Scalar?.(e,t,r):tV(t)?n.Alias?.(e,t,r):void 0
}function yV(e,t,n){const r=t[t.length-1]
;if(sV(r))r.items[e]=n;else if(oV(r))"key"===e?r.key=n:r.value=n;else{
if(!nV(r)){const e=tV(r)?"alias":"scalar"
;throw new Error(`Cannot replace node with ${e} parent`)}r.contents=n}}
hV.BREAK=uV,hV.SKIP=dV,hV.REMOVE=pV,mV.BREAK=uV,mV.SKIP=dV,mV.REMOVE=pV
;const OV={"!":"%21",",":"%2C","[":"%5B","]":"%5D","{":"%7B","}":"%7D"}
;class wV{constructor(e,t){
this.docStart=null,this.docEnd=!1,this.yaml=Object.assign({},wV.defaultYaml,e),
this.tags=Object.assign({},wV.defaultTags,t)}clone(){
const e=new wV(this.yaml,this.tags);return e.docStart=this.docStart,e}
atDocument(){const e=new wV(this.yaml,this.tags);switch(this.yaml.version){
case"1.1":this.atNextDocument=!0;break;case"1.2":
this.atNextDocument=!1,this.yaml={explicit:wV.defaultYaml.explicit,version:"1.2"
},this.tags=Object.assign({},wV.defaultTags)}return e}add(e,t){
this.atNextDocument&&(this.yaml={explicit:wV.defaultYaml.explicit,version:"1.1"
},this.tags=Object.assign({},wV.defaultTags),this.atNextDocument=!1)
;const n=e.trim().split(/[ \t]+/),r=n.shift();switch(r){case"%TAG":{
if(2!==n.length&&(t(0,"%TAG directive should contain exactly two parts"),
n.length<2))return!1;const[e,r]=n;return this.tags[e]=r,!0}case"%YAML":{
if(this.yaml.explicit=!0,
1!==n.length)return t(0,"%YAML directive should contain exactly one part"),!1
;const[e]=n;if("1.1"===e||"1.2"===e)return this.yaml.version=e,!0
;return t(6,`Unsupported YAML version ${e}`,/^\d+\.\d+$/.test(e)),!1}default:
return t(0,`Unknown directive ${r}`,!0),!1}}tagName(e,t){if("!"===e)return"!"
;if("!"!==e[0])return t(`Not a valid tag: ${e}`),null;if("<"===e[1]){
const n=e.slice(2,-1)
;return"!"===n||"!!"===n?(t(`Verbatim tags aren't resolved, so ${e} is invalid.`),
null):(">"!==e[e.length-1]&&t("Verbatim tags must end with a >"),n)}
const[,n,r]=e.match(/^(.*!)([^!]*)$/s);r||t(`The ${e} tag has no suffix`)
;const o=this.tags[n];if(o)try{return o+decodeURIComponent(r)}catch(a){
return t(String(a)),null}return"!"===n?e:(t(`Could not resolve tag: ${e}`),null)
}tagString(e){
for(const[t,n]of Object.entries(this.tags))if(e.startsWith(n))return t+e.substring(n.length).replace(/[!,[\]{}]/g,(e=>OV[e]))
;return"!"===e[0]?e:`!<${e}>`}toString(e){
const t=this.yaml.explicit?[`%YAML ${this.yaml.version||"1.2"}`]:[],n=Object.entries(this.tags)
;let r;if(e&&n.length>0&&lV(e.contents)){const t={};hV(e.contents,((e,n)=>{
lV(n)&&n.tag&&(t[n.tag]=!0)})),r=Object.keys(t)}else r=[]
;for(const[o,a]of n)"!!"===o&&"tag:yaml.org,2002:"===a||e&&!r.some((e=>e.startsWith(a)))||t.push(`%TAG ${o} ${a}`)
;return t.join("\n")}}function xV(e){if(/[\x00-\x19\s,[\]{}]/.test(e)){
const t=JSON.stringify(e)
;throw new Error(`Anchor must not contain whitespace or control characters: ${t}`)
}return!0}function kV(e){const t=new Set;return hV(e,{Value(e,n){
n.anchor&&t.add(n.anchor)}}),t}function SV(e,t){for(let n=1;;++n){
const r=`${e}${n}`;if(!t.has(r))return r}}function _V(e,t,n,r){
if(r&&"object"==typeof r)if(Array.isArray(r))for(let o=0,a=r.length;o<a;++o){
const t=r[o],n=_V(e,r,String(o),t);void 0===n?delete r[o]:n!==t&&(r[o]=n)
}else if(r instanceof Map)for(const o of Array.from(r.keys())){
const t=r.get(o),n=_V(e,r,o,t);void 0===n?r.delete(o):n!==t&&r.set(o,n)
}else if(r instanceof Set)for(const o of Array.from(r)){const t=_V(e,r,o,o)
;void 0===t?r.delete(o):t!==o&&(r.delete(o),r.add(t))
}else for(const[o,a]of Object.entries(r)){const t=_V(e,r,o,a)
;void 0===t?delete r[o]:t!==a&&(r[o]=t)}return e.call(t,n,r)}function TV(e,t,n){
if(Array.isArray(e))return e.map(((e,t)=>TV(e,String(t),n)))
;if(e&&"function"==typeof e.toJSON){if(!n||!cV(e))return e.toJSON(t,n);const r={
aliasCount:0,count:1,res:void 0};n.anchors.set(e,r),n.onCreate=e=>{
r.res=e,delete n.onCreate};const o=e.toJSON(t,n)
;return n.onCreate&&n.onCreate(o),o}
return"bigint"!=typeof e||n?.keep?e:Number(e)}wV.defaultYaml={explicit:!1,
version:"1.2"},wV.defaultTags={"!!":"tag:yaml.org,2002:"};class EV{
constructor(e){Object.defineProperty(this,eV,{value:e})}clone(){
const e=Object.create(Object.getPrototypeOf(this),Object.getOwnPropertyDescriptors(this))
;return this.range&&(e.range=this.range.slice()),e}
toJS(e,{mapAsMap:t,maxAliasCount:n,onAnchor:r,reviver:o}={}){
if(!nV(e))throw new TypeError("A document argument is required");const a={
anchors:new Map,doc:e,keep:!0,mapAsMap:!0===t,mapKeyWarned:!1,
maxAliasCount:"number"==typeof n?n:100},i=TV(this,"",a)
;if("function"==typeof r)for(const{count:s,res:l}of a.anchors.values())r(l,s)
;return"function"==typeof o?_V(o,{"":i},"",i):i}}let AV=class extends EV{
constructor(e){super(WH),this.source=e,Object.defineProperty(this,"tag",{set(){
throw new Error("Alias nodes cannot have tags")}})}resolve(e,t){let n,r
;t?.aliasResolveCache?n=t.aliasResolveCache:(n=[],hV(e,{Node:(e,t)=>{
(tV(t)||cV(t))&&n.push(t)}}),t&&(t.aliasResolveCache=n));for(const o of n){
if(o===this)break;o.anchor===this.source&&(r=o)}return r}toJSON(e,t){
if(!t)return{source:this.source}
;const{anchors:n,doc:r,maxAliasCount:o}=t,a=this.resolve(r,t);if(!a){
const e=`Unresolved alias (the anchor must be set before the alias): ${this.source}`
;throw new ReferenceError(e)}let i=n.get(a)
;if(i||(TV(a,null,t),i=n.get(a)),!i||void 0===i.res){
throw new ReferenceError("This should not happen: Alias anchor was not resolved?")
}
if(o>=0&&(i.count+=1,0===i.aliasCount&&(i.aliasCount=CV(r,a,n)),i.count*i.aliasCount>o)){
throw new ReferenceError("Excessive alias count indicates a resource exhaustion attack")
}return i.res}toString(e,t,n){const r=`*${this.source}`;if(e){
if(xV(this.source),e.options.verifyAliasOrder&&!e.anchors.has(this.source)){
const e=`Unresolved alias (the anchor must be set before the alias): ${this.source}`
;throw new Error(e)}if(e.implicitKey)return`${r} `}return r}}
;function CV(e,t,n){if(tV(t)){const r=t.resolve(e),o=n&&r&&n.get(r)
;return o?o.count*o.aliasCount:0}if(sV(t)){let r=0;for(const o of t.items){
const t=CV(e,o,n);t>r&&(r=t)}return r}if(oV(t)){
const r=CV(e,t.key,n),o=CV(e,t.value,n);return Math.max(r,o)}return 1}
const $V=e=>!e||"function"!=typeof e&&"object"!=typeof e;class PV extends EV{
constructor(e){super(KH),this.value=e}toJSON(e,t){
return t?.keep?this.value:TV(this.value,e,t)}toString(){
return String(this.value)}}
PV.BLOCK_FOLDED="BLOCK_FOLDED",PV.BLOCK_LITERAL="BLOCK_LITERAL",
PV.PLAIN="PLAIN",PV.QUOTE_DOUBLE="QUOTE_DOUBLE",PV.QUOTE_SINGLE="QUOTE_SINGLE"
;const DV="tag:yaml.org,2002:";function IV(e,t,n){
if(nV(e)&&(e=e.contents),lV(e))return e;if(oV(e)){
const t=n.schema[GH].createNode?.(n.schema,null,n);return t.items.push(e),t}
(e instanceof String||e instanceof Number||e instanceof Boolean||"undefined"!=typeof BigInt&&e instanceof BigInt)&&(e=e.valueOf())
;const{aliasDuplicateObjects:r,onAnchor:o,onTagObj:a,schema:i,sourceObjects:s}=n
;let l;if(r&&e&&"object"==typeof e){
if(l=s.get(e),l)return l.anchor??(l.anchor=o(e)),new AV(l.anchor);l={
anchor:null,node:null},s.set(e,l)}t?.startsWith("!!")&&(t=DV+t.slice(2))
;let c=function(e,t,n){if(t){
const e=n.filter((e=>e.tag===t)),r=e.find((e=>!e.format))??e[0]
;if(!r)throw new Error(`Tag ${t} not found`);return r}
return n.find((t=>t.identify?.(e)&&!t.format))}(e,t,i.tags);if(!c){
if(e&&"function"==typeof e.toJSON&&(e=e.toJSON()),!e||"object"!=typeof e){
const t=new PV(e);return l&&(l.node=t),t}
c=e instanceof Map?i[GH]:Symbol.iterator in Object(e)?i[JH]:i[GH]}
a&&(a(c),delete n.onTagObj)
;const u=c?.createNode?c.createNode(n.schema,e,n):"function"==typeof c?.nodeClass?.from?c.nodeClass.from(n.schema,e,n):new PV(e)
;return t?u.tag=t:c.default||(u.tag=c.tag),l&&(l.node=u),u}function MV(e,t,n){
let r=n;for(let o=t.length-1;o>=0;--o){const e=t[o]
;if("number"==typeof e&&Number.isInteger(e)&&e>=0){const t=[];t[e]=r,r=t
}else r=new Map([[e,r]])}return IV(r,void 0,{aliasDuplicateObjects:!1,
keepUndefined:!1,onAnchor:()=>{
throw new Error("This should not happen, please report a bug.")},schema:e,
sourceObjects:new Map})}
const NV=e=>null==e||"object"==typeof e&&!!e[Symbol.iterator]().next().done
;class RV extends EV{constructor(e,t){
super(e),Object.defineProperty(this,"schema",{value:t,configurable:!0,
enumerable:!1,writable:!0})}clone(e){
const t=Object.create(Object.getPrototypeOf(this),Object.getOwnPropertyDescriptors(this))
;return e&&(t.schema=e),
t.items=t.items.map((t=>lV(t)||oV(t)?t.clone(e):t)),this.range&&(t.range=this.range.slice()),
t}addIn(e,t){if(NV(e))this.add(t);else{const[n,...r]=e,o=this.get(n,!0)
;if(sV(o))o.addIn(r,t);else{
if(void 0!==o||!this.schema)throw new Error(`Expected YAML collection at ${n}. Remaining path: ${r}`)
;this.set(n,MV(this.schema,r,t))}}}deleteIn(e){const[t,...n]=e
;if(0===n.length)return this.delete(t);const r=this.get(t,!0)
;if(sV(r))return r.deleteIn(n)
;throw new Error(`Expected YAML collection at ${t}. Remaining path: ${n}`)}
getIn(e,t){const[n,...r]=e,o=this.get(n,!0)
;return 0===r.length?!t&&aV(o)?o.value:o:sV(o)?o.getIn(r,t):void 0}
hasAllNullValues(e){return this.items.every((t=>{if(!oV(t))return!1
;const n=t.value
;return null==n||e&&aV(n)&&null==n.value&&!n.commentBefore&&!n.comment&&!n.tag
}))}hasIn(e){const[t,...n]=e;if(0===n.length)return this.has(t)
;const r=this.get(t,!0);return!!sV(r)&&r.hasIn(n)}setIn(e,t){const[n,...r]=e
;if(0===r.length)this.set(n,t);else{const e=this.get(n,!0)
;if(sV(e))e.setIn(r,t);else{
if(void 0!==e||!this.schema)throw new Error(`Expected YAML collection at ${n}. Remaining path: ${r}`)
;this.set(n,MV(this.schema,r,t))}}}}const LV=e=>e.replace(/^(?!$)(?: $)?/gm,"#")
;function BV(e,t){
return/^\n+$/.test(e)?e.substring(1):t?e.replace(/^(?! *$)/gm,t):e}
const jV=(e,t,n)=>e.endsWith("\n")?BV(n,t):n.includes("\n")?"\n"+BV(n,t):(e.endsWith(" ")?"":" ")+n,UV="flow",zV="block",FV="quoted"
;function ZV(e,t,n="flow",{indentAtStart:r,lineWidth:o=80,minContentWidth:a=20,onFold:i,onOverflow:s}={}){
if(!o||o<0)return e;o<a&&(a=0);const l=Math.max(1+a,1+o-t.length)
;if(e.length<=l)return e;const c=[],u={};let d,p,h=o-t.length
;"number"==typeof r&&(r>o-Math.max(2,a)?c.push(0):h=o-r);let f=!1,m=-1,g=-1,v=-1
;n===zV&&(m=QV(e,m,t.length),-1!==m&&(h=m+l));for(let y;y=e[m+=1];){
if(n===FV&&"\\"===y){switch(g=m,e[m+1]){case"x":m+=3;break;case"u":m+=5;break
;case"U":m+=9;break;default:m+=1}v=m}
if("\n"===y)n===zV&&(m=QV(e,m,t.length)),h=m+t.length+l,d=void 0;else{
if(" "===y&&p&&" "!==p&&"\n"!==p&&"\t"!==p){const t=e[m+1]
;t&&" "!==t&&"\n"!==t&&"\t"!==t&&(d=m)}
if(m>=h)if(d)c.push(d),h=d+l,d=void 0;else if(n===FV){
for(;" "===p||"\t"===p;)p=y,y=e[m+=1],f=!0;const t=m>v+1?m-2:g-1
;if(u[t])return e;c.push(t),u[t]=!0,h=t+l,d=void 0}else f=!0}p=y}
if(f&&s&&s(),0===c.length)return e;i&&i();let b=e.slice(0,c[0])
;for(let y=0;y<c.length;++y){const r=c[y],o=c[y+1]||e.length
;0===r?b=`\n${t}${e.slice(0,o)}`:(n===FV&&u[r]&&(b+=`${e[r]}\\`),
b+=`\n${t}${e.slice(r+1,o)}`)}return b}function QV(e,t,n){let r=t,o=t+1,a=e[o]
;for(;" "===a||"\t"===a;)if(t<o+n)a=e[++t];else{do{a=e[++t]}while(a&&"\n"!==a)
;r=t,o=t+1,a=e[o]}return r}const HV=(e,t)=>({
indentAtStart:t?e.indent.length:e.indentAtStart,lineWidth:e.options.lineWidth,
minContentWidth:e.options.minContentWidth}),VV=e=>/^(%|---|\.\.\.)/m.test(e)
;function qV(e,t){const n=JSON.stringify(e)
;if(t.options.doubleQuotedAsJSON)return n
;const{implicitKey:r}=t,o=t.options.doubleQuotedMinMultiLineLength,a=t.indent||(VV(e)?"  ":"")
;let i="",s=0
;for(let l=0,c=n[l];c;c=n[++l])if(" "===c&&"\\"===n[l+1]&&"n"===n[l+2]&&(i+=n.slice(s,l)+"\\ ",
l+=1,s=l,c="\\"),"\\"===c)switch(n[l+1]){case"u":{i+=n.slice(s,l)
;const e=n.substr(l+2,4);switch(e){case"0000":i+="\\0";break;case"0007":i+="\\a"
;break;case"000b":i+="\\v";break;case"001b":i+="\\e";break;case"0085":i+="\\N"
;break;case"00a0":i+="\\_";break;case"2028":i+="\\L";break;case"2029":i+="\\P"
;break;default:"00"===e.substr(0,2)?i+="\\x"+e.substr(2):i+=n.substr(l,6)}
l+=5,s=l+1}break;case"n":if(r||'"'===n[l+2]||n.length<o)l+=1;else{
for(i+=n.slice(s,l)+"\n\n";"\\"===n[l+2]&&"n"===n[l+3]&&'"'!==n[l+4];)i+="\n",
l+=2;i+=a," "===n[l+2]&&(i+="\\"),l+=1,s=l+1}break;default:l+=1}
return i=s?i+n.slice(s):n,r?i:ZV(i,a,FV,HV(t,!1))}function WV(e,t){
if(!1===t.options.singleQuote||t.implicitKey&&e.includes("\n")||/[ \t]\n|\n[ \t]/.test(e))return qV(e,t)
;const n=t.indent||(VV(e)?"  ":""),r="'"+e.replace(/'/g,"''").replace(/\n+/g,`$&\n${n}`)+"'"
;return t.implicitKey?r:ZV(r,n,UV,HV(t,!1))}function XV(e,t){
const{singleQuote:n}=t.options;let r;if(!1===n)r=qV;else{
const t=e.includes('"'),o=e.includes("'");r=t&&!o?WV:o&&!t?qV:n?WV:qV}
return r(e,t)}let GV;try{GV=new RegExp("(^|(?<!\n))\n+(?!\n|$)","g")}catch{
GV=/\n+(?!\n|$)/g}function YV({comment:e,type:t,value:n},r,o,a){
const{blockQuote:i,commentString:s,lineWidth:l}=r.options
;if(!i||/\n[\t ]+$/.test(n)||/^\s*$/.test(n))return XV(n,r)
;const c=r.indent||(r.forceBlockIndent||VV(n)?"  ":""),u="literal"===i||"folded"!==i&&t!==PV.BLOCK_FOLDED&&(t===PV.BLOCK_LITERAL||!function(e,t,n){
if(!t||t<0)return!1;const r=t-n,o=e.length;if(o<=r)return!1
;for(let a=0,i=0;a<o;++a)if("\n"===e[a]){if(a-i>r)return!0
;if(i=a+1,o-i<=r)return!1}return!0}(n,l,c.length));if(!n)return u?"|\n":">\n"
;let d,p;for(p=n.length;p>0;--p){const e=n[p-1]
;if("\n"!==e&&"\t"!==e&&" "!==e)break}let h=n.substring(p)
;const f=h.indexOf("\n");-1===f?d="-":n===h||f!==h.length-1?(d="+",a&&a()):d="",
h&&(n=n.slice(0,-h.length),
"\n"===h[h.length-1]&&(h=h.slice(0,-1)),h=h.replace(GV,`$&${c}`))
;let m,g=!1,v=-1;for(m=0;m<n.length;++m){const e=n[m];if(" "===e)g=!0;else{
if("\n"!==e)break;v=m}}let b=n.substring(0,v<m?v+1:m)
;b&&(n=n.substring(b.length),b=b.replace(/\n+/g,`$&${c}`))
;let y=(g?c?"2":"1":"")+d
;if(e&&(y+=" "+s(e.replace(/ ?[\r\n]+/g," ")),o&&o()),!u){
const e=n.replace(/\n+/g,"\n$&").replace(/(?:^|\n)([\t ].*)(?:([\n\t ]*)\n(?![\n\t ]))?/g,"$1$2").replace(/\n+/g,`$&${c}`)
;let o=!1;const a=HV(r,!0)
;"folded"!==i&&t!==PV.BLOCK_FOLDED&&(a.onOverflow=()=>{o=!0})
;const s=ZV(`${b}${e}${h}`,c,zV,a);if(!o)return`>${y}\n${c}${s}`}
return`|${y}\n${c}${b}${n=n.replace(/\n+/g,`$&${c}`)}${h}`}function KV(e,t,n,r){
const{implicitKey:o,inFlow:a}=t,i="string"==typeof e.value?e:Object.assign({},e,{
value:String(e.value)});let{type:s}=e
;s!==PV.QUOTE_DOUBLE&&/[\x00-\x08\x0b-\x1f\x7f-\x9f\u{D800}-\u{DFFF}]/u.test(i.value)&&(s=PV.QUOTE_DOUBLE)
;const l=e=>{switch(e){case PV.BLOCK_FOLDED:case PV.BLOCK_LITERAL:
return o||a?XV(i.value,t):YV(i,t,n,r);case PV.QUOTE_DOUBLE:return qV(i.value,t)
;case PV.QUOTE_SINGLE:return WV(i.value,t);case PV.PLAIN:
return function(e,t,n,r){
const{type:o,value:a}=e,{actualString:i,implicitKey:s,indent:l,indentStep:c,inFlow:u}=t
;if(s&&a.includes("\n")||u&&/[[\]{},]/.test(a))return XV(a,t)
;if(/^[\n\t ,[\]{}#&*!|>'"%@`]|^[?-]$|^[?-][ \t]|[\n:][ \t]|[ \t]\n|[\n\t ]#|[\n\t :]$/.test(a))return s||u||!a.includes("\n")?XV(a,t):YV(e,t,n,r)
;if(!s&&!u&&o!==PV.PLAIN&&a.includes("\n"))return YV(e,t,n,r);if(VV(a)){
if(""===l)return t.forceBlockIndent=!0,YV(e,t,n,r);if(s&&l===c)return XV(a,t)}
const d=a.replace(/\n+/g,`$&\n${l}`);if(i){
const e=e=>e.default&&"tag:yaml.org,2002:str"!==e.tag&&e.test?.test(d),{compat:n,tags:r}=t.doc.schema
;if(r.some(e)||n?.some(e))return XV(a,t)}return s?d:ZV(d,l,UV,HV(t,!1))
}(i,t,n,r);default:return null}};let c=l(s);if(null===c){
const{defaultKeyType:e,defaultStringType:n}=t.options,r=o&&e||n
;if(c=l(r),null===c)throw new Error(`Unsupported default string type ${r}`)}
return c}function JV(e,t){const n=Object.assign({blockQuote:!0,commentString:LV,
defaultKeyType:null,defaultStringType:"PLAIN",directives:null,
doubleQuotedAsJSON:!1,doubleQuotedMinMultiLineLength:40,falseStr:"false",
flowCollectionPadding:!0,indentSeq:!0,lineWidth:80,minContentWidth:20,
nullStr:"null",simpleKeys:!1,singleQuote:null,trueStr:"true",verifyAliasOrder:!0
},e.schema.toStringOptions,t);let r;switch(n.collectionStyle){case"block":r=!1
;break;case"flow":r=!0;break;default:r=null}return{anchors:new Set,doc:e,
flowCollectionPadding:n.flowCollectionPadding?" ":"",indent:"",
indentStep:"number"==typeof n.indent?" ".repeat(n.indent):"  ",inFlow:r,
options:n}}function eq(e,t,n,r){if(oV(e))return e.toString(t,n,r);if(tV(e)){
if(t.doc.directives)return e.toString(t)
;if(t.resolvedAliases?.has(e))throw new TypeError("Cannot stringify circular structure without alias nodes")
;t.resolvedAliases?t.resolvedAliases.add(e):t.resolvedAliases=new Set([e]),
e=e.resolve(t.doc)}let o;const a=lV(e)?e:t.doc.createNode(e,{onTagObj:e=>o=e})
;o??(o=function(e,t){if(t.tag){const n=e.filter((e=>e.tag===t.tag))
;if(n.length>0)return n.find((e=>e.format===t.format))??n[0]}let n,r;if(aV(t)){
r=t.value;let o=e.filter((e=>e.identify?.(r)));if(o.length>1){
const e=o.filter((e=>e.test));e.length>0&&(o=e)}
n=o.find((e=>e.format===t.format))??o.find((e=>!e.format))
}else r=t,n=e.find((e=>e.nodeClass&&r instanceof e.nodeClass))
;if(!n)throw new Error(`Tag not resolved for ${r?.constructor?.name??(null===r?"null":typeof r)} value`)
;return n}(t.doc.schema.tags,a));const i=function(e,t,{anchors:n,doc:r}){
if(!r.directives)return"";const o=[],a=(aV(e)||sV(e))&&e.anchor
;a&&xV(a)&&(n.add(a),o.push(`&${a}`));const i=e.tag??(t.default?null:t.tag)
;return i&&o.push(r.directives.tagString(i)),o.join(" ")}(a,o,t)
;i.length>0&&(t.indentAtStart=(t.indentAtStart??0)+i.length+1)
;const s="function"==typeof o.stringify?o.stringify(a,t,n,r):aV(a)?KV(a,t,n,r):a.toString(t,n,r)
;return i?aV(a)||"{"===s[0]||"["===s[0]?`${i} ${s}`:`${i}\n${t.indent}${s}`:s}
function tq(e,t){"debug"!==e&&"warn"!==e||console.warn(t)}const nq="<<",rq={
identify:e=>e===nq||"symbol"==typeof e&&e.description===nq,default:"key",
tag:"tag:yaml.org,2002:merge",test:/^<<$/,
resolve:()=>Object.assign(new PV(Symbol(nq)),{addToJSMap:oq}),stringify:()=>nq}
;function oq(e,t,n){
if(n=e&&tV(n)?n.resolve(e.doc):n,iV(n))for(const r of n.items)aq(e,t,r);else if(Array.isArray(n))for(const r of n)aq(e,t,r);else aq(e,t,n)
}function aq(e,t,n){const r=e&&tV(n)?n.resolve(e.doc):n
;if(!rV(r))throw new Error("Merge sources must be maps or map aliases")
;const o=r.toJSON(null,e,Map)
;for(const[a,i]of o)t instanceof Map?t.has(a)||t.set(a,i):t instanceof Set?t.add(a):Object.prototype.hasOwnProperty.call(t,a)||Object.defineProperty(t,a,{
value:i,writable:!0,enumerable:!0,configurable:!0});return t}
function iq(e,t,{key:n,value:r}){
if(lV(n)&&n.addToJSMap)n.addToJSMap(e,t,r);else if(((e,t)=>(rq.identify(t)||aV(t)&&(!t.type||t.type===PV.PLAIN)&&rq.identify(t.value))&&e?.doc.schema.tags.some((e=>e.tag===rq.tag&&e.default)))(e,n))oq(e,t,r);else{
const o=TV(n,"",e)
;if(t instanceof Map)t.set(o,TV(r,o,e));else if(t instanceof Set)t.add(o);else{
const a=function(e,t,n){if(null===t)return""
;if("object"!=typeof t)return String(t);if(lV(e)&&n?.doc){const t=JV(n.doc,{})
;t.anchors=new Set;for(const e of n.anchors.keys())t.anchors.add(e.anchor)
;t.inFlow=!0,t.inStringifyKey=!0;const r=e.toString(t);if(!n.mapKeyWarned){
let e=JSON.stringify(r)
;e.length>40&&(e=e.substring(0,36)+'..."'),tq(n.doc.options.logLevel,`Keys with collection values will be stringified due to JS Object restrictions: ${e}. Set mapAsMap: true to use object keys.`),
n.mapKeyWarned=!0}return r}return JSON.stringify(t)}(n,o,e),i=TV(r,a,e)
;a in t?Object.defineProperty(t,a,{value:i,writable:!0,enumerable:!0,
configurable:!0}):t[a]=i}}return t}function sq(e,t,n){
const r=IV(e,void 0,n),o=IV(t,void 0,n);return new lq(r,o)}class lq{
constructor(e,t=null){Object.defineProperty(this,eV,{value:YH
}),this.key=e,this.value=t}clone(e){let{key:t,value:n}=this
;return lV(t)&&(t=t.clone(e)),lV(n)&&(n=n.clone(e)),new lq(t,n)}toJSON(e,t){
return iq(t,t?.mapAsMap?new Map:{},this)}toString(e,t,n){
return e?.doc?function({key:e,value:t},n,r,o){
const{allNullValues:a,doc:i,indent:s,indentStep:l,options:{commentString:c,indentSeq:u,simpleKeys:d}}=n
;let p=lV(e)&&e.comment||null;if(d){
if(p)throw new Error("With simple keys, key nodes cannot have comments")
;if(sV(e)||!lV(e)&&"object"==typeof e)throw new Error("With simple keys, collection cannot be used as a key value")
}
let h=!d&&(!e||p&&null==t&&!n.inFlow||sV(e)||(aV(e)?e.type===PV.BLOCK_FOLDED||e.type===PV.BLOCK_LITERAL:"object"==typeof e))
;n=Object.assign({},n,{allNullValues:!1,implicitKey:!h&&(d||!a),indent:s+l})
;let f,m,g,v=!1,b=!1,y=eq(e,n,(()=>v=!0),(()=>b=!0))
;if(!h&&!n.inFlow&&y.length>1024){
if(d)throw new Error("With simple keys, single line scalar must not span more than 1024 characters")
;h=!0}if(n.inFlow){if(a||null==t)return v&&r&&r(),""===y?"?":h?`? ${y}`:y
}else if(a&&!d||null==t&&h)return y=`? ${y}`,
p&&!v?y+=jV(y,n.indent,c(p)):b&&o&&o(),y
;v&&(p=null),h?(p&&(y+=jV(y,n.indent,c(p))),
y=`? ${y}\n${s}:`):(y=`${y}:`,p&&(y+=jV(y,n.indent,c(p)))),
lV(t)?(f=!!t.spaceBefore,
m=t.commentBefore,g=t.comment):(f=!1,m=null,g=null,t&&"object"==typeof t&&(t=i.createNode(t))),
n.implicitKey=!1,
h||p||!aV(t)||(n.indentAtStart=y.length+1),b=!1,u||!(l.length>=2)||n.inFlow||h||!iV(t)||t.flow||t.tag||t.anchor||(n.indent=n.indent.substring(2))
;let O=!1;const w=eq(t,n,(()=>O=!0),(()=>b=!0));let x=" "
;if(p||f||m)x=f?"\n":"",
m&&(x+=`\n${BV(c(m),n.indent)}`),""!==w||n.inFlow?x+=`\n${n.indent}`:"\n"===x&&(x="\n\n");else if(!h&&sV(t)){
const e=w[0],r=w.indexOf("\n"),o=-1!==r,a=n.inFlow??t.flow??0===t.items.length
;if(o||!a){let t=!1;if(o&&("&"===e||"!"===e)){let n=w.indexOf(" ")
;"&"===e&&-1!==n&&n<r&&"!"===w[n+1]&&(n=w.indexOf(" ",n+1)),
(-1===n||r<n)&&(t=!0)}t||(x=`\n${n.indent}`)}}else""!==w&&"\n"!==w[0]||(x="")
;return y+=x+w,n.inFlow?O&&r&&r():g&&!O?y+=jV(y,n.indent,c(g)):b&&o&&o(),y
}(this,e,t,n):JSON.stringify(this)}}function cq(e,t,n){
return(t.inFlow??e.flow?dq:uq)(e,t,n)}
function uq({comment:e,items:t},n,{blockItemPrefix:r,flowChars:o,itemIndent:a,onChompKeep:i,onComment:s}){
const{indent:l,options:{commentString:c}}=n,u=Object.assign({},n,{indent:a,
type:null});let d=!1;const p=[];for(let f=0;f<t.length;++f){const e=t[f]
;let o=null
;if(lV(e))!d&&e.spaceBefore&&p.push(""),pq(n,p,e.commentBefore,d),e.comment&&(o=e.comment);else if(oV(e)){
const t=lV(e.key)?e.key:null
;t&&(!d&&t.spaceBefore&&p.push(""),pq(n,p,t.commentBefore,d))}d=!1
;let i=eq(e,u,(()=>o=null),(()=>d=!0))
;o&&(i+=jV(i,a,c(o))),d&&o&&(d=!1),p.push(r+i)}let h
;if(0===p.length)h=o.start+o.end;else{h=p[0];for(let e=1;e<p.length;++e){
const t=p[e];h+=t?`\n${l}${t}`:"\n"}}
return e?(h+="\n"+BV(c(e),l),s&&s()):d&&i&&i(),h}
function dq({items:e},t,{flowChars:n,itemIndent:r}){
const{indent:o,indentStep:a,flowCollectionPadding:i,options:{commentString:s}}=t
;r+=a;const l=Object.assign({},t,{indent:r,inFlow:!0,type:null});let c=!1,u=0
;const d=[];for(let f=0;f<e.length;++f){const n=e[f];let o=null
;if(lV(n))n.spaceBefore&&d.push(""),
pq(t,d,n.commentBefore,!1),n.comment&&(o=n.comment);else if(oV(n)){
const e=lV(n.key)?n.key:null
;e&&(e.spaceBefore&&d.push(""),pq(t,d,e.commentBefore,!1),e.comment&&(c=!0))
;const r=lV(n.value)?n.value:null
;r?(r.comment&&(o=r.comment),r.commentBefore&&(c=!0)):null==n.value&&e?.comment&&(o=e.comment)
}o&&(c=!0);let a=eq(n,l,(()=>o=null))
;f<e.length-1&&(a+=","),o&&(a+=jV(a,r,s(o))),
!c&&(d.length>u||a.includes("\n"))&&(c=!0),d.push(a),u=d.length}
const{start:p,end:h}=n;if(0===d.length)return p+h;if(!c){
const e=d.reduce(((e,t)=>e+t.length+2),2)
;c=t.options.lineWidth>0&&e>t.options.lineWidth}if(c){let e=p
;for(const t of d)e+=t?`\n${a}${o}${t}`:"\n";return`${e}\n${o}${h}`}
return`${p}${i}${d.join(" ")}${i}${h}`}
function pq({indent:e,options:{commentString:t}},n,r,o){
if(r&&o&&(r=r.replace(/^\n+/,"")),r){const o=BV(t(r),e);n.push(o.trimStart())}}
function hq(e,t){const n=aV(t)?t.value:t;for(const r of e)if(oV(r)){
if(r.key===t||r.key===n)return r;if(aV(r.key)&&r.key.value===n)return r}}
class fq extends RV{static get tagName(){return"tag:yaml.org,2002:map"}
constructor(e){super(GH,e),this.items=[]}static from(e,t,n){
const{keepUndefined:r,replacer:o}=n,a=new this(e),i=(e,i)=>{
if("function"==typeof o)i=o.call(t,e,i);else if(Array.isArray(o)&&!o.includes(e))return
;(void 0!==i||r)&&a.items.push(sq(e,i,n))}
;if(t instanceof Map)for(const[s,l]of t)i(s,l);else if(t&&"object"==typeof t)for(const s of Object.keys(t))i(s,t[s])
;return"function"==typeof e.sortMapEntries&&a.items.sort(e.sortMapEntries),a}
add(e,t){let n
;n=oV(e)?e:e&&"object"==typeof e&&"key"in e?new lq(e.key,e.value):new lq(e,e?.value)
;const r=hq(this.items,n.key),o=this.schema?.sortMapEntries;if(r){
if(!t)throw new Error(`Key ${n.key} already set`)
;aV(r.value)&&$V(n.value)?r.value.value=n.value:r.value=n.value}else if(o){
const e=this.items.findIndex((e=>o(n,e)<0))
;-1===e?this.items.push(n):this.items.splice(e,0,n)}else this.items.push(n)}
delete(e){const t=hq(this.items,e);if(!t)return!1
;return this.items.splice(this.items.indexOf(t),1).length>0}get(e,t){
const n=hq(this.items,e),r=n?.value;return(!t&&aV(r)?r.value:r)??void 0}has(e){
return!!hq(this.items,e)}set(e,t){this.add(new lq(e,t),!0)}toJSON(e,t,n){
const r=n?new n:t?.mapAsMap?new Map:{};t?.onCreate&&t.onCreate(r)
;for(const o of this.items)iq(t,r,o);return r}toString(e,t,n){
if(!e)return JSON.stringify(this)
;for(const r of this.items)if(!oV(r))throw new Error(`Map items must all be pairs; found ${JSON.stringify(r)} instead`)
;return!e.allNullValues&&this.hasAllNullValues(!1)&&(e=Object.assign({},e,{
allNullValues:!0})),cq(this,e,{blockItemPrefix:"",flowChars:{start:"{",end:"}"},
itemIndent:e.indent||"",onChompKeep:n,onComment:t})}}const mq={collection:"map",
default:!0,nodeClass:fq,tag:"tag:yaml.org,2002:map",
resolve:(e,t)=>(rV(e)||t("Expected a mapping for this tag"),e),
createNode:(e,t,n)=>fq.from(e,t,n)};class gq extends RV{static get tagName(){
return"tag:yaml.org,2002:seq"}constructor(e){super(JH,e),this.items=[]}add(e){
this.items.push(e)}delete(e){const t=vq(e);if("number"!=typeof t)return!1
;return this.items.splice(t,1).length>0}get(e,t){const n=vq(e)
;if("number"!=typeof n)return;const r=this.items[n];return!t&&aV(r)?r.value:r}
has(e){const t=vq(e);return"number"==typeof t&&t<this.items.length}set(e,t){
const n=vq(e)
;if("number"!=typeof n)throw new Error(`Expected a valid index, not ${e}.`)
;const r=this.items[n];aV(r)&&$V(t)?r.value=t:this.items[n]=t}toJSON(e,t){
const n=[];t?.onCreate&&t.onCreate(n);let r=0
;for(const o of this.items)n.push(TV(o,String(r++),t));return n}toString(e,t,n){
return e?cq(this,e,{blockItemPrefix:"- ",flowChars:{start:"[",end:"]"},
itemIndent:(e.indent||"")+"  ",onChompKeep:n,onComment:t}):JSON.stringify(this)}
static from(e,t,n){const{replacer:r}=n,o=new this(e)
;if(t&&Symbol.iterator in Object(t)){let e=0;for(let a of t){
if("function"==typeof r){const n=t instanceof Set?a:String(e++);a=r.call(t,n,a)}
o.items.push(IV(a,void 0,n))}}return o}}function vq(e){let t=aV(e)?e.value:e
;return t&&"string"==typeof t&&(t=Number(t)),
"number"==typeof t&&Number.isInteger(t)&&t>=0?t:null}const bq={collection:"seq",
default:!0,nodeClass:gq,tag:"tag:yaml.org,2002:seq",
resolve:(e,t)=>(iV(e)||t("Expected a sequence for this tag"),e),
createNode:(e,t,n)=>gq.from(e,t,n)},yq={identify:e=>"string"==typeof e,
default:!0,tag:"tag:yaml.org,2002:str",resolve:e=>e,
stringify:(e,t,n,r)=>KV(e,t=Object.assign({actualString:!0},t),n,r)},Oq={
identify:e=>null==e,createNode:()=>new PV(null),default:!0,
tag:"tag:yaml.org,2002:null",test:/^(?:~|[Nn]ull|NULL)?$/,
resolve:()=>new PV(null),
stringify:({source:e},t)=>"string"==typeof e&&Oq.test.test(e)?e:t.options.nullStr
},wq={identify:e=>"boolean"==typeof e,default:!0,tag:"tag:yaml.org,2002:bool",
test:/^(?:[Tt]rue|TRUE|[Ff]alse|FALSE)$/,
resolve:e=>new PV("t"===e[0]||"T"===e[0]),stringify({source:e,value:t},n){
if(e&&wq.test.test(e)){if(t===("t"===e[0]||"T"===e[0]))return e}
return t?n.options.trueStr:n.options.falseStr}}
;function xq({format:e,minFractionDigits:t,tag:n,value:r}){
if("bigint"==typeof r)return String(r);const o="number"==typeof r?r:Number(r)
;if(!isFinite(o))return isNaN(o)?".nan":o<0?"-.inf":".inf"
;let a=JSON.stringify(r)
;if(!e&&t&&(!n||"tag:yaml.org,2002:float"===n)&&/^\d/.test(a)){
let e=a.indexOf(".");e<0&&(e=a.length,a+=".");let n=t-(a.length-e-1)
;for(;n-- >0;)a+="0"}return a}const kq={identify:e=>"number"==typeof e,
default:!0,tag:"tag:yaml.org,2002:float",
test:/^(?:[-+]?\.(?:inf|Inf|INF)|\.nan|\.NaN|\.NAN)$/,
resolve:e=>"nan"===e.slice(-3).toLowerCase()?NaN:"-"===e[0]?Number.NEGATIVE_INFINITY:Number.POSITIVE_INFINITY,
stringify:xq},Sq={identify:e=>"number"==typeof e,default:!0,
tag:"tag:yaml.org,2002:float",format:"EXP",
test:/^[-+]?(?:\.[0-9]+|[0-9]+(?:\.[0-9]*)?)[eE][-+]?[0-9]+$/,
resolve:e=>parseFloat(e),stringify(e){const t=Number(e.value)
;return isFinite(t)?t.toExponential():xq(e)}},_q={
identify:e=>"number"==typeof e,default:!0,tag:"tag:yaml.org,2002:float",
test:/^[-+]?(?:\.[0-9]+|[0-9]+\.[0-9]*)$/,resolve(e){
const t=new PV(parseFloat(e)),n=e.indexOf(".")
;return-1!==n&&"0"===e[e.length-1]&&(t.minFractionDigits=e.length-n-1),t},
stringify:xq
},Tq=e=>"bigint"==typeof e||Number.isInteger(e),Eq=(e,t,n,{intAsBigInt:r})=>r?BigInt(e):parseInt(e.substring(t),n)
;function Aq(e,t,n){const{value:r}=e;return Tq(r)&&r>=0?n+r.toString(t):xq(e)}
const Cq={identify:e=>Tq(e)&&e>=0,default:!0,tag:"tag:yaml.org,2002:int",
format:"OCT",test:/^0o[0-7]+$/,resolve:(e,t,n)=>Eq(e,2,8,n),
stringify:e=>Aq(e,8,"0o")},$q={identify:Tq,default:!0,
tag:"tag:yaml.org,2002:int",test:/^[-+]?[0-9]+$/,resolve:(e,t,n)=>Eq(e,0,10,n),
stringify:xq},Pq={identify:e=>Tq(e)&&e>=0,default:!0,
tag:"tag:yaml.org,2002:int",format:"HEX",test:/^0x[0-9a-fA-F]+$/,
resolve:(e,t,n)=>Eq(e,2,16,n),stringify:e=>Aq(e,16,"0x")
},Dq=[mq,bq,yq,Oq,wq,Cq,$q,Pq,kq,Sq,_q];function Iq(e){
return"bigint"==typeof e||Number.isInteger(e)}
const Mq=({value:e})=>JSON.stringify(e),Nq=[mq,bq].concat([{
identify:e=>"string"==typeof e,default:!0,tag:"tag:yaml.org,2002:str",
resolve:e=>e,stringify:Mq},{identify:e=>null==e,createNode:()=>new PV(null),
default:!0,tag:"tag:yaml.org,2002:null",test:/^null$/,resolve:()=>null,
stringify:Mq},{identify:e=>"boolean"==typeof e,default:!0,
tag:"tag:yaml.org,2002:bool",test:/^true$|^false$/,resolve:e=>"true"===e,
stringify:Mq},{identify:Iq,default:!0,tag:"tag:yaml.org,2002:int",
test:/^-?(?:0|[1-9][0-9]*)$/,
resolve:(e,t,{intAsBigInt:n})=>n?BigInt(e):parseInt(e,10),
stringify:({value:e})=>Iq(e)?e.toString():JSON.stringify(e)},{
identify:e=>"number"==typeof e,default:!0,tag:"tag:yaml.org,2002:float",
test:/^-?(?:0|[1-9][0-9]*)(?:\.[0-9]*)?(?:[eE][-+]?[0-9]+)?$/,
resolve:e=>parseFloat(e),stringify:Mq}],{default:!0,tag:"",test:/^/,
resolve:(e,t)=>(t(`Unresolved plain scalar ${JSON.stringify(e)}`),e)}),Rq={
identify:e=>e instanceof Uint8Array,default:!1,tag:"tag:yaml.org,2002:binary",
resolve(e,t){if("function"==typeof atob){
const t=atob(e.replace(/[\n\r]/g,"")),n=new Uint8Array(t.length)
;for(let e=0;e<t.length;++e)n[e]=t.charCodeAt(e);return n}
return t("This environment does not support reading binary tags; either Buffer or atob is required"),
e},stringify({comment:e,type:t,value:n},r,o,a){if(!n)return"";const i=n;let s
;if("function"!=typeof btoa)throw new Error("This environment does not support writing binary tags; either Buffer or btoa is required")
;{let e="";for(let t=0;t<i.length;++t)e+=String.fromCharCode(i[t]);s=btoa(e)}
if(t??(t=PV.BLOCK_LITERAL),t!==PV.QUOTE_DOUBLE){
const e=Math.max(r.options.lineWidth-r.indent.length,r.options.minContentWidth),n=Math.ceil(s.length/e),o=new Array(n)
;for(let t=0,r=0;t<n;++t,r+=e)o[t]=s.substr(r,e)
;s=o.join(t===PV.BLOCK_LITERAL?"\n":" ")}return KV({comment:e,type:t,value:s
},r,o,a)}};function Lq(e,t){if(iV(e))for(let n=0;n<e.items.length;++n){
let r=e.items[n];if(!oV(r)){if(rV(r)){
r.items.length>1&&t("Each pair must have its own sequence indicator")
;const e=r.items[0]||new lq(new PV(null))
;if(r.commentBefore&&(e.key.commentBefore=e.key.commentBefore?`${r.commentBefore}\n${e.key.commentBefore}`:r.commentBefore),
r.comment){const t=e.value??e.key
;t.comment=t.comment?`${r.comment}\n${t.comment}`:r.comment}r=e}
e.items[n]=oV(r)?r:new lq(r)}}else t("Expected a sequence for this tag")
;return e}function Bq(e,t,n){const{replacer:r}=n,o=new gq(e)
;o.tag="tag:yaml.org,2002:pairs";let a=0
;if(t&&Symbol.iterator in Object(t))for(let i of t){let e,s
;if("function"==typeof r&&(i=r.call(t,String(a++),i)),Array.isArray(i)){
if(2!==i.length)throw new TypeError(`Expected [key, value] tuple: ${i}`);e=i[0],
s=i[1]}else if(i&&i instanceof Object){const t=Object.keys(i)
;if(1!==t.length)throw new TypeError(`Expected tuple with one key, not ${t.length} keys`)
;e=t[0],s=i[e]}else e=i;o.items.push(sq(e,s,n))}return o}const jq={
collection:"seq",default:!1,tag:"tag:yaml.org,2002:pairs",resolve:Lq,
createNode:Bq};class Uq extends gq{constructor(){
super(),this.add=fq.prototype.add.bind(this),
this.delete=fq.prototype.delete.bind(this),this.get=fq.prototype.get.bind(this),
this.has=fq.prototype.has.bind(this),
this.set=fq.prototype.set.bind(this),this.tag=Uq.tag}toJSON(e,t){
if(!t)return super.toJSON(e);const n=new Map;t?.onCreate&&t.onCreate(n)
;for(const r of this.items){let e,o
;if(oV(r)?(e=TV(r.key,"",t),o=TV(r.value,e,t)):e=TV(r,"",t),
n.has(e))throw new Error("Ordered maps must not include duplicate keys")
;n.set(e,o)}return n}static from(e,t,n){const r=Bq(e,t,n),o=new this
;return o.items=r.items,o}}Uq.tag="tag:yaml.org,2002:omap";const zq={
collection:"seq",identify:e=>e instanceof Map,nodeClass:Uq,default:!1,
tag:"tag:yaml.org,2002:omap",resolve(e,t){const n=Lq(e,t),r=[]
;for(const{key:o}of n.items)aV(o)&&(r.includes(o.value)?t(`Ordered maps must not include duplicate keys: ${o.value}`):r.push(o.value))
;return Object.assign(new Uq,n)},createNode:(e,t,n)=>Uq.from(e,t,n)}
;function Fq({value:e,source:t},n){
return t&&(e?Zq:Qq).test.test(t)?t:e?n.options.trueStr:n.options.falseStr}
const Zq={identify:e=>!0===e,default:!0,tag:"tag:yaml.org,2002:bool",
test:/^(?:Y|y|[Yy]es|YES|[Tt]rue|TRUE|[Oo]n|ON)$/,resolve:()=>new PV(!0),
stringify:Fq},Qq={identify:e=>!1===e,default:!0,tag:"tag:yaml.org,2002:bool",
test:/^(?:N|n|[Nn]o|NO|[Ff]alse|FALSE|[Oo]ff|OFF)$/,resolve:()=>new PV(!1),
stringify:Fq},Hq={identify:e=>"number"==typeof e,default:!0,
tag:"tag:yaml.org,2002:float",
test:/^(?:[-+]?\.(?:inf|Inf|INF)|\.nan|\.NaN|\.NAN)$/,
resolve:e=>"nan"===e.slice(-3).toLowerCase()?NaN:"-"===e[0]?Number.NEGATIVE_INFINITY:Number.POSITIVE_INFINITY,
stringify:xq},Vq={identify:e=>"number"==typeof e,default:!0,
tag:"tag:yaml.org,2002:float",format:"EXP",
test:/^[-+]?(?:[0-9][0-9_]*)?(?:\.[0-9_]*)?[eE][-+]?[0-9]+$/,
resolve:e=>parseFloat(e.replace(/_/g,"")),stringify(e){const t=Number(e.value)
;return isFinite(t)?t.toExponential():xq(e)}},qq={
identify:e=>"number"==typeof e,default:!0,tag:"tag:yaml.org,2002:float",
test:/^[-+]?(?:[0-9][0-9_]*)?\.[0-9_]*$/,resolve(e){
const t=new PV(parseFloat(e.replace(/_/g,""))),n=e.indexOf(".");if(-1!==n){
const r=e.substring(n+1).replace(/_/g,"")
;"0"===r[r.length-1]&&(t.minFractionDigits=r.length)}return t},stringify:xq
},Wq=e=>"bigint"==typeof e||Number.isInteger(e)
;function Xq(e,t,n,{intAsBigInt:r}){const o=e[0]
;if("-"!==o&&"+"!==o||(t+=1),e=e.substring(t).replace(/_/g,""),r){switch(n){
case 2:e=`0b${e}`;break;case 8:e=`0o${e}`;break;case 16:e=`0x${e}`}
const t=BigInt(e);return"-"===o?BigInt(-1)*t:t}const a=parseInt(e,n)
;return"-"===o?-1*a:a}function Gq(e,t,n){const{value:r}=e;if(Wq(r)){
const e=r.toString(t);return r<0?"-"+n+e.substr(1):n+e}return xq(e)}const Yq={
identify:Wq,default:!0,tag:"tag:yaml.org,2002:int",format:"BIN",
test:/^[-+]?0b[0-1_]+$/,resolve:(e,t,n)=>Xq(e,2,2,n),stringify:e=>Gq(e,2,"0b")
},Kq={identify:Wq,default:!0,tag:"tag:yaml.org,2002:int",format:"OCT",
test:/^[-+]?0[0-7_]+$/,resolve:(e,t,n)=>Xq(e,1,8,n),stringify:e=>Gq(e,8,"0")
},Jq={identify:Wq,default:!0,tag:"tag:yaml.org,2002:int",
test:/^[-+]?[0-9][0-9_]*$/,resolve:(e,t,n)=>Xq(e,0,10,n),stringify:xq},eW={
identify:Wq,default:!0,tag:"tag:yaml.org,2002:int",format:"HEX",
test:/^[-+]?0x[0-9a-fA-F_]+$/,resolve:(e,t,n)=>Xq(e,2,16,n),
stringify:e=>Gq(e,16,"0x")};class tW extends fq{constructor(e){
super(e),this.tag=tW.tag}add(e){let t
;t=oV(e)?e:e&&"object"==typeof e&&"key"in e&&"value"in e&&null===e.value?new lq(e.key,null):new lq(e,null)
;hq(this.items,t.key)||this.items.push(t)}get(e,t){const n=hq(this.items,e)
;return!t&&oV(n)?aV(n.key)?n.key.value:n.key:n}set(e,t){
if("boolean"!=typeof t)throw new Error("Expected boolean value for set(key, value) in a YAML set, not "+typeof t)
;const n=hq(this.items,e)
;n&&!t?this.items.splice(this.items.indexOf(n),1):!n&&t&&this.items.push(new lq(e))
}toJSON(e,t){return super.toJSON(e,t,Set)}toString(e,t,n){
if(!e)return JSON.stringify(this)
;if(this.hasAllNullValues(!0))return super.toString(Object.assign({},e,{
allNullValues:!0}),t,n);throw new Error("Set items must all have null values")}
static from(e,t,n){const{replacer:r}=n,o=new this(e)
;if(t&&Symbol.iterator in Object(t))for(let a of t)"function"==typeof r&&(a=r.call(t,a,a)),
o.items.push(sq(a,null,n));return o}}tW.tag="tag:yaml.org,2002:set";const nW={
collection:"map",identify:e=>e instanceof Set,nodeClass:tW,default:!1,
tag:"tag:yaml.org,2002:set",createNode:(e,t,n)=>tW.from(e,t,n),resolve(e,t){
if(rV(e)){if(e.hasAllNullValues(!0))return Object.assign(new tW,e)
;t("Set items must all have null values")
}else t("Expected a mapping for this tag");return e}};function rW(e,t){
const n=e[0],r="-"===n||"+"===n?e.substring(1):e,o=e=>t?BigInt(e):Number(e),a=r.replace(/_/g,"").split(":").reduce(((e,t)=>e*o(60)+o(t)),o(0))
;return"-"===n?o(-1)*a:a}function oW(e){let{value:t}=e,n=e=>e
;if("bigint"==typeof t)n=e=>BigInt(e);else if(isNaN(t)||!isFinite(t))return xq(e)
;let r="";t<0&&(r="-",t*=n(-1));const o=n(60),a=[t%o]
;return t<60?a.unshift(0):(t=(t-a[0])/o,
a.unshift(t%o),t>=60&&(t=(t-a[0])/o,a.unshift(t))),
r+a.map((e=>String(e).padStart(2,"0"))).join(":").replace(/000000\d*$/,"")}
const aW={identify:e=>"bigint"==typeof e||Number.isInteger(e),default:!0,
tag:"tag:yaml.org,2002:int",format:"TIME",
test:/^[-+]?[0-9][0-9_]*(?::[0-5]?[0-9])+$/,
resolve:(e,t,{intAsBigInt:n})=>rW(e,n),stringify:oW},iW={
identify:e=>"number"==typeof e,default:!0,tag:"tag:yaml.org,2002:float",
format:"TIME",test:/^[-+]?[0-9][0-9_]*(?::[0-5]?[0-9])+\.[0-9_]*$/,
resolve:e=>rW(e,!1),stringify:oW},sW={identify:e=>e instanceof Date,default:!0,
tag:"tag:yaml.org,2002:timestamp",
test:RegExp("^([0-9]{4})-([0-9]{1,2})-([0-9]{1,2})(?:(?:t|T|[ \\t]+)([0-9]{1,2}):([0-9]{1,2}):([0-9]{1,2}(\\.[0-9]+)?)(?:[ \\t]*(Z|[-+][012]?[0-9](?::[0-9]{2})?))?)?$"),
resolve(e){const t=e.match(sW.test)
;if(!t)throw new Error("!!timestamp expects a date, starting with yyyy-mm-dd")
;const[,n,r,o,a,i,s]=t.map(Number),l=t[7]?Number((t[7]+"00").substr(1,3)):0
;let c=Date.UTC(n,r-1,o,a||0,i||0,s||0,l);const u=t[8];if(u&&"Z"!==u){
let e=rW(u,!1);Math.abs(e)<30&&(e*=60),c-=6e4*e}return new Date(c)},
stringify:({value:e})=>e?.toISOString().replace(/(T00:00:00)?\.000Z$/,"")??""
},lW=[mq,bq,yq,Oq,Zq,Qq,Yq,Kq,Jq,eW,Hq,Vq,qq,Rq,rq,zq,jq,nW,aW,iW,sW],cW=new Map([["core",Dq],["failsafe",[mq,bq,yq]],["json",Nq],["yaml11",lW],["yaml-1.1",lW]]),uW={
binary:Rq,bool:wq,float:_q,floatExp:Sq,floatNaN:kq,floatTime:iW,int:$q,
intHex:Pq,intOct:Cq,intTime:aW,map:mq,merge:rq,null:Oq,omap:zq,pairs:jq,seq:bq,
set:nW,timestamp:sW},dW={"tag:yaml.org,2002:binary":Rq,
"tag:yaml.org,2002:merge":rq,"tag:yaml.org,2002:omap":zq,
"tag:yaml.org,2002:pairs":jq,"tag:yaml.org,2002:set":nW,
"tag:yaml.org,2002:timestamp":sW};function pW(e,t,n){const r=cW.get(t)
;if(r&&!e)return n&&!r.includes(rq)?r.concat(rq):r.slice();let o=r;if(!o){
if(!Array.isArray(e)){
const e=Array.from(cW.keys()).filter((e=>"yaml11"!==e)).map((e=>JSON.stringify(e))).join(", ")
;throw new Error(`Unknown schema "${t}"; use one of ${e} or define customTags array`)
}o=[]}
if(Array.isArray(e))for(const a of e)o=o.concat(a);else"function"==typeof e&&(o=e(o.slice()))
;return n&&(o=o.concat(rq)),o.reduce(((e,t)=>{const n="string"==typeof t?uW[t]:t
;if(!n){
const e=JSON.stringify(t),n=Object.keys(uW).map((e=>JSON.stringify(e))).join(", ")
;throw new Error(`Unknown custom tag ${e}; use one of ${n}`)}
return e.includes(n)||e.push(n),e}),[])}
const hW=(e,t)=>e.key<t.key?-1:e.key>t.key?1:0;let fW=class e{
constructor({compat:e,customTags:t,merge:n,resolveKnownTags:r,schema:o,sortMapEntries:a,toStringDefaults:i}){
this.compat=Array.isArray(e)?pW(e,"compat"):e?pW(null,e):null,
this.name="string"==typeof o&&o||"core",
this.knownTags=r?dW:{},this.tags=pW(t,this.name,n),this.toStringOptions=i??null,
Object.defineProperty(this,GH,{value:mq}),Object.defineProperty(this,KH,{
value:yq}),Object.defineProperty(this,JH,{value:bq
}),this.sortMapEntries="function"==typeof a?a:!0===a?hW:null}clone(){
const t=Object.create(e.prototype,Object.getOwnPropertyDescriptors(this))
;return t.tags=this.tags.slice(),t}};let mW=class e{constructor(e,t,n){
this.commentBefore=null,
this.comment=null,this.errors=[],this.warnings=[],Object.defineProperty(this,eV,{
value:XH});let r=null
;"function"==typeof t||Array.isArray(t)?r=t:void 0===n&&t&&(n=t,t=void 0)
;const o=Object.assign({intAsBigInt:!1,keepSourceTokens:!1,logLevel:"warn",
prettyErrors:!0,strict:!0,stringKeys:!1,uniqueKeys:!0,version:"1.2"},n)
;this.options=o;let{version:a}=o
;n?._directives?(this.directives=n._directives.atDocument(),
this.directives.yaml.explicit&&(a=this.directives.yaml.version)):this.directives=new wV({
version:a
}),this.setSchema(a,n),this.contents=void 0===e?null:this.createNode(e,r,n)}
clone(){const t=Object.create(e.prototype,{[eV]:{value:XH}})
;return t.commentBefore=this.commentBefore,
t.comment=this.comment,t.errors=this.errors.slice(),
t.warnings=this.warnings.slice(),
t.options=Object.assign({},this.options),this.directives&&(t.directives=this.directives.clone()),
t.schema=this.schema.clone(),
t.contents=lV(this.contents)?this.contents.clone(t.schema):this.contents,
this.range&&(t.range=this.range.slice()),t}add(e){
gW(this.contents)&&this.contents.add(e)}addIn(e,t){
gW(this.contents)&&this.contents.addIn(e,t)}createAlias(e,t){if(!e.anchor){
const n=kV(this);e.anchor=!t||n.has(t)?SV(t||"a",n):t}return new AV(e.anchor)}
createNode(e,t,n){let r;if("function"==typeof t)e=t.call({"":e
},"",e),r=t;else if(Array.isArray(t)){
const e=e=>"number"==typeof e||e instanceof String||e instanceof Number,n=t.filter(e).map(String)
;n.length>0&&(t=t.concat(n)),r=t}else void 0===n&&t&&(n=t,t=void 0)
;const{aliasDuplicateObjects:o,anchorPrefix:a,flow:i,keepUndefined:s,onTagObj:l,tag:c}=n??{},{onAnchor:u,setAnchors:d,sourceObjects:p}=function(e,t){
const n=[],r=new Map;let o=null;return{onAnchor:r=>{n.push(r),o??(o=kV(e))
;const a=SV(t,o);return o.add(a),a},setAnchors:()=>{for(const e of n){
const t=r.get(e);if("object"!=typeof t||!t.anchor||!aV(t.node)&&!sV(t.node)){
const t=new Error("Failed to resolve repeated object (this should not happen)")
;throw t.source=e,t}t.node.anchor=t.anchor}},sourceObjects:r}
}(this,a||"a"),h=IV(e,c,{aliasDuplicateObjects:o??!0,keepUndefined:s??!1,
onAnchor:u,onTagObj:l,replacer:r,schema:this.schema,sourceObjects:p})
;return i&&sV(h)&&(h.flow=!0),d(),h}createPair(e,t,n={}){
const r=this.createNode(e,null,n),o=this.createNode(t,null,n);return new lq(r,o)
}delete(e){return!!gW(this.contents)&&this.contents.delete(e)}deleteIn(e){
return NV(e)?null!=this.contents&&(this.contents=null,
!0):!!gW(this.contents)&&this.contents.deleteIn(e)}get(e,t){
return sV(this.contents)?this.contents.get(e,t):void 0}getIn(e,t){
return NV(e)?!t&&aV(this.contents)?this.contents.value:this.contents:sV(this.contents)?this.contents.getIn(e,t):void 0
}has(e){return!!sV(this.contents)&&this.contents.has(e)}hasIn(e){
return NV(e)?void 0!==this.contents:!!sV(this.contents)&&this.contents.hasIn(e)}
set(e,t){
null==this.contents?this.contents=MV(this.schema,[e],t):gW(this.contents)&&this.contents.set(e,t)
}setIn(e,t){
NV(e)?this.contents=t:null==this.contents?this.contents=MV(this.schema,Array.from(e),t):gW(this.contents)&&this.contents.setIn(e,t)
}setSchema(e,t={}){let n;switch("number"==typeof e&&(e=String(e)),e){case"1.1":
this.directives?this.directives.yaml.version="1.1":this.directives=new wV({
version:"1.1"}),n={resolveKnownTags:!1,schema:"yaml-1.1"};break;case"1.2":
case"next":
this.directives?this.directives.yaml.version=e:this.directives=new wV({version:e
}),n={resolveKnownTags:!0,schema:"core"};break;case null:
this.directives&&delete this.directives,n=null;break;default:{
const t=JSON.stringify(e)
;throw new Error(`Expected '1.1', '1.2' or null as first argument, but found: ${t}`)
}}if(t.schema instanceof Object)this.schema=t.schema;else{
if(!n)throw new Error("With a null YAML version, the { schema: Schema } option is required")
;this.schema=new fW(Object.assign(n,t))}}
toJS({json:e,jsonArg:t,mapAsMap:n,maxAliasCount:r,onAnchor:o,reviver:a}={}){
const i={anchors:new Map,doc:this,keep:!e,mapAsMap:!0===n,mapKeyWarned:!1,
maxAliasCount:"number"==typeof r?r:100},s=TV(this.contents,t??"",i)
;if("function"==typeof o)for(const{count:l,res:c}of i.anchors.values())o(c,l)
;return"function"==typeof a?_V(a,{"":s},"",s):s}toJSON(e,t){return this.toJS({
json:!0,jsonArg:e,mapAsMap:!1,onAnchor:t})}toString(e={}){
if(this.errors.length>0)throw new Error("Document with errors cannot be stringified")
;if("indent"in e&&(!Number.isInteger(e.indent)||Number(e.indent)<=0)){
const t=JSON.stringify(e.indent)
;throw new Error(`"indent" option must be a positive integer, not ${t}`)}
return function(e,t){const n=[];let r=!0===t.directives
;if(!1!==t.directives&&e.directives){const t=e.directives.toString(e)
;t?(n.push(t),r=!0):e.directives.docStart&&(r=!0)}r&&n.push("---")
;const o=JV(e,t),{commentString:a}=o.options;if(e.commentBefore){
1!==n.length&&n.unshift("");const t=a(e.commentBefore);n.unshift(BV(t,""))}
let i=!1,s=null;if(e.contents){if(lV(e.contents)){
if(e.contents.spaceBefore&&r&&n.push(""),e.contents.commentBefore){
const t=a(e.contents.commentBefore);n.push(BV(t,""))}
o.forceBlockIndent=!!e.comment,s=e.contents.comment}const t=s?void 0:()=>i=!0
;let l=eq(e.contents,o,(()=>s=null),t)
;s&&(l+=jV(l,"",a(s))),"|"!==l[0]&&">"!==l[0]||"---"!==n[n.length-1]?n.push(l):n[n.length-1]=`--- ${l}`
}else n.push(eq(e.contents,o));if(e.directives?.docEnd)if(e.comment){
const t=a(e.comment)
;t.includes("\n")?(n.push("..."),n.push(BV(t,""))):n.push(`... ${t}`)
}else n.push("...");else{let t=e.comment
;t&&i&&(t=t.replace(/^\n+/,"")),t&&(i&&!s||""===n[n.length-1]||n.push(""),
n.push(BV(a(t),"")))}return n.join("\n")+"\n"}(this,e)}};function gW(e){
if(sV(e))return!0
;throw new Error("Expected a YAML collection as document contents")}
class vW extends Error{constructor(e,t,n,r){
super(),this.name=e,this.code=n,this.message=r,this.pos=t}}class bW extends vW{
constructor(e,t,n){super("YAMLParseError",e,t,n)}}class yW extends vW{
constructor(e,t,n){super("YAMLWarning",e,t,n)}}const OW=(e,t)=>n=>{
if(-1===n.pos[0])return;n.linePos=n.pos.map((e=>t.linePos(e)))
;const{line:r,col:o}=n.linePos[0];n.message+=` at line ${r}, column ${o}`
;let a=o-1,i=e.substring(t.lineStarts[r-1],t.lineStarts[r]).replace(/[\n\r]+$/,"")
;if(a>=60&&i.length>80){const e=Math.min(a-39,i.length-79);i="…"+i.substring(e),
a-=e-1}
if(i.length>80&&(i=i.substring(0,79)+"…"),r>1&&/^ *$/.test(i.substring(0,a))){
let n=e.substring(t.lineStarts[r-2],t.lineStarts[r-1])
;n.length>80&&(n=n.substring(0,79)+"…\n"),i=n+i}if(/[^ ]/.test(i)){let e=1
;const t=n.linePos[1]
;t&&t.line===r&&t.col>o&&(e=Math.max(1,Math.min(t.col-o,80-a)))
;const s=" ".repeat(a)+"^".repeat(e);n.message+=`:\n\n${i}\n${s}\n`}}
;function wW(e,{flow:t,indicator:n,next:r,offset:o,onError:a,parentIndent:i,startOnNewline:s}){
let l=!1,c=s,u=s,d="",p="",h=!1,f=!1,m=null,g=null,v=null,b=null,y=null,O=null,w=null
;for(const S of e)switch(f&&("space"!==S.type&&"newline"!==S.type&&"comma"!==S.type&&a(S.offset,"MISSING_CHAR","Tags and anchors must be separated from the next token by white space"),
f=!1),
m&&(c&&"comment"!==S.type&&"newline"!==S.type&&a(m,"TAB_AS_INDENT","Tabs are not allowed as indentation"),
m=null),S.type){case"space":
t||"doc-start"===n&&"flow-collection"===r?.type||!S.source.includes("\t")||(m=S),
u=!0;break;case"comment":{
u||a(S,"MISSING_CHAR","Comments must be separated from other tokens by white space characters")
;const e=S.source.substring(1)||" ";d?d+=p+e:d=e,p="",c=!1;break}case"newline":
c?d?d+=S.source:O&&"seq-item-ind"===n||(l=!0):p+=S.source,
c=!0,h=!0,(g||v)&&(b=S),u=!0;break;case"anchor":
g&&a(S,"MULTIPLE_ANCHORS","A node can have at most one anchor"),
S.source.endsWith(":")&&a(S.offset+S.source.length-1,"BAD_ALIAS","Anchor ending in : is ambiguous",!0),
g=S,w??(w=S.offset),c=!1,u=!1,f=!0;break;case"tag":
v&&a(S,"MULTIPLE_TAGS","A node can have at most one tag"),
v=S,w??(w=S.offset),c=!1,u=!1,f=!0;break;case n:
(g||v)&&a(S,"BAD_PROP_ORDER",`Anchors and tags must be after the ${S.source} indicator`),
O&&a(S,"UNEXPECTED_TOKEN",`Unexpected ${S.source} in ${t??"collection"}`),
O=S,c="seq-item-ind"===n||"explicit-key-ind"===n,u=!1;break;case"comma":if(t){
y&&a(S,"UNEXPECTED_TOKEN",`Unexpected , in ${t}`),y=S,c=!1,u=!1;break}default:
a(S,"UNEXPECTED_TOKEN",`Unexpected ${S.type} token`),c=!1,u=!1}
const x=e[e.length-1],k=x?x.offset+x.source.length:o
;return f&&r&&"space"!==r.type&&"newline"!==r.type&&"comma"!==r.type&&("scalar"!==r.type||""!==r.source)&&a(r.offset,"MISSING_CHAR","Tags and anchors must be separated from the next token by white space"),
m&&(c&&m.indent<=i||"block-map"===r?.type||"block-seq"===r?.type)&&a(m,"TAB_AS_INDENT","Tabs are not allowed as indentation"),
{comma:y,found:O,spaceBefore:l,comment:d,hasNewline:h,anchor:g,tag:v,
newlineAfterProp:b,end:k,start:w??k}}function xW(e){if(!e)return null
;switch(e.type){case"alias":case"scalar":case"double-quoted-scalar":
case"single-quoted-scalar":if(e.source.includes("\n"))return!0
;if(e.end)for(const t of e.end)if("newline"===t.type)return!0;return!1
;case"flow-collection":for(const t of e.items){
for(const e of t.start)if("newline"===e.type)return!0
;if(t.sep)for(const e of t.sep)if("newline"===e.type)return!0
;if(xW(t.key)||xW(t.value))return!0}return!1;default:return!0}}
function kW(e,t,n){if("flow-collection"===t?.type){const r=t.end[0]
;if(r.indent===e&&("]"===r.source||"}"===r.source)&&xW(t)){
n(r,"BAD_INDENT","Flow end indicator should be more indented than parent",!0)}}}
function SW(e,t,n){const{uniqueKeys:r}=e.options;if(!1===r)return!1
;const o="function"==typeof r?r:(e,t)=>e===t||aV(e)&&aV(t)&&e.value===t.value
;return t.some((e=>o(e.key,n)))}
const _W="All mapping items must start at the same column";function TW(e,t,n,r){
let o="";if(e){let a=!1,i="";for(const s of e){const{source:e,type:l}=s
;switch(l){case"space":a=!0;break;case"comment":{
n&&!a&&r(s,"MISSING_CHAR","Comments must be separated from other tokens by white space characters")
;const t=e.substring(1)||" ";o?o+=i+t:o=t,i="";break}case"newline":
o&&(i+=e),a=!0;break;default:
r(s,"UNEXPECTED_TOKEN",`Unexpected ${l} at node end`)}t+=e.length}}return{
comment:o,offset:t}}
const EW="Block collections are not allowed within flow collections",AW=e=>e&&("block-map"===e.type||"block-seq"===e.type)
;function CW(e,t,n,r,o,a){
const i="block-map"===n.type?function({composeNode:e,composeEmptyNode:t},n,r,o,a){
const i=new(a?.nodeClass??fq)(n.schema);n.atRoot&&(n.atRoot=!1)
;let s=r.offset,l=null;for(const c of r.items){
const{start:a,key:u,sep:d,value:p}=c,h=wW(a,{indicator:"explicit-key-ind",
next:u??d?.[0],offset:s,onError:o,parentIndent:r.indent,startOnNewline:!0
}),f=!h.found;if(f){
if(u&&("block-seq"===u.type?o(s,"BLOCK_AS_IMPLICIT_KEY","A block sequence may not be used as an implicit map key"):"indent"in u&&u.indent!==r.indent&&o(s,"BAD_INDENT",_W)),
!h.anchor&&!h.tag&&!d){
l=h.end,h.comment&&(i.comment?i.comment+="\n"+h.comment:i.comment=h.comment)
;continue}
(h.newlineAfterProp||xW(u))&&o(u??a[a.length-1],"MULTILINE_IMPLICIT_KEY","Implicit keys need to be on a single line")
}else h.found?.indent!==r.indent&&o(s,"BAD_INDENT",_W);n.atKey=!0
;const m=h.end,g=u?e(n,u,h,o):t(n,m,a,null,h,o)
;n.schema.compat&&kW(r.indent,u,o),
n.atKey=!1,SW(n,i.items,g)&&o(m,"DUPLICATE_KEY","Map keys must be unique")
;const v=wW(d??[],{indicator:"map-value-ind",next:p,offset:g.range[2],onError:o,
parentIndent:r.indent,startOnNewline:!u||"block-scalar"===u.type})
;if(s=v.end,v.found){
f&&("block-map"!==p?.type||v.hasNewline||o(s,"BLOCK_AS_IMPLICIT_KEY","Nested mappings are not allowed in compact mappings"),
n.options.strict&&h.start<v.found.offset-1024&&o(g.range,"KEY_OVER_1024_CHARS","The : indicator must be at most 1024 chars after the start of an implicit block mapping key"))
;const a=p?e(n,p,v,o):t(n,s,d,null,v,o)
;n.schema.compat&&kW(r.indent,p,o),s=a.range[2];const l=new lq(g,a)
;n.options.keepSourceTokens&&(l.srcToken=c),i.items.push(l)}else{
f&&o(g.range,"MISSING_CHAR","Implicit map keys need to be followed by map values"),
v.comment&&(g.comment?g.comment+="\n"+v.comment:g.comment=v.comment)
;const e=new lq(g);n.options.keepSourceTokens&&(e.srcToken=c),i.items.push(e)}}
return l&&l<s&&o(l,"IMPOSSIBLE","Map comment with trailing content"),
i.range=[r.offset,s,l??s],i
}(e,t,n,r,a):"block-seq"===n.type?function({composeNode:e,composeEmptyNode:t},n,r,o,a){
const i=new(a?.nodeClass??gq)(n.schema)
;n.atRoot&&(n.atRoot=!1),n.atKey&&(n.atKey=!1);let s=r.offset,l=null
;for(const{start:c,value:u}of r.items){const a=wW(c,{indicator:"seq-item-ind",
next:u,offset:s,onError:o,parentIndent:r.indent,startOnNewline:!0})
;if(!a.found){if(!(a.anchor||a.tag||u)){l=a.end,a.comment&&(i.comment=a.comment)
;continue}
u&&"block-seq"===u.type?o(a.end,"BAD_INDENT","All sequence items must start at the same column"):o(s,"MISSING_CHAR","Sequence item without - indicator")
}const d=u?e(n,u,a,o):t(n,a.end,c,null,a,o)
;n.schema.compat&&kW(r.indent,u,o),s=d.range[2],i.items.push(d)}
return i.range=[r.offset,s,l??s],i
}(e,t,n,r,a):function({composeNode:e,composeEmptyNode:t},n,r,o,a){
const i="{"===r.start.source,s=i?"flow map":"flow sequence",l=new(a?.nodeClass??(i?fq:gq))(n.schema)
;l.flow=!0;const c=n.atRoot;c&&(n.atRoot=!1),n.atKey&&(n.atKey=!1)
;let u=r.offset+r.start.source.length;for(let m=0;m<r.items.length;++m){
const a=r.items[m],{start:c,key:d,sep:p,value:h}=a,f=wW(c,{flow:s,
indicator:"explicit-key-ind",next:d??p?.[0],offset:u,onError:o,
parentIndent:r.indent,startOnNewline:!1});if(!f.found){
if(!(f.anchor||f.tag||p||h)){
0===m&&f.comma?o(f.comma,"UNEXPECTED_TOKEN",`Unexpected , in ${s}`):m<r.items.length-1&&o(f.start,"UNEXPECTED_TOKEN",`Unexpected empty item in ${s}`),
f.comment&&(l.comment?l.comment+="\n"+f.comment:l.comment=f.comment),u=f.end
;continue}
!i&&n.options.strict&&xW(d)&&o(d,"MULTILINE_IMPLICIT_KEY","Implicit keys of flow sequence pairs need to be on a single line")
}
if(0===m)f.comma&&o(f.comma,"UNEXPECTED_TOKEN",`Unexpected , in ${s}`);else if(f.comma||o(f.start,"MISSING_CHAR",`Missing , between ${s} items`),
f.comment){let e="";e:for(const t of c)switch(t.type){case"comma":case"space":
break;case"comment":e=t.source.substring(1);break e;default:break e}if(e){
let t=l.items[l.items.length-1]
;oV(t)&&(t=t.value??t.key),t.comment?t.comment+="\n"+e:t.comment=e,
f.comment=f.comment.substring(e.length+1)}}if(i||p||f.found){n.atKey=!0
;const m=f.end,g=d?e(n,d,f,o):t(n,m,c,null,f,o)
;AW(d)&&o(g.range,"BLOCK_IN_FLOW",EW),n.atKey=!1;const v=wW(p??[],{flow:s,
indicator:"map-value-ind",next:h,offset:g.range[2],onError:o,
parentIndent:r.indent,startOnNewline:!1});if(v.found){
if(!i&&!f.found&&n.options.strict){if(p)for(const e of p){if(e===v.found)break
;if("newline"===e.type){
o(e,"MULTILINE_IMPLICIT_KEY","Implicit keys of flow sequence pairs need to be on a single line")
;break}}
f.start<v.found.offset-1024&&o(v.found,"KEY_OVER_1024_CHARS","The : indicator must be at most 1024 chars after the start of an implicit flow sequence key")
}
}else h&&("source"in h&&h.source&&":"===h.source[0]?o(h,"MISSING_CHAR",`Missing space after : in ${s}`):o(v.start,"MISSING_CHAR",`Missing , or : between ${s} items`))
;const b=h?e(n,h,v,o):v.found?t(n,v.end,p,null,v,o):null
;b?AW(h)&&o(b.range,"BLOCK_IN_FLOW",EW):v.comment&&(g.comment?g.comment+="\n"+v.comment:g.comment=v.comment)
;const y=new lq(g,b);if(n.options.keepSourceTokens&&(y.srcToken=a),i){const e=l
;SW(n,e.items,g)&&o(m,"DUPLICATE_KEY","Map keys must be unique"),e.items.push(y)
}else{const e=new fq(n.schema);e.flow=!0,e.items.push(y);const t=(b??g).range
;e.range=[g.range[0],t[1],t[2]],l.items.push(e)}u=b?b.range[2]:v.end}else{
const r=h?e(n,h,f,o):t(n,f.end,p,null,f,o)
;l.items.push(r),u=r.range[2],AW(h)&&o(r.range,"BLOCK_IN_FLOW",EW)}}
const d=i?"}":"]",[p,...h]=r.end;let f=u
;if(p&&p.source===d)f=p.offset+p.source.length;else{
const e=s[0].toUpperCase()+s.substring(1)
;o(u,c?"MISSING_CHAR":"BAD_INDENT",c?`${e} must end with a ${d}`:`${e} in block collection must be sufficiently indented and end with a ${d}`),
p&&1!==p.source.length&&h.unshift(p)}if(h.length>0){
const e=TW(h,f,n.options.strict,o)
;e.comment&&(l.comment?l.comment+="\n"+e.comment:l.comment=e.comment),
l.range=[r.offset,f,e.offset]}else l.range=[r.offset,f,f];return l
}(e,t,n,r,a),s=i.constructor
;return"!"===o||o===s.tagName?(i.tag=s.tagName,i):(o&&(i.tag=o),i)}
function $W(e,t,n){const r=t.offset,o=function({offset:e,props:t},n,r){
if("block-scalar-header"!==t[0].type)return r(t[0],"IMPOSSIBLE","Block scalar header not found"),
null;const{source:o}=t[0],a=o[0];let i=0,s="",l=-1;for(let p=1;p<o.length;++p){
const t=o[p];if(s||"-"!==t&&"+"!==t){const n=Number(t);!i&&n?i=n:-1===l&&(l=e+p)
}else s=t}
-1!==l&&r(l,"UNEXPECTED_TOKEN",`Block scalar header includes extra characters: ${o}`)
;let c=!1,u="",d=o.length;for(let p=1;p<t.length;++p){const e=t[p]
;switch(e.type){case"space":c=!0;case"newline":d+=e.source.length;break
;case"comment":if(n&&!c){
r(e,"MISSING_CHAR","Comments must be separated from other tokens by white space characters")
}d+=e.source.length,u=e.source.substring(1);break;case"error":
r(e,"UNEXPECTED_TOKEN",e.message),d+=e.source.length;break;default:{
r(e,"UNEXPECTED_TOKEN",`Unexpected token in block scalar header: ${e.type}`)
;const t=e.source;t&&"string"==typeof t&&(d+=t.length)}}}return{mode:a,indent:i,
chomp:s,comment:u,length:d}}(t,e.options.strict,n);if(!o)return{value:"",
type:null,comment:"",range:[r,r,r]}
;const a=">"===o.mode?PV.BLOCK_FOLDED:PV.BLOCK_LITERAL,i=t.source?function(e){
const t=e.split(/\n( *)/),n=t[0],r=n.match(/^( *)/),o=[r?.[1]?[r[1],n.slice(r[1].length)]:["",n]]
;for(let a=1;a<t.length;a+=2)o.push([t[a],t[a+1]]);return o}(t.source):[]
;let s=i.length;for(let m=i.length-1;m>=0;--m){const e=i[m][1]
;if(""!==e&&"\r"!==e)break;s=m}if(0===s){
const e="+"===o.chomp&&i.length>0?"\n".repeat(Math.max(1,i.length-1)):""
;let n=r+o.length;return t.source&&(n+=t.source.length),{value:e,type:a,
comment:o.comment,range:[r,n,n]}}let l=t.indent+o.indent,c=t.offset+o.length,u=0
;for(let m=0;m<s;++m){const[t,r]=i[m];if(""!==r&&"\r"!==r){if(t.length<l){
const e="Block scalars with more-indented leading empty lines must use an explicit indentation indicator"
;n(c+t.length,"MISSING_CHAR",e)}
if(0===o.indent&&(l=t.length),u=m,0===l&&!e.atRoot){
n(c,"BAD_INDENT","Block scalar values in collections must be indented")}break}
0===o.indent&&t.length>l&&(l=t.length),c+=t.length+r.length+1}
for(let m=i.length-1;m>=s;--m)i[m][0].length>l&&(s=m+1);let d="",p="",h=!1
;for(let m=0;m<u;++m)d+=i[m][0].slice(l)+"\n";for(let m=u;m<s;++m){let[e,t]=i[m]
;c+=e.length+t.length+1;const r="\r"===t[t.length-1]
;if(r&&(t=t.slice(0,-1)),t&&e.length<l){
const a=`Block scalar lines must not be less indented than their ${o.indent?"explicit indentation indicator":"first line"}`
;n(c-t.length-(r?2:1),"BAD_INDENT",a),e=""}
a===PV.BLOCK_LITERAL?(d+=p+e.slice(l)+t,
p="\n"):e.length>l||"\t"===t[0]?(" "===p?p="\n":h||"\n"!==p||(p="\n\n"),
d+=p+e.slice(l)+t,
p="\n",h=!0):""===t?"\n"===p?d+="\n":p="\n":(d+=p+t,p=" ",h=!1)}switch(o.chomp){
case"-":break;case"+":for(let e=s;e<i.length;++e)d+="\n"+i[e][0].slice(l)
;"\n"!==d[d.length-1]&&(d+="\n");break;default:d+="\n"}
const f=r+o.length+t.source.length;return{value:d,type:a,comment:o.comment,
range:[r,f,f]}}function PW(e,t,n){const{offset:r,type:o,source:a,end:i}=e
;let s,l;const c=(e,t,o)=>n(r+e,t,o);switch(o){case"scalar":
s=PV.PLAIN,l=function(e,t){let n="";switch(e[0]){case"\t":n="a tab character"
;break;case",":n="flow indicator character ,";break;case"%":
n="directive indicator character %";break;case"|":case">":
n=`block scalar indicator ${e[0]}`;break;case"@":case"`":
n=`reserved character ${e[0]}`}
n&&t(0,"BAD_SCALAR_START",`Plain value cannot start with ${n}`);return DW(e)
}(a,c);break;case"single-quoted-scalar":s=PV.QUOTE_SINGLE,l=function(e,t){
"'"===e[e.length-1]&&1!==e.length||t(e.length,"MISSING_CHAR","Missing closing 'quote")
;return DW(e.slice(1,-1)).replace(/''/g,"'")}(a,c);break
;case"double-quoted-scalar":s=PV.QUOTE_DOUBLE,l=function(e,t){let n=""
;for(let r=1;r<e.length-1;++r){const o=e[r]
;if("\r"!==o||"\n"!==e[r+1])if("\n"===o){const{fold:t,offset:o}=IW(e,r);n+=t,r=o
}else if("\\"===o){let o=e[++r];const a=MW[o]
;if(a)n+=a;else if("\n"===o)for(o=e[r+1];" "===o||"\t"===o;)o=e[1+ ++r];else if("\r"===o&&"\n"===e[r+1])for(o=e[1+ ++r];" "===o||"\t"===o;)o=e[1+ ++r];else if("x"===o||"u"===o||"U"===o){
const a={x:2,u:4,U:8}[o];n+=NW(e,r+1,a,t),r+=a}else{const o=e.substr(r-1,2)
;t(r-1,"BAD_DQ_ESCAPE",`Invalid escape sequence ${o}`),n+=o}
}else if(" "===o||"\t"===o){const t=r;let a=e[r+1]
;for(;" "===a||"\t"===a;)a=e[1+ ++r]
;"\n"===a||"\r"===a&&"\n"===e[r+2]||(n+=r>t?e.slice(t,r+1):o)}else n+=o}
'"'===e[e.length-1]&&1!==e.length||t(e.length,"MISSING_CHAR",'Missing closing "quote')
;return n}(a,c);break;default:
return n(e,"UNEXPECTED_TOKEN",`Expected a flow scalar value, but found: ${o}`),{
value:"",type:null,comment:"",range:[r,r+a.length,r+a.length]}}
const u=r+a.length,d=TW(i,u,t,n);return{value:l,type:s,comment:d.comment,
range:[r,u,d.offset]}}function DW(e){let t,n;try{
t=new RegExp("(.*?)(?<![ \t])[ \t]*\r?\n","sy"),
n=new RegExp("[ \t]*(.*?)(?:(?<![ \t])[ \t]*)?\r?\n","sy")}catch{
t=/(.*?)[ \t]*\r?\n/sy,n=/[ \t]*(.*?)[ \t]*\r?\n/sy}let r=t.exec(e)
;if(!r)return e;let o=r[1],a=" ",i=t.lastIndex
;for(n.lastIndex=i;r=n.exec(e);)""===r[1]?"\n"===a?o+=a:a="\n":(o+=a+r[1],
a=" "),i=n.lastIndex;const s=/[ \t]*(.*)/sy
;return s.lastIndex=i,r=s.exec(e),o+a+(r?.[1]??"")}function IW(e,t){
let n="",r=e[t+1]
;for(;!(" "!==r&&"\t"!==r&&"\n"!==r&&"\r"!==r||"\r"===r&&"\n"!==e[t+2]);)"\n"===r&&(n+="\n"),
r=e[(t+=1)+1];return n||(n=" "),{fold:n,offset:t}}const MW={0:"\0",a:"",b:"\b",
e:"",f:"\f",n:"\n",r:"\r",t:"\t",v:"\v",N:"",_:" ",L:"\u2028",P:"\u2029",
" ":" ",'"':'"',"/":"/","\\":"\\","\t":"\t"};function NW(e,t,n,r){
const o=e.substr(t,n),a=o.length===n&&/^[0-9a-fA-F]+$/.test(o)?parseInt(o,16):NaN
;if(isNaN(a)){const o=e.substr(t-2,n+2)
;return r(t-2,"BAD_DQ_ESCAPE",`Invalid escape sequence ${o}`),o}
return String.fromCodePoint(a)}function RW(e,t,n,r){
const{value:o,type:a,comment:i,range:s}="block-scalar"===t.type?$W(e,t,r):PW(t,e.options.strict,r),l=n?e.directives.tagName(n.source,(e=>r(n,"TAG_RESOLVE_FAILED",e))):null
;let c,u;c=e.options.stringKeys&&e.atKey?e.schema[KH]:l?function(e,t,n,r,o){
if("!"===n)return e[KH];const a=[]
;for(const s of e.tags)if(!s.collection&&s.tag===n){
if(!s.default||!s.test)return s;a.push(s)}
for(const s of a)if(s.test?.test(t))return s;const i=e.knownTags[n]
;if(i&&!i.collection)return e.tags.push(Object.assign({},i,{default:!1,
test:void 0})),i
;return o(r,"TAG_RESOLVE_FAILED",`Unresolved tag: ${n}`,"tag:yaml.org,2002:str"!==n),
e[KH]
}(e.schema,o,l,n,r):"scalar"===t.type?function({atKey:e,directives:t,schema:n},r,o,a){
const i=n.tags.find((t=>(!0===t.default||e&&"key"===t.default)&&t.test?.test(r)))||n[KH]
;if(n.compat){const e=n.compat.find((e=>e.default&&e.test?.test(r)))??n[KH]
;if(i.tag!==e.tag){
a(o,"TAG_RESOLVE_FAILED",`Value may be parsed as either ${t.tagString(i.tag)} or ${t.tagString(e.tag)}`,!0)
}}return i}(e,o,t,r):e.schema[KH];try{
const a=c.resolve(o,(e=>r(n??t,"TAG_RESOLVE_FAILED",e)),e.options)
;u=aV(a)?a:new PV(a)}catch(d){const e=d instanceof Error?d.message:String(d)
;r(n??t,"TAG_RESOLVE_FAILED",e),u=new PV(o)}
return u.range=s,u.source=o,a&&(u.type=a),
l&&(u.tag=l),c.format&&(u.format=c.format),i&&(u.comment=i),u}
function LW(e,t,n){if(t){n??(n=t.length);for(let r=n-1;r>=0;--r){let n=t[r]
;switch(n.type){case"space":case"comment":case"newline":e-=n.source.length
;continue}for(n=t[++r];"space"===n?.type;)e+=n.source.length,n=t[++r];break}}
return e}const BW={composeNode:jW,composeEmptyNode:UW};function jW(e,t,n,r){
const o=e.atKey,{spaceBefore:a,comment:i,anchor:s,tag:l}=n;let c,u=!0
;switch(t.type){case"alias":c=function({options:e},{offset:t,source:n,end:r},o){
const a=new AV(n.substring(1))
;""===a.source&&o(t,"BAD_ALIAS","Alias cannot be an empty string")
;a.source.endsWith(":")&&o(t+n.length-1,"BAD_ALIAS","Alias ending in : is ambiguous",!0)
;const i=t+n.length,s=TW(r,i,e.strict,o)
;a.range=[t,i,s.offset],s.comment&&(a.comment=s.comment);return a
}(e,t,r),(s||l)&&r(t,"ALIAS_PROPS","An alias node must not specify any properties")
;break;case"scalar":case"single-quoted-scalar":case"double-quoted-scalar":
case"block-scalar":c=RW(e,t,l,r),s&&(c.anchor=s.source.substring(1));break
;case"block-map":case"block-seq":case"flow-collection":c=function(e,t,n,r,o){
const a=r.tag,i=a?t.directives.tagName(a.source,(e=>o(a,"TAG_RESOLVE_FAILED",e))):null
;if("block-seq"===n.type){
const{anchor:e,newlineAfterProp:t}=r,n=e&&a?e.offset>a.offset?e:a:e??a
;n&&(!t||t.offset<n.offset)&&o(n,"MISSING_CHAR","Missing newline after block sequence props")
}
const s="block-map"===n.type?"map":"block-seq"===n.type?"seq":"{"===n.start.source?"map":"seq"
;if(!a||!i||"!"===i||i===fq.tagName&&"map"===s||i===gq.tagName&&"seq"===s)return CW(e,t,n,o,i)
;let l=t.schema.tags.find((e=>e.tag===i&&e.collection===s));if(!l){
const r=t.schema.knownTags[i]
;if(!r||r.collection!==s)return r?o(a,"BAD_COLLECTION_TYPE",`${r.tag} used for ${s} collection, but expects ${r.collection??"scalar"}`,!0):o(a,"TAG_RESOLVE_FAILED",`Unresolved tag: ${i}`,!0),
CW(e,t,n,o,i);t.schema.tags.push(Object.assign({},r,{default:!1})),l=r}
const c=CW(e,t,n,o,i,l),u=l.resolve?.(c,(e=>o(a,"TAG_RESOLVE_FAILED",e)),t.options)??c,d=lV(u)?u:new PV(u)
;return d.range=c.range,d.tag=i,l?.format&&(d.format=l.format),d
}(BW,e,t,n,r),s&&(c.anchor=s.source.substring(1));break;default:
r(t,"UNEXPECTED_TOKEN","error"===t.type?t.message:`Unsupported token (type: ${t.type})`),
c=UW(e,t.offset,void 0,null,n,r),u=!1}
if(s&&""===c.anchor&&r(s,"BAD_ALIAS","Anchor cannot be an empty string"),
o&&e.options.stringKeys&&(!aV(c)||"string"!=typeof c.value||c.tag&&"tag:yaml.org,2002:str"!==c.tag)){
r(l??t,"NON_STRING_KEY","With stringKeys, all keys must be strings")}
return a&&(c.spaceBefore=!0),
i&&("scalar"===t.type&&""===t.source?c.comment=i:c.commentBefore=i),
e.options.keepSourceTokens&&u&&(c.srcToken=t),c}
function UW(e,t,n,r,{spaceBefore:o,comment:a,anchor:i,tag:s,end:l},c){
const u=RW(e,{type:"scalar",offset:LW(t,n,r),indent:-1,source:""},s,c)
;return i&&(u.anchor=i.source.substring(1),
""===u.anchor&&c(i,"BAD_ALIAS","Anchor cannot be an empty string")),
o&&(u.spaceBefore=!0),a&&(u.comment=a,u.range[2]=l),u}function zW(e){
if("number"==typeof e)return[e,e+1]
;if(Array.isArray(e))return 2===e.length?e:[e[0],e[1]]
;const{offset:t,source:n}=e;return[t,t+("string"==typeof n?n.length:1)]}
function FW(e){let t="",n=!1,r=!1;for(let o=0;o<e.length;++o){const a=e[o]
;switch(a[0]){case"#":
t+=(""===t?"":r?"\n\n":"\n")+(a.substring(1)||" "),n=!0,r=!1;break;case"%":
"#"!==e[o+1]?.[0]&&(o+=1),n=!1;break;default:n||(r=!0),n=!1}}return{comment:t,
afterEmptyLine:r}}class ZW{constructor(e={}){this.doc=null,this.atDirectives=!1,
this.prelude=[],this.errors=[],this.warnings=[],this.onError=(e,t,n,r)=>{
const o=zW(e)
;r?this.warnings.push(new yW(o,t,n)):this.errors.push(new bW(o,t,n))
},this.directives=new wV({version:e.version||"1.2"}),this.options=e}
decorate(e,t){const{comment:n,afterEmptyLine:r}=FW(this.prelude);if(n){
const o=e.contents
;if(t)e.comment=e.comment?`${e.comment}\n${n}`:n;else if(r||e.directives.docStart||!o)e.commentBefore=n;else if(sV(o)&&!o.flow&&o.items.length>0){
let e=o.items[0];oV(e)&&(e=e.key);const t=e.commentBefore
;e.commentBefore=t?`${n}\n${t}`:n}else{const e=o.commentBefore
;o.commentBefore=e?`${n}\n${e}`:n}}
t?(Array.prototype.push.apply(e.errors,this.errors),
Array.prototype.push.apply(e.warnings,this.warnings)):(e.errors=this.errors,
e.warnings=this.warnings),this.prelude=[],this.errors=[],this.warnings=[]}
streamInfo(){return{comment:FW(this.prelude).comment,directives:this.directives,
errors:this.errors,warnings:this.warnings}}*compose(e,t=!1,n=-1){
for(const r of e)yield*this.next(r);yield*this.end(t,n)}*next(e){switch(e.type){
case"directive":this.directives.add(e.source,((t,n,r)=>{const o=zW(e)
;o[0]+=t,this.onError(o,"BAD_DIRECTIVE",n,r)
})),this.prelude.push(e.source),this.atDirectives=!0;break;case"document":{
const t=function(e,t,{offset:n,start:r,value:o,end:a},i){const s=Object.assign({
_directives:t},e),l=new mW(void 0,s),c={atKey:!1,atRoot:!0,
directives:l.directives,options:l.options,schema:l.schema},u=wW(r,{
indicator:"doc-start",next:o??a?.[0],offset:n,onError:i,parentIndent:0,
startOnNewline:!0})
;u.found&&(l.directives.docStart=!0,!o||"block-map"!==o.type&&"block-seq"!==o.type||u.hasNewline||i(u.end,"MISSING_CHAR","Block collection cannot start on same line with directives-end marker")),
l.contents=o?jW(c,o,u,i):UW(c,u.end,r,null,u,i)
;const d=l.contents.range[2],p=TW(a,d,!1,i)
;return p.comment&&(l.comment=p.comment),l.range=[n,d,p.offset],l
}(this.options,this.directives,e,this.onError)
;this.atDirectives&&!t.directives.docStart&&this.onError(e,"MISSING_CHAR","Missing directives-end/doc-start indicator line"),
this.decorate(t,!1),this.doc&&(yield this.doc),this.doc=t,this.atDirectives=!1
;break}case"byte-order-mark":case"space":break;case"comment":case"newline":
this.prelude.push(e.source);break;case"error":{
const t=e.source?`${e.message}: ${JSON.stringify(e.source)}`:e.message,n=new bW(zW(e),"UNEXPECTED_TOKEN",t)
;this.atDirectives||!this.doc?this.errors.push(n):this.doc.errors.push(n);break}
case"doc-end":{if(!this.doc){
const t="Unexpected doc-end without preceding document"
;this.errors.push(new bW(zW(e),"UNEXPECTED_TOKEN",t));break}
this.doc.directives.docEnd=!0
;const t=TW(e.end,e.offset+e.source.length,this.doc.options.strict,this.onError)
;if(this.decorate(this.doc,!0),t.comment){const e=this.doc.comment
;this.doc.comment=e?`${e}\n${t.comment}`:t.comment}this.doc.range[2]=t.offset
;break}default:
this.errors.push(new bW(zW(e),"UNEXPECTED_TOKEN",`Unsupported token ${e.type}`))
}}*end(e=!1,t=-1){
if(this.doc)this.decorate(this.doc,!0),yield this.doc,this.doc=null;else if(e){
const e=Object.assign({_directives:this.directives
},this.options),n=new mW(void 0,e)
;this.atDirectives&&this.onError(t,"MISSING_CHAR","Missing directives-end indicator line"),
n.range=[0,t,t],this.decorate(n,!1),yield n}}}function QW(e,t){
if(t)for(const n of t)switch(n.type){case"space":case"comment":e.push(n);break
;case"newline":return e.push(n),!0}return!1}function HW(e,t,n){switch(e.type){
case"scalar":case"double-quoted-scalar":case"single-quoted-scalar":
e.type=n,e.source=t;break;case"block-scalar":{const r=e.props.slice(1)
;let o=t.length
;"block-scalar-header"===e.props[0].type&&(o-=e.props[0].source.length)
;for(const e of r)e.offset+=o;delete e.props,Object.assign(e,{type:n,source:t,
end:r});break}case"block-map":case"block-seq":{const r={type:"newline",
offset:e.offset+t.length,indent:e.indent,source:"\n"}
;delete e.items,Object.assign(e,{type:n,source:t,end:[r]});break}default:{
const r="indent"in e?e.indent:-1,o="end"in e&&Array.isArray(e.end)?e.end.filter((e=>"space"===e.type||"comment"===e.type||"newline"===e.type)):[]
;for(const t of Object.keys(e))"type"!==t&&"offset"!==t&&delete e[t]
;Object.assign(e,{type:n,indent:r,source:t,end:o})}}}function VW(e){
switch(e.type){case"block-scalar":{let t="";for(const n of e.props)t+=VW(n)
;return t+e.source}case"block-map":case"block-seq":{let t=""
;for(const n of e.items)t+=qW(n);return t}case"flow-collection":{
let t=e.start.source;for(const n of e.items)t+=qW(n)
;for(const n of e.end)t+=n.source;return t}case"document":{let t=qW(e)
;if(e.end)for(const n of e.end)t+=n.source;return t}default:{let t=e.source
;if("end"in e&&e.end)for(const n of e.end)t+=n.source;return t}}}
function qW({start:e,key:t,sep:n,value:r}){let o="";for(const a of e)o+=a.source
;if(t&&(o+=VW(t)),n)for(const a of n)o+=a.source;return r&&(o+=VW(r)),o}
const WW=Symbol("break visit"),XW=Symbol("skip children"),GW=Symbol("remove item")
;function YW(e,t){"type"in e&&"document"===e.type&&(e={start:e.start,
value:e.value}),KW(Object.freeze([]),e,t)}function KW(e,t,n){let r=n(t,e)
;if("symbol"==typeof r)return r;for(const o of["key","value"]){const a=t[o]
;if(a&&"items"in a){for(let t=0;t<a.items.length;++t){
const r=KW(Object.freeze(e.concat([[o,t]])),a.items[t],n)
;if("number"==typeof r)t=r-1;else{if(r===WW)return WW
;r===GW&&(a.items.splice(t,1),t-=1)}}"function"==typeof r&&"key"===o&&(r=r(t,e))
}}return"function"==typeof r?r(t,e):r}
YW.BREAK=WW,YW.SKIP=XW,YW.REMOVE=GW,YW.itemAtPath=(e,t)=>{let n=e
;for(const[r,o]of t){const e=n?.[r];if(!e||!("items"in e))return;n=e.items[o]}
return n},YW.parentCollection=(e,t)=>{
const n=YW.itemAtPath(e,t.slice(0,-1)),r=t[t.length-1][0],o=n?.[r]
;if(o&&"items"in o)return o;throw new Error("Parent collection not found")}
;const JW="\ufeff",eX="",tX="",nX="";function rX(e){switch(e){case JW:
return"byte-order-mark";case eX:return"doc-mode";case tX:return"flow-error-end"
;case nX:return"scalar";case"---":return"doc-start";case"...":return"doc-end"
;case"":case"\n":case"\r\n":return"newline";case"-":return"seq-item-ind"
;case"?":return"explicit-key-ind";case":":return"map-value-ind";case"{":
return"flow-map-start";case"}":return"flow-map-end";case"[":
return"flow-seq-start";case"]":return"flow-seq-end";case",":return"comma"}
switch(e[0]){case" ":case"\t":return"space";case"#":return"comment";case"%":
return"directive-line";case"*":return"alias";case"&":return"anchor";case"!":
return"tag";case"'":return"single-quoted-scalar";case'"':
return"double-quoted-scalar";case"|":case">":return"block-scalar-header"}
return null}const oX=Object.freeze(Object.defineProperty({__proto__:null,BOM:JW,
DOCUMENT:eX,FLOW_END:tX,SCALAR:nX,createScalarToken:function(e,t){
const{implicitKey:n=!1,indent:r,inFlow:o=!1,offset:a=-1,type:i="PLAIN"}=t,s=KV({
type:i,value:e},{implicitKey:n,indent:r>0?" ".repeat(r):"",inFlow:o,options:{
blockQuote:!0,lineWidth:-1}}),l=t.end??[{type:"newline",offset:-1,indent:r,
source:"\n"}];switch(s[0]){case"|":case">":{
const e=s.indexOf("\n"),t=s.substring(0,e),n=s.substring(e+1)+"\n",o=[{
type:"block-scalar-header",offset:a,indent:r,source:t}];return QW(o,l)||o.push({
type:"newline",offset:-1,indent:r,source:"\n"}),{type:"block-scalar",offset:a,
indent:r,props:o,source:n}}case'"':return{type:"double-quoted-scalar",offset:a,
indent:r,source:s,end:l};case"'":return{type:"single-quoted-scalar",offset:a,
indent:r,source:s,end:l};default:return{type:"scalar",offset:a,indent:r,
source:s,end:l}}},isCollection:e=>!!e&&"items"in e,
isScalar:e=>!!e&&("scalar"===e.type||"single-quoted-scalar"===e.type||"double-quoted-scalar"===e.type||"block-scalar"===e.type),
prettyToken:function(e){switch(e){case JW:return"<BOM>";case eX:return"<DOC>"
;case tX:return"<FLOW_END>";case nX:return"<SCALAR>";default:
return JSON.stringify(e)}},resolveAsScalar:function(e,t=!0,n){if(e){
const r=(e,t,r)=>{const o="number"==typeof e?e:Array.isArray(e)?e[0]:e.offset
;if(!n)throw new bW([o,o+1],t,r);n(o,t,r)};switch(e.type){case"scalar":
case"single-quoted-scalar":case"double-quoted-scalar":return PW(e,t,r)
;case"block-scalar":return $W({options:{strict:t}},e,r)}}return null},
setScalarValue:function(e,t,n={}){
let{afterKey:r=!1,implicitKey:o=!1,inFlow:a=!1,type:i}=n,s="indent"in e?e.indent:null
;if(r&&"number"==typeof s&&(s+=2),!i)switch(e.type){case"single-quoted-scalar":
i="QUOTE_SINGLE";break;case"double-quoted-scalar":i="QUOTE_DOUBLE";break
;case"block-scalar":{const t=e.props[0]
;if("block-scalar-header"!==t.type)throw new Error("Invalid block scalar header")
;i=">"===t.source[0]?"BLOCK_FOLDED":"BLOCK_LITERAL";break}default:i="PLAIN"}
const l=KV({type:i,value:t},{implicitKey:o||null===s,
indent:null!==s&&s>0?" ".repeat(s):"",inFlow:a,options:{blockQuote:!0,
lineWidth:-1}});switch(l[0]){case"|":case">":!function(e,t){
const n=t.indexOf("\n"),r=t.substring(0,n),o=t.substring(n+1)+"\n"
;if("block-scalar"===e.type){const t=e.props[0]
;if("block-scalar-header"!==t.type)throw new Error("Invalid block scalar header")
;t.source=r,e.source=o}else{const{offset:t}=e,n="indent"in e?e.indent:-1,a=[{
type:"block-scalar-header",offset:t,indent:n,source:r}]
;QW(a,"end"in e?e.end:void 0)||a.push({type:"newline",offset:-1,indent:n,
source:"\n"})
;for(const r of Object.keys(e))"type"!==r&&"offset"!==r&&delete e[r]
;Object.assign(e,{type:"block-scalar",indent:n,props:a,source:o})}}(e,l);break
;case'"':HW(e,l,"double-quoted-scalar");break;case"'":
HW(e,l,"single-quoted-scalar");break;default:HW(e,l,"scalar")}},
stringify:e=>"type"in e?VW(e):qW(e),tokenType:rX,visit:YW},Symbol.toStringTag,{
value:"Module"}));function aX(e){switch(e){case void 0:case" ":case"\n":
case"\r":case"\t":return!0;default:return!1}}
const iX=new Set("0123456789ABCDEFabcdef"),sX=new Set("0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz-#;/?:@&=+$_.!~*'()"),lX=new Set(",[]{}"),cX=new Set(" ,[]{}\n\r\t"),uX=e=>!e||cX.has(e)
;class dX{constructor(){
this.atEnd=!1,this.blockScalarIndent=-1,this.blockScalarKeep=!1,
this.buffer="",this.flowKey=!1,
this.flowLevel=0,this.indentNext=0,this.indentValue=0,
this.lineEndPos=null,this.next=null,this.pos=0}*lex(e,t=!1){if(e){
if("string"!=typeof e)throw TypeError("source is not a string")
;this.buffer=this.buffer?this.buffer+e:e,this.lineEndPos=null}this.atEnd=!t
;let n=this.next??"stream"
;for(;n&&(t||this.hasChars(1));)n=yield*this.parseNext(n)}atLineEnd(){
let e=this.pos,t=this.buffer[e];for(;" "===t||"\t"===t;)t=this.buffer[++e]
;return!t||"#"===t||"\n"===t||"\r"===t&&"\n"===this.buffer[e+1]}charAt(e){
return this.buffer[this.pos+e]}continueScalar(e){let t=this.buffer[e]
;if(this.indentNext>0){let n=0;for(;" "===t;)t=this.buffer[++n+e];if("\r"===t){
const t=this.buffer[n+e+1];if("\n"===t||!t&&!this.atEnd)return e+n+1}
return"\n"===t||n>=this.indentNext||!t&&!this.atEnd?e+n:-1}if("-"===t||"."===t){
const t=this.buffer.substr(e,3)
;if(("---"===t||"..."===t)&&aX(this.buffer[e+3]))return-1}return e}getLine(){
let e=this.lineEndPos
;return("number"!=typeof e||-1!==e&&e<this.pos)&&(e=this.buffer.indexOf("\n",this.pos),
this.lineEndPos=e),
-1===e?this.atEnd?this.buffer.substring(this.pos):null:("\r"===this.buffer[e-1]&&(e-=1),
this.buffer.substring(this.pos,e))}hasChars(e){
return this.pos+e<=this.buffer.length}setNext(e){
return this.buffer=this.buffer.substring(this.pos),
this.pos=0,this.lineEndPos=null,this.next=e,null}peek(e){
return this.buffer.substr(this.pos,e)}*parseNext(e){switch(e){case"stream":
return yield*this.parseStream();case"line-start":
return yield*this.parseLineStart();case"block-start":
return yield*this.parseBlockStart();case"doc":return yield*this.parseDocument()
;case"flow":return yield*this.parseFlowCollection();case"quoted-scalar":
return yield*this.parseQuotedScalar();case"block-scalar":
return yield*this.parseBlockScalar();case"plain-scalar":
return yield*this.parsePlainScalar()}}*parseStream(){let e=this.getLine()
;if(null===e)return this.setNext("stream")
;if(e[0]===JW&&(yield*this.pushCount(1),e=e.substring(1)),"%"===e[0]){
let t=e.length,n=e.indexOf("#");for(;-1!==n;){const r=e[n-1]
;if(" "===r||"\t"===r){t=n-1;break}n=e.indexOf("#",n+1)}for(;;){const n=e[t-1]
;if(" "!==n&&"\t"!==n)break;t-=1}
const r=(yield*this.pushCount(t))+(yield*this.pushSpaces(!0))
;return yield*this.pushCount(e.length-r),this.pushNewline(),"stream"}
if(this.atLineEnd()){const t=yield*this.pushSpaces(!0)
;return yield*this.pushCount(e.length-t),yield*this.pushNewline(),"stream"}
return yield eX,yield*this.parseLineStart()}*parseLineStart(){
const e=this.charAt(0);if(!e&&!this.atEnd)return this.setNext("line-start")
;if("-"===e||"."===e){
if(!this.atEnd&&!this.hasChars(4))return this.setNext("line-start")
;const e=this.peek(3)
;if(("---"===e||"..."===e)&&aX(this.charAt(3)))return yield*this.pushCount(3),
this.indentValue=0,this.indentNext=0,"---"===e?"doc":"stream"}
return this.indentValue=yield*this.pushSpaces(!1),
this.indentNext>this.indentValue&&!aX(this.charAt(1))&&(this.indentNext=this.indentValue),
yield*this.parseBlockStart()}*parseBlockStart(){const[e,t]=this.peek(2)
;if(!t&&!this.atEnd)return this.setNext("block-start")
;if(("-"===e||"?"===e||":"===e)&&aX(t)){
const e=(yield*this.pushCount(1))+(yield*this.pushSpaces(!0))
;return this.indentNext=this.indentValue+1,
this.indentValue+=e,yield*this.parseBlockStart()}return"doc"}*parseDocument(){
yield*this.pushSpaces(!0);const e=this.getLine()
;if(null===e)return this.setNext("doc");let t=yield*this.pushIndicators()
;switch(e[t]){case"#":yield*this.pushCount(e.length-t);case void 0:
return yield*this.pushNewline(),yield*this.parseLineStart();case"{":case"[":
return yield*this.pushCount(1),this.flowKey=!1,this.flowLevel=1,"flow";case"}":
case"]":return yield*this.pushCount(1),"doc";case"*":
return yield*this.pushUntil(uX),"doc";case'"':case"'":
return yield*this.parseQuotedScalar();case"|":case">":
return t+=(yield*this.parseBlockScalarHeader()),
t+=(yield*this.pushSpaces(!0)),yield*this.pushCount(e.length-t),
yield*this.pushNewline(),yield*this.parseBlockScalar();default:
return yield*this.parsePlainScalar()}}*parseFlowCollection(){let e,t,n=-1;do{
e=yield*this.pushNewline(),
e>0?(t=yield*this.pushSpaces(!1),this.indentValue=n=t):t=0,
t+=(yield*this.pushSpaces(!0))}while(e+t>0);const r=this.getLine()
;if(null===r)return this.setNext("flow")
;if(-1!==n&&n<this.indentNext&&"#"!==r[0]||0===n&&(r.startsWith("---")||r.startsWith("..."))&&aX(r[3])){
if(!(n===this.indentNext-1&&1===this.flowLevel&&("]"===r[0]||"}"===r[0])))return this.flowLevel=0,
yield tX,yield*this.parseLineStart()}let o=0
;for(;","===r[o];)o+=(yield*this.pushCount(1)),
o+=(yield*this.pushSpaces(!0)),this.flowKey=!1
;switch(o+=(yield*this.pushIndicators()),r[o]){case void 0:return"flow";case"#":
return yield*this.pushCount(r.length-o),"flow";case"{":case"[":
return yield*this.pushCount(1),this.flowKey=!1,this.flowLevel+=1,"flow";case"}":
case"]":
return yield*this.pushCount(1),this.flowKey=!0,this.flowLevel-=1,this.flowLevel?"flow":"doc"
;case"*":return yield*this.pushUntil(uX),"flow";case'"':case"'":
return this.flowKey=!0,yield*this.parseQuotedScalar();case":":{
const e=this.charAt(1)
;if(this.flowKey||aX(e)||","===e)return this.flowKey=!1,yield*this.pushCount(1),
yield*this.pushSpaces(!0),"flow"}default:
return this.flowKey=!1,yield*this.parsePlainScalar()}}*parseQuotedScalar(){
const e=this.charAt(0);let t=this.buffer.indexOf(e,this.pos+1)
;if("'"===e)for(;-1!==t&&"'"===this.buffer[t+1];)t=this.buffer.indexOf("'",t+2);else for(;-1!==t;){
let e=0;for(;"\\"===this.buffer[t-1-e];)e+=1;if(e%2==0)break
;t=this.buffer.indexOf('"',t+1)}const n=this.buffer.substring(0,t)
;let r=n.indexOf("\n",this.pos);if(-1!==r){for(;-1!==r;){
const e=this.continueScalar(r+1);if(-1===e)break;r=n.indexOf("\n",e)}
-1!==r&&(t=r-("\r"===n[r-1]?2:1))}if(-1===t){
if(!this.atEnd)return this.setNext("quoted-scalar");t=this.buffer.length}
return yield*this.pushToIndex(t+1,!1),this.flowLevel?"flow":"doc"}
*parseBlockScalarHeader(){this.blockScalarIndent=-1,this.blockScalarKeep=!1
;let e=this.pos;for(;;){const t=this.buffer[++e]
;if("+"===t)this.blockScalarKeep=!0;else if(t>"0"&&t<="9")this.blockScalarIndent=Number(t)-1;else if("-"!==t)break
}return yield*this.pushUntil((e=>aX(e)||"#"===e))}*parseBlockScalar(){
let e,t=this.pos-1,n=0;e:for(let o=this.pos;e=this.buffer[o];++o)switch(e){
case" ":n+=1;break;case"\n":t=o,n=0;break;case"\r":{const e=this.buffer[o+1]
;if(!e&&!this.atEnd)return this.setNext("block-scalar");if("\n"===e)break}
default:break e}if(!e&&!this.atEnd)return this.setNext("block-scalar")
;if(n>=this.indentNext){
-1===this.blockScalarIndent?this.indentNext=n:this.indentNext=this.blockScalarIndent+(0===this.indentNext?1:this.indentNext)
;do{const e=this.continueScalar(t+1);if(-1===e)break
;t=this.buffer.indexOf("\n",e)}while(-1!==t);if(-1===t){
if(!this.atEnd)return this.setNext("block-scalar");t=this.buffer.length}}
let r=t+1;for(e=this.buffer[r];" "===e;)e=this.buffer[++r];if("\t"===e){
for(;"\t"===e||" "===e||"\r"===e||"\n"===e;)e=this.buffer[++r];t=r-1
}else if(!this.blockScalarKeep)for(;;){let e=t-1,r=this.buffer[e]
;"\r"===r&&(r=this.buffer[--e]);const o=e;for(;" "===r;)r=this.buffer[--e]
;if(!("\n"===r&&e>=this.pos&&e+1+n>o))break;t=e}
return yield nX,yield*this.pushToIndex(t+1,!0),yield*this.parseLineStart()}
*parsePlainScalar(){const e=this.flowLevel>0;let t,n=this.pos-1,r=this.pos-1
;for(;t=this.buffer[++r];)if(":"===t){const t=this.buffer[r+1]
;if(aX(t)||e&&lX.has(t))break;n=r}else if(aX(t)){let o=this.buffer[r+1]
;if("\r"===t&&("\n"===o?(r+=1,
t="\n",o=this.buffer[r+1]):n=r),"#"===o||e&&lX.has(o))break;if("\n"===t){
const e=this.continueScalar(r+1);if(-1===e)break;r=Math.max(r,e-2)}}else{
if(e&&lX.has(t))break;n=r}
return t||this.atEnd?(yield nX,yield*this.pushToIndex(n+1,!0),
e?"flow":"doc"):this.setNext("plain-scalar")}*pushCount(e){
return e>0?(yield this.buffer.substr(this.pos,e),this.pos+=e,e):0}
*pushToIndex(e,t){const n=this.buffer.slice(this.pos,e)
;return n?(yield n,this.pos+=n.length,n.length):(t&&(yield""),0)}
*pushIndicators(){switch(this.charAt(0)){case"!":
return(yield*this.pushTag())+(yield*this.pushSpaces(!0))+(yield*this.pushIndicators())
;case"&":
return(yield*this.pushUntil(uX))+(yield*this.pushSpaces(!0))+(yield*this.pushIndicators())
;case"-":case"?":case":":{const e=this.flowLevel>0,t=this.charAt(1)
;if(aX(t)||e&&lX.has(t))return e?this.flowKey&&(this.flowKey=!1):this.indentNext=this.indentValue+1,
(yield*this.pushCount(1))+(yield*this.pushSpaces(!0))+(yield*this.pushIndicators())
}}return 0}*pushTag(){if("<"===this.charAt(1)){let e=this.pos+2,t=this.buffer[e]
;for(;!aX(t)&&">"!==t;)t=this.buffer[++e]
;return yield*this.pushToIndex(">"===t?e+1:e,!1)}{
let e=this.pos+1,t=this.buffer[e];for(;t;)if(sX.has(t))t=this.buffer[++e];else{
if("%"!==t||!iX.has(this.buffer[e+1])||!iX.has(this.buffer[e+2]))break
;t=this.buffer[e+=3]}return yield*this.pushToIndex(e,!1)}}*pushNewline(){
const e=this.buffer[this.pos]
;return"\n"===e?yield*this.pushCount(1):"\r"===e&&"\n"===this.charAt(1)?yield*this.pushCount(2):0
}*pushSpaces(e){let t,n=this.pos-1;do{t=this.buffer[++n]
}while(" "===t||e&&"\t"===t);const r=n-this.pos
;return r>0&&(yield this.buffer.substr(this.pos,r),this.pos=n),r}*pushUntil(e){
let t=this.pos,n=this.buffer[t];for(;!e(n);)n=this.buffer[++t]
;return yield*this.pushToIndex(t,!1)}}class pX{constructor(){this.lineStarts=[],
this.addNewLine=e=>this.lineStarts.push(e),this.linePos=e=>{
let t=0,n=this.lineStarts.length;for(;t<n;){const r=t+n>>1
;this.lineStarts[r]<e?t=r+1:n=r}if(this.lineStarts[t]===e)return{line:t+1,col:1}
;if(0===t)return{line:0,col:e};return{line:t,col:e-this.lineStarts[t-1]+1}}}}
function hX(e,t){for(let n=0;n<e.length;++n)if(e[n].type===t)return!0;return!1}
function fX(e){for(let t=0;t<e.length;++t)switch(e[t].type){case"space":
case"comment":case"newline":break;default:return t}return-1}function mX(e){
switch(e?.type){case"alias":case"scalar":case"single-quoted-scalar":
case"double-quoted-scalar":case"flow-collection":return!0;default:return!1}}
function gX(e){switch(e.type){case"document":return e.start;case"block-map":{
const t=e.items[e.items.length-1];return t.sep??t.start}case"block-seq":
return e.items[e.items.length-1].start;default:return[]}}function vX(e){
if(0===e.length)return[];let t=e.length;e:for(;--t>=0;)switch(e[t].type){
case"doc-start":case"explicit-key-ind":case"map-value-ind":case"seq-item-ind":
case"newline":break e}for(;"space"===e[++t]?.type;);return e.splice(t,e.length)}
function bX(e){
if("flow-seq-start"===e.start.type)for(const t of e.items)!t.sep||t.value||hX(t.start,"explicit-key-ind")||hX(t.sep,"map-value-ind")||(t.key&&(t.value=t.key),
delete t.key,
mX(t.value)?t.value.end?Array.prototype.push.apply(t.value.end,t.sep):t.value.end=t.sep:Array.prototype.push.apply(t.start,t.sep),
delete t.sep)}let yX=class{constructor(e){
this.atNewLine=!0,this.atScalar=!1,this.indent=0,
this.offset=0,this.onKeyLine=!1,
this.stack=[],this.source="",this.type="",this.lexer=new dX,this.onNewLine=e}
*parse(e,t=!1){this.onNewLine&&0===this.offset&&this.onNewLine(0)
;for(const n of this.lexer.lex(e,t))yield*this.next(n);t||(yield*this.end())}
*next(e){
if(this.source=e,this.atScalar)return this.atScalar=!1,yield*this.step(),
void(this.offset+=e.length);const t=rX(e)
;if(t)if("scalar"===t)this.atNewLine=!1,
this.atScalar=!0,this.type="scalar";else{
switch(this.type=t,yield*this.step(),t){case"newline":
this.atNewLine=!0,this.indent=0,
this.onNewLine&&this.onNewLine(this.offset+e.length);break;case"space":
this.atNewLine&&" "===e[0]&&(this.indent+=e.length);break
;case"explicit-key-ind":case"map-value-ind":case"seq-item-ind":
this.atNewLine&&(this.indent+=e.length);break;case"doc-mode":
case"flow-error-end":return;default:this.atNewLine=!1}this.offset+=e.length
}else{const t=`Not a YAML token: ${e}`;yield*this.pop({type:"error",
offset:this.offset,message:t,source:e}),this.offset+=e.length}}*end(){
for(;this.stack.length>0;)yield*this.pop()}get sourceToken(){return{
type:this.type,offset:this.offset,indent:this.indent,source:this.source}}
*step(){const e=this.peek(1);if("doc-end"!==this.type||e&&"doc-end"===e.type){
if(!e)return yield*this.stream();switch(e.type){case"document":
return yield*this.document(e);case"alias":case"scalar":
case"single-quoted-scalar":case"double-quoted-scalar":
return yield*this.scalar(e);case"block-scalar":return yield*this.blockScalar(e)
;case"block-map":return yield*this.blockMap(e);case"block-seq":
return yield*this.blockSequence(e);case"flow-collection":
return yield*this.flowCollection(e);case"doc-end":
return yield*this.documentEnd(e)}yield*this.pop()}else{
for(;this.stack.length>0;)yield*this.pop();this.stack.push({type:"doc-end",
offset:this.offset,source:this.source})}}peek(e){
return this.stack[this.stack.length-e]}*pop(e){const t=e??this.stack.pop()
;if(t)if(0===this.stack.length)yield t;else{const e=this.peek(1)
;switch("block-scalar"===t.type?t.indent="indent"in e?e.indent:0:"flow-collection"===t.type&&"document"===e.type&&(t.indent=0),
"flow-collection"===t.type&&bX(t),e.type){case"document":e.value=t;break
;case"block-scalar":e.props.push(t);break;case"block-map":{
const n=e.items[e.items.length-1];if(n.value)return e.items.push({start:[],
key:t,sep:[]}),void(this.onKeyLine=!0);if(!n.sep)return Object.assign(n,{key:t,
sep:[]}),void(this.onKeyLine=!n.explicitKey);n.value=t;break}case"block-seq":{
const n=e.items[e.items.length-1];n.value?e.items.push({start:[],value:t
}):n.value=t;break}case"flow-collection":{const n=e.items[e.items.length-1]
;return void(!n||n.value?e.items.push({start:[],key:t,sep:[]
}):n.sep?n.value=t:Object.assign(n,{key:t,sep:[]}))}default:
yield*this.pop(),yield*this.pop(t)}
if(!("document"!==e.type&&"block-map"!==e.type&&"block-seq"!==e.type||"block-map"!==t.type&&"block-seq"!==t.type)){
const n=t.items[t.items.length-1]
;n&&!n.sep&&!n.value&&n.start.length>0&&-1===fX(n.start)&&(0===t.indent||n.start.every((e=>"comment"!==e.type||e.indent<t.indent)))&&("document"===e.type?e.end=n.start:e.items.push({
start:n.start}),t.items.splice(-1,1))}}else{
const e="Tried to pop an empty stack";yield{type:"error",offset:this.offset,
source:"",message:e}}}*stream(){switch(this.type){case"directive-line":
return void(yield{type:"directive",offset:this.offset,source:this.source})
;case"byte-order-mark":case"space":case"comment":case"newline":
return void(yield this.sourceToken);case"doc-mode":case"doc-start":{const e={
type:"document",offset:this.offset,start:[]}
;return"doc-start"===this.type&&e.start.push(this.sourceToken),
void this.stack.push(e)}}yield{type:"error",offset:this.offset,
message:`Unexpected ${this.type} token in YAML stream`,source:this.source}}
*document(e){if(e.value)return yield*this.lineEnd(e);switch(this.type){
case"doc-start":
return void(-1!==fX(e.start)?(yield*this.pop(),yield*this.step()):e.start.push(this.sourceToken))
;case"anchor":case"tag":case"space":case"comment":case"newline":
return void e.start.push(this.sourceToken)}const t=this.startBlockValue(e)
;t?this.stack.push(t):yield{type:"error",offset:this.offset,
message:`Unexpected ${this.type} token in YAML document`,source:this.source}}
*scalar(e){if("map-value-ind"===this.type){const t=vX(gX(this.peek(2)));let n
;e.end?(n=e.end,n.push(this.sourceToken),delete e.end):n=[this.sourceToken]
;const r={type:"block-map",offset:e.offset,indent:e.indent,items:[{start:t,
key:e,sep:n}]};this.onKeyLine=!0,this.stack[this.stack.length-1]=r
}else yield*this.lineEnd(e)}*blockScalar(e){switch(this.type){case"space":
case"comment":case"newline":return void e.props.push(this.sourceToken)
;case"scalar":
if(e.source=this.source,this.atNewLine=!0,this.indent=0,this.onNewLine){
let e=this.source.indexOf("\n")+1
;for(;0!==e;)this.onNewLine(this.offset+e),e=this.source.indexOf("\n",e)+1}
yield*this.pop();break;default:yield*this.pop(),yield*this.step()}}*blockMap(e){
const t=e.items[e.items.length-1];switch(this.type){case"newline":
if(this.onKeyLine=!1,t.value){
const n="end"in t.value?t.value.end:void 0,r=Array.isArray(n)?n[n.length-1]:void 0
;"comment"===r?.type?n?.push(this.sourceToken):e.items.push({
start:[this.sourceToken]})
}else t.sep?t.sep.push(this.sourceToken):t.start.push(this.sourceToken);return
;case"space":case"comment":if(t.value)e.items.push({start:[this.sourceToken]
});else if(t.sep)t.sep.push(this.sourceToken);else{
if(this.atIndentedComment(t.start,e.indent)){
const n=e.items[e.items.length-2],r=n?.value?.end
;if(Array.isArray(r))return Array.prototype.push.apply(r,t.start),
r.push(this.sourceToken),void e.items.pop()}t.start.push(this.sourceToken)}
return}if(this.indent>=e.indent){
const n=!this.onKeyLine&&this.indent===e.indent,r=n&&(t.sep||t.explicitKey)&&"seq-item-ind"!==this.type
;let o=[];if(r&&t.sep&&!t.value){const n=[];for(let r=0;r<t.sep.length;++r){
const o=t.sep[r];switch(o.type){case"newline":n.push(r);break;case"space":break
;case"comment":o.indent>e.indent&&(n.length=0);break;default:n.length=0}}
n.length>=2&&(o=t.sep.splice(n[1]))}switch(this.type){case"anchor":case"tag":
return void(r||t.value?(o.push(this.sourceToken),e.items.push({start:o
}),this.onKeyLine=!0):t.sep?t.sep.push(this.sourceToken):t.start.push(this.sourceToken))
;case"explicit-key-ind":
return t.sep||t.explicitKey?r||t.value?(o.push(this.sourceToken),e.items.push({
start:o,explicitKey:!0})):this.stack.push({type:"block-map",offset:this.offset,
indent:this.indent,items:[{start:[this.sourceToken],explicitKey:!0}]
}):(t.start.push(this.sourceToken),t.explicitKey=!0),void(this.onKeyLine=!0)
;case"map-value-ind":if(t.explicitKey)if(t.sep)if(t.value)e.items.push({
start:[],key:null,sep:[this.sourceToken]
});else if(hX(t.sep,"map-value-ind"))this.stack.push({type:"block-map",
offset:this.offset,indent:this.indent,items:[{start:o,key:null,
sep:[this.sourceToken]}]});else if(mX(t.key)&&!hX(t.sep,"newline")){
const e=vX(t.start),n=t.key,r=t.sep
;r.push(this.sourceToken),delete t.key,delete t.sep,this.stack.push({
type:"block-map",offset:this.offset,indent:this.indent,items:[{start:e,key:n,
sep:r}]})
}else o.length>0?t.sep=t.sep.concat(o,this.sourceToken):t.sep.push(this.sourceToken);else if(hX(t.start,"newline"))Object.assign(t,{
key:null,sep:[this.sourceToken]});else{const e=vX(t.start);this.stack.push({
type:"block-map",offset:this.offset,indent:this.indent,items:[{start:e,key:null,
sep:[this.sourceToken]}]})}else t.sep?t.value||r?e.items.push({start:o,key:null,
sep:[this.sourceToken]}):hX(t.sep,"map-value-ind")?this.stack.push({
type:"block-map",offset:this.offset,indent:this.indent,items:[{start:[],
key:null,sep:[this.sourceToken]}]
}):t.sep.push(this.sourceToken):Object.assign(t,{key:null,sep:[this.sourceToken]
});return void(this.onKeyLine=!0);case"alias":case"scalar":
case"single-quoted-scalar":case"double-quoted-scalar":{
const n=this.flowScalar(this.type);return void(r||t.value?(e.items.push({
start:o,key:n,sep:[]
}),this.onKeyLine=!0):t.sep?this.stack.push(n):(Object.assign(t,{key:n,sep:[]}),
this.onKeyLine=!0))}default:{const r=this.startBlockValue(e);if(r){
if("block-seq"===r.type){
if(!t.explicitKey&&t.sep&&!hX(t.sep,"newline"))return void(yield*this.pop({
type:"error",offset:this.offset,
message:"Unexpected block-seq-ind on same line with key",source:this.source}))
}else n&&e.items.push({start:o});return void this.stack.push(r)}}}}
yield*this.pop(),yield*this.step()}*blockSequence(e){
const t=e.items[e.items.length-1];switch(this.type){case"newline":if(t.value){
const n="end"in t.value?t.value.end:void 0,r=Array.isArray(n)?n[n.length-1]:void 0
;"comment"===r?.type?n?.push(this.sourceToken):e.items.push({
start:[this.sourceToken]})}else t.start.push(this.sourceToken);return
;case"space":case"comment":if(t.value)e.items.push({start:[this.sourceToken]
});else{if(this.atIndentedComment(t.start,e.indent)){
const n=e.items[e.items.length-2],r=n?.value?.end
;if(Array.isArray(r))return Array.prototype.push.apply(r,t.start),
r.push(this.sourceToken),void e.items.pop()}t.start.push(this.sourceToken)}
return;case"anchor":case"tag":if(t.value||this.indent<=e.indent)break
;return void t.start.push(this.sourceToken);case"seq-item-ind":
if(this.indent!==e.indent)break
;return void(t.value||hX(t.start,"seq-item-ind")?e.items.push({
start:[this.sourceToken]}):t.start.push(this.sourceToken))}
if(this.indent>e.indent){const t=this.startBlockValue(e)
;if(t)return void this.stack.push(t)}yield*this.pop(),yield*this.step()}
*flowCollection(e){const t=e.items[e.items.length-1]
;if("flow-error-end"===this.type){let e;do{yield*this.pop(),e=this.peek(1)
}while(e&&"flow-collection"===e.type)}else if(0===e.end.length){
switch(this.type){case"comma":case"explicit-key-ind":
return void(!t||t.sep?e.items.push({start:[this.sourceToken]
}):t.start.push(this.sourceToken));case"map-value-ind":
return void(!t||t.value?e.items.push({start:[],key:null,sep:[this.sourceToken]
}):t.sep?t.sep.push(this.sourceToken):Object.assign(t,{key:null,
sep:[this.sourceToken]}));case"space":case"comment":case"newline":case"anchor":
case"tag":return void(!t||t.value?e.items.push({start:[this.sourceToken]
}):t.sep?t.sep.push(this.sourceToken):t.start.push(this.sourceToken))
;case"alias":case"scalar":case"single-quoted-scalar":case"double-quoted-scalar":
{const n=this.flowScalar(this.type);return void(!t||t.value?e.items.push({
start:[],key:n,sep:[]}):t.sep?this.stack.push(n):Object.assign(t,{key:n,sep:[]
}))}case"flow-map-end":case"flow-seq-end":
return void e.end.push(this.sourceToken)}const n=this.startBlockValue(e)
;n?this.stack.push(n):(yield*this.pop(),yield*this.step())}else{
const t=this.peek(2)
;if("block-map"===t.type&&("map-value-ind"===this.type&&t.indent===e.indent||"newline"===this.type&&!t.items[t.items.length-1].sep))yield*this.pop(),
yield*this.step();else if("map-value-ind"===this.type&&"flow-collection"!==t.type){
const n=vX(gX(t));bX(e);const r=e.end.splice(1,e.end.length)
;r.push(this.sourceToken);const o={type:"block-map",offset:e.offset,
indent:e.indent,items:[{start:n,key:e,sep:r}]}
;this.onKeyLine=!0,this.stack[this.stack.length-1]=o}else yield*this.lineEnd(e)}
}flowScalar(e){if(this.onNewLine){let e=this.source.indexOf("\n")+1
;for(;0!==e;)this.onNewLine(this.offset+e),e=this.source.indexOf("\n",e)+1}
return{type:e,offset:this.offset,indent:this.indent,source:this.source}}
startBlockValue(e){switch(this.type){case"alias":case"scalar":
case"single-quoted-scalar":case"double-quoted-scalar":
return this.flowScalar(this.type);case"block-scalar-header":return{
type:"block-scalar",offset:this.offset,indent:this.indent,
props:[this.sourceToken],source:""};case"flow-map-start":case"flow-seq-start":
return{type:"flow-collection",offset:this.offset,indent:this.indent,
start:this.sourceToken,items:[],end:[]};case"seq-item-ind":return{
type:"block-seq",offset:this.offset,indent:this.indent,items:[{
start:[this.sourceToken]}]};case"explicit-key-ind":{this.onKeyLine=!0
;const t=vX(gX(e));return t.push(this.sourceToken),{type:"block-map",
offset:this.offset,indent:this.indent,items:[{start:t,explicitKey:!0}]}}
case"map-value-ind":{this.onKeyLine=!0;const t=vX(gX(e));return{
type:"block-map",offset:this.offset,indent:this.indent,items:[{start:t,key:null,
sep:[this.sourceToken]}]}}}return null}atIndentedComment(e,t){
return"comment"===this.type&&(!(this.indent<=t)&&e.every((e=>"newline"===e.type||"space"===e.type)))
}*documentEnd(e){
"doc-mode"!==this.type&&(e.end?e.end.push(this.sourceToken):e.end=[this.sourceToken],
"newline"===this.type&&(yield*this.pop()))}*lineEnd(e){switch(this.type){
case"comma":case"doc-start":case"doc-end":case"flow-seq-end":case"flow-map-end":
case"map-value-ind":yield*this.pop(),yield*this.step();break;case"newline":
this.onKeyLine=!1;default:
e.end?e.end.push(this.sourceToken):e.end=[this.sourceToken],
"newline"===this.type&&(yield*this.pop())}}};function OX(e){
const t=!1!==e.prettyErrors;return{lineCounter:e.lineCounter||t&&new pX||null,
prettyErrors:t}}function wX(e,t={}){
const{lineCounter:n,prettyErrors:r}=OX(t),o=new yX(n?.addNewLine),a=new ZW(t)
;let i=null;for(const s of a.compose(o.parse(e),!0,e.length))if(i){
if("silent"!==i.options.logLevel){
i.errors.push(new bW(s.range.slice(0,2),"MULTIPLE_DOCS","Source contains multiple documents; please use YAML.parseAllDocuments()"))
;break}}else i=s
;return r&&n&&(i.errors.forEach(OW(e,n)),i.warnings.forEach(OW(e,n))),i}
function xX(e,t,n){let r
;"function"==typeof t?r=t:void 0===n&&t&&"object"==typeof t&&(n=t)
;const o=wX(e,n);if(!o)return null
;if(o.warnings.forEach((e=>tq(o.options.logLevel,e))),o.errors.length>0){
if("silent"!==o.options.logLevel)throw o.errors[0];o.errors=[]}
return o.toJS(Object.assign({reviver:r},n))}function kX(e,t,n){let r=null
;if("function"==typeof t||Array.isArray(t)?r=t:void 0===n&&t&&(n=t),
"string"==typeof n&&(n=n.length),"number"==typeof n){const e=Math.round(n)
;n=e<1?void 0:e>8?{indent:8}:{indent:e}}if(void 0===e){
const{keepUndefined:e}=n??t??{};if(!e)return}
return nV(e)&&!r?e.toString(n):new mW(e,r,n).toString(n)}
const SX=Object.freeze(Object.defineProperty({__proto__:null,Alias:AV,CST:oX,
Composer:ZW,Document:mW,Lexer:dX,LineCounter:pX,Pair:lq,Parser:yX,Scalar:PV,
Schema:fW,YAMLError:vW,YAMLMap:fq,YAMLParseError:bW,YAMLSeq:gq,YAMLWarning:yW,
isAlias:tV,isCollection:sV,isDocument:nV,isMap:rV,isNode:lV,isPair:oV,
isScalar:aV,isSeq:iV,parse:xX,parseAllDocuments:function(e,t={}){
const{lineCounter:n,prettyErrors:r}=OX(t),o=new yX(n?.addNewLine),a=new ZW(t),i=Array.from(a.compose(o.parse(e)))
;if(r&&n)for(const s of i)s.errors.forEach(OW(e,n)),s.warnings.forEach(OW(e,n))
;return i.length>0?i:Object.assign([],{empty:!0},a.streamInfo())},
parseDocument:wX,stringify:kX,visit:hV,visitAsync:mV},Symbol.toStringTag,{
value:"Module"})),_X={parse:e=>{const t=xX(e,{merge:!0,maxAliasCount:1e4})
;if("object"!=typeof t)throw Error("Invalid YAML object");return t},
parseSafe(e,t){try{return _X.parse(e)}catch(n){return"function"==typeof t?t(n):t
}},stringify:kX},TX={parse:e=>{const t=JSON.parse(e)
;if("object"!=typeof t)throw Error("Invalid JSON object");return t},
parseSafe(e,t){try{return TX.parse(e)}catch(n){return"function"==typeof t?t(n):t
}},stringify:e=>JSON.stringify(e)
},EX=e=>"string"==typeof e&&!!TX.parseSafe(e,!1);function AX(e){if(!e)return e
;const t={...e};return Object.entries(t).forEach((([e,n])=>{const r=function(e){
if("string"==typeof e)return e.replace(/;.*$/,"").replace(/\/(?!.*vnd\.|fhir\+).*\+/,"/").trim()
}(e);r&&(t[r]=n)})),t}const CX=zc({lang:cl().optional().catch(void 0),
label:cl().optional().catch(void 0),source:cl()}),$X=zc({
"x-codeSamples":CX.array().optional().catch(void 0),
"x-code-samples":CX.array().optional().catch(void 0),
"x-custom-examples":CX.array().optional().catch(void 0)}),PX=zc({
"x-post-response":cl().optional()}),DX=zc({"x-scalar-sdk-installation":zc({
lang:cl(),source:cl().optional().catch(void 0),
description:cl().optional().catch(void 0)}).array().optional().catch(void 0)
}),IX={Deprecated:"deprecated",Experimental:"experimental",Stable:"stable"};zc({
"x-scalar-stability":cu(Object.values(IX)).optional().catch(void 0)})
;const MX=e=>e.deprecated||e["x-scalar-stability"]===IX.Deprecated,NX=e=>e.deprecated?IX.Deprecated:e["x-scalar-stability"],RX=e=>{
switch(NX(e)){case IX.Deprecated:return"text-red";case IX.Experimental:
return"text-orange";case IX.Stable:return"text-green";default:return""}},LX=e=>{
if("string"==typeof e)return EX(e)?JSON.stringify(JSON.parse(e),null,2):e
;if("object"==typeof e)try{return JSON.stringify(e,null,2)}catch{
return function(e){const t=new Set;return JSON.stringify(e,((e,n)=>{
if("object"==typeof n&&null!==n){if(t.has(n))return"[Circular]";t.add(n)}
return n}),2)}(e)}return e?.toString()??""};let BX=(e=21)=>{
let t="",n=crypto.getRandomValues(new Uint8Array(e|=0))
;for(;e--;)t+="useandom-26T198340PX75pxJACKVERYMINDBUSHWOLF_GQZbfghjklqvwyzrict"[63&n[e]]
;return t};const jX=cl().min(7).default((()=>BX())),UX=zc({
enum:Bc(cl()).optional(),default:cl().optional(),description:cl().optional()
}).extend({value:cl().optional()
}).refine((e=>(Array.isArray(e.enum)&&!e.enum.includes(e.default??"")&&e.enum.length>0&&(e.default=e.enum[0]),
Array.isArray(e.enum)&&0===e.enum.length&&delete e.enum,!0)));zc({url:cl(),
description:cl().optional(),variables:tu(cl(),UX).optional()}).extend({
uid:jX.brand()});var zX=Object.defineProperty,FX=(e,t,n)=>(((e,t,n)=>{
t in e?zX(e,t,{enumerable:!0,configurable:!0,writable:!0,value:n}):e[t]=n
})(e,"symbol"!=typeof t?t+"":t,n),n);!function(e){if(typeof document>"u")return
;let t=document.head||document.getElementsByTagName("head")[0],n=document.createElement("style")
;n.type="text/css",
t.appendChild(n),n.styleSheet?n.styleSheet.cssText=e:n.appendChild(document.createTextNode(e))
}("[data-sonner-toaster][dir=ltr],html[dir=ltr]{--toast-icon-margin-start:-3px;--toast-icon-margin-end:4px;--toast-svg-margin-start:-1px;--toast-svg-margin-end:0px;--toast-button-margin-start:auto;--toast-button-margin-end:0;--toast-close-button-start:0;--toast-close-button-end:unset;--toast-close-button-transform:translate(-35%, -35%)}[data-sonner-toaster][dir=rtl],html[dir=rtl]{--toast-icon-margin-start:4px;--toast-icon-margin-end:-3px;--toast-svg-margin-start:0px;--toast-svg-margin-end:-1px;--toast-button-margin-start:0;--toast-button-margin-end:auto;--toast-close-button-start:unset;--toast-close-button-end:0;--toast-close-button-transform:translate(35%, -35%)}[data-sonner-toaster]{position:fixed;width:var(--width);font-family:ui-sans-serif,system-ui,-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica Neue,Arial,Noto Sans,sans-serif,Apple Color Emoji,Segoe UI Emoji,Segoe UI Symbol,Noto Color Emoji;--gray1:hsl(0, 0%, 99%);--gray2:hsl(0, 0%, 97.3%);--gray3:hsl(0, 0%, 95.1%);--gray4:hsl(0, 0%, 93%);--gray5:hsl(0, 0%, 90.9%);--gray6:hsl(0, 0%, 88.7%);--gray7:hsl(0, 0%, 85.8%);--gray8:hsl(0, 0%, 78%);--gray9:hsl(0, 0%, 56.1%);--gray10:hsl(0, 0%, 52.3%);--gray11:hsl(0, 0%, 43.5%);--gray12:hsl(0, 0%, 9%);--border-radius:8px;box-sizing:border-box;padding:0;margin:0;list-style:none;outline:0;z-index:999999999}[data-sonner-toaster][data-x-position=right]{right:max(var(--offset),env(safe-area-inset-right))}[data-sonner-toaster][data-x-position=left]{left:max(var(--offset),env(safe-area-inset-left))}[data-sonner-toaster][data-x-position=center]{left:50%;transform:translateX(-50%)}[data-sonner-toaster][data-y-position=top]{top:max(var(--offset),env(safe-area-inset-top))}[data-sonner-toaster][data-y-position=bottom]{bottom:max(var(--offset),env(safe-area-inset-bottom))}[data-sonner-toast]{--y:translateY(100%);--lift-amount:calc(var(--lift) * var(--gap));z-index:var(--z-index);position:absolute;opacity:0;transform:var(--y);touch-action:none;will-change:transform,opacity,height;transition:transform .4s,opacity .4s,height .4s,box-shadow .2s;box-sizing:border-box;outline:0;overflow-wrap:anywhere}[data-sonner-toast][data-styled=true]{padding:16px;background:var(--normal-bg);border:1px solid var(--normal-border);color:var(--normal-text);border-radius:var(--border-radius);box-shadow:0 4px 12px rgba(0,0,0,.1);width:var(--width);font-size:13px;display:flex;align-items:center;gap:6px}[data-sonner-toast]:focus-visible{box-shadow:0 4px 12px rgba(0,0,0,.1),0 0 0 2px rgba(0,0,0,.2)}[data-sonner-toast][data-y-position=top]{top:0;--y:translateY(-100%);--lift:1;--lift-amount:calc(1 * var(--gap))}[data-sonner-toast][data-y-position=bottom]{bottom:0;--y:translateY(100%);--lift:-1;--lift-amount:calc(var(--lift) * var(--gap))}[data-sonner-toast] [data-description]{font-weight:400;line-height:1.4;color:inherit}[data-sonner-toast] [data-title]{font-weight:500;line-height:1.5;color:inherit}[data-sonner-toast] [data-icon]{display:flex;height:16px;width:16px;position:relative;justify-content:flex-start;align-items:center;flex-shrink:0;margin-left:var(--toast-icon-margin-start);margin-right:var(--toast-icon-margin-end)}[data-sonner-toast][data-promise=true] [data-icon]>svg{opacity:0;transform:scale(.8);transform-origin:center;animation:sonner-fade-in .3s ease forwards}[data-sonner-toast] [data-icon]>*{flex-shrink:0}[data-sonner-toast] [data-icon] svg{margin-left:var(--toast-svg-margin-start);margin-right:var(--toast-svg-margin-end)}[data-sonner-toast] [data-content]{display:flex;flex-direction:column;gap:2px;transform:translateZ(0)}[data-sonner-toast] [data-button]{border-radius:4px;padding-left:8px;padding-right:8px;height:24px;font-size:12px;color:var(--normal-bg);background:var(--normal-text);margin-left:var(--toast-button-margin-start);margin-right:var(--toast-button-margin-end);border:none;cursor:pointer;outline:0;display:flex;align-items:center;flex-shrink:0;transition:opacity .4s,box-shadow .2s}[data-sonner-toast] [data-button]:focus-visible{box-shadow:0 0 0 2px rgba(0,0,0,.4)}[data-sonner-toast] [data-button]:first-of-type{margin-left:var(--toast-button-margin-start);margin-right:var(--toast-button-margin-end)}[data-sonner-toast] [data-cancel]{color:var(--normal-text);background:rgba(0,0,0,.08)}[data-sonner-toast][data-theme=dark] [data-cancel]{background:rgba(255,255,255,.3)}[data-sonner-toast] [data-close-button]{position:absolute;left:var(--toast-close-button-start);right:var(--toast-close-button-end);top:0;height:20px;width:20px;display:flex;justify-content:center;align-items:center;padding:0;background:var(--gray1);color:var(--gray12);border:1px solid var(--gray4);transform:var(--toast-close-button-transform);border-radius:50%;cursor:pointer;z-index:1;transition:opacity .1s,background .2s,border-color .2s}[data-sonner-toast] [data-close-button]:focus-visible{box-shadow:0 4px 12px rgba(0,0,0,.1),0 0 0 2px rgba(0,0,0,.2)}[data-sonner-toast] [data-disabled=true]{cursor:not-allowed}[data-sonner-toast]:hover [data-close-button]:hover{background:var(--gray2);border-color:var(--gray5)}[data-sonner-toast][data-swiping=true]:before{content:'';position:absolute;left:0;right:0;height:100%;z-index:-1}[data-sonner-toast][data-y-position=top][data-swiping=true]:before{bottom:50%;transform:scaleY(3) translateY(50%)}[data-sonner-toast][data-y-position=bottom][data-swiping=true]:before{top:50%;transform:scaleY(3) translateY(-50%)}[data-sonner-toast][data-swiping=false][data-removed=true]:before{content:'';position:absolute;inset:0;transform:scaleY(2)}[data-sonner-toast]:after{content:'';position:absolute;left:0;height:calc(var(--gap) + 1px);bottom:100%;width:100%}[data-sonner-toast][data-mounted=true]{--y:translateY(0);opacity:1}[data-sonner-toast][data-expanded=false][data-front=false]{--scale:var(--toasts-before) * 0.05 + 1;--y:translateY(calc(var(--lift-amount) * var(--toasts-before))) scale(calc(-1 * var(--scale)));height:var(--front-toast-height)}[data-sonner-toast]>*{transition:opacity .4s}[data-sonner-toast][data-expanded=false][data-front=false][data-styled=true]>*{opacity:0}[data-sonner-toast][data-visible=false]{opacity:0;pointer-events:none}[data-sonner-toast][data-mounted=true][data-expanded=true]{--y:translateY(calc(var(--lift) * var(--offset)));height:var(--initial-height)}[data-sonner-toast][data-removed=true][data-front=true][data-swipe-out=false]{--y:translateY(calc(var(--lift) * -100%));opacity:0}[data-sonner-toast][data-removed=true][data-front=false][data-swipe-out=false][data-expanded=true]{--y:translateY(calc(var(--lift) * var(--offset) + var(--lift) * -100%));opacity:0}[data-sonner-toast][data-removed=true][data-front=false][data-swipe-out=false][data-expanded=false]{--y:translateY(40%);opacity:0;transition:transform .5s,opacity .2s}[data-sonner-toast][data-removed=true][data-front=false]:before{height:calc(var(--initial-height) + 20%)}[data-sonner-toast][data-swiping=true]{transform:var(--y) translateY(var(--swipe-amount,0));transition:none}[data-sonner-toast][data-swipe-out=true][data-y-position=bottom],[data-sonner-toast][data-swipe-out=true][data-y-position=top]{animation:swipe-out .2s ease-out forwards}@keyframes swipe-out{from{transform:translateY(calc(var(--lift) * var(--offset) + var(--swipe-amount)));opacity:1}to{transform:translateY(calc(var(--lift) * var(--offset) + var(--swipe-amount) + var(--lift) * -100%));opacity:0}}@media (max-width:600px){[data-sonner-toaster]{position:fixed;--mobile-offset:16px;right:var(--mobile-offset);left:var(--mobile-offset);width:100%}[data-sonner-toaster] [data-sonner-toast]{left:0;right:0;width:calc(100% - 32px)}[data-sonner-toaster][data-x-position=left]{left:var(--mobile-offset)}[data-sonner-toaster][data-y-position=bottom]{bottom:20px}[data-sonner-toaster][data-y-position=top]{top:20px}[data-sonner-toaster][data-x-position=center]{left:var(--mobile-offset);right:var(--mobile-offset);transform:none}}[data-sonner-toaster][data-theme=light]{--normal-bg:#fff;--normal-border:var(--gray4);--normal-text:var(--gray12);--success-bg:hsl(143, 85%, 96%);--success-border:hsl(145, 92%, 91%);--success-text:hsl(140, 100%, 27%);--info-bg:hsl(208, 100%, 97%);--info-border:hsl(221, 91%, 91%);--info-text:hsl(210, 92%, 45%);--warning-bg:hsl(49, 100%, 97%);--warning-border:hsl(49, 91%, 91%);--warning-text:hsl(31, 92%, 45%);--error-bg:hsl(359, 100%, 97%);--error-border:hsl(359, 100%, 94%);--error-text:hsl(360, 100%, 45%)}[data-sonner-toaster][data-theme=light] [data-sonner-toast][data-invert=true]{--normal-bg:#000;--normal-border:hsl(0, 0%, 20%);--normal-text:var(--gray1)}[data-sonner-toaster][data-theme=dark] [data-sonner-toast][data-invert=true]{--normal-bg:#fff;--normal-border:var(--gray3);--normal-text:var(--gray12)}[data-sonner-toaster][data-theme=dark]{--normal-bg:#000;--normal-border:hsl(0, 0%, 20%);--normal-text:var(--gray1);--success-bg:hsl(150, 100%, 6%);--success-border:hsl(147, 100%, 12%);--success-text:hsl(150, 86%, 65%);--info-bg:hsl(215, 100%, 6%);--info-border:hsl(223, 100%, 12%);--info-text:hsl(216, 87%, 65%);--warning-bg:hsl(64, 100%, 6%);--warning-border:hsl(60, 100%, 12%);--warning-text:hsl(46, 87%, 65%);--error-bg:hsl(358, 76%, 10%);--error-border:hsl(357, 89%, 16%);--error-text:hsl(358, 100%, 81%)}[data-rich-colors=true] [data-sonner-toast][data-type=success]{background:var(--success-bg);border-color:var(--success-border);color:var(--success-text)}[data-rich-colors=true] [data-sonner-toast][data-type=success] [data-close-button]{background:var(--success-bg);border-color:var(--success-border);color:var(--success-text)}[data-rich-colors=true] [data-sonner-toast][data-type=info]{background:var(--info-bg);border-color:var(--info-border);color:var(--info-text)}[data-rich-colors=true] [data-sonner-toast][data-type=info] [data-close-button]{background:var(--info-bg);border-color:var(--info-border);color:var(--info-text)}[data-rich-colors=true] [data-sonner-toast][data-type=warning]{background:var(--warning-bg);border-color:var(--warning-border);color:var(--warning-text)}[data-rich-colors=true] [data-sonner-toast][data-type=warning] [data-close-button]{background:var(--warning-bg);border-color:var(--warning-border);color:var(--warning-text)}[data-rich-colors=true] [data-sonner-toast][data-type=error]{background:var(--error-bg);border-color:var(--error-border);color:var(--error-text)}[data-rich-colors=true] [data-sonner-toast][data-type=error] [data-close-button]{background:var(--error-bg);border-color:var(--error-border);color:var(--error-text)}.sonner-loading-wrapper{--size:16px;height:var(--size);width:var(--size);position:absolute;inset:0;z-index:10}.sonner-loading-wrapper[data-visible=false]{transform-origin:center;animation:sonner-fade-out .2s ease forwards}.sonner-spinner{position:relative;top:50%;left:50%;height:var(--size);width:var(--size)}.sonner-loading-bar{animation:sonner-spin 1.2s linear infinite;background:var(--gray11);border-radius:6px;height:8%;left:-10%;position:absolute;top:-3.9%;width:24%}.sonner-loading-bar:first-child{animation-delay:-1.2s;transform:rotate(.0001deg) translate(146%)}.sonner-loading-bar:nth-child(2){animation-delay:-1.1s;transform:rotate(30deg) translate(146%)}.sonner-loading-bar:nth-child(3){animation-delay:-1s;transform:rotate(60deg) translate(146%)}.sonner-loading-bar:nth-child(4){animation-delay:-.9s;transform:rotate(90deg) translate(146%)}.sonner-loading-bar:nth-child(5){animation-delay:-.8s;transform:rotate(120deg) translate(146%)}.sonner-loading-bar:nth-child(6){animation-delay:-.7s;transform:rotate(150deg) translate(146%)}.sonner-loading-bar:nth-child(7){animation-delay:-.6s;transform:rotate(180deg) translate(146%)}.sonner-loading-bar:nth-child(8){animation-delay:-.5s;transform:rotate(210deg) translate(146%)}.sonner-loading-bar:nth-child(9){animation-delay:-.4s;transform:rotate(240deg) translate(146%)}.sonner-loading-bar:nth-child(10){animation-delay:-.3s;transform:rotate(270deg) translate(146%)}.sonner-loading-bar:nth-child(11){animation-delay:-.2s;transform:rotate(300deg) translate(146%)}.sonner-loading-bar:nth-child(12){animation-delay:-.1s;transform:rotate(330deg) translate(146%)}@keyframes sonner-fade-in{0%{opacity:0;transform:scale(.8)}100%{opacity:1;transform:scale(1)}}@keyframes sonner-fade-out{0%{opacity:1;transform:scale(1)}100%{opacity:0;transform:scale(.8)}}@keyframes sonner-spin{0%{opacity:1}100%{opacity:.15}}@media (prefers-reduced-motion){.sonner-loading-bar,[data-sonner-toast],[data-sonner-toast]>*{transition:none!important;animation:none!important}}.sonner-loader{position:absolute;top:50%;left:50%;transform:translate(-50%,-50%);transform-origin:center;transition:opacity .2s,transform .2s}.sonner-loader[data-visible=false]{opacity:0;transform:scale(.8) translate(-50%,-50%)}")
;let ZX=0;const QX=new class{constructor(){
FX(this,"subscribers"),FX(this,"toasts"),
FX(this,"subscribe",(e=>(this.subscribers.push(e),()=>{
const t=this.subscribers.indexOf(e);this.subscribers.splice(t,1)
}))),FX(this,"publish",(e=>{this.subscribers.forEach((t=>t(e)))
})),FX(this,"addToast",(e=>{this.publish(e),this.toasts=[...this.toasts,e]
})),FX(this,"create",(e=>{var t
;const{message:n,...r}=e,o="number"==typeof e.id||e.id&&(null==(t=e.id)?void 0:t.length)>0?e.id:ZX++,a=this.toasts.find((e=>e.id===o)),i=void 0===e.dismissible||e.dismissible
;return a?this.toasts=this.toasts.map((t=>t.id===o?(this.publish({...t,...e,
id:o,title:n}),{...t,...e,id:o,dismissible:i,title:n}):t)):this.addToast({
title:n,...r,dismissible:i,id:o}),o
})),FX(this,"dismiss",(e=>(e||this.toasts.forEach((e=>{
this.subscribers.forEach((t=>t({id:e.id,dismiss:!0})))
})),this.subscribers.forEach((t=>t({id:e,dismiss:!0
}))),e))),FX(this,"message",((e,t)=>this.create({...t,message:e,type:"default"
}))),FX(this,"error",((e,t)=>this.create({...t,type:"error",message:e
}))),FX(this,"success",((e,t)=>this.create({...t,type:"success",message:e
}))),FX(this,"info",((e,t)=>this.create({...t,type:"info",message:e
}))),FX(this,"warning",((e,t)=>this.create({...t,type:"warning",message:e
}))),FX(this,"loading",((e,t)=>this.create({...t,type:"loading",message:e
}))),FX(this,"promise",((e,t)=>{if(!t)return;let n
;void 0!==t.loading&&(n=this.create({...t,promise:e,type:"loading",
message:t.loading,
description:"function"!=typeof t.description?t.description:void 0}))
;const r=e instanceof Promise?e:e();let o=void 0!==n;return r.then((e=>{
if(e&&"boolean"==typeof e.ok&&!e.ok){o=!1
;const e="function"==typeof t.error?t.error(`HTTP error! status: ${response.status}`):t.error,r="function"==typeof t.description?t.description(`HTTP error! status: ${response.status}`):t.description
;this.create({id:n,type:"error",message:e,description:r})
}else if(void 0!==t.success){o=!1
;const r="function"==typeof t.success?t.success(e):t.success,a="function"==typeof t.description?t.description(e):t.description
;this.create({id:n,type:"success",message:r,description:a})}})).catch((e=>{
if(void 0!==t.error){o=!1
;const r="function"==typeof t.error?t.error(e):t.error,a="function"==typeof t.description?t.description(e):t.description
;this.create({id:n,type:"error",message:r,description:a})}})).finally((()=>{
var e;o&&(this.dismiss(n),n=void 0),null==(e=t.finally)||e.call(t)})),n
})),FX(this,"custom",((e,t)=>{const n=(null==t?void 0:t.id)||ZX++
;return this.publish({component:e,id:n,...t}),n
})),this.subscribers=[],this.toasts=[]}},HX=(e,t)=>{
const n=(null==t?void 0:t.id)||ZX++;return QX.create({message:e,id:n,
type:"default",...t}),n},VX=Object.assign(HX,{success:QX.success,info:QX.info,
warning:QX.warning,error:QX.error,custom:QX.custom,message:QX.message,
promise:QX.promise,dismiss:QX.dismiss,loading:QX.loading}),qX=(e,t)=>{
const n=e.__vccOpts||e;for(const[r,o]of t)n[r]=o;return n},WX={},XX={
xmlns:"http://www.w3.org/2000/svg",width:"12",height:"12",viewBox:"0 0 24 24",
fill:"none",stroke:"currentColor","stoke-width":"1.5","stroke-linecap":"round",
"stroke-linejoin":"round"},GX=[Gb("line",{x1:"18",y1:"6",x2:"6",y2:"18"
},null,-1),Gb("line",{x1:"6",y1:"6",x2:"18",y2:"18"},null,-1)]
;const YX=qX(WX,[["render",function(e,t){return Ub(),Qb("svg",XX,GX)
}]]),KX=["aria-live","data-styled","data-mounted","data-promise","data-removed","data-visible","data-y-position","data-x-position","data-index","data-front","data-swiping","data-dismissible","data-type","data-invert","data-swipe-out","data-expanded"],JX=["aria-label","data-disabled"],eG={
key:0,"data-icon":""},tG={"data-content":""},nG=Qg({__name:"Toast",props:{
toast:{},toasts:{},index:{},expanded:{type:Boolean},invert:{type:Boolean},
heights:{},gap:{},position:{},visibleToasts:{},expandByDefault:{type:Boolean},
closeButton:{type:Boolean},interacting:{type:Boolean},duration:{},
descriptionClass:{},style:{},cancelButtonStyle:{},actionButtonStyle:{},
unstyled:{type:Boolean},loadingIcon:{},class:{},classes:{},icons:{},
closeButtonAriaLabel:{},pauseWhenPageIsHidden:{type:Boolean},cn:{type:Function}
},emits:["update:heights","removeToast"],setup(e,{emit:t}){
const n=t,r=e,o=bm(!1),a=bm(!1),i=bm(!1),s=bm(!1),l=bm(0),c=bm(0),u=bm(null),d=bm(null),p=Sy((()=>0===r.index)),h=Sy((()=>r.index+1<=r.visibleToasts)),f=Sy((()=>r.toast.type)),m=Sy((()=>!1!==r.toast.dismissible)),g=Sy((()=>{
var e,t,n,o,a,i,s
;return r.cn(null==(e=r.classes)?void 0:e.toast,null==(n=null==(t=r.toast)?void 0:t.classes)?void 0:n.toast,null==(o=r.classes)?void 0:o.default,null==(a=r.classes)?void 0:a[r.toast.type||"default"],null==(s=null==(i=r.toast)?void 0:i.classes)?void 0:s[r.toast.type||"default"])
})),v=r.toast.style||{},b=Sy((()=>r.heights.findIndex((e=>e.toastId===r.toast.id))||0)),y=Sy((()=>r.toast.closeButton??r.closeButton)),O=Sy((()=>r.toast.duration||r.duration||4e3)),w=bm(0),x=bm(0),k=bm(O.value),S=bm(0),_=bm(null),T=Sy((()=>r.position.split("-"))),E=Sy((()=>T.value[0])),A=Sy((()=>T.value[1])),C="string"!=typeof r.toast.title,$="string"!=typeof r.toast.description,P=Sy((()=>r.heights.reduce(((e,t,n)=>n>=b.value?e:e+t.height),0))),D=(()=>{
const e=bm(!1);return fg((()=>{const t=()=>{e.value=document.hidden}
;return document.addEventListener("visibilitychange",t),
()=>window.removeEventListener("visibilitychange",t)})),{isDocumentHidden:e}
})(),I=Sy((()=>r.toast.invert||r.invert)),M=Sy((()=>"loading"===f.value))
;iv((()=>{if(!o.value)return;const e=d.value,t=null==e?void 0:e.style.height
;e.style.height="auto";const a=e.getBoundingClientRect().height;let i
;e.style.height=t,
c.value=a,i=r.heights.find((e=>e.toastId===r.toast.id))?r.heights.map((e=>e.toastId===r.toast.id?{
...e,height:a}:e)):[{toastId:r.toast.id,height:a,position:r.toast.position
},...r.heights],n("update:heights",i)}));const N=()=>{a.value=!0,l.value=x.value
;const e=r.heights.filter((e=>e.toastId!==r.toast.id))
;n("update:heights",e),setTimeout((()=>{n("removeToast",r.toast)}),200)},R=()=>{
var e,t
;M.value||!m.value||(N(),null==(t=(e=r.toast).onDismiss)||t.call(e,r.toast))
},L=e=>{
M.value||!m.value||(u.value=new Date,l.value=x.value,e.target.setPointerCapture(e.pointerId),
"BUTTON"!==e.target.tagName&&(i.value=!0,_.value={x:e.clientX,y:e.clientY}))
},B=e=>{var t,n,o,a;if(s.value)return;_.value=null
;const c=Number((null==(t=d.value)?void 0:t.style.getPropertyValue("--swipe-amount").replace("px",""))||0),p=(new Date).getTime()-u.value.getTime(),h=Math.abs(c)/p
;if(Math.abs(c)>=20||h>.11)return l.value=x.value,
null==(o=(n=r.toast).onDismiss)||o.call(n,r.toast),N(),void(s.value=!0)
;null==(a=d.value)||a.style.setProperty("--swipe-amount","0px"),i.value=!1
},j=e=>{var t;if(!_.value)return
;const n=e.clientY-_.value.y,r=e.clientX-_.value.x,o=("top"===T.value[0]?Math.min:Math.max)(0,n),a="touch"===e.pointerType?10:2
;Math.abs(o)>a?null==(t=d.value)||t.style.setProperty("--swipe-amount",`${n}px`):Math.abs(r)>a&&(_.value=null)
};return fg((()=>{x.value=14*b.value+P.value})),fg((e=>{
if(r.toast.promise&&"loading"===f.value||r.toast.duration===1/0||"loading"===r.toast.type)return
;let t;r.expanded||r.interacting||r.pauseWhenPageIsHidden&&D?(()=>{
if(S.value<w.value){const e=(new Date).getTime()-w.value;k.value=k.value-e}
S.value=(new Date).getTime()
})():(w.value=(new Date).getTime(),t=setTimeout((()=>{var e,t
;null==(t=(e=r.toast).onAutoClose)||t.call(e,r.toast),N()}),k.value)),e((()=>{
clearTimeout(t)}))})),fg((()=>{r.toast.delete&&N()})),iv((()=>{if(d.value){
const e=d.value.getBoundingClientRect().height;c.value=e;const t=[{
toastId:r.toast.id,height:e,position:r.toast.position},...r.heights]
;n("update:heights",t)}o.value=!0})),uv((()=>{if(d.value){
const e=r.heights.filter((e=>e.toastId!==r.toast.id));n("update:heights",e)}})),
(e,t)=>{var n,r,u,b,O,w,k,S,_,T,P,D;return Ub(),Qb("li",{
"aria-live":e.toast.important?"assertive":"polite","aria-atomic":"true",
role:"status",tabindex:"0",ref_key:"toastRef",ref:d,"data-sonner-toast":"",
class:Ih(g.value),
"data-styled":!(e.toast.component||null!=(n=e.toast)&&n.unstyled||e.unstyled),
"data-mounted":o.value,"data-promise":!!e.toast.promise,"data-removed":a.value,
"data-visible":h.value,"data-y-position":E.value,"data-x-position":A.value,
"data-index":e.index,"data-front":p.value,"data-swiping":i.value,
"data-dismissible":m.value,"data-type":f.value,"data-invert":I.value,
"data-swipe-out":s.value,
"data-expanded":!!(e.expanded||e.expandByDefault&&o.value),style:Ah({
"--index":e.index,"--toasts-before":e.index,"--z-index":e.toasts.length-e.index,
"--offset":`${a.value?l.value:x.value}px`,
"--initial-height":e.expandByDefault?"auto":`${c.value}px`,...e.style,...xm(v)
}),onPointerdown:L,onPointerup:B,onPointermove:j
},[y.value&&!e.toast.component?(Ub(),Qb("button",{key:0,
"aria-label":e.closeButtonAriaLabel||"Close toast","data-disabled":M.value,
"data-close-button":"",
class:Ih(e.cn(null==(r=e.classes)?void 0:r.closeButton,null==(b=null==(u=e.toast)?void 0:u.classes)?void 0:b.closeButton)),
onClick:R
},[Yb(YX)],10,JX)):ny("",!0),e.toast.component?(Ub(),Hb(bv(e.toast.component),iy({
key:1},e.toast.componentProps,{onCloseToast:N}),null,16)):(Ub(),Qb(Mb,{key:2
},["default"!==f.value||e.toast.icon||e.toast.promise?(Ub(),
Qb("div",eG,[!e.toast.promise&&"loading"!==f.value||e.toast.icon?ny("",!0):kv(e.$slots,"loading-icon",{
key:0}),e.toast.icon?(Ub(),Hb(bv(e.toast.icon),{key:1})):(Ub(),Qb(Mb,{key:2
},["success"===f.value?kv(e.$slots,"success-icon",{key:0
}):"error"===f.value?kv(e.$slots,"error-icon",{key:1
}):"warning"===f.value?kv(e.$slots,"warning-icon",{key:2
}):"info"===f.value?kv(e.$slots,"info-icon",{key:3
}):ny("",!0)],64))])):ny("",!0),Gb("div",tG,[Gb("div",{"data-title":"",
class:Ih(e.cn(null==(O=e.classes)?void 0:O.title,null==(w=e.toast.classes)?void 0:w.title))
},[C?(Ub(),Hb(bv(e.toast.title),Mh(iy({key:0
},e.toast.componentProps)),null,16)):(Ub(),Qb(Mb,{key:1
},[ey(Uh(e.toast.title),1)],64))],2),e.toast.description?(Ub(),Qb("div",{key:0,
"data-description":"",
class:Ih(e.cn(e.descriptionClass,e.toast.descriptionClass,null==(k=e.classes)?void 0:k.description,null==(S=e.toast.classes)?void 0:S.description))
},[$?(Ub(),Hb(bv(e.toast.description),Mh(iy({key:0
},e.toast.componentProps)),null,16)):(Ub(),Qb(Mb,{key:1
},[ey(Uh(e.toast.description),1)],64))],2)):ny("",!0)]),e.toast.cancel?(Ub(),
Qb("button",{key:1,
class:Ih(e.cn(null==(_=e.classes)?void 0:_.cancelButton,null==(T=e.toast.classes)?void 0:T.cancelButton)),
"data-button":"","data-cancel":"",onClick:t[0]||(t[0]=()=>{var t
;N(),null!=(t=e.toast.cancel)&&t.onClick&&e.toast.cancel.onClick()})
},Uh(e.toast.cancel.label),3)):ny("",!0),e.toast.action?(Ub(),Qb("button",{
key:2,
class:Ih(e.cn(null==(P=e.classes)?void 0:P.actionButton,null==(D=e.toast.classes)?void 0:D.actionButton)),
"data-button":"",onClick:t[1]||(t[1]=t=>{var n
;null==(n=e.toast.action)||n.onClick(t),!t.defaultPrevented&&N()})
},Uh(e.toast.action.label),3)):ny("",!0)],64))],46,KX)}}
}),rG=["data-visible"],oG={class:"sonner-spinner"},aG=Qg({__name:"Loader",
props:{visible:{type:Boolean}},setup(e){const t=Array(12).fill(0)
;return(e,n)=>(Ub(),Qb("div",{class:"sonner-loading-wrapper",
"data-visible":e.visible
},[Gb("div",oG,[(Ub(!0),Qb(Mb,null,wv(xm(t),(e=>(Ub(),Qb("div",{
key:`spinner-bar-${e}`,class:"sonner-loading-bar"})))),128))])],8,rG))}
}),iG={},sG={xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 20 20",
fill:"currentColor",height:"20",width:"20"},lG=[Gb("path",{
"fill-rule":"evenodd",
d:"M10 18a8 8 0 100-16 8 8 0 000 16zm3.857-9.809a.75.75 0 00-1.214-.882l-3.483 4.79-1.88-1.88a.75.75 0 10-1.06 1.061l2.5 2.5a.75.75 0 001.137-.089l4-5.5z",
"clip-rule":"evenodd"},null,-1)];const cG=qX(iG,[["render",function(e,t){
return Ub(),Qb("svg",sG,lG)}]]),uG={},dG={xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 20 20",fill:"currentColor",height:"20",width:"20"},pG=[Gb("path",{
"fill-rule":"evenodd",
d:"M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-7-4a1 1 0 11-2 0 1 1 0 012 0zM9 9a.75.75 0 000 1.5h.253a.25.25 0 01.244.304l-.459 2.066A1.75 1.75 0 0010.747 15H11a.75.75 0 000-1.5h-.253a.25.25 0 01-.244-.304l.459-2.066A1.75 1.75 0 009.253 9H9z",
"clip-rule":"evenodd"},null,-1)];const hG=qX(uG,[["render",function(e,t){
return Ub(),Qb("svg",dG,pG)}]]),fG={},mG={xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 24 24",fill:"currentColor",height:"20",width:"20"},gG=[Gb("path",{
"fill-rule":"evenodd",
d:"M9.401 3.003c1.155-2 4.043-2 5.197 0l7.355 12.748c1.154 2-.29 4.5-2.599 4.5H4.645c-2.309 0-3.752-2.5-2.598-4.5L9.4 3.003zM12 8.25a.75.75 0 01.75.75v3.75a.75.75 0 01-1.5 0V9a.75.75 0 01.75-.75zm0 8.25a.75.75 0 100-1.5.75.75 0 000 1.5z",
"clip-rule":"evenodd"},null,-1)];const vG=qX(fG,[["render",function(e,t){
return Ub(),Qb("svg",mG,gG)}]]),bG={},yG={xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 20 20",fill:"currentColor",height:"20",width:"20"},OG=[Gb("path",{
"fill-rule":"evenodd",
d:"M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-8-5a.75.75 0 01.75.75v4.5a.75.75 0 01-1.5 0v-4.5A.75.75 0 0110 5zm0 10a1 1 0 100-2 1 1 0 000 2z",
"clip-rule":"evenodd"},null,-1)];const wG=qX(bG,[["render",function(e,t){
return Ub(),Qb("svg",yG,OG)
}]]),xG=["aria-label"],kG=["dir","data-theme","data-rich-colors","data-y-position","data-x-position"],SG="32px",_G=typeof window<"u"&&typeof document<"u",TG=Qg({
name:"Toaster",inheritAttrs:!1,__name:"Toaster",props:{invert:{type:Boolean,
default:!1},theme:{default:"light"},position:{default:"bottom-right"},hotkey:{
default:()=>["altKey","KeyT"]},richColors:{type:Boolean,default:!1},expand:{
type:Boolean,default:!1},duration:{default:4e3},gap:{default:14},visibleToasts:{
default:3},closeButton:{type:Boolean,default:!1},toastOptions:{default:()=>({})
},class:{default:""},style:{default:()=>({})},offset:{default:SG},dir:{
default:"auto"},icons:{},containerAriaLabel:{default:"Notifications"},
pauseWhenPageIsHidden:{type:Boolean,default:!1},cn:{}},setup(e){
function t(...e){return e.filter(Boolean).join(" ")}function n(){
if(typeof window>"u"||typeof document>"u")return"ltr"
;const e=document.documentElement.getAttribute("dir")
;return"auto"!==e&&e?e:window.getComputedStyle(document.documentElement).direction
}const r=e,o=Pv(),a=bm([]),i=Sy((()=>{
const e=a.value.filter((e=>e.position)).map((e=>e.position))
;return e.length>0?Array.from(new Set([r.position].concat(e))):[r.position]
})),s=bm([]),l=bm(!1),c=bm(!1),u=bm("system"!==r.theme?r.theme:typeof window<"u"&&window.matchMedia&&window.matchMedia("(prefers-color-scheme: dark)").matches?"dark":"light"),d=Sy((()=>r.cn||t)),p=bm(null),h=bm(null),f=bm(!1),m=r.hotkey.join("+").replace(/Key/g,"").replace(/Digit/g,"")
;function g(e){a.value=a.value.filter((({id:t})=>t!==e.id))}const v=e=>{var t,n
;f.value&&(null==(n=null==(t=e.currentTarget)?void 0:t.contains)||!n.call(t,e.relatedTarget))&&(f.value=!1,
h.value&&(h.value.focus({preventScroll:!0}),h.value=null))},b=e=>{
e.target instanceof HTMLElement&&"false"===e.target.dataset.dismissible||f.value||(f.value=!0,
h.value=e.relatedTarget)},y=e=>{
e.target&&e.target instanceof HTMLElement&&"false"===e.target.dataset.dismissible||(c.value=!1)
};return fg((e=>{const t=QX.subscribe((e=>{
e.dismiss?a.value=a.value.map((t=>t.id===e.id?{...t,delete:!0}:t)):Xm((()=>{
const t=a.value.findIndex((t=>t.id===e.id))
;-1!==t?a.value.splice(t,1,e):a.value=[e,...a.value]}))}));e((()=>{t()}))
})),mg((()=>r.theme),(e=>{
"system"===e?("system"===e&&(window.matchMedia&&window.matchMedia("(prefers-color-scheme: dark)").matches?u.value="dark":u.value="light"),
!(typeof window>"u")&&window.matchMedia("(prefers-color-scheme: dark)").addEventListener("change",(({matches:e})=>{
u.value=e?"dark":"light"}))):u.value=e})),mg((()=>p.value),(()=>{
if(p.value)return()=>{h.value&&(h.value.focus({preventScroll:!0
}),h.value=null,f.value=!1)}})),fg((()=>{a.value.length<=1&&(l.value=!1)
})),fg((e=>{function t(e){
const t=r.hotkey.every((t=>e[t]||e.code===t)),n=Array.isArray(p.value)?p.value[0]:p.value
;t&&(l.value=!0,null==n||n.focus())
;const o=document.activeElement===p.value||(null==n?void 0:n.contains(document.activeElement))
;"Escape"===e.code&&o&&(l.value=!1)}_G&&(document.addEventListener("keydown",t),
e((()=>{document.removeEventListener("keydown",t)})))
})),(e,t)=>(Ub(),Qb("section",{"aria-label":`${e.containerAriaLabel} ${xm(m)}`,
tabIndex:-1},[(Ub(!0),Qb(Mb,null,wv(i.value,((r,i)=>{var u
;return Ub(),Qb("ol",iy({key:r,ref_for:!0,ref_key:"listRef",ref:p,
"data-sonner-toaster":"",class:e.class,dir:"auto"===e.dir?n():e.dir,tabIndex:-1,
"data-theme":e.theme,"data-rich-colors":e.richColors,
"data-y-position":r.split("-")[0],"data-x-position":r.split("-")[1],style:{
"--front-toast-height":`${null==(u=s.value[0])?void 0:u.height}px`,
"--offset":"number"==typeof e.offset?`${e.offset}px`:e.offset||SG,
"--width":"356px","--gap":"14px",...e.style,...xm(o).style},onBlur:v,onFocus:b,
onMouseenter:t[1]||(t[1]=e=>l.value=!0),onMousemove:t[2]||(t[2]=e=>l.value=!0),
onMouseleave:t[3]||(t[3]=()=>{c.value||(l.value=!1)}),onPointerdown:y,
onPointerup:t[4]||(t[4]=e=>c.value=!1)
},e.$attrs),[(Ub(!0),Qb(Mb,null,wv(a.value.filter((t=>!t.position&&0===i||t.position===e.position)),((n,r)=>{
var o,i,u,p,h,f,m,v,b;return Ub(),Hb(nG,{key:n.id,index:r,toast:n,
duration:(null==(o=e.toastOptions)?void 0:o.duration)??e.duration,
class:Ih(null==(i=e.toastOptions)?void 0:i.class),
descriptionClass:null==(u=e.toastOptions)?void 0:u.descriptionClass,
invert:e.invert,visibleToasts:e.visibleToasts,
closeButton:(null==(p=e.toastOptions)?void 0:p.closeButton)??e.closeButton,
interacting:c.value,position:e.position,
style:Ah(null==(h=e.toastOptions)?void 0:h.style),
unstyled:null==(f=e.toastOptions)?void 0:f.unstyled,
classes:null==(m=e.toastOptions)?void 0:m.classes,
cancelButtonStyle:null==(v=e.toastOptions)?void 0:v.cancelButtonStyle,
actionButtonStyle:null==(b=e.toastOptions)?void 0:b.actionButtonStyle,
toasts:a.value,expandByDefault:e.expand,gap:e.gap,expanded:l.value,
pauseWhenPageIsHidden:e.pauseWhenPageIsHidden,cn:d.value,heights:s.value,
"onUpdate:heights":t[0]||(t[0]=e=>s.value=e),onRemoveToast:g},{
"loading-icon":ig((()=>[kv(e.$slots,"loading-icon",{},(()=>[Yb(aG,{
visible:"loading"===n.type},null,8,["visible"])]))])),
"success-icon":ig((()=>[kv(e.$slots,"success-icon",{},(()=>[Yb(cG)]))])),
"error-icon":ig((()=>[kv(e.$slots,"error-icon",{},(()=>[Yb(wG)]))])),
"warning-icon":ig((()=>[kv(e.$slots,"warning-icon",{},(()=>[Yb(vG)]))])),
"info-icon":ig((()=>[kv(e.$slots,"info-icon",{},(()=>[Yb(hG)]))])),_:2
},1032,["index","toast","duration","class","descriptionClass","invert","visibleToasts","closeButton","interacting","position","style","unstyled","classes","cancelButtonStyle","actionButtonStyle","toasts","expandByDefault","gap","expanded","pauseWhenPageIsHidden","cn","heights"])
})),128))],16,kG)})),128))],8,xG))}}),EG={toast:()=>null};function AG(e){
EG.toast=e}function CG(){return{initializeToasts:AG,toast:(e,t="info",n={
timeout:3e3})=>{EG.toast(e,t,n)}}}const $G=Qg({__name:"ScalarToasts",setup(e){
const t=bm(!1);iv((()=>t.value=!0));const n={success:VX.success,error:VX.error,
warn:VX.warning,info:VX},{initializeToasts:r}=CG()
;return r(((e,t="info",r={})=>{(n[t]||n.info)(e,{duration:r.timeout||3e3,
description:r.description})})),(e,n)=>t.value?(Ub(),Hb(xm(TG),{key:0,
class:"scalar-toaster"})):ny("",!0)}});!function(){try{if(typeof document<"u"){
var e=document.createElement("style")
;e.appendChild(document.createTextNode(".scalar-toaster [data-sonner-toast][data-styled=true]{background:var(--scalar-background-1);color:var(--scalar-color-1);padding:18px;border:none;border-radius:var(--scalar-radius-lg);font-size:var(--scalar-font-size-3);font-weight:var(--scalar-font-medium);box-shadow:var(--scalar-shadow-2)}.scalar-toaster [data-sonner-toast] [data-icon]{align-self:flex-start;position:relative;top:2px}.scalar-toaster [data-sonner-toast][data-styled=true][data-expanded=true]{height:auto}.scalar-toaster [data-sonner-toast][data-type=error]{background:var(--scalar-background-1)}.scalar-toaster [data-sonner-toast][data-type=error] [data-icon]{color:color-mix(in srgb,var(--scalar-color-red) 75%,var(--scalar-color-1))}.scalar-toaster [data-sonner-toast][data-type=warning]{background:var(--scalar-background-1)}.scalar-toaster [data-sonner-toast][data-type=warning] [data-icon]{color:color-mix(in srgb,var(--scalar-color-orange) 90%,var(--scalar-color-1))}")),
document.head.appendChild(e)}}catch(Kw){
console.error("vite-plugin-css-injected-by-js",Kw)}}();function PG(e={}){
const{notify:t=e=>n(e,"info")}=e,{toast:n}=CG();return{
copyToClipboard:async function(e){try{
const n=(e=>void 0===e?"undefined":"string"==typeof e?e:JSON.stringify(e))(e)
;await navigator.clipboard.writeText(n),t("Copied to the clipboard")}catch(Bw){
const n=Bw;console.error(n.message),t("Failed to copy to clipboard")}}}}
const DG={key:0,class:"sr-only",role:"alert"},IG=Qg({
__name:"ScalarCodeBlockCopy",props:{content:{},controls:{},class:{}},setup(e){
const{copyToClipboard:t}=PG(),n=bm(!1),r=async()=>{if(n.value)return
;const r="string"==typeof e.content?e.content:JSON.stringify(e.content,null,2)
;await t(r),n.value=!0,setTimeout((()=>{n.value=!1}),1200)},o=jS({
base:"absolute top-0 right-0 h-8 w-8 p-0 flex items-center justify-center brightness-lifted bg-inherit rounded focus-visible:opacity-100 -outline-offset-1",
variants:{showCopied:{true:"text-c-1",false:"text-c-3 hover:text-c-1"}}})
;return(t,a)=>(Ub(),Qb("div",{
class:Ih(xm(US)("scalar-code-copy opacity-0 group-hover/code-block:opacity-100 sticky flex inset-0 justify-end items-start bg-inherit",e.class))
},[Yb(xm(WS),{"aria-controls":e.controls,"aria-label":"Copy",
class:Ih(xm(US)(xm(o)({showCopied:n.value}))),type:"button",variant:"ghost",
onClick:r},{default:ig((()=>[Yb(xm(dT),{class:Ih(["copy-icon size-4",{
copied:n.value}])},null,8,["class"]),Yb(xm(oT),{class:Ih(["check-icon size-4",{
visible:n.value}])},null,8,["class"])])),_:1
},8,["aria-controls","class"]),n.value?(Ub(),
Qb("div",DG," Copied ")):ny("",!0)],2))}
}),MG=HS(IG,[["__scopeId","data-v-e1870266"]]),NG={
class:"scalar-code-block group/code-block custom-scroll min-h-12 focus-visible:outline",
tabindex:"0"},RG=["id","innerHTML"],LG=Qg({__name:"ScalarCodeBlock",props:{
content:{},prettyPrintedContent:{},lang:{default:"plaintext"},lineNumbers:{
type:Boolean,default:!1},hideCredentials:{},copy:{type:Boolean,default:!0}},
setup(e){
const t=Hg(),n=Sy((()=>e.prettyPrintedContent||LX(e.content??""))),r=Sy((()=>uj(n.value,{
lang:e.lang.trim(),languages:hj,lineNumbers:e.lineNumbers,
maskCredentials:e.hideCredentials
}).slice(5,-6))),o=Sy((()=>null!==n.value&&"null"!==n.value&&"404 Not Found"!==n.value))
;return(a,i)=>(Ub(),Qb("div",NG,[e.copy&&o.value?(Ub(),Hb(xm(MG),{key:0,
content:n.value,controls:xm(t)
},null,8,["content","controls"])):ny("",!0),Gb("pre",{id:xm(t),
class:"scalar-codeblock-pre",innerHTML:r.value},null,8,RG)]))}
}),BG=bm("dark"),jG=cu(["dark","light","system"]).optional().catch(void 0)
;function UG(e={}){const{initialColorMode:t="system",overrideColorMode:n}=e
;function r(e){
BG.value=e,"undefined"!=typeof window&&window?.localStorage?.setItem("colorMode",BG.value)
}function o(){
return"undefined"==typeof window?"light":"function"!=typeof window?.matchMedia||window?.matchMedia("(prefers-color-scheme: dark)")?.matches?"dark":"light"
}const a=Sy({get:()=>"system"===BG.value?o():BG.value,set:r}),i=Sy({
get:()=>"dark"===a.value,set:e=>r(e?"dark":"light")});function s(e){
if("undefined"==typeof document||"undefined"==typeof window)return
;"dark"===(n??("system"===e?o():e))?(document.body.classList.add("dark-mode"),
document.body.classList.remove("light-mode")):(document.body.classList.add("light-mode"),
document.body.classList.remove("dark-mode"))}
const l=jG.parse("undefined"!=typeof window?window?.localStorage?.getItem("colorMode"):"system")
;BG.value=n??l??t,mg(BG,s,{immediate:!0})
;const c=()=>"system"===BG.value&&s("system"),u=bm(null);return iv((()=>{
"undefined"!=typeof window&&"function"==typeof window?.matchMedia&&(u.value=window.matchMedia("(prefers-color-scheme: dark)"),
u.value?.addEventListener("change",c))})),uv((()=>{
u.value?.removeEventListener("change",c)})),{colorMode:Sy({get:()=>BG.value,
set:r}),darkLightMode:a,isDarkMode:i,toggleColorMode:function(){
BG.value="dark"===a.value?"light":"dark",
"undefined"!=typeof window&&window?.localStorage?.setItem("colorMode",BG.value)
},setColorMode:r,getSystemModePreference:o}}const zG=Qg({inheritAttrs:!1,
__name:"ScalarColorModeToggleIcon",props:{is:{default:"button"},mode:{
default:"light"}},setup(e){
const{cx:t}=zS(),n=Sy((()=>"dark"===e.mode?"Set light mode":"Set dark mode"))
;return(r,o)=>(Ub(),Hb(bv(e.is),iy({"aria-label":n.value,
class:`toggle-icon-${e.mode}`,type:"button"===e.is?"button":void 0
},xm(t)("size-3 flex items-center justify-center text-c-1")),{
default:ig((()=>[...o[0]||(o[0]=[Gb("span",{class:"toggle-icon-sun-ray"
},null,-1),Gb("span",{class:"toggle-icon-sun-ray"},null,-1),Gb("span",{
class:"toggle-icon-sun-ray"},null,-1),Gb("span",{class:"toggle-icon-sun-ray"
},null,-1),Gb("span",{class:"toggle-icon-ellipse"},[Gb("span",{
class:"toggle-icon-moon-mask"})],-1)])])),_:1
},16,["aria-label","class","type"]))}
}),FG=HS(zG,[["__scopeId","data-v-60be8692"]]),ZG=["aria-pressed"],QG=Qg({
inheritAttrs:!1,__name:"ScalarColorModeToggleButton",props:{modelValue:{
type:Boolean},modelModifiers:{}},emits:["update:modelValue"],setup(e){
const{cx:t}=zS(),n=Kv(e,"modelValue");return(e,r)=>(Ub(),Qb("button",iy({
"aria-pressed":n.value,type:"button"
},xm(t)("group/toggle flex h-6 w-[38px] brightness-lifted -mx-px items-center py-1.5 -my-1.5 relative outline-none"),{
onClick:r[0]||(r[0]=e=>n.value=!n.value)}),[r[1]||(r[1]=Gb("div",{
class:"h-3 w-full bg-border mx-px rounded-xl group-focus-visible/toggle:outline -outline-offset-1"
},null,-1)),Gb("div",{
class:Ih(["size-[23px] left-border absolute border rounded-full flex items-center justify-center bg-b-1 group-focus-visible/toggle:outline -outline-offset-1 transition-transform duration-300 ease-in-out",{
"translate-x-[14px]":n.value}])},[Yb(FG,{is:"div",mode:n.value?"dark":"light"
},null,8,["mode"])],2)],16,ZG))}}),HG=Qg({__name:"ScalarColorModeToggle",props:{
variant:{default:"switch"}},setup(e){
const{isDarkMode:t,toggleColorMode:n,darkLightMode:r}=UG(),o=Sy((()=>t.value?"Set light mode":"Set dark mode"))
;return(a,i)=>"switch"===e.variant?(Ub(),Hb(QG,{key:0,modelValue:xm(t),
"onUpdate:modelValue":i[0]||(i[0]=e=>vm(t)?t.value=e:null),"aria-label":o.value
},null,8,["modelValue","aria-label"])):(Ub(),Hb(FG,{key:1,"aria-label":o.value,
mode:xm(r),onClick:xm(n)},null,8,["aria-label","mode","onClick"]))}
}),VG=["aria-selected"],qG=Qg({__name:"ScalarComboboxOption",props:{active:{
type:Boolean},selected:{type:Boolean}},setup(e){const t=jS({
base:["group/item","flex min-w-0 items-center gap-1.5 rounded px-2 py-1.5 text-left","truncate bg-transparent text-c-1","cursor-pointer hover:bg-b-2"],
variants:{selected:{true:"text-c-1"},active:{true:"bg-b-2"}}})
;return(n,r)=>(Ub(),Qb("li",{"aria-selected":e.selected,class:Ih(xm(US)(xm(t)({
active:e.active,selected:e.selected}))),role:"option",tabindex:"-1"
},[kv(n.$slots,"default",{active:e.active,selected:e.selected})],10,VG))}
}),WG=["id","aria-labelledby","role"],XG=["id"],GG=Qg({
__name:"ScalarComboboxOptionGroup",props:{id:{default:()=>Hg()},hidden:{
type:Boolean,default:!1}},setup:e=>(t,n)=>(Ub(),Qb("div",{id:e.id,
"aria-labelledby":e.id?`${e.id}-label`:void 0,class:"contents",
role:e.hidden?void 0:"group"},[e.hidden?ny("",!0):(Ub(),Qb("div",{key:0,
id:`${e.id}-label`,class:"min-w-0 truncate px-2.5 py-1.5 text-c-2"
},[kv(t.$slots,"label")],8,XG)),kv(t.$slots,"default")],8,WG))});function YG(e){
return!!e[0]&&function(e){return void 0!==e?.options}(e[0])}const KG=Qg({
__name:"ScalarListboxCheckbox",props:{selected:{type:Boolean},multiselect:{
type:Boolean}},setup:e=>(t,n)=>(Ub(),Qb("div",{
class:Ih(["flex size-4 items-center justify-center p-0.75",[e.selected?"bg-c-accent text-b-1":"text-transparent shadow-border",e.multiselect?"rounded":"rounded-full"]])
},[e.selected?(Ub(),Hb(xm(oT),{key:0,class:"size-3",weight:"bold"
})):ny("",!0)],2))}),JG={class:"relative flex"
},eY=["aria-activedescendant","placeholder"],tY=["aria-multiselectable"],nY={
class:"inline-block min-w-0 flex-1 truncate text-c-1"},rY=Qg({inheritAttrs:!1,
__name:"ScalarComboboxOptions",props:Nv({options:{},placeholder:{},multiselect:{
type:Boolean}},{modelValue:{default:[]},modelModifiers:{}}),
emits:Nv(["add"],["update:modelValue"]),setup(e,{emit:t}){
const n=e,r=t,o=Kv(e,"modelValue"),a=$v(),i=`scalar-combobox-items-${Hg()}`,s={
id:`${Hg()}-add`,label:"Add a new option"};function l(e){return`${i}-${e.id}`}
const c=Sy((()=>YG(n.options)?n.options.flatMap((e=>e.options)):n.options)),u=Sy((()=>YG(n.options)?n.options:[{
label:"",options:n.options}])),d=bm(""),p=bm(o.value?.[0]??c.value[0]);iv((()=>{
d.value="",p.value=o.value?.[0]??c.value[0],o.value[0]&&setTimeout((()=>{
const e=o.value[0];e&&document?.getElementById(l(e))?.scrollIntoView({
block:"nearest"})}),10)})),mg((()=>d.value),(()=>p.value=f.value[0]))
;const h=Sy((()=>""===d.value?c.value:c.value.filter((e=>e.label.toLowerCase().includes(d.value.toLowerCase()))))),f=Sy((()=>a.add?[...h.value,s]:h.value))
;function m(e){if(e){if(e.id===s.id)return void v()
;n.multiselect?o.value.some((t=>t.id===e.id))?o.value=o.value.filter((t=>t.id!==e.id)):o.value=[...o.value,c.value.find((t=>t.id===e.id))]:o.value=[c.value.find((t=>t.id===e.id))]
}}function g(e){const t=f.value,n=t.findIndex((e=>e.id===p.value?.id))+e
;n<0||n>t.length-1||(p.value=t[n],
p.value&&document?.getElementById(l(p.value))?.scrollIntoView({
behavior:"smooth",block:"nearest"}))}function v(){r("add"),d.value=""}
const b=bm(null)
;return iv((()=>setTimeout((()=>b.value?.focus()),0))),(t,n)=>(Ub(),
Qb(Mb,null,[Gb("div",JG,[Yb(xm(ZA),{
class:"pointer-events-none absolute left-2.5 top-1/2 -translate-y-1/2 text-c-3 size-4"
}),sg(Gb("input",{ref_key:"input",ref:b,
"onUpdate:modelValue":n[0]||(n[0]=e=>d.value=e),
"aria-activedescendant":p.value?l(p.value):void 0,"aria-autocomplete":"list",
"aria-controls":i,
class:"min-w-0 flex-1 rounded border-0 py-2.5 pl-8 pr-3 leading-none text-c-1 -outline-offset-1",
"data-1p-ignore":"",placeholder:e.placeholder,role:"combobox",tabindex:"0",
type:"text",
onKeydown:[n[1]||(n[1]=UO(BO((e=>g(1)),["prevent"]),["down"])),n[2]||(n[2]=UO(BO((e=>p.value&&m(p.value)),["prevent"]),["enter"])),n[3]||(n[3]=UO(BO((e=>g(-1)),["prevent"]),["up"]))]
},null,40,eY),[[TO,d.value]])]),sg(Gb("ul",{id:i,
"aria-multiselectable":e.multiselect,
class:"border-t p-0.75 custom-scroll overscroll-contain flex-1 min-h-0",
role:"listbox",tabindex:"-1"
},[(Ub(!0),Qb(Mb,null,wv(u.value,((r,a)=>(Ub(),Hb(GG,{id:`${i}-group-${a}`,
key:a,hidden:!r.options.some((e=>h.value.some((t=>t.id===e.id))))||!r.label},{
label:ig((()=>[t.$slots.group?kv(t.$slots,"group",{key:0,group:r}):(Ub(),Qb(Mb,{
key:1},[ey(Uh(r.label),1)],64))])),
default:ig((()=>[(Ub(!0),Qb(Mb,null,wv(h.value,(a=>(Ub(),Qb(Mb,{key:a.id
},[r.options.some((e=>e.id===a.id))?(Ub(),Hb(qG,{key:0,id:l(a),
active:p.value?.id===a.id,selected:o.value.some((e=>e.id===a.id)),
onClick:e=>m(a),onMousedown:n[4]||(n[4]=BO((()=>{}),["prevent"])),
onMouseenter:e=>p.value=a},{
default:ig((({active:n,selected:r})=>[t.$slots.option?kv(t.$slots,"option",{
key:0,active:n,option:a,selected:r}):(Ub(),Qb(Mb,{key:1},[Yb(xm(KG),{
multiselect:e.multiselect,selected:o.value.some((e=>e.id===a.id))
},null,8,["multiselect","selected"]),Gb("span",nY,Uh(a.label),1)],64))])),_:2
},1032,["id","active","selected","onClick","onMouseenter"])):ny("",!0)],64)))),128))])),
_:2},1032,["id","hidden"])))),128)),a.add?(Ub(),Hb(qG,{key:0,id:l(s),
active:p.value?.id===s.id,onClick:v,
onMousedown:n[5]||(n[5]=BO((()=>{}),["prevent"])),
onMouseenter:n[6]||(n[6]=e=>p.value=s)},{default:ig((({active:e})=>[Yb(xm(uC),{
class:"size-4 p-px"}),kv(t.$slots,"add",{active:e})])),_:3
},8,["id","active"])):ny("",!0)],8,tY),[[Jy,h.value.length||a.add]])],64))}
}),oY=["top","right","bottom","left"],aY=Math.min,iY=Math.max,sY=Math.round,lY=Math.floor,cY=e=>({
x:e,y:e}),uY={left:"right",right:"left",bottom:"top",top:"bottom"},dY={
start:"end",end:"start"};function pY(e,t,n){return iY(e,aY(t,n))}
function hY(e,t){return"function"==typeof e?e(t):e}function fY(e){
return e.split("-")[0]}function mY(e){return e.split("-")[1]}function gY(e){
return"x"===e?"y":"x"}function vY(e){return"y"===e?"height":"width"}
const bY=new Set(["top","bottom"]);function yY(e){return bY.has(fY(e))?"y":"x"}
function OY(e){return gY(yY(e))}function wY(e){
return e.replace(/start|end/g,(e=>dY[e]))}
const xY=["left","right"],kY=["right","left"],SY=["top","bottom"],_Y=["bottom","top"]
;function TY(e,t,n,r){const o=mY(e);let a=function(e,t,n){switch(e){case"top":
case"bottom":return n?t?kY:xY:t?xY:kY;case"left":case"right":return t?SY:_Y
;default:return[]}}(fY(e),"start"===n,r)
;return o&&(a=a.map((e=>e+"-"+o)),t&&(a=a.concat(a.map(wY)))),a}function EY(e){
return e.replace(/left|right|bottom|top/g,(e=>uY[e]))}function AY(e){
return"number"!=typeof e?function(e){return{top:0,right:0,bottom:0,left:0,...e}
}(e):{top:e,right:e,bottom:e,left:e}}function CY(e){
const{x:t,y:n,width:r,height:o}=e;return{width:r,height:o,top:n,left:t,
right:t+r,bottom:n+o,x:t,y:n}}function $Y(e,t,n){let{reference:r,floating:o}=e
;const a=yY(t),i=OY(t),s=vY(i),l=fY(t),c="y"===a,u=r.x+r.width/2-o.width/2,d=r.y+r.height/2-o.height/2,p=r[s]/2-o[s]/2
;let h;switch(l){case"top":h={x:u,y:r.y-o.height};break;case"bottom":h={x:u,
y:r.y+r.height};break;case"right":h={x:r.x+r.width,y:d};break;case"left":h={
x:r.x-o.width,y:d};break;default:h={x:r.x,y:r.y}}switch(mY(t)){case"start":
h[i]-=p*(n&&c?-1:1);break;case"end":h[i]+=p*(n&&c?-1:1)}return h}
async function PY(e,t){var n;void 0===t&&(t={})
;const{x:r,y:o,platform:a,rects:i,elements:s,strategy:l}=e,{boundary:c="clippingAncestors",rootBoundary:u="viewport",elementContext:d="floating",altBoundary:p=!1,padding:h=0}=hY(t,e),f=AY(h),m=s[p?"floating"===d?"reference":"floating":d],g=CY(await a.getClippingRect({
element:null==(n=await(null==a.isElement?void 0:a.isElement(m)))||n?m:m.contextElement||await(null==a.getDocumentElement?void 0:a.getDocumentElement(s.floating)),
boundary:c,rootBoundary:u,strategy:l})),v="floating"===d?{x:r,y:o,
width:i.floating.width,height:i.floating.height
}:i.reference,b=await(null==a.getOffsetParent?void 0:a.getOffsetParent(s.floating)),y=await(null==a.isElement?void 0:a.isElement(b))&&await(null==a.getScale?void 0:a.getScale(b))||{
x:1,y:1
},O=CY(a.convertOffsetParentRelativeRectToViewportRelativeRect?await a.convertOffsetParentRelativeRectToViewportRelativeRect({
elements:s,rect:v,offsetParent:b,strategy:l}):v);return{
top:(g.top-O.top+f.top)/y.y,bottom:(O.bottom-g.bottom+f.bottom)/y.y,
left:(g.left-O.left+f.left)/y.x,right:(O.right-g.right+f.right)/y.x}}
function DY(e,t){return{top:e.top-t.height,right:e.right-t.width,
bottom:e.bottom-t.height,left:e.left-t.width}}function IY(e){
return oY.some((t=>e[t]>=0))}const MY=new Set(["left","top"]);function NY(){
return"undefined"!=typeof window}function RY(e){
return jY(e)?(e.nodeName||"").toLowerCase():"#document"}function LY(e){var t
;return(null==e||null==(t=e.ownerDocument)?void 0:t.defaultView)||window}
function BY(e){var t
;return null==(t=(jY(e)?e.ownerDocument:e.document)||window.document)?void 0:t.documentElement
}function jY(e){return!!NY()&&(e instanceof Node||e instanceof LY(e).Node)}
function UY(e){return!!NY()&&(e instanceof Element||e instanceof LY(e).Element)}
function zY(e){
return!!NY()&&(e instanceof HTMLElement||e instanceof LY(e).HTMLElement)}
function FY(e){
return!(!NY()||"undefined"==typeof ShadowRoot)&&(e instanceof ShadowRoot||e instanceof LY(e).ShadowRoot)
}const ZY=new Set(["inline","contents"]);function QY(e){
const{overflow:t,overflowX:n,overflowY:r,display:o}=nK(e)
;return/auto|scroll|overlay|hidden|clip/.test(t+r+n)&&!ZY.has(o)}
const HY=new Set(["table","td","th"]);function VY(e){return HY.has(RY(e))}
const qY=[":popover-open",":modal"];function WY(e){return qY.some((t=>{try{
return e.matches(t)}catch(n){return!1}}))}
const XY=["transform","translate","scale","rotate","perspective"],GY=["transform","translate","scale","rotate","perspective","filter"],YY=["paint","layout","strict","content"]
;function KY(e){const t=JY(),n=UY(e)?nK(e):e
;return XY.some((e=>!!n[e]&&"none"!==n[e]))||!!n.containerType&&"normal"!==n.containerType||!t&&!!n.backdropFilter&&"none"!==n.backdropFilter||!t&&!!n.filter&&"none"!==n.filter||GY.some((e=>(n.willChange||"").includes(e)))||YY.some((e=>(n.contain||"").includes(e)))
}function JY(){
return!("undefined"==typeof CSS||!CSS.supports)&&CSS.supports("-webkit-backdrop-filter","none")
}const eK=new Set(["html","body","#document"]);function tK(e){
return eK.has(RY(e))}function nK(e){return LY(e).getComputedStyle(e)}
function rK(e){return UY(e)?{scrollLeft:e.scrollLeft,scrollTop:e.scrollTop}:{
scrollLeft:e.scrollX,scrollTop:e.scrollY}}function oK(e){
if("html"===RY(e))return e
;const t=e.assignedSlot||e.parentNode||FY(e)&&e.host||BY(e)
;return FY(t)?t.host:t}function aK(e){const t=oK(e)
;return tK(t)?e.ownerDocument?e.ownerDocument.body:e.body:zY(t)&&QY(t)?t:aK(t)}
function iK(e,t,n){var r;void 0===t&&(t=[]),void 0===n&&(n=!0)
;const o=aK(e),a=o===(null==(r=e.ownerDocument)?void 0:r.body),i=LY(o);if(a){
const e=sK(i);return t.concat(i,i.visualViewport||[],QY(o)?o:[],e&&n?iK(e):[])}
return t.concat(o,iK(o,[],n))}function sK(e){
return e.parent&&Object.getPrototypeOf(e.parent)?e.frameElement:null}
function lK(e){const t=nK(e)
;let n=parseFloat(t.width)||0,r=parseFloat(t.height)||0
;const o=zY(e),a=o?e.offsetWidth:n,i=o?e.offsetHeight:r,s=sY(n)!==a||sY(r)!==i
;return s&&(n=a,r=i),{width:n,height:r,$:s}}function cK(e){
return UY(e)?e:e.contextElement}function uK(e){const t=cK(e)
;if(!zY(t))return cY(1)
;const n=t.getBoundingClientRect(),{width:r,height:o,$:a}=lK(t)
;let i=(a?sY(n.width):n.width)/r,s=(a?sY(n.height):n.height)/o
;return i&&Number.isFinite(i)||(i=1),s&&Number.isFinite(s)||(s=1),{x:i,y:s}}
const dK=cY(0);function pK(e){const t=LY(e);return JY()&&t.visualViewport?{
x:t.visualViewport.offsetLeft,y:t.visualViewport.offsetTop}:dK}
function hK(e,t,n,r){void 0===t&&(t=!1),void 0===n&&(n=!1)
;const o=e.getBoundingClientRect(),a=cK(e);let i=cY(1)
;t&&(r?UY(r)&&(i=uK(r)):i=uK(e));const s=function(e,t,n){
return void 0===t&&(t=!1),!(!n||t&&n!==LY(e))&&t}(a,n,r)?pK(a):cY(0)
;let l=(o.left+s.x)/i.x,c=(o.top+s.y)/i.y,u=o.width/i.x,d=o.height/i.y;if(a){
const e=LY(a),t=r&&UY(r)?LY(r):r;let n=e,o=sK(n);for(;o&&r&&t!==n;){
const e=uK(o),t=o.getBoundingClientRect(),r=nK(o),a=t.left+(o.clientLeft+parseFloat(r.paddingLeft))*e.x,i=t.top+(o.clientTop+parseFloat(r.paddingTop))*e.y
;l*=e.x,c*=e.y,u*=e.x,d*=e.y,l+=a,c+=i,n=LY(o),o=sK(n)}}return CY({width:u,
height:d,x:l,y:c})}function fK(e,t){const n=rK(e).scrollLeft
;return t?t.left+n:hK(BY(e)).left+n}function mK(e,t){
const n=e.getBoundingClientRect();return{x:n.left+t.scrollLeft-fK(e,n),
y:n.top+t.scrollTop}}const gK=25;const vK=new Set(["absolute","fixed"])
;function bK(e,t,n){let r;if("viewport"===t)r=function(e,t){
const n=LY(e),r=BY(e),o=n.visualViewport
;let a=r.clientWidth,i=r.clientHeight,s=0,l=0;if(o){a=o.width,i=o.height
;const e=JY();(!e||e&&"fixed"===t)&&(s=o.offsetLeft,l=o.offsetTop)}const c=fK(r)
;if(c<=0){
const e=r.ownerDocument,t=e.body,n=getComputedStyle(t),o="CSS1Compat"===e.compatMode&&parseFloat(n.marginLeft)+parseFloat(n.marginRight)||0,i=Math.abs(r.clientWidth-t.clientWidth-o)
;i<=gK&&(a-=i)}else c<=gK&&(a+=c);return{width:a,height:i,x:s,y:l}
}(e,n);else if("document"===t)r=function(e){
const t=BY(e),n=rK(e),r=e.ownerDocument.body,o=iY(t.scrollWidth,t.clientWidth,r.scrollWidth,r.clientWidth),a=iY(t.scrollHeight,t.clientHeight,r.scrollHeight,r.clientHeight)
;let i=-n.scrollLeft+fK(e);const s=-n.scrollTop
;return"rtl"===nK(r).direction&&(i+=iY(t.clientWidth,r.clientWidth)-o),{width:o,
height:a,x:i,y:s}}(BY(e));else if(UY(t))r=function(e,t){
const n=hK(e,!0,"fixed"===t),r=n.top+e.clientTop,o=n.left+e.clientLeft,a=zY(e)?uK(e):cY(1)
;return{width:e.clientWidth*a.x,height:e.clientHeight*a.y,x:o*a.x,y:r*a.y}
}(t,n);else{const n=pK(e);r={x:t.x-n.x,y:t.y-n.y,width:t.width,height:t.height}}
return CY(r)}function yK(e,t){const n=oK(e)
;return!(n===t||!UY(n)||tK(n))&&("fixed"===nK(n).position||yK(n,t))}
function OK(e,t,n){const r=zY(t),o=BY(t),a="fixed"===n,i=hK(e,!0,a,t);let s={
scrollLeft:0,scrollTop:0};const l=cY(0);function c(){l.x=fK(o)}
if(r||!r&&!a)if(("body"!==RY(t)||QY(o))&&(s=rK(t)),r){const e=hK(t,!0,a,t)
;l.x=e.x+t.clientLeft,l.y=e.y+t.clientTop}else o&&c();a&&!r&&o&&c()
;const u=!o||r||a?cY(0):mK(o,s);return{x:i.left+s.scrollLeft-l.x-u.x,
y:i.top+s.scrollTop-l.y-u.y,width:i.width,height:i.height}}function wK(e){
return"static"===nK(e).position}function xK(e,t){
if(!zY(e)||"fixed"===nK(e).position)return null;if(t)return t(e)
;let n=e.offsetParent;return BY(e)===n&&(n=n.ownerDocument.body),n}
function kK(e,t){const n=LY(e);if(WY(e))return n;if(!zY(e)){let t=oK(e)
;for(;t&&!tK(t);){if(UY(t)&&!wK(t))return t;t=oK(t)}return n}let r=xK(e,t)
;for(;r&&VY(r)&&wK(r);)r=xK(r,t)
;return r&&tK(r)&&wK(r)&&!KY(r)?n:r||function(e){let t=oK(e)
;for(;zY(t)&&!tK(t);){if(KY(t))return t;if(WY(t))return null;t=oK(t)}return null
}(e)||n}const SK={
convertOffsetParentRelativeRectToViewportRelativeRect:function(e){
let{elements:t,rect:n,offsetParent:r,strategy:o}=e
;const a="fixed"===o,i=BY(r),s=!!t&&WY(t.floating);if(r===i||s&&a)return n
;let l={scrollLeft:0,scrollTop:0},c=cY(1);const u=cY(0),d=zY(r)
;if((d||!d&&!a)&&(("body"!==RY(r)||QY(i))&&(l=rK(r)),zY(r))){const e=hK(r)
;c=uK(r),u.x=e.x+r.clientLeft,u.y=e.y+r.clientTop}const p=!i||d||a?cY(0):mK(i,l)
;return{width:n.width*c.x,height:n.height*c.y,
x:n.x*c.x-l.scrollLeft*c.x+u.x+p.x,y:n.y*c.y-l.scrollTop*c.y+u.y+p.y}},
getDocumentElement:BY,getClippingRect:function(e){
let{element:t,boundary:n,rootBoundary:r,strategy:o}=e
;const a=[..."clippingAncestors"===n?WY(t)?[]:function(e,t){const n=t.get(e)
;if(n)return n;let r=iK(e,[],!1).filter((e=>UY(e)&&"body"!==RY(e))),o=null
;const a="fixed"===nK(e).position;let i=a?oK(e):e;for(;UY(i)&&!tK(i);){
const t=nK(i),n=KY(i)
;n||"fixed"!==t.position||(o=null),(a?!n&&!o:!n&&"static"===t.position&&o&&vK.has(o.position)||QY(i)&&!n&&yK(e,i))?r=r.filter((e=>e!==i)):o=t,
i=oK(i)}return t.set(e,r),r
}(t,this._c):[].concat(n),r],i=a[0],s=a.reduce(((e,n)=>{const r=bK(t,n,o)
;return e.top=iY(r.top,e.top),
e.right=aY(r.right,e.right),e.bottom=aY(r.bottom,e.bottom),
e.left=iY(r.left,e.left),e}),bK(t,i,o));return{width:s.right-s.left,
height:s.bottom-s.top,x:s.left,y:s.top}},getOffsetParent:kK,
getElementRects:async function(e){
const t=this.getOffsetParent||kK,n=this.getDimensions,r=await n(e.floating)
;return{reference:OK(e.reference,await t(e.floating),e.strategy),floating:{x:0,
y:0,width:r.width,height:r.height}}},getClientRects:function(e){
return Array.from(e.getClientRects())},getDimensions:function(e){
const{width:t,height:n}=lK(e);return{width:t,height:n}},getScale:uK,
isElement:UY,isRTL:function(e){return"rtl"===nK(e).direction}};function _K(e,t){
return e.x===t.x&&e.y===t.y&&e.width===t.width&&e.height===t.height}
function TK(e,t,n,r){void 0===r&&(r={})
;const{ancestorScroll:o=!0,ancestorResize:a=!0,elementResize:i="function"==typeof ResizeObserver,layoutShift:s="function"==typeof IntersectionObserver,animationFrame:l=!1}=r,c=cK(e),u=o||a?[...c?iK(c):[],...iK(t)]:[]
;u.forEach((e=>{o&&e.addEventListener("scroll",n,{passive:!0
}),a&&e.addEventListener("resize",n)}));const d=c&&s?function(e,t){let n,r=null
;const o=BY(e);function a(){var e
;clearTimeout(n),null==(e=r)||e.disconnect(),r=null}return function i(s,l){
void 0===s&&(s=!1),void 0===l&&(l=1),a()
;const c=e.getBoundingClientRect(),{left:u,top:d,width:p,height:h}=c
;if(s||t(),!p||!h)return;const f={
rootMargin:-lY(d)+"px "+-lY(o.clientWidth-(u+p))+"px "+-lY(o.clientHeight-(d+h))+"px "+-lY(u)+"px",
threshold:iY(0,aY(1,l))||1};let m=!0;function g(t){
const r=t[0].intersectionRatio;if(r!==l){if(!m)return i()
;r?i(!1,r):n=setTimeout((()=>{i(!1,1e-7)}),1e3)}
1!==r||_K(c,e.getBoundingClientRect())||i(),m=!1}try{
r=new IntersectionObserver(g,{...f,root:o.ownerDocument})}catch(v){
r=new IntersectionObserver(g,f)}r.observe(e)}(!0),a}(c,n):null;let p,h=-1,f=null
;i&&(f=new ResizeObserver((e=>{let[r]=e
;r&&r.target===c&&f&&(f.unobserve(t),cancelAnimationFrame(h),
h=requestAnimationFrame((()=>{var e;null==(e=f)||e.observe(t)}))),n()
})),c&&!l&&f.observe(c),f.observe(t));let m=l?hK(e):null;return l&&function t(){
const r=hK(e);m&&!_K(m,r)&&n();m=r,p=requestAnimationFrame(t)}(),n(),()=>{var e
;u.forEach((e=>{
o&&e.removeEventListener("scroll",n),a&&e.removeEventListener("resize",n)
})),null==d||d(),null==(e=f)||e.disconnect(),f=null,l&&cancelAnimationFrame(p)}}
const EK=function(e){return void 0===e&&(e=0),{name:"offset",options:e,
async fn(t){var n,r
;const{x:o,y:a,placement:i,middlewareData:s}=t,l=await async function(e,t){
const{placement:n,platform:r,elements:o}=e,a=await(null==r.isRTL?void 0:r.isRTL(o.floating)),i=fY(n),s=mY(n),l="y"===yY(n),c=MY.has(i)?-1:1,u=a&&l?-1:1,d=hY(t,e)
;let{mainAxis:p,crossAxis:h,alignmentAxis:f}="number"==typeof d?{mainAxis:d,
crossAxis:0,alignmentAxis:null}:{mainAxis:d.mainAxis||0,
crossAxis:d.crossAxis||0,alignmentAxis:d.alignmentAxis}
;return s&&"number"==typeof f&&(h="end"===s?-1*f:f),l?{x:h*u,y:p*c}:{x:p*c,y:h*u
}}(t,e)
;return i===(null==(n=s.offset)?void 0:n.placement)&&null!=(r=s.arrow)&&r.alignmentOffset?{}:{
x:o+l.x,y:a+l.y,data:{...l,placement:i}}}}},AK=function(e){
return void 0===e&&(e={}),{name:"shift",options:e,async fn(t){
const{x:n,y:r,placement:o}=t,{mainAxis:a=!0,crossAxis:i=!1,limiter:s={fn:e=>{
let{x:t,y:n}=e;return{x:t,y:n}}},...l}=hY(e,t),c={x:n,y:r
},u=await PY(t,l),d=yY(fY(o)),p=gY(d);let h=c[p],f=c[d];if(a){
const e="y"===p?"bottom":"right";h=pY(h+u["y"===p?"top":"left"],h,h-u[e])}if(i){
const e="y"===d?"bottom":"right";f=pY(f+u["y"===d?"top":"left"],f,f-u[e])}
const m=s.fn({...t,[p]:h,[d]:f});return{...m,data:{x:m.x-n,y:m.y-r,enabled:{
[p]:a,[d]:i}}}}}},CK=function(e){return void 0===e&&(e={}),{name:"flip",
options:e,async fn(t){var n,r
;const{placement:o,middlewareData:a,rects:i,initialPlacement:s,platform:l,elements:c}=t,{mainAxis:u=!0,crossAxis:d=!0,fallbackPlacements:p,fallbackStrategy:h="bestFit",fallbackAxisSideDirection:f="none",flipAlignment:m=!0,...g}=hY(e,t)
;if(null!=(n=a.arrow)&&n.alignmentOffset)return{}
;const v=fY(o),b=yY(s),y=fY(s)===s,O=await(null==l.isRTL?void 0:l.isRTL(c.floating)),w=p||(y||!m?[EY(s)]:function(e){
const t=EY(e);return[wY(e),t,wY(t)]}(s)),x="none"!==f
;!p&&x&&w.push(...TY(s,m,f,O));const k=[s,...w],S=await PY(t,g),_=[]
;let T=(null==(r=a.flip)?void 0:r.overflows)||[];if(u&&_.push(S[v]),d){
const e=function(e,t,n){void 0===n&&(n=!1);const r=mY(e),o=OY(e),a=vY(o)
;let i="x"===o?r===(n?"end":"start")?"right":"left":"start"===r?"bottom":"top"
;return t.reference[a]>t.floating[a]&&(i=EY(i)),[i,EY(i)]}(o,i,O)
;_.push(S[e[0]],S[e[1]])}if(T=[...T,{placement:o,overflows:_
}],!_.every((e=>e<=0))){var E,A
;const e=((null==(E=a.flip)?void 0:E.index)||0)+1,t=k[e];if(t){
if(!("alignment"===d&&b!==yY(t))||T.every((e=>yY(e.placement)!==b||e.overflows[0]>0)))return{
data:{index:e,overflows:T},reset:{placement:t}}}
let n=null==(A=T.filter((e=>e.overflows[0]<=0)).sort(((e,t)=>e.overflows[1]-t.overflows[1]))[0])?void 0:A.placement
;if(!n)switch(h){case"bestFit":{var C;const e=null==(C=T.filter((e=>{if(x){
const t=yY(e.placement);return t===b||"y"===t}return!0
})).map((e=>[e.placement,e.overflows.filter((e=>e>0)).reduce(((e,t)=>e+t),0)])).sort(((e,t)=>e[1]-t[1]))[0])?void 0:C[0]
;e&&(n=e);break}case"initialPlacement":n=s}if(o!==n)return{reset:{placement:n}}}
return{}}}},$K=function(e){return void 0===e&&(e={}),{name:"size",options:e,
async fn(t){var n,r
;const{placement:o,rects:a,platform:i,elements:s}=t,{apply:l=()=>{},...c}=hY(e,t),u=await PY(t,c),d=fY(o),p=mY(o),h="y"===yY(o),{width:f,height:m}=a.floating
;let g,v
;"top"===d||"bottom"===d?(g=d,v=p===(await(null==i.isRTL?void 0:i.isRTL(s.floating))?"start":"end")?"left":"right"):(v=d,
g="end"===p?"top":"bottom")
;const b=m-u.top-u.bottom,y=f-u.left-u.right,O=aY(m-u[g],b),w=aY(f-u[v],y),x=!t.middlewareData.shift
;let k=O,S=w
;if(null!=(n=t.middlewareData.shift)&&n.enabled.x&&(S=y),null!=(r=t.middlewareData.shift)&&r.enabled.y&&(k=b),
x&&!p){const e=iY(u.left,0),t=iY(u.right,0),n=iY(u.top,0),r=iY(u.bottom,0)
;h?S=f-2*(0!==e||0!==t?e+t:iY(u.left,u.right)):k=m-2*(0!==n||0!==r?n+r:iY(u.top,u.bottom))
}await l({...t,availableWidth:S,availableHeight:k})
;const _=await i.getDimensions(s.floating);return f!==_.width||m!==_.height?{
reset:{rects:!0}}:{}}}},PK=function(e){return void 0===e&&(e={}),{name:"hide",
options:e,async fn(t){
const{rects:n}=t,{strategy:r="referenceHidden",...o}=hY(e,t);switch(r){
case"referenceHidden":{const e=DY(await PY(t,{...o,elementContext:"reference"
}),n.reference);return{data:{referenceHiddenOffsets:e,referenceHidden:IY(e)}}}
case"escaped":{const e=DY(await PY(t,{...o,altBoundary:!0}),n.floating);return{
data:{escapedOffsets:e,escaped:IY(e)}}}default:return{}}}}},DK=e=>({
name:"arrow",options:e,async fn(t){
const{x:n,y:r,placement:o,rects:a,platform:i,elements:s,middlewareData:l}=t,{element:c,padding:u=0}=hY(e,t)||{}
;if(null==c)return{};const d=AY(u),p={x:n,y:r
},h=OY(o),f=vY(h),m=await i.getDimensions(c),g="y"===h,v=g?"top":"left",b=g?"bottom":"right",y=g?"clientHeight":"clientWidth",O=a.reference[f]+a.reference[h]-p[h]-a.floating[f],w=p[h]-a.reference[h],x=await(null==i.getOffsetParent?void 0:i.getOffsetParent(c))
;let k=x?x[y]:0
;k&&await(null==i.isElement?void 0:i.isElement(x))||(k=s.floating[y]||a.floating[f])
;const S=O/2-w/2,_=k/2-m[f]/2-1,T=aY(d[v],_),E=aY(d[b],_),A=T,C=k-m[f]-E,$=k/2-m[f]/2+S,P=pY(A,$,C),D=!l.arrow&&null!=mY(o)&&$!==P&&a.reference[f]/2-($<A?T:E)-m[f]/2<0,I=D?$<A?$-A:$-C:0
;return{[h]:p[h]+I,data:{[h]:P,centerOffset:$-P-I,...D&&{alignmentOffset:I}},
reset:D}}}),IK=function(e){return void 0===e&&(e={}),{options:e,fn(t){
const{x:n,y:r,placement:o,rects:a,middlewareData:i}=t,{offset:s=0,mainAxis:l=!0,crossAxis:c=!0}=hY(e,t),u={
x:n,y:r},d=yY(o),p=gY(d);let h=u[p],f=u[d]
;const m=hY(s,t),g="number"==typeof m?{mainAxis:m,crossAxis:0}:{mainAxis:0,
crossAxis:0,...m};if(l){
const e="y"===p?"height":"width",t=a.reference[p]-a.floating[e]+g.mainAxis,n=a.reference[p]+a.reference[e]-g.mainAxis
;h<t?h=t:h>n&&(h=n)}if(c){var v,b
;const e="y"===p?"width":"height",t=MY.has(fY(o)),n=a.reference[d]-a.floating[e]+(t&&(null==(v=i.offset)?void 0:v[d])||0)+(t?0:g.crossAxis),r=a.reference[d]+a.reference[e]+(t?0:(null==(b=i.offset)?void 0:b[d])||0)-(t?g.crossAxis:0)
;f<n?f=n:f>r&&(f=r)}return{[p]:h,[d]:f}}}},MK=(e,t,n)=>{const r=new Map,o={
platform:SK,...n},a={...o.platform,_c:r};return(async(e,t,n)=>{
const{placement:r="bottom",strategy:o="absolute",middleware:a=[],platform:i}=n,s=a.filter(Boolean),l=await(null==i.isRTL?void 0:i.isRTL(t))
;let c=await i.getElementRects({reference:e,floating:t,strategy:o
}),{x:u,y:d}=$Y(c,r,l),p=r,h={},f=0;for(let m=0;m<s.length;m++){
const{name:n,fn:a}=s[m],{x:g,y:v,data:b,reset:y}=await a({x:u,y:d,
initialPlacement:r,placement:p,strategy:o,middlewareData:h,rects:c,platform:i,
elements:{reference:e,floating:t}});u=null!=g?g:u,d=null!=v?v:d,h={...h,[n]:{
...h[n],...b}},y&&f<=50&&(f++,"object"==typeof y&&(y.placement&&(p=y.placement),
y.rects&&(c=!0===y.rects?await i.getElementRects({reference:e,floating:t,
strategy:o}):y.rects),({x:u,y:d}=$Y(c,p,l))),m=-1)}return{x:u,y:d,placement:p,
strategy:o,middlewareData:h}})(e,t,{...o,platform:a})};function NK(e){
if(function(e){return null!=e&&"object"==typeof e&&"$el"in e}(e)){const t=e.$el
;return jY(t)&&"#comment"===RY(t)?null:t}return e}function RK(e){
return"function"==typeof e?e():xm(e)}function LK(e){
if("undefined"==typeof window)return 1
;return(e.ownerDocument.defaultView||window).devicePixelRatio||1}
function BK(e,t){const n=LK(e);return Math.round(t*n)/n}function jK(e,t,n){
void 0===n&&(n={});const r=n.whileElementsMounted,o=Sy((()=>{var e
;return null==(e=RK(n.open))||e})),a=Sy((()=>RK(n.middleware))),i=Sy((()=>{var e
;return null!=(e=RK(n.placement))?e:"bottom"})),s=Sy((()=>{var e
;return null!=(e=RK(n.strategy))?e:"absolute"})),l=Sy((()=>{var e
;return null==(e=RK(n.transform))||e
})),c=Sy((()=>NK(e.value))),u=Sy((()=>NK(t.value))),d=bm(0),p=bm(0),h=bm(s.value),f=bm(i.value),m=ym({}),g=bm(!1),v=Sy((()=>{
const e={position:h.value,left:"0",top:"0"};if(!u.value)return e
;const t=BK(u.value,d.value),n=BK(u.value,p.value);return l.value?{...e,
transform:"translate("+t+"px, "+n+"px)",...LK(u.value)>=1.5&&{
willChange:"transform"}}:{position:h.value,left:t+"px",top:n+"px"}}));let b
;function y(){if(null==c.value||null==u.value)return;const e=o.value
;MK(c.value,u.value,{middleware:a.value,placement:i.value,strategy:s.value
}).then((t=>{
d.value=t.x,p.value=t.y,h.value=t.strategy,f.value=t.placement,m.value=t.middlewareData,
g.value=!1!==e}))}function O(){"function"==typeof b&&(b(),b=void 0)}
return mg([a,i,s,o],y,{flush:"sync"}),mg([c,u],(function(){
O(),void 0!==r?null==c.value||null==u.value||(b=r(c.value,u.value,y)):y()}),{
flush:"sync"}),mg(o,(function(){o.value||(g.value=!1)}),{flush:"sync"
}),Wh()&&Xh(O),{x:sm(d),y:sm(p),strategy:sm(h),placement:sm(f),
middlewareData:sm(m),isPositioned:sm(g),floatingStyles:v,update:y}}
const UK=Symbol(),zK=Qg({inheritAttrs:!1,__name:"ScalarTeleport",props:{to:{},
immediate:{type:Boolean},disabled:{type:Boolean}},setup(e){const t=ug(UK,"body")
;return(n,r)=>(Ub(),Hb(Ag,{defer:!e.immediate,disabled:e.disabled,to:e.to||xm(t)
},[Gb("div",iy({class:"scalar-app",style:{display:"contents"}
},n.$attrs),[kv(n.$slots,"default")],16)],8,["defer","disabled","to"]))}
}),FK=Qg({inheritAttrs:!1,__name:"ScalarFloating",props:{placement:{},offset:{
type:[Number,Object,Function],default:5},resize:{type:Boolean,default:!1},
target:{},middleware:{default:()=>[]},teleport:{type:[Boolean,String]}},
setup(e,{expose:t}){const n=bm(null),r=bm(null),o=Sy((()=>{
if(typeof window<"u"&&r.value){if("string"==typeof e.target){
const t=document.getElementById(e.target);if(t)return t
;console.warn(`ScalarFloating: Target with id="${e.target}" not found`)
}else if(e.target instanceof HTMLElement)return e.target
;const t=r.value.children?.[0];return t instanceof HTMLElement?t:r.value}
})),a=function(e,t={enabled:bm(!0)}){const n=bm(0),r=bm(0),o=bm()
;return typeof ResizeObserver<"u"&&(o.value=new ResizeObserver((([e])=>{
e&&(n.value=e.borderBoxSize[0]?.inlineSize??0,
r.value=e.borderBoxSize[0]?.blockSize??0)
}))),mg([()=>km(t.enabled),()=>km(e)],(([e,t])=>{
!t||!o.value||(e?o.value.observe(t):o.value.disconnect())}),{immediate:!0}),{
width:Sy((()=>km(t.enabled)?`${n.value}px`:void 0)),
height:Sy((()=>km(t.enabled)?`${r.value}px`:void 0))}}(o,{
enabled:Sy((()=>e.resize))
}),i=Sy((()=>"y"===yY(e.placement??"bottom")?a.width.value:void 0)),s=Sy((()=>"x"===yY(e.placement??"bottom")?a.height.value:void 0)),{floatingStyles:l,middlewareData:c}=jK(o,n,{
placement:Sy((()=>e.placement??"bottom")),whileElementsMounted:TK,
middleware:Sy((()=>[EK(e.offset),CK(),AK({padding:10}),$K({
apply({availableWidth:e,availableHeight:t,elements:n}){
Object.assign(n.floating.style,{maxWidth:Math.max(0,e)-20+"px",
maxHeight:Math.max(0,t)-20+"px"})}}),...e.middleware]))});return t({targetRef:o
}),(t,o)=>(Ub(),Qb(Mb,null,[Gb("div",{ref_key:"wrapperRef",ref:r,class:Ih({
contents:!!t.$slots.default})
},[kv(t.$slots,"default")],2),t.$slots.floating?(Ub(),Hb(xm(zK),{key:0,
disabled:!e.teleport,to:"string"==typeof e.teleport?e.teleport:void 0},{
default:ig((()=>[Gb("div",{ref_key:"floatingRef",ref:n,
class:"relative z-context",style:Ah(xm(l))},[kv(t.$slots,"floating",{data:xm(c),
height:s.value,width:i.value})],4)])),_:3},8,["disabled","to"])):ny("",!0)],64))
}}),ZK=Qg({inheritAttrs:!1,__name:"ScalarFloatingBackdrop",setup(e){
const{cx:t}=zS()
;return(e,n)=>(Ub(),Qb("div",Mh(Kb(xm(t)("absolute inset-0 -z-1 rounded bg-b-1 shadow-lg brightness-lifted"))),[kv(e.$slots,"default")],16))
}}),QK=Qg({inheritAttrs:!1,__name:"ScalarComboboxPopover",props:{placement:{},
offset:{type:[Number,Object,Function]},resize:{type:Boolean},target:{},
middleware:{},teleport:{type:[Boolean,String]}},setup(e,{expose:t}){
const{cx:n}=zS(),r=bm(null),o=e=>{
["ArrowUp","ArrowDown"].includes(e.key)&&(e.preventDefault(),
e.target?.dispatchEvent(new KeyboardEvent("keydown",{key:"Enter"})))};return t({
popoverButtonRef:r}),(e,t)=>(Ub(),Hb(xm(_k),{as:"template"},{
default:ig((({open:t})=>[Yb(xm(FK),Mh(Kb(e.$props)),xv({
default:ig((()=>[Yb(xm(Tk),{ref_key:"popoverButtonRef",ref:r,as:"template",
onKeydown:o},{default:ig((()=>[kv(e.$slots,"default",{open:t})])),_:2},1536)])),
_:2},[t?{name:"floating",fn:ig((({width:r})=>[Yb(xm(Ek),iy({style:{width:r}
},xm(n)("relative flex flex-col max-h-[inherit] w-40 rounded text-sm")),{
default:ig((({close:n})=>[kv(e.$slots,"popover",{close:n,open:t}),Yb(xm(ZK))])),
_:2},1040,["style"])])),key:"0"}:void 0]),1040)])),_:3}))}}),HK=Qg({
__name:"ScalarCombobox",props:Nv({options:{},placeholder:{},placement:{},
offset:{type:[Number,Object,Function]},resize:{type:Boolean},target:{},
middleware:{},teleport:{type:[Boolean,String]}},{modelValue:{},modelModifiers:{}
}),emits:Nv(["add"],["update:modelValue"]),setup(e,{emit:t}){
const n=t,r=Kv(e,"modelValue");return(t,o)=>(Ub(),Hb(QK,{
middleware:e.middleware,offset:e.offset,placement:e.placement??"bottom-start",
resize:e.resize,target:e.target,teleport:e.teleport},{
default:ig((({open:e})=>[kv(t.$slots,"default",{open:e})])),
popover:ig((({open:o,close:a})=>[Yb(rY,{modelValue:r.value?[r.value]:[],open:o,
options:e.options,placeholder:e.placeholder,onAdd:()=>(a(),n("add")),
"onUpdate:modelValue":e=>(a(),r.value=e[0])},xv({_:2},[t.$slots.option?{
name:"option",fn:ig((e=>[kv(t.$slots,"option",Mh(Kb(e)))])),key:"0"
}:void 0,t.$slots.group?{name:"group",
fn:ig((e=>[kv(t.$slots,"group",Mh(Kb(e)))])),key:"1"}:void 0,t.$slots.add?{
name:"add",fn:ig((e=>[kv(t.$slots,"add",Mh(Kb(e)))])),key:"2"
}:void 0]),1032,["modelValue","open","options","placeholder","onAdd","onUpdate:modelValue"])])),
_:3},8,["middleware","offset","placement","resize","target","teleport"]))}
}),VK=Qg({__name:"ScalarComboboxMultiselect",props:Nv({options:{},
placeholder:{},placement:{},offset:{type:[Number,Object,Function]},resize:{
type:Boolean},target:{},middleware:{},teleport:{type:[Boolean,String]}},{
modelValue:{default:[]},modelModifiers:{}}),
emits:Nv(["add"],["update:modelValue"]),setup(e,{expose:t,emit:n}){
const r=n,o=Kv(e,"modelValue"),a=bm(null);return t({comboboxPopoverRef:a
}),(t,n)=>(Ub(),Hb(QK,{ref_key:"comboboxPopoverRef",ref:a,
middleware:e.middleware,offset:e.offset,placement:e.placement??"bottom-start",
resize:e.resize,target:e.target,teleport:e.teleport},{
default:ig((({open:e})=>[kv(t.$slots,"default",{open:e})])),
popover:ig((({open:a})=>[e.options?.length?(Ub(),Hb(rY,{key:0,
modelValue:o.value,"onUpdate:modelValue":n[0]||(n[0]=e=>o.value=e),
multiselect:"",open:a,options:e.options,placeholder:e.placeholder,
onAdd:n[1]||(n[1]=e=>r("add"))},xv({_:2},[t.$slots.option?{name:"option",
fn:ig((e=>[kv(t.$slots,"option",Mh(Kb(e)))])),key:"0"}:void 0,t.$slots.group?{
name:"group",fn:ig((e=>[kv(t.$slots,"group",Mh(Kb(e)))])),key:"1"
}:void 0,t.$slots.add?{name:"add",fn:ig((e=>[kv(t.$slots,"add",Mh(Kb(e)))])),
key:"2"
}:void 0]),1032,["modelValue","open","options","placeholder"])):ny("",!0)])),_:3
},8,["middleware","offset","placement","resize","target","teleport"]))}})
;function qK(e,t){const n=Symbol("string"!=typeof e||t?t:`${e}Context`)
;return[t=>{const r=ug(n,t);if(r||null===r)return r
;throw new Error(`Injection \`${n.toString()}\` not found. Component must be used within ${Array.isArray(e)?`one of the following components: ${e.join(", ")}`:`\`${e}\``}`)
},e=>(cg(n,e),e)]}function WK(e,t,n){
const r=n.originalEvent.target,o=new CustomEvent(e,{bubbles:!1,cancelable:!0,
detail:n});t&&r.addEventListener(e,t,{once:!0}),r.dispatchEvent(o)}
function XK(e){return!!Wh()&&(Xh(e),!0)}function GK(e){let t,n,r=0;const o=()=>{
r-=1,n&&r<=0&&(n.stop(),t=void 0,n=void 0)}
;return(...a)=>(r+=1,t||(n=qh(!0),t=n.run((()=>e(...a)))),XK(o),t)}
function YK(e){return"function"==typeof e?e():xm(e)}
const KK=typeof window<"u"&&typeof document<"u"
;typeof WorkerGlobalScope<"u"&&(globalThis,WorkerGlobalScope)
;const JK=Object.prototype.toString,eJ=e=>"[object Object]"===JK.call(e),tJ=()=>{},nJ=rJ()
;function rJ(){var e,t
;return KK&&(null==(e=null==window?void 0:window.navigator)?void 0:e.userAgent)&&(/iP(?:ad|hone|od)/.test(window.navigator.userAgent)||(null==(t=null==window?void 0:window.navigator)?void 0:t.maxTouchPoints)>2&&/iPad|Macintosh/.test(null==window?void 0:window.navigator.userAgent))
}function oJ(e,t=1e4){return Em(((n,r)=>{let o,a=YK(e);return XK((()=>{
clearTimeout(o)})),{get:()=>(n(),a),set(n){
a=n,r(),clearTimeout(o),o=setTimeout((()=>{a=YK(e),r()}),YK(t))}}}))}
function aJ(e,t){dy()&&cv(e,t)}function iJ(e){var t;const n=YK(e)
;return null!=(t=null==n?void 0:n.$el)?t:n}const sJ=KK?window:void 0
;function lJ(...e){let t,n,r,o
;if("string"==typeof e[0]||Array.isArray(e[0])?([n,r,o]=e,
t=sJ):[t,n,r,o]=e,!t)return tJ
;Array.isArray(n)||(n=[n]),Array.isArray(r)||(r=[r]);const a=[],i=()=>{
a.forEach((e=>e())),a.length=0},s=mg((()=>[iJ(t),YK(o)]),(([e,t])=>{
if(i(),!e)return;const o=eJ(t)?{...t}:t
;a.push(...n.flatMap((t=>r.map((n=>((e,t,n,r)=>(e.addEventListener(t,n,r),
()=>e.removeEventListener(t,n,r)))(e,t,n,o))))))}),{immediate:!0,flush:"post"
}),l=()=>{s(),i()};return XK(l),l}function cJ(...e){let t,n,r={}
;3===e.length?(t=e[0],
n=e[1],r=e[2]):2===e.length?"object"==typeof e[1]?(t=!0,n=e[0],
r=e[1]):(t=e[0],n=e[1]):(t=!0,n=e[0])
;const{target:o=sJ,eventName:a="keydown",passive:i=!1,dedupe:s=!1}=r,l=function(e){
return"function"==typeof e?e:"string"==typeof e?t=>t.key===e:Array.isArray(e)?t=>e.includes(t.key):()=>!0
}(t);return lJ(o,a,(e=>{e.repeat&&YK(s)||l(e)&&n(e)}),i)}
function uJ(e,t,n,r={}){var o,a,i
;const{clone:s=!1,passive:l=!1,eventName:c,deep:u=!1,defaultValue:d,shouldEmit:p}=r,h=dy(),f=n||(null==h?void 0:h.emit)||(null==(o=null==h?void 0:h.$emit)?void 0:o.bind(h))||(null==(i=null==(a=null==h?void 0:h.proxy)?void 0:a.$emit)?void 0:i.bind(null==h?void 0:h.proxy))
;let m=c;t||(t="modelValue"),m=m||`update:${t.toString()}`
;const g=e=>s?"function"==typeof s?s(e):function(e){
return JSON.parse(JSON.stringify(e))
}(e):e,v=()=>(e=>typeof e<"u")(e[t])?g(e[t]):d,b=e=>{p?p(e)&&f(m,e):f(m,e)}
;if(l){const n=bm(v());let r=!1;return mg((()=>e[t]),(e=>{r||(r=!0,n.value=g(e),
Xm((()=>r=!1)))})),mg(n,(n=>{!r&&(n!==e[t]||u)&&b(n)}),{deep:u}),n}return Sy({
get:()=>v(),set(e){b(e)}})}function dJ(e){
return e?e.flatMap((e=>e.type===Mb?dJ(e.children):[e])):[]}function pJ(){
let e=document.activeElement;if(null==e)return null
;for(;null!=e&&null!=e.shadowRoot&&null!=e.shadowRoot.activeElement;)e=e.shadowRoot.activeElement
;return e}const hJ=["INPUT","TEXTAREA"];function fJ(e,t,n,r={}){
if(!t||r.enableIgnoredElement&&hJ.includes(t.nodeName))return null
;const{arrowKeyOptions:o="both",attributeName:a="[data-radix-vue-collection-item]",itemsArray:i=[],loop:s=!0,dir:l="ltr",preventScroll:c=!0,focus:u=!1}=r,[d,p,h,f,m,g]=["ArrowRight"===e.key,"ArrowLeft"===e.key,"ArrowUp"===e.key,"ArrowDown"===e.key,"Home"===e.key,"End"===e.key],v=h||f,b=d||p
;if(!m&&!g&&(!v&&!b||"vertical"===o&&b||"horizontal"===o&&v))return null
;const y=n?Array.from(n.querySelectorAll(a)):i;if(!y.length)return null
;c&&e.preventDefault();let O=null;return b||v?O=mJ(y,t,{
goForward:v?f:"ltr"===l?d:p,loop:s
}):m?O=y.at(0)||null:g&&(O=y.at(-1)||null),u&&(null==O||O.focus()),O}
function mJ(e,t,n,r=e.length){if(0==--r)return null
;const o=e.indexOf(t),a=n.goForward?o+1:o-1
;if(!n.loop&&(a<0||a>=e.length))return null;const i=e[(a+e.length)%e.length]
;return i?i.hasAttribute("disabled")&&"false"!==i.getAttribute("disabled")?mJ(e,i,n,r):i:null
}function gJ(e){if(null===e||"object"!=typeof e)return!1
;const t=Object.getPrototypeOf(e)
;return!(null!==t&&t!==Object.prototype&&null!==Object.getPrototypeOf(t)||Symbol.iterator in e)&&(!(Symbol.toStringTag in e)||"[object Module]"===Object.prototype.toString.call(e))
}function vJ(e,t,n=".",r){if(!gJ(t))return vJ(e,{},n)
;const o=Object.assign({},t);for(const a in e){
if("__proto__"===a||"constructor"===a)continue;const t=e[a]
;null!=t&&(Array.isArray(t)&&Array.isArray(o[a])?o[a]=[...t,...o[a]]:gJ(t)&&gJ(o[a])?o[a]=vJ(t,o[a],(n?`${n}.`:"")+a.toString()):o[a]=t)
}return o}
const bJ=(...e)=>e.reduce(((e,t)=>vJ(e,t,"")),{}),[yJ]=qK("ConfigProvider")
;const OJ=GK((()=>{const e=bm(new Map),t=bm(),n=Sy((()=>{
for(const t of e.value.values())if(t)return!0;return!1})),r=yJ({
scrollBody:bm(!0)});let o=null;return mg(n,((e,n)=>{var a;if(!KK)return
;if(!e)return void(n&&(document.body.style.paddingRight="",
document.body.style.marginRight="",
document.body.style.pointerEvents="",document.body.style.removeProperty("--scrollbar-width"),
document.body.style.overflow=t.value??"",nJ&&(null==o||o()),t.value=void 0))
;void 0===t.value&&(t.value=document.body.style.overflow)
;const i=window.innerWidth-document.documentElement.clientWidth,s={padding:i,
margin:0
},l=null!=(a=r.scrollBody)&&a.value?"object"==typeof r.scrollBody.value?bJ({
padding:!0===r.scrollBody.value.padding?i:r.scrollBody.value.padding,
margin:!0===r.scrollBody.value.margin?i:r.scrollBody.value.margin},s):s:{
padding:0,margin:0}
;i>0&&(document.body.style.paddingRight="number"==typeof l.padding?`${l.padding}px`:String(l.padding),
document.body.style.marginRight="number"==typeof l.margin?`${l.margin}px`:String(l.margin),
document.body.style.setProperty("--scrollbar-width",`${i}px`),
document.body.style.overflow="hidden"),
nJ&&(o=lJ(document,"touchmove",(e=>function(e){
const t=e||window.event,n=t.target
;return!(n instanceof Element&&xJ(n))&&(t.touches.length>1||(t.preventDefault&&t.cancelable&&t.preventDefault(),
!1))}(e)),{passive:!1})),Xm((()=>{
document.body.style.pointerEvents="none",document.body.style.overflow="hidden"
}))}),{immediate:!0,flush:"sync"}),e}));function wJ(e){const t=((e=21)=>{
let t="",n=e
;for(;n--;)t+="useandom-26T198340PX75pxJACKVERYMINDBUSHWOLF_GQZbfghjklqvwyzrict"[64*Math.random()|0]
;return t})(6),n=OJ();n.value.set(t,e??!1);const r=Sy({
get:()=>n.value.get(t)??!1,set:e=>n.value.set(t,e)});return aJ((()=>{
n.value.delete(t)})),r}function xJ(e){const t=window.getComputedStyle(e)
;if("scroll"===t.overflowX||"scroll"===t.overflowY||"auto"===t.overflowX&&e.clientWidth<e.scrollWidth||"auto"===t.overflowY&&e.clientHeight<e.scrollHeight)return!0
;{const t=e.parentNode;return t instanceof Element&&"BODY"!==t.tagName&&xJ(t)}}
function kJ(e){const t=yJ({dir:bm("ltr")});return Sy((()=>{var n
;return(null==e?void 0:e.value)||(null==(n=t.dir)?void 0:n.value)||"ltr"}))}
function SJ(e){const t=dy(),n=null==t?void 0:t.type.emits,r={}
;return null!=n&&n.length||console.warn(`No emitted event found. Please check component: ${null==t?void 0:t.type.__name}`),
null==n||n.forEach((t=>{r[Oh(gh(t))]=(...n)=>e(t,...n)})),r}let _J=0
;function TJ(){const e=document.createElement("span")
;return e.setAttribute("data-radix-focus-guard",""),
e.tabIndex=0,e.style.outline="none",
e.style.opacity="0",e.style.position="fixed",e.style.pointerEvents="none",e}
function EJ(e,t){const n=function(e){
const t=dy(),n=Object.keys((null==t?void 0:t.type.props)??{}).reduce(((e,n)=>{
const r=(null==t?void 0:t.type.props[n]).default;return void 0!==r&&(e[n]=r),e
}),{}),r=Pm(e);return Sy((()=>{const e={},o=(null==t?void 0:t.vnode.props)??{}
;return Object.keys(o).forEach((t=>{e[gh(t)]=o[t]})),Object.keys({...n,...e
}).reduce(((e,t)=>(void 0!==r.value[t]&&(e[t]=r.value[t]),e)),{})}))
}(e),r=t?SJ(t):{};return Sy((()=>({...n.value,...r})))}function AJ(){
const e=dy(),t=bm(),n=Sy((()=>{var e,n
;return["#text","#comment"].includes(null==(e=t.value)?void 0:e.$el.nodeName)?null==(n=t.value)?void 0:n.$el.nextElementSibling:iJ(t)
})),r=Object.assign({},e.exposed),o={}
;for(const a in e.props)Object.defineProperty(o,a,{enumerable:!0,
configurable:!0,get:()=>e.props[a]})
;if(Object.keys(r).length>0)for(const a in r)Object.defineProperty(o,a,{
enumerable:!0,configurable:!0,get:()=>r[a]})
;return Object.defineProperty(o,"$el",{enumerable:!0,configurable:!0,
get:()=>e.vnode.el}),e.exposed=o,{forwardRef:function(n){
t.value=n,n&&(Object.defineProperty(o,"$el",{enumerable:!0,configurable:!0,
get:()=>n instanceof Element?n:n.$el}),e.exposed=o)},currentRef:t,
currentElement:n}}var CJ=new WeakMap,$J=new WeakMap,PJ={},DJ=0,IJ=function(e){
return e&&(e.host||IJ(e.parentNode))},MJ=function(e,t,n,r){var o=function(e,t){
return t.map((function(t){if(e.contains(t))return t;var n=IJ(t)
;return n&&e.contains(n)?n:(console.error("aria-hidden",t,"in not contained inside",e,". Doing nothing"),
null)})).filter((function(e){return!!e}))}(t,Array.isArray(e)?e:[e])
;PJ[n]||(PJ[n]=new WeakMap)
;var a=PJ[n],i=[],s=new Set,l=new Set(o),c=function(e){
!e||s.has(e)||(s.add(e),c(e.parentNode))};o.forEach(c);var u=function(e){
!e||l.has(e)||Array.prototype.forEach.call(e.children,(function(e){
if(s.has(e))u(e);else try{
var t=e.getAttribute(r),o=null!==t&&"false"!==t,l=(CJ.get(e)||0)+1,c=(a.get(e)||0)+1
;CJ.set(e,l),
a.set(e,c),i.push(e),1===l&&o&&$J.set(e,!0),1===c&&e.setAttribute(n,"true"),
o||e.setAttribute(r,"true")}catch(d){
console.error("aria-hidden: cannot operate on ",e,d)}}))};return u(t),s.clear(),
DJ++,function(){i.forEach((function(e){var t=CJ.get(e)-1,o=a.get(e)-1
;CJ.set(e,t),
a.set(e,o),t||($J.has(e)||e.removeAttribute(r),$J.delete(e)),o||e.removeAttribute(n)
})),--DJ||(CJ=new WeakMap,CJ=new WeakMap,$J=new WeakMap,PJ={})}
},NJ=function(e,t,n){void 0===n&&(n="data-aria-hidden")
;var r=Array.from(Array.isArray(e)?e:[e]),o=function(e){
return typeof document>"u"?null:(Array.isArray(e)?e[0]:e).ownerDocument.body}(e)
;return o?(r.push.apply(r,Array.from(o.querySelectorAll("[aria-live]"))),
MJ(r,o,n,"aria-hidden")):function(){return null}};let RJ=0
;function LJ(e,t="radix"){const n=yJ({useId:void 0})
;return Hg?`${t}-${Hg()}`:n.useId?`${t}-${n.useId()}`:`${t}-${++RJ}`}
function BJ(e,t){const n=bm(e);return{state:n,dispatch:e=>{n.value=function(e){
return t[n.value][e]??n.value}(e)}}}function jJ(e){const t=oJ("",1e3);return{
search:t,handleTypeaheadSearch:(n,r)=>{if(!(null!=e&&e.value||r))return
;t.value=t.value+n;const o=(null==e?void 0:e.value)??r,a=pJ(),i=o.map((e=>{var t
;return{ref:e,
textValue:(null==(t=(e.querySelector("[data-item-text]")??e).textContent)?void 0:t.trim())??""
}})),s=i.find((e=>e.ref===a)),l=function(e,t,n){
const r=t.length>1&&Array.from(t).every((e=>e===t[0]))?t[0]:t,o=n?e.indexOf(n):-1
;let a=function(e,t){return e.map(((n,r)=>e[(t+r)%e.length]))}(e,Math.max(o,0))
;1===r.length&&(a=a.filter((e=>e!==n)))
;const i=a.find((e=>e.toLowerCase().startsWith(r.toLowerCase())))
;return i!==n?i:void 0
}(i.map((e=>e.textValue)),t.value,null==s?void 0:s.textValue),c=i.find((e=>e.textValue===l))
;return c&&c.ref.focus(),null==c?void 0:c.ref},resetTypeahead:()=>{t.value=""}}}
const UJ=Qg({name:"PrimitiveSlot",inheritAttrs:!1,
setup:(e,{attrs:t,slots:n})=>()=>{var e,r;if(!n.default)return null
;const o=dJ(n.default()),a=o.findIndex((e=>e.type!==Rb));if(-1===a)return o
;const i=o[a];null==(e=i.props)||delete e.ref;const s=i.props?iy(t,i.props):t
;t.class&&null!=(r=i.props)&&r.class&&delete i.props.class;const l=Jb(i,s)
;for(const t in s)t.startsWith("on")&&(l.props||(l.props={}),l.props[t]=s[t])
;return 1===o.length?l:(o[a]=l,o)}}),zJ=Qg({name:"Primitive",inheritAttrs:!1,
props:{asChild:{type:Boolean,default:!1},as:{type:[String,Object],default:"div"}
},setup(e,{attrs:t,slots:n}){const r=e.asChild?"template":e.as
;return"string"==typeof r&&["area","img","input"].includes(r)?()=>_y(r,t):"template"!==r?()=>_y(e.as,t,{
default:n.default}):()=>_y(UJ,t,{default:n.default})}});function FJ(){
const e=bm(),t=Sy((()=>{var t,n
;return["#text","#comment"].includes(null==(t=e.value)?void 0:t.$el.nodeName)?null==(n=e.value)?void 0:n.$el.nextElementSibling:iJ(e)
}));return{primitiveElement:e,currentElement:t}}function ZJ(e){
return e&&getComputedStyle(e).animationName||"none"}const QJ=Qg({
name:"Presence",props:{present:{type:Boolean,required:!0},forceMount:{
type:Boolean}},slots:{},setup(e,{slots:t,expose:n}){var r
;const{present:o,forceMount:a}=Am(e),i=bm(),{isPresent:s}=function(e,t){var n
;const r=bm({}),o=bm("none"),a=bm(e),i=e.value?"mounted":"unmounted";let s
;const l=(null==(n=t.value)?void 0:n.ownerDocument.defaultView)??sJ,{state:c,dispatch:u}=BJ(i,{
mounted:{UNMOUNT:"unmounted",ANIMATION_OUT:"unmountSuspended"},
unmountSuspended:{MOUNT:"mounted",ANIMATION_END:"unmounted"},unmounted:{
MOUNT:"mounted"}}),d=e=>{var n;if(KK){const r=new CustomEvent(e,{bubbles:!1,
cancelable:!1});null==(n=t.value)||n.dispatchEvent(r)}};mg(e,(async(e,n)=>{var a
;const i=n!==e;if(await Xm(),i){const i=o.value,s=ZJ(t.value)
;e?(u("MOUNT"),d("enter"),
"none"===s&&d("after-enter")):"none"===s||"none"===(null==(a=r.value)?void 0:a.display)?(u("UNMOUNT"),
d("leave"),
d("after-leave")):n&&i!==s?(u("ANIMATION_OUT"),d("leave")):(u("UNMOUNT"),
d("after-leave"))}}),{immediate:!0});const p=e=>{
const n=ZJ(t.value),r=n.includes(e.animationName),o="mounted"===c.value?"enter":"leave"
;if(e.target===t.value&&r&&(d(`after-${o}`),u("ANIMATION_END"),!a.value)){
const e=t.value.style.animationFillMode
;t.value.style.animationFillMode="forwards",s=null==l?void 0:l.setTimeout((()=>{
var n
;"forwards"===(null==(n=t.value)?void 0:n.style.animationFillMode)&&(t.value.style.animationFillMode=e)
}))}e.target===t.value&&"none"===n&&u("ANIMATION_END")},h=e=>{
e.target===t.value&&(o.value=ZJ(t.value))},f=mg(t,((e,t)=>{
e?(r.value=getComputedStyle(e),
e.addEventListener("animationstart",h),e.addEventListener("animationcancel",p),
e.addEventListener("animationend",p)):(u("ANIMATION_END"),
void 0!==s&&(null==l||l.clearTimeout(s)),
null==t||t.removeEventListener("animationstart",h),
null==t||t.removeEventListener("animationcancel",p),
null==t||t.removeEventListener("animationend",p))}),{immediate:!0
}),m=mg(c,(()=>{const e=ZJ(t.value);o.value="mounted"===c.value?e:"none"}))
;return uv((()=>{f(),m()})),{
isPresent:Sy((()=>["mounted","unmountSuspended"].includes(c.value)))}}(o,i);n({
present:s});let l=t.default({present:s});l=dJ(l||[]);const c=dy()
;if(l&&(null==l?void 0:l.length)>1){
const e=null!=(r=null==c?void 0:c.parent)&&r.type.name?`<${c.parent.type.name} />`:"component"
;throw new Error([`Detected an invalid children for \`${e}\` for  \`Presence\` component.`,"","Note: Presence works similarly to `v-if` directly, but it waits for animation/transition to finished before unmounting. So it expect only one direct child of valid VNode type.","You can apply a few solutions:",["Provide a single child element so that `presence` directive attach correctly.","Ensure the first child is an actual element instead of a raw text node or comment node."].map((e=>`  - ${e}`)).join("\n")].join("\n"))
}return()=>a.value||o.value||s.value?_y(t.default({present:s})[0],{ref:e=>{
const t=iJ(e)
;return typeof(null==t?void 0:t.hasAttribute)>"u"||(null!=t&&t.hasAttribute("data-radix-popper-content-wrapper")?i.value=t.firstElementChild:i.value=t),
t}}):null}}),HJ=Qg({__name:"Teleport",props:{to:{default:"body"},disabled:{
type:Boolean},forceMount:{type:Boolean}},setup(e){const t=function(){
const e=bm(!1),t=dy();return t&&iv((()=>{e.value=!0}),t),e}()
;return(e,n)=>xm(t)||e.forceMount?(Ub(),Hb(Ag,{key:0,to:e.to,disabled:e.disabled
},[kv(e.$slots,"default")],8,["to","disabled"])):ny("",!0)}});function VJ(e,t){
const n=t.closest("[data-dismissable-layer]"),r=""===e.dataset.dismissableLayer?e:e.querySelector("[data-dismissable-layer]"),o=Array.from(e.ownerDocument.querySelectorAll("[data-dismissable-layer]"))
;return!!(n&&r===n||o.indexOf(r)<o.indexOf(n))}const qJ=am({layersRoot:new Set,
layersWithOutsidePointerEventsDisabled:new Set,branches:new Set}),WJ=Qg({
__name:"DismissableLayer",props:{disableOutsidePointerEvents:{type:Boolean,
default:!1},asChild:{type:Boolean},as:{}},
emits:["escapeKeyDown","pointerDownOutside","focusOutside","interactOutside","dismiss"],
setup(e,{emit:t}){const n=e,r=t,{forwardRef:o,currentElement:a}=AJ(),i=Sy((()=>{
var e;return(null==(e=a.value)?void 0:e.ownerDocument)??globalThis.document
})),s=Sy((()=>qJ.layersRoot)),l=Sy((()=>a.value?Array.from(s.value).indexOf(a.value):-1)),c=Sy((()=>qJ.layersWithOutsidePointerEventsDisabled.size>0)),u=Sy((()=>{
const e=Array.from(s.value),[t]=[...qJ.layersWithOutsidePointerEventsDisabled].slice(-1),n=e.indexOf(t)
;return l.value>=n})),d=function(e,t){var n
;const r=(null==(n=null==t?void 0:t.value)?void 0:n.ownerDocument)??(null==globalThis?void 0:globalThis.document),o=bm(!1),a=bm((()=>{}))
;return fg((n=>{if(!KK)return;const i=async n=>{const i=n.target
;if(null!=t&&t.value){if(VJ(t.value,i))return void(o.value=!1)
;if(n.target&&!o.value){let t=function(){
WK("dismissableLayer.pointerDownOutside",e,o)};const o={originalEvent:n}
;"touch"===n.pointerType?(r.removeEventListener("click",a.value),
a.value=t,r.addEventListener("click",a.value,{once:!0})):t()
}else r.removeEventListener("click",a.value);o.value=!1}
},s=window.setTimeout((()=>{r.addEventListener("pointerdown",i)}),0);n((()=>{
window.clearTimeout(s),
r.removeEventListener("pointerdown",i),r.removeEventListener("click",a.value)}))
})),{onPointerDownCapture:()=>o.value=!0}}((async e=>{
const t=[...qJ.branches].some((t=>null==t?void 0:t.contains(e.target)))
;!u.value||t||(r("pointerDownOutside",e),
r("interactOutside",e),await Xm(),e.defaultPrevented||r("dismiss"))
}),a),p=function(e,t){var n
;const r=(null==(n=null==t?void 0:t.value)?void 0:n.ownerDocument)??(null==globalThis?void 0:globalThis.document),o=bm(!1)
;return fg((n=>{if(!KK)return;const a=async n=>{
null!=t&&t.value&&(await Xm(),t.value&&!VJ(t.value,n.target)&&n.target&&!o.value&&WK("dismissableLayer.focusOutside",e,{
originalEvent:n}))}
;r.addEventListener("focusin",a),n((()=>r.removeEventListener("focusin",a)))})),
{onFocusCapture:()=>o.value=!0,onBlurCapture:()=>o.value=!1}}((e=>{
[...qJ.branches].some((t=>null==t?void 0:t.contains(e.target)))||(r("focusOutside",e),
r("interactOutside",e),e.defaultPrevented||r("dismiss"))}),a);let h
;return cJ("Escape",(e=>{
l.value===s.value.size-1&&(r("escapeKeyDown",e),e.defaultPrevented||r("dismiss"))
})),fg((e=>{
a.value&&(n.disableOutsidePointerEvents&&(0===qJ.layersWithOutsidePointerEventsDisabled.size&&(h=i.value.body.style.pointerEvents,
i.value.body.style.pointerEvents="none"),
qJ.layersWithOutsidePointerEventsDisabled.add(a.value)),
s.value.add(a.value),e((()=>{
n.disableOutsidePointerEvents&&1===qJ.layersWithOutsidePointerEventsDisabled.size&&(i.value.body.style.pointerEvents=h)
})))})),fg((e=>{e((()=>{
a.value&&(s.value.delete(a.value),qJ.layersWithOutsidePointerEventsDisabled.delete(a.value))
}))})),(e,t)=>(Ub(),Hb(xm(zJ),{ref:xm(o),"as-child":e.asChild,as:e.as,
"data-dismissable-layer":"",style:Ah({
pointerEvents:c.value?u.value?"auto":"none":void 0}),
onFocusCapture:xm(p).onFocusCapture,onBlurCapture:xm(p).onBlurCapture,
onPointerdownCapture:xm(d).onPointerDownCapture},{
default:ig((()=>[kv(e.$slots,"default")])),_:3
},8,["as-child","as","style","onFocusCapture","onBlurCapture","onPointerdownCapture"]))
}}),XJ="focusScope.autoFocusOnMount",GJ="focusScope.autoFocusOnUnmount",YJ={
bubbles:!1,cancelable:!0};function KJ(e){
const t=[],n=document.createTreeWalker(e,NodeFilter.SHOW_ELEMENT,{
acceptNode:e=>{const t="INPUT"===e.tagName&&"hidden"===e.type
;return e.disabled||e.hidden||t?NodeFilter.FILTER_SKIP:e.tabIndex>=0?NodeFilter.FILTER_ACCEPT:NodeFilter.FILTER_SKIP
}});for(;n.nextNode();)t.push(n.currentNode);return t}function JJ(e,t){
for(const n of e)if(!e0(n,{upTo:t}))return n}function e0(e,{upTo:t}){
if("hidden"===getComputedStyle(e).visibility)return!0;for(;e;){
if(void 0!==t&&e===t)return!1;if("none"===getComputedStyle(e).display)return!0
;e=e.parentElement}return!1}function t0(e,{select:t=!1}={}){if(e&&e.focus){
const n=pJ();e.focus({preventScroll:!0}),e!==n&&function(e){
return e instanceof HTMLInputElement&&"select"in e}(e)&&t&&e.select()}}
const n0=function(e){let t,n=!1;const r=qh(!0)
;return(...o)=>(n||(t=r.run((()=>e(...o))),n=!0),t)}((()=>bm([])))
;function r0(e,t){const n=[...e],r=n.indexOf(t);return-1!==r&&n.splice(r,1),n}
const o0=Qg({__name:"FocusScope",props:{loop:{type:Boolean,default:!1},trapped:{
type:Boolean,default:!1},asChild:{type:Boolean},as:{}},
emits:["mountAutoFocus","unmountAutoFocus"],setup(e,{emit:t}){
const n=e,r=t,{currentRef:o,currentElement:a}=AJ(),i=bm(null),s=function(){
const e=n0();return{add(t){const n=e.value[0]
;t!==n&&(null==n||n.pause()),e.value=r0(e.value,t),e.value.unshift(t)},
remove(t){var n;e.value=r0(e.value,t),null==(n=e.value[0])||n.resume()}}
}(),l=am({paused:!1,pause(){this.paused=!0},resume(){this.paused=!1}})
;function c(e){if(!n.loop&&!n.trapped||l.paused)return
;const t="Tab"===e.key&&!e.altKey&&!e.ctrlKey&&!e.metaKey,r=pJ();if(t&&r){
const t=e.currentTarget,[o,a]=function(e){const t=KJ(e)
;return[JJ(t,e),JJ(t.reverse(),e)]}(t)
;o&&a?e.shiftKey||r!==a?e.shiftKey&&r===o&&(e.preventDefault(),n.loop&&t0(a,{
select:!0})):(e.preventDefault(),n.loop&&t0(o,{select:!0
})):r===t&&e.preventDefault()}}return fg((e=>{if(!KK)return;const t=a.value
;if(!n.trapped)return;function r(e){if(l.paused||!t)return;const n=e.target
;t.contains(n)?i.value=n:t0(i.value,{select:!0})}function o(e){
if(l.paused||!t)return;const n=e.relatedTarget
;null!==n&&(t.contains(n)||t0(i.value,{select:!0}))}
document.addEventListener("focusin",r),document.addEventListener("focusout",o)
;const s=new MutationObserver((function(e){t.contains(i.value)||t0(t)}))
;t&&s.observe(t,{childList:!0,subtree:!0}),e((()=>{
document.removeEventListener("focusin",r),
document.removeEventListener("focusout",o),s.disconnect()}))})),fg((async e=>{
const t=a.value;if(await Xm(),!t)return;s.add(l);const n=pJ()
;if(!t.contains(n)){const e=new CustomEvent(XJ,YJ)
;t.addEventListener(XJ,(e=>r("mountAutoFocus",e))),
t.dispatchEvent(e),e.defaultPrevented||(function(e,{select:t=!1}={}){
const n=pJ();for(const r of e)if(t0(r,{select:t}),pJ()!==n)return!0
}(function(e){return e.filter((e=>"A"!==e.tagName))}(KJ(t)),{select:!0
}),pJ()===n&&t0(t))}e((()=>{t.removeEventListener(XJ,(e=>r("mountAutoFocus",e)))
;const e=new CustomEvent(GJ,YJ),o=e=>{r("unmountAutoFocus",e)}
;t.addEventListener(GJ,o),t.dispatchEvent(e),setTimeout((()=>{
e.defaultPrevented||t0(n??document.body,{select:!0
}),t.removeEventListener(GJ,o),s.remove(l)}),0)}))})),(e,t)=>(Ub(),Hb(xm(zJ),{
ref_key:"currentRef",ref:o,tabindex:"-1","as-child":e.asChild,as:e.as,
onKeydown:c},{default:ig((()=>[kv(e.$slots,"default")])),_:3
},8,["as-child","as"]))}
}),a0=["Enter"," "],i0=["ArrowUp","PageDown","End"],s0=["ArrowDown","PageUp","Home",...i0],l0={
ltr:[...a0,"ArrowRight"],rtl:[...a0,"ArrowLeft"]},c0={ltr:["ArrowLeft"],
rtl:["ArrowRight"]};function u0(e){return e?"open":"closed"}function d0(e){
return"indeterminate"===e}function p0(e){
return d0(e)?"indeterminate":e?"checked":"unchecked"}function h0(e){
return"mouse"===e.pointerType}const[f0,m0]=qK("PopperRoot"),g0=Qg({
inheritAttrs:!1,__name:"PopperRoot",setup(e){const t=bm();return m0({anchor:t,
onAnchorChange:e=>t.value=e}),(e,t)=>kv(e.$slots,"default")}}),v0=Qg({
__name:"PopperAnchor",props:{element:{},asChild:{type:Boolean},as:{}},setup(e){
const t=e,{forwardRef:n,currentElement:r}=AJ(),o=f0();return fg((()=>{
o.onAnchorChange(t.element??r.value)})),(e,t)=>(Ub(),Hb(xm(zJ),{ref:xm(n),
as:e.as,"as-child":e.asChild},{default:ig((()=>[kv(e.$slots,"default")])),_:3
},8,["as","as-child"]))}});function b0(e){return null!==e}function y0(e){return{
name:"transformOrigin",options:e,fn(t){var n,r,o
;const{placement:a,rects:i,middlewareData:s}=t,l=0!==(null==(n=s.arrow)?void 0:n.centerOffset),c=l?0:e.arrowWidth,u=l?0:e.arrowHeight,[d,p]=O0(a),h={
start:"0%",center:"50%",end:"100%"
}[p],f=((null==(r=s.arrow)?void 0:r.x)??0)+c/2,m=((null==(o=s.arrow)?void 0:o.y)??0)+u/2
;let g="",v=""
;return"bottom"===d?(g=l?h:`${f}px`,v=-u+"px"):"top"===d?(g=l?h:`${f}px`,
v=`${i.floating.height+u}px`):"right"===d?(g=-u+"px",
v=l?h:`${m}px`):"left"===d&&(g=`${i.floating.width+u}px`,v=l?h:`${m}px`),{data:{
x:g,y:v}}}}}function O0(e){const[t,n="center"]=e.split("-");return[t,n]}
const w0={side:"bottom",sideOffset:0,align:"center",alignOffset:0,
arrowPadding:0,avoidCollisions:!0,collisionBoundary:()=>[],collisionPadding:0,
sticky:"partial",hideWhenDetached:!1,updatePositionStrategy:"optimized",
prioritizePosition:!1},[x0,k0]=qK("PopperContent"),S0=Qg({inheritAttrs:!1,
__name:"PopperContent",props:Mv({side:{},sideOffset:{},align:{},alignOffset:{},
avoidCollisions:{type:Boolean},collisionBoundary:{},collisionPadding:{},
arrowPadding:{},sticky:{},hideWhenDetached:{type:Boolean},
updatePositionStrategy:{},prioritizePosition:{type:Boolean},asChild:{
type:Boolean},as:{}},{...w0}),emits:["placed"],setup(e,{emit:t}){
const n=e,r=t,o=f0(),{forwardRef:a,currentElement:i}=AJ(),s=bm(),l=bm(),{width:c,height:u}=function(e){
const t=bm(),n=Sy((()=>{var e;return(null==(e=t.value)?void 0:e.width)??0
})),r=Sy((()=>{var e;return(null==(e=t.value)?void 0:e.height)??0}))
;return iv((()=>{const n=iJ(e);if(n){t.value={width:n.offsetWidth,
height:n.offsetHeight};const e=new ResizeObserver((e=>{
if(!Array.isArray(e)||!e.length)return;const r=e[0];let o,a
;if("borderBoxSize"in r){const e=r.borderBoxSize,t=Array.isArray(e)?e[0]:e
;o=t.inlineSize,a=t.blockSize}else o=n.offsetWidth,a=n.offsetHeight;t.value={
width:o,height:a}}));return e.observe(n,{box:"border-box"}),()=>e.unobserve(n)}
t.value=void 0})),{width:n,height:r}
}(l),d=Sy((()=>n.side+("center"!==n.align?`-${n.align}`:""))),p=Sy((()=>"number"==typeof n.collisionPadding?n.collisionPadding:{
top:0,right:0,bottom:0,left:0,...n.collisionPadding
})),h=Sy((()=>Array.isArray(n.collisionBoundary)?n.collisionBoundary:[n.collisionBoundary])),f=Sy((()=>({
padding:p.value,boundary:h.value.filter(b0),altBoundary:h.value.length>0
}))),m=function(e,t){const n=ym();return fg((()=>{n.value=e()}),{...t,
flush:"sync"}),im(n)}((()=>{return[EK({mainAxis:n.sideOffset+u.value,
alignmentAxis:n.alignOffset}),n.prioritizePosition&&n.avoidCollisions&&CK({
...f.value}),n.avoidCollisions&&AK({mainAxis:!0,
crossAxis:!!n.prioritizePosition,limiter:"partial"===n.sticky?IK():void 0,
...f.value}),!n.prioritizePosition&&n.avoidCollisions&&CK({...f.value}),$K({
...f.value,apply:({elements:e,rects:t,availableWidth:n,availableHeight:r})=>{
const{width:o,height:a}=t.reference,i=e.floating.style
;i.setProperty("--radix-popper-available-width",`${n}px`),
i.setProperty("--radix-popper-available-height",`${r}px`),
i.setProperty("--radix-popper-anchor-width",`${o}px`),
i.setProperty("--radix-popper-anchor-height",`${a}px`)}}),l.value&&(e={
element:l.value,padding:n.arrowPadding},{name:"arrow",options:e,fn(t){
const n=NK(RK(e.element));return null==n?{}:DK({element:n,padding:e.padding
}).fn(t)}}),y0({arrowWidth:c.value,arrowHeight:u.value
}),n.hideWhenDetached&&PK({strategy:"referenceHidden",...f.value})];var e
})),{floatingStyles:g,placement:v,isPositioned:b,middlewareData:y}=jK(o.anchor,s,{
strategy:"fixed",placement:d,whileElementsMounted:(...e)=>TK(...e,{
animationFrame:"always"===n.updatePositionStrategy}),middleware:m
}),O=Sy((()=>O0(v.value)[0])),w=Sy((()=>O0(v.value)[1]));gg((()=>{
b.value&&r("placed")}),null,{flush:"post"});const x=Sy((()=>{var e
;return 0!==(null==(e=y.value.arrow)?void 0:e.centerOffset)})),k=bm("")
;fg((()=>{i.value&&(k.value=window.getComputedStyle(i.value).zIndex)}))
;const S=Sy((()=>{var e;return(null==(e=y.value.arrow)?void 0:e.x)??0
})),_=Sy((()=>{var e;return(null==(e=y.value.arrow)?void 0:e.y)??0}))
;return k0({placedSide:O,onArrowChange:e=>l.value=e,arrowX:S,arrowY:_,
shouldHideArrow:x}),(e,t)=>{var r,o,i;return Ub(),Qb("div",{
ref_key:"floatingRef",ref:s,"data-radix-popper-content-wrapper":"",style:Ah({
...xm(g),transform:xm(b)?xm(g).transform:"translate(0, -200%)",
minWidth:"max-content",zIndex:k.value,
"--radix-popper-transform-origin":[null==(r=xm(y).transformOrigin)?void 0:r.x,null==(o=xm(y).transformOrigin)?void 0:o.y].join(" "),
...(null==(i=xm(y).hide)?void 0:i.referenceHidden)&&{visibility:"hidden",
pointerEvents:"none"}})},[Yb(xm(zJ),iy({ref:xm(a)},e.$attrs,{
"as-child":n.asChild,as:e.as,"data-side":O.value,"data-align":w.value,style:{
animation:xm(b)?void 0:"none"}}),{default:ig((()=>[kv(e.$slots,"default")])),_:3
},16,["as-child","as","data-side","data-align","style"])],4)}}
}),_0=Gb("polygon",{points:"0,0 30,0 15,10"},null,-1),T0=Qg({__name:"Arrow",
props:{width:{default:10},height:{default:5},asChild:{type:Boolean},as:{
default:"svg"}},setup(e){const t=e;return AJ(),(e,n)=>(Ub(),Hb(xm(zJ),iy(t,{
width:e.width,height:e.height,viewBox:e.asChild?void 0:"0 0 30 10",
preserveAspectRatio:e.asChild?void 0:"none"}),{
default:ig((()=>[kv(e.$slots,"default",{},(()=>[_0]))])),_:3
},16,["width","height","viewBox","preserveAspectRatio"]))}}),E0={top:"bottom",
right:"left",bottom:"top",left:"right"},A0=Qg({inheritAttrs:!1,
__name:"PopperArrow",props:{width:{},height:{},asChild:{type:Boolean},as:{
default:"svg"}},setup(e){
const{forwardRef:t}=AJ(),n=x0(),r=Sy((()=>E0[n.placedSide.value]))
;return(e,o)=>{var a,i,s,l;return Ub(),Qb("span",{ref:e=>{xm(n).onArrowChange(e)
},style:Ah({position:"absolute",
left:null!=(a=xm(n).arrowX)&&a.value?`${null==(i=xm(n).arrowX)?void 0:i.value}px`:void 0,
top:null!=(s=xm(n).arrowY)&&s.value?`${null==(l=xm(n).arrowY)?void 0:l.value}px`:void 0,
[r.value]:0,transformOrigin:{top:"",right:"0 0",bottom:"center 0",left:"100% 0"
}[xm(n).placedSide.value],transform:{top:"translateY(100%)",
right:"translateY(50%) rotate(90deg) translateX(-50%)",bottom:"rotate(180deg)",
left:"translateY(50%) rotate(-90deg) translateX(50%)"}[xm(n).placedSide.value],
visibility:xm(n).shouldHideArrow.value?"hidden":void 0})},[Yb(T0,iy(e.$attrs,{
ref:xm(t),style:{display:"block"},as:e.as,"as-child":e.asChild,width:e.width,
height:e.height}),{default:ig((()=>[kv(e.$slots,"default")])),_:3
},16,["as","as-child","width","height"])],4)}}
}),[C0,$0]=qK("CollectionProvider")
;function P0(e="data-radix-vue-collection-item"){
const t=bm(new Map),n=bm(),r=$0({collectionRef:n,itemMap:t,attrName:e
}),{getItems:o}=function(e){const t=e??C0();return{getItems:()=>{
const e=t.collectionRef.value;if(!e)return[]
;const n=Array.from(e.querySelectorAll(`[${t.attrName}]`))
;return Array.from(t.itemMap.value.values()).sort(((e,t)=>n.indexOf(e.ref)-n.indexOf(t.ref)))
}}}(r);return{getItems:o,
reactiveItems:Sy((()=>Array.from(r.itemMap.value.values()))),
itemMapSize:Sy((()=>r.itemMap.value.size))}}const D0=Qg({name:"CollectionSlot",
setup(e,{slots:t}){const n=C0(),{primitiveElement:r,currentElement:o}=FJ()
;return mg(o,(()=>{n.collectionRef.value=o.value})),()=>_y(UJ,{ref:r},t)}
}),I0=Qg({name:"CollectionItem",inheritAttrs:!1,props:{value:{validator:()=>!0}
},setup(e,{slots:t,attrs:n}){
const r=C0(),{primitiveElement:o,currentElement:a}=FJ();return fg((t=>{
if(a.value){const n=fm(a.value);r.itemMap.value.set(n,{ref:a.value,value:e.value
}),t((()=>r.itemMap.value.delete(n)))}})),()=>_y(UJ,{...n,[r.attrName]:"",ref:o
},t)}});const M0=Qg({__name:"MenuAnchor",props:{element:{},asChild:{type:Boolean
},as:{}},setup(e){const t=e;return(e,n)=>(Ub(),Hb(xm(v0),Mh(Kb(t)),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}}),N0=Qg({
__name:"MenuArrow",props:{width:{},height:{},asChild:{type:Boolean},as:{}},
setup(e){const t=e;return(e,n)=>(Ub(),Hb(xm(A0),Mh(Kb(t)),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}});const R0=GK((function(){
const e=bm(!1);return iv((()=>{lJ("keydown",(()=>{e.value=!0}),{capture:!0,
passive:!0}),lJ(["pointerdown","pointermove"],(()=>{e.value=!1}),{capture:!0,
passive:!0})})),e
})),[L0,B0]=qK(["MenuRoot","MenuSub"],"MenuContext"),[j0,U0]=qK("MenuRoot"),z0=Qg({
__name:"MenuRoot",props:{open:{type:Boolean,default:!1},dir:{},modal:{
type:Boolean,default:!0}},emits:["update:open"],setup(e,{emit:t}){
const n=e,r=t,{modal:o,dir:a}=Am(n),i=kJ(a),s=uJ(n,"open",r),l=bm(),c=R0()
;return B0({open:s,onOpenChange:e=>{s.value=e},content:l,onContentChange:e=>{
l.value=e}}),U0({onClose:()=>{s.value=!1},isUsingKeyboardRef:c,dir:i,modal:o
}),(e,t)=>(Ub(),Hb(xm(g0),null,{default:ig((()=>[kv(e.$slots,"default")])),_:3
}))}}),F0={bubbles:!1,cancelable:!0};const[Z0,Q0]=qK("RovingFocusGroup"),H0=Qg({
__name:"RovingFocusGroup",props:{orientation:{default:void 0},dir:{},loop:{
type:Boolean,default:!1},currentTabStopId:{},defaultCurrentTabStopId:{},
preventScrollOnEntryFocus:{type:Boolean,default:!1},asChild:{type:Boolean},as:{}
},emits:["entryFocus","update:currentTabStopId"],setup(e,{expose:t,emit:n}){
const r=e,o=n,{loop:a,orientation:i,dir:s}=Am(r),l=kJ(s),c=uJ(r,"currentTabStopId",o,{
defaultValue:r.defaultCurrentTabStopId,passive:void 0===r.currentTabStopId
}),u=bm(!1),d=bm(!1),p=bm(0),{getItems:h}=P0();function f(e){const t=!d.value
;if(e.currentTarget&&e.target===e.currentTarget&&t&&!u.value){
const t=new CustomEvent("rovingFocusGroup.onEntryFocus",F0)
;if(e.currentTarget.dispatchEvent(t),o("entryFocus",t),!t.defaultPrevented){
const e=h().map((e=>e.ref)).filter((e=>""!==e.dataset.disabled))
;!function(e,t=!1){const n=pJ();for(const r of e)if(r===n||(r.focus({
preventScroll:t}),pJ()!==n))return
}([e.find((e=>"true"===e.getAttribute("data-active"))),e.find((e=>e.id===c.value)),...e].filter(Boolean),r.preventScrollOnEntryFocus)
}}d.value=!1}function m(){setTimeout((()=>{d.value=!1}),1)}return t({getItems:h
}),Q0({loop:a,dir:l,orientation:i,currentTabStopId:c,onItemFocus:e=>{c.value=e},
onItemShiftTab:()=>{u.value=!0},onFocusableItemAdd:()=>{p.value++},
onFocusableItemRemove:()=>{p.value--}}),(e,t)=>(Ub(),Hb(xm(D0),null,{
default:ig((()=>[Yb(xm(zJ),{tabindex:u.value||0===p.value?-1:0,
"data-orientation":xm(i),as:e.as,"as-child":e.asChild,dir:xm(l),style:{
outline:"none"},onMousedown:t[0]||(t[0]=e=>d.value=!0),onMouseup:m,onFocus:f,
onBlur:t[1]||(t[1]=e=>u.value=!1)},{default:ig((()=>[kv(e.$slots,"default")])),
_:3},8,["tabindex","data-orientation","as","as-child","dir"])])),_:3}))}
}),[V0,q0]=qK("MenuContent"),W0=Qg({__name:"MenuContentImpl",props:Mv({loop:{
type:Boolean},disableOutsidePointerEvents:{type:Boolean},disableOutsideScroll:{
type:Boolean},trapFocus:{type:Boolean},side:{},sideOffset:{},align:{},
alignOffset:{},avoidCollisions:{type:Boolean},collisionBoundary:{},
collisionPadding:{},arrowPadding:{},sticky:{},hideWhenDetached:{type:Boolean},
updatePositionStrategy:{},prioritizePosition:{type:Boolean},asChild:{
type:Boolean},as:{}},{...w0}),
emits:["escapeKeyDown","pointerDownOutside","focusOutside","interactOutside","entryFocus","openAutoFocus","closeAutoFocus","dismiss"],
setup(e,{emit:t}){
const n=e,r=t,o=L0(),a=j0(),{trapFocus:i,disableOutsidePointerEvents:s,loop:l}=Am(n)
;fg((e=>{if(!KK)return
;const t=document.querySelectorAll("[data-radix-focus-guard]")
;document.body.insertAdjacentElement("afterbegin",t[0]??TJ()),
document.body.insertAdjacentElement("beforeend",t[1]??TJ()),_J++,e((()=>{
1===_J&&document.querySelectorAll("[data-radix-focus-guard]").forEach((e=>e.remove())),
_J--}))})),wJ(s.value)
;const c=bm(""),u=bm(0),d=bm(0),p=bm(null),h=bm("right"),f=bm(0),m=bm(null),{createCollection:g}=function(e,t="data-radix-vue-collection-item"){
const n=Symbol();return{createCollection:e=>{const r=bm([]);function o(){
const n=iJ(e)
;return r.value=n?Array.from(n.querySelectorAll(`[${t}]:not([data-disabled])`)):[]
}return sv((()=>{r.value=[]})),iv(o),lv(o),mg((()=>null==e?void 0:e.value),o,{
immediate:!0}),cg(n,r),r},injectCollection:()=>ug(n,bm([]))}
}(),{forwardRef:v,currentElement:b}=AJ(),y=g(b);mg(b,(e=>{o.onContentChange(e)
}));const{handleTypeaheadSearch:O}=jJ(y);function w(e){var t,n
;return h.value===(null==(t=p.value)?void 0:t.side)&&function(e,t){
return!!t&&function(e,t){const{x:n,y:r}=e;let o=!1
;for(let a=0,i=t.length-1;a<t.length;i=a++){
const e=t[a].x,s=t[a].y,l=t[i].x,c=t[i].y
;s>r!=c>r&&n<(l-e)*(r-s)/(c-s)+e&&(o=!o)}return o}({x:e.clientX,y:e.clientY},t)
}(e,null==(n=p.value)?void 0:n.area)}async function x(e){var t
;r("openAutoFocus",e),
!e.defaultPrevented&&(e.preventDefault(),null==(t=b.value)||t.focus({
preventScroll:!0}))}function k(e){if(e.defaultPrevented)return
;const t=e.target.closest("[data-radix-menu-content]")===e.currentTarget,n=e.ctrlKey||e.altKey||e.metaKey,r=1===e.key.length,o=fJ(e,pJ(),b.value,{
loop:l.value,arrowKeyOptions:"vertical",dir:null==a?void 0:a.dir.value,focus:!0,
attributeName:"[data-radix-vue-collection-item]:not([data-disabled])"})
;if(o)return null==o?void 0:o.focus()
;if("Space"===e.code||(t&&("Tab"===e.key&&e.preventDefault(),
!n&&r&&O(e.key)),e.target!==b.value)||!s0.includes(e.key))return
;e.preventDefault();const i=y.value;i0.includes(e.key)&&i.reverse(),function(e){
const t=pJ();for(const n of e)if(n===t||(n.focus(),pJ()!==t))return}(i)}
function S(e){var t,n
;null!=(n=null==(t=null==e?void 0:e.currentTarget)?void 0:t.contains)&&n.call(t,e.target)||(window.clearTimeout(u.value),
c.value="")}function _(e){var t;if(!h0(e))return
;const n=e.target,r=f.value!==e.clientX
;if(null!=(t=null==e?void 0:e.currentTarget)&&t.contains(n)&&r){
const t=e.clientX>f.value?"right":"left";h.value=t,f.value=e.clientX}}
return uv((()=>{window.clearTimeout(u.value)})),q0({onItemEnter:e=>!!w(e),
onItemLeave:e=>{var t;w(e)||(null==(t=b.value)||t.focus(),m.value=null)},
onTriggerLeave:e=>!!w(e),searchRef:c,pointerGraceTimerRef:d,
onPointerGraceIntentChange:e=>{p.value=e}}),(e,t)=>(Ub(),Hb(xm(o0),{
"as-child":"",trapped:xm(i),onMountAutoFocus:x,
onUnmountAutoFocus:t[7]||(t[7]=e=>r("closeAutoFocus",e))},{
default:ig((()=>[Yb(xm(WJ),{"as-child":"",
"disable-outside-pointer-events":xm(s),
onEscapeKeyDown:t[2]||(t[2]=e=>r("escapeKeyDown",e)),
onPointerDownOutside:t[3]||(t[3]=e=>r("pointerDownOutside",e)),
onFocusOutside:t[4]||(t[4]=e=>r("focusOutside",e)),
onInteractOutside:t[5]||(t[5]=e=>r("interactOutside",e)),
onDismiss:t[6]||(t[6]=e=>r("dismiss"))},{default:ig((()=>[Yb(xm(H0),{
"current-tab-stop-id":m.value,
"onUpdate:currentTabStopId":t[0]||(t[0]=e=>m.value=e),"as-child":"",
orientation:"vertical",dir:xm(a).dir.value,loop:xm(l),
onEntryFocus:t[1]||(t[1]=e=>{
r("entryFocus",e),xm(a).isUsingKeyboardRef.value||e.preventDefault()})},{
default:ig((()=>[Yb(xm(S0),{ref:xm(v),role:"menu",as:e.as,"as-child":e.asChild,
"aria-orientation":"vertical","data-radix-menu-content":"",
"data-state":xm(u0)(xm(o).open.value),dir:xm(a).dir.value,side:e.side,
"side-offset":e.sideOffset,align:e.align,"align-offset":e.alignOffset,
"avoid-collisions":e.avoidCollisions,"collision-boundary":e.collisionBoundary,
"collision-padding":e.collisionPadding,"arrow-padding":e.arrowPadding,
"prioritize-position":e.prioritizePosition,sticky:e.sticky,
"hide-when-detached":e.hideWhenDetached,onKeydown:k,onBlur:S,onPointermove:_},{
default:ig((()=>[kv(e.$slots,"default")])),_:3
},8,["as","as-child","data-state","dir","side","side-offset","align","align-offset","avoid-collisions","collision-boundary","collision-padding","arrow-padding","prioritize-position","sticky","hide-when-detached"])])),
_:3},8,["current-tab-stop-id","dir","loop"])])),_:3
},8,["disable-outside-pointer-events"])])),_:3},8,["trapped"]))}}),X0=Qg({
inheritAttrs:!1,__name:"MenuItemImpl",props:{disabled:{type:Boolean},
textValue:{},asChild:{type:Boolean},as:{}},setup(e){
const t=e,n=V0(),{forwardRef:r}=AJ(),o=bm(!1);async function a(e){
if(!e.defaultPrevented&&h0(e))if(t.disabled)n.onItemLeave(e);else if(!n.onItemEnter(e)){
const t=e.currentTarget;null==t||t.focus({preventScroll:!0})}}
async function i(e){await Xm(),!e.defaultPrevented&&h0(e)&&n.onItemLeave(e)}
return(e,t)=>(Ub(),Hb(xm(I0),{value:{textValue:e.textValue}},{
default:ig((()=>[Yb(xm(zJ),iy({ref:xm(r),role:"menuitem",tabindex:"-1"
},e.$attrs,{as:e.as,"as-child":e.asChild,"data-radix-vue-collection-item":"",
"aria-disabled":e.disabled||void 0,"data-disabled":e.disabled?"":void 0,
"data-highlighted":o.value?"":void 0,onPointermove:a,onPointerleave:i,
onFocus:t[0]||(t[0]=async t=>{
await Xm(),!t.defaultPrevented&&!e.disabled&&(o.value=!0)}),
onBlur:t[1]||(t[1]=async e=>{await Xm(),!e.defaultPrevented&&(o.value=!1)})}),{
default:ig((()=>[kv(e.$slots,"default")])),_:3
},16,["as","as-child","aria-disabled","data-disabled","data-highlighted"])])),
_:3},8,["value"]))}}),G0=Qg({__name:"MenuItem",props:{disabled:{type:Boolean},
textValue:{},asChild:{type:Boolean},as:{}},emits:["select"],setup(e,{emit:t}){
const n=e,r=t,{forwardRef:o,currentElement:a}=AJ(),i=j0(),s=V0(),l=bm(!1)
;async function c(){const e=a.value;if(!n.disabled&&e){
const e=new CustomEvent("menu.itemSelect",{bubbles:!0,cancelable:!0})
;r("select",e),await Xm(),e.defaultPrevented?l.value=!1:i.onClose()}}
return(e,t)=>(Ub(),Hb(X0,iy(n,{ref:xm(o),onClick:c,
onPointerdown:t[0]||(t[0]=()=>{l.value=!0}),onPointerup:t[1]||(t[1]=async e=>{
var t
;await Xm(),!e.defaultPrevented&&(l.value||null==(t=e.currentTarget)||t.click())
}),onKeydown:t[2]||(t[2]=async t=>{const n=""!==xm(s).searchRef.value
;e.disabled||n&&" "===t.key||xm(a0).includes(t.key)&&(t.currentTarget.click(),
t.preventDefault())})}),{default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}
}),[Y0,K0]=qK(["MenuCheckboxItem","MenuRadioItem"],"MenuItemIndicatorContext"),J0=Qg({
__name:"MenuItemIndicator",props:{forceMount:{type:Boolean},asChild:{
type:Boolean},as:{default:"span"}},setup(e){const t=Y0({checked:bm(!1)})
;return(e,n)=>(Ub(),Hb(xm(QJ),{
present:e.forceMount||xm(d0)(xm(t).checked.value)||!0===xm(t).checked.value},{
default:ig((()=>[Yb(xm(zJ),{as:e.as,"as-child":e.asChild,
"data-state":xm(p0)(xm(t).checked.value)},{
default:ig((()=>[kv(e.$slots,"default")])),_:3
},8,["as","as-child","data-state"])])),_:3},8,["present"]))}}),e1=Qg({
__name:"MenuCheckboxItem",props:{checked:{type:[Boolean,String],default:!1},
disabled:{type:Boolean},textValue:{},asChild:{type:Boolean},as:{}},
emits:["select","update:checked"],setup(e,{emit:t}){
const n=e,r=t,o=uJ(n,"checked",r);return K0({checked:o}),(e,t)=>(Ub(),Hb(G0,iy({
role:"menuitemcheckbox"},n,{"aria-checked":xm(d0)(xm(o))?"mixed":xm(o),
"data-state":xm(p0)(xm(o)),onSelect:t[0]||(t[0]=async e=>{
r("select",e),xm(d0)(xm(o))?o.value=!0:o.value=!xm(o)})}),{
default:ig((()=>[kv(e.$slots,"default",{checked:xm(o)})])),_:3
},16,["aria-checked","data-state"]))}}),t1=Qg({__name:"MenuRootContentModal",
props:{loop:{type:Boolean},side:{},sideOffset:{},align:{},alignOffset:{},
avoidCollisions:{type:Boolean},collisionBoundary:{},collisionPadding:{},
arrowPadding:{},sticky:{},hideWhenDetached:{type:Boolean},
updatePositionStrategy:{},prioritizePosition:{type:Boolean},asChild:{
type:Boolean},as:{}},
emits:["escapeKeyDown","pointerDownOutside","focusOutside","interactOutside","entryFocus","openAutoFocus","closeAutoFocus"],
setup(e,{emit:t}){
const n=t,r=EJ(e,n),o=L0(),{forwardRef:a,currentElement:i}=AJ()
;return function(e){let t;mg((()=>iJ(e)),(e=>{e?t=NJ(e):t&&t()})),uv((()=>{
t&&t()}))}(i),(e,t)=>(Ub(),Hb(W0,iy(xm(r),{ref:xm(a),
"trap-focus":xm(o).open.value,"disable-outside-pointer-events":xm(o).open.value,
"disable-outside-scroll":!0,onDismiss:t[0]||(t[0]=e=>xm(o).onOpenChange(!1)),
onFocusOutside:t[1]||(t[1]=BO((e=>n("focusOutside",e)),["prevent"]))}),{
default:ig((()=>[kv(e.$slots,"default")])),_:3
},16,["trap-focus","disable-outside-pointer-events"]))}}),n1=Qg({
__name:"MenuRootContentNonModal",props:{loop:{type:Boolean},side:{},
sideOffset:{},align:{},alignOffset:{},avoidCollisions:{type:Boolean},
collisionBoundary:{},collisionPadding:{},arrowPadding:{},sticky:{},
hideWhenDetached:{type:Boolean},updatePositionStrategy:{},prioritizePosition:{
type:Boolean},asChild:{type:Boolean},as:{}},
emits:["escapeKeyDown","pointerDownOutside","focusOutside","interactOutside","entryFocus","openAutoFocus","closeAutoFocus"],
setup(e,{emit:t}){const n=EJ(e,t),r=L0();return(e,t)=>(Ub(),Hb(W0,iy(xm(n),{
"trap-focus":!1,"disable-outside-pointer-events":!1,"disable-outside-scroll":!1,
onDismiss:t[0]||(t[0]=e=>xm(r).onOpenChange(!1))}),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}}),r1=Qg({
__name:"MenuContent",props:{forceMount:{type:Boolean},loop:{type:Boolean},
side:{},sideOffset:{},align:{},alignOffset:{},avoidCollisions:{type:Boolean},
collisionBoundary:{},collisionPadding:{},arrowPadding:{},sticky:{},
hideWhenDetached:{type:Boolean},updatePositionStrategy:{},prioritizePosition:{
type:Boolean},asChild:{type:Boolean},as:{}},
emits:["escapeKeyDown","pointerDownOutside","focusOutside","interactOutside","entryFocus","openAutoFocus","closeAutoFocus"],
setup(e,{emit:t}){const n=EJ(e,t),r=L0(),o=j0();return(e,t)=>(Ub(),Hb(xm(QJ),{
present:e.forceMount||xm(r).open.value},{
default:ig((()=>[xm(o).modal.value?(Ub(),Hb(t1,Mh(iy({key:0},{...e.$attrs,
...xm(n)})),{default:ig((()=>[kv(e.$slots,"default")])),_:3
},16)):(Ub(),Hb(n1,Mh(iy({key:1},{...e.$attrs,...xm(n)})),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))])),_:3},8,["present"]))}
}),o1=Qg({__name:"MenuGroup",props:{asChild:{type:Boolean},as:{}},setup(e){
const t=e;return(e,n)=>(Ub(),Hb(xm(zJ),iy({role:"group"},t),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}}),a1=Qg({
__name:"MenuLabel",props:{asChild:{type:Boolean},as:{default:"div"}},setup(e){
const t=e;return(e,n)=>(Ub(),Hb(xm(zJ),Mh(Kb(t)),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}}),i1=Qg({
__name:"MenuPortal",props:{to:{},disabled:{type:Boolean},forceMount:{
type:Boolean}},setup(e){const t=e;return(e,n)=>(Ub(),Hb(xm(HJ),Mh(Kb(t)),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}
}),[s1,l1]=qK("MenuRadioGroup"),c1=Qg({__name:"MenuRadioGroup",props:{
modelValue:{default:""},asChild:{type:Boolean},as:{}},
emits:["update:modelValue"],setup(e,{emit:t}){const n=e,r=uJ(n,"modelValue",t)
;return l1({modelValue:r,onValueChange:e=>{r.value=e}
}),(e,t)=>(Ub(),Hb(o1,Mh(Kb(n)),{default:ig((()=>[kv(e.$slots,"default",{
modelValue:xm(r)})])),_:3},16))}}),u1=Qg({__name:"MenuRadioItem",props:{
value:{},disabled:{type:Boolean},textValue:{},asChild:{type:Boolean},as:{}},
emits:["select"],setup(e,{emit:t}){
const n=e,r=t,{value:o}=Am(n),a=s1(),i=Sy((()=>a.modelValue.value===(null==o?void 0:o.value)))
;return K0({checked:i}),(e,t)=>(Ub(),Hb(G0,iy({role:"menuitemradio"},n,{
"aria-checked":i.value,"data-state":xm(p0)(i.value),
onSelect:t[0]||(t[0]=async e=>{r("select",e),xm(a).onValueChange(xm(o))})}),{
default:ig((()=>[kv(e.$slots,"default")])),_:3
},16,["aria-checked","data-state"]))}}),d1=Qg({__name:"MenuSeparator",props:{
asChild:{type:Boolean},as:{}},setup(e){const t=e
;return(e,n)=>(Ub(),Hb(xm(zJ),iy(t,{role:"separator",
"aria-orientation":"horizontal"}),{default:ig((()=>[kv(e.$slots,"default")])),
_:3},16))}}),[p1,h1]=qK("MenuSub"),f1=Qg({__name:"MenuSub",props:{open:{
type:Boolean,default:void 0}},emits:["update:open"],setup(e,{emit:t}){
const n=uJ(e,"open",t,{defaultValue:!1,passive:void 0===e.open
}),r=L0(),o=bm(),a=bm();return fg((e=>{
!1===(null==r?void 0:r.open.value)&&(n.value=!1),e((()=>n.value=!1))})),B0({
open:n,onOpenChange:e=>{n.value=e},content:a,onContentChange:e=>{a.value=e}
}),h1({triggerId:"",contentId:"",trigger:o,onTriggerChange:e=>{o.value=e}
}),(e,t)=>(Ub(),Hb(xm(g0),null,{default:ig((()=>[kv(e.$slots,"default")])),_:3
}))}}),m1=Qg({__name:"MenuSubContent",props:{forceMount:{type:Boolean},loop:{
type:Boolean},sideOffset:{},alignOffset:{},avoidCollisions:{type:Boolean},
collisionBoundary:{},collisionPadding:{},arrowPadding:{},sticky:{},
hideWhenDetached:{type:Boolean},updatePositionStrategy:{},prioritizePosition:{
type:Boolean,default:!0},asChild:{type:Boolean},as:{}},
emits:["escapeKeyDown","pointerDownOutside","focusOutside","interactOutside","entryFocus","openAutoFocus","closeAutoFocus"],
setup(e,{emit:t}){
const n=EJ(e,t),r=L0(),o=j0(),a=p1(),{forwardRef:i,currentElement:s}=AJ()
;return a.contentId||(a.contentId=LJ(0,"radix-vue-menu-sub-content")),
(e,t)=>(Ub(),Hb(xm(QJ),{present:e.forceMount||xm(r).open.value},{
default:ig((()=>[Yb(W0,iy(xm(n),{id:xm(a).contentId,ref:xm(i),
"aria-labelledby":xm(a).triggerId,align:"start",
side:"rtl"===xm(o).dir.value?"left":"right","disable-outside-pointer-events":!1,
"disable-outside-scroll":!1,"trap-focus":!1,onOpenAutoFocus:t[0]||(t[0]=BO((e=>{
var t;xm(o).isUsingKeyboardRef.value&&(null==(t=xm(s))||t.focus())
}),["prevent"])),onCloseAutoFocus:t[1]||(t[1]=BO((()=>{}),["prevent"])),
onFocusOutside:t[2]||(t[2]=e=>{
e.defaultPrevented||e.target!==xm(a).trigger.value&&xm(r).onOpenChange(!1)}),
onEscapeKeyDown:t[3]||(t[3]=e=>{xm(o).onClose(),e.preventDefault()}),
onKeydown:t[4]||(t[4]=e=>{var t,n
;const i=null==(t=e.currentTarget)?void 0:t.contains(e.target),s=xm(c0)[xm(o).dir.value].includes(e.key)
;i&&s&&(xm(r).onOpenChange(!1),
null==(n=xm(a).trigger.value)||n.focus(),e.preventDefault())})}),{
default:ig((()=>[kv(e.$slots,"default")])),_:3
},16,["id","aria-labelledby","side"])])),_:3},8,["present"]))}}),g1=Qg({
__name:"MenuSubTrigger",props:{disabled:{type:Boolean},textValue:{},asChild:{
type:Boolean},as:{}},setup(e){const t=e,n=L0(),r=j0(),o=p1(),a=V0(),i=bm(null)
;function s(){i.value&&window.clearTimeout(i.value),i.value=null}function l(e){
!h0(e)||a.onItemEnter(e)||!t.disabled&&!n.open.value&&!i.value&&(a.onPointerGraceIntentChange(null),
i.value=window.setTimeout((()=>{n.onOpenChange(!0),s()}),100))}
async function c(e){var t,r;if(!h0(e))return;s()
;const o=null==(t=n.content.value)?void 0:t.getBoundingClientRect()
;if(null!=o&&o.width){
const t=null==(r=n.content.value)?void 0:r.dataset.side,i="right"===t,s=i?-5:5,l=o[i?"left":"right"],c=o[i?"right":"left"]
;a.onPointerGraceIntentChange({area:[{x:e.clientX+s,y:e.clientY},{x:l,y:o.top},{
x:c,y:o.top},{x:c,y:o.bottom},{x:l,y:o.bottom}],side:t
}),window.clearTimeout(a.pointerGraceTimerRef.value),
a.pointerGraceTimerRef.value=window.setTimeout((()=>a.onPointerGraceIntentChange(null)),300)
}else{if(a.onTriggerLeave(e))return;a.onPointerGraceIntentChange(null)}}
async function u(e){var o;const i=""!==a.searchRef.value
;t.disabled||i&&" "===e.key||l0[r.dir.value].includes(e.key)&&(n.onOpenChange(!0),
await Xm(),null==(o=n.content.value)||o.focus(),e.preventDefault())}
return o.triggerId||(o.triggerId=LJ(0,"radix-vue-menu-sub-trigger")),uv((()=>{
s()})),(e,r)=>(Ub(),Hb(M0,{"as-child":""},{default:ig((()=>[Yb(X0,iy(t,{
id:xm(o).triggerId,ref:e=>{var t
;null==(t=xm(o))||t.onTriggerChange(null==e?void 0:e.$el)},
"aria-haspopup":"menu","aria-expanded":xm(n).open.value,
"aria-controls":xm(o).contentId,"data-state":xm(u0)(xm(n).open.value),
onClick:r[0]||(r[0]=async e=>{
t.disabled||e.defaultPrevented||(e.currentTarget.focus(),
xm(n).open.value||xm(n).onOpenChange(!0))}),onPointermove:l,onPointerleave:c,
onKeydown:u}),{default:ig((()=>[kv(e.$slots,"default")])),_:3
},16,["id","aria-expanded","aria-controls","data-state"])])),_:3}))}
}),[v1,b1]=qK("DropdownMenuRoot"),y1=Qg({__name:"DropdownMenuRoot",props:{
defaultOpen:{type:Boolean},open:{type:Boolean,default:void 0},dir:{},modal:{
type:Boolean,default:!0}},emits:["update:open"],setup(e,{emit:t}){const n=e,r=t
;AJ();const o=uJ(n,"open",r,{defaultValue:n.defaultOpen,passive:void 0===n.open
}),a=bm(),{modal:i,dir:s}=Am(n),l=kJ(s);return b1({open:o,onOpenChange:e=>{
o.value=e},onOpenToggle:()=>{o.value=!o.value},triggerId:"",triggerElement:a,
contentId:"",modal:i,dir:l}),(e,t)=>(Ub(),Hb(xm(z0),{open:xm(o),
"onUpdate:open":t[0]||(t[0]=e=>vm(o)?o.value=e:null),dir:xm(l),modal:xm(i)},{
default:ig((()=>[kv(e.$slots,"default",{open:xm(o)})])),_:3
},8,["open","dir","modal"]))}}),O1=Qg({__name:"DropdownMenuTrigger",props:{
disabled:{type:Boolean},asChild:{type:Boolean},as:{default:"button"}},setup(e){
const t=e,n=v1(),{forwardRef:r,currentElement:o}=AJ();return iv((()=>{
n.triggerElement=o
})),n.triggerId||(n.triggerId=LJ(0,"radix-vue-dropdown-menu-trigger")),
(e,o)=>(Ub(),Hb(xm(M0),{"as-child":""},{default:ig((()=>[Yb(xm(zJ),{
id:xm(n).triggerId,ref:xm(r),type:"button"===e.as?"button":void 0,
"as-child":t.asChild,as:e.as,"aria-haspopup":"menu",
"aria-expanded":xm(n).open.value,
"aria-controls":xm(n).open.value?xm(n).contentId:void 0,
"data-disabled":e.disabled?"":void 0,disabled:e.disabled,
"data-state":xm(n).open.value?"open":"closed",onClick:o[0]||(o[0]=async t=>{
var r
;!e.disabled&&0===t.button&&!1===t.ctrlKey&&(null==(r=xm(n))||r.onOpenToggle(),
await Xm(),xm(n).open.value&&t.preventDefault())}),
onKeydown:o[1]||(o[1]=UO((t=>{
e.disabled||(["Enter"," "].includes(t.key)&&xm(n).onOpenToggle(),
"ArrowDown"===t.key&&xm(n).onOpenChange(!0),
["Enter"," ","ArrowDown"].includes(t.key)&&t.preventDefault())
}),["enter","space","arrow-down"]))},{
default:ig((()=>[kv(e.$slots,"default")])),_:3
},8,["id","type","as-child","as","aria-expanded","aria-controls","data-disabled","disabled","data-state"])])),
_:3}))}}),w1=Qg({__name:"DropdownMenuPortal",props:{to:{},disabled:{type:Boolean
},forceMount:{type:Boolean}},setup(e){const t=e
;return(e,n)=>(Ub(),Hb(xm(i1),Mh(Kb(t)),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}}),x1=Qg({
__name:"DropdownMenuContent",props:{forceMount:{type:Boolean},loop:{type:Boolean
},side:{},sideOffset:{},align:{},alignOffset:{},avoidCollisions:{type:Boolean},
collisionBoundary:{},collisionPadding:{},arrowPadding:{},sticky:{},
hideWhenDetached:{type:Boolean},updatePositionStrategy:{},prioritizePosition:{
type:Boolean},asChild:{type:Boolean},as:{}},
emits:["escapeKeyDown","pointerDownOutside","focusOutside","interactOutside","closeAutoFocus"],
setup(e,{emit:t}){const n=EJ(e,t);AJ();const r=v1(),o=bm(!1);function a(e){
e.defaultPrevented||(o.value||setTimeout((()=>{var e
;null==(e=r.triggerElement.value)||e.focus()}),0),o.value=!1,e.preventDefault())
}
return r.contentId||(r.contentId=LJ(0,"radix-vue-dropdown-menu-content")),(e,t)=>{
var i;return Ub(),Hb(xm(r1),iy(xm(n),{id:xm(r).contentId,
"aria-labelledby":null==(i=xm(r))?void 0:i.triggerId,style:{
"--radix-dropdown-menu-content-transform-origin":"var(--radix-popper-transform-origin)",
"--radix-dropdown-menu-content-available-width":"var(--radix-popper-available-width)",
"--radix-dropdown-menu-content-available-height":"var(--radix-popper-available-height)",
"--radix-dropdown-menu-trigger-width":"var(--radix-popper-anchor-width)",
"--radix-dropdown-menu-trigger-height":"var(--radix-popper-anchor-height)"},
onCloseAutoFocus:a,onInteractOutside:t[0]||(t[0]=e=>{var t
;if(e.defaultPrevented)return
;const n=e.detail.originalEvent,a=0===n.button&&!0===n.ctrlKey,i=2===n.button||a
;(!xm(r).modal.value||i)&&(o.value=!0),
null!=(t=xm(r).triggerElement.value)&&t.contains(e.target)&&e.preventDefault()})
}),{default:ig((()=>[kv(e.$slots,"default")])),_:3},16,["id","aria-labelledby"])
}}}),k1=Qg({__name:"DropdownMenuArrow",props:{width:{default:10},height:{
default:5},asChild:{type:Boolean},as:{default:"svg"}},setup(e){const t=e
;return AJ(),(e,n)=>(Ub(),Hb(xm(N0),Mh(Kb(t)),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}}),S1=Qg({
__name:"DropdownMenuItem",props:{disabled:{type:Boolean},textValue:{},asChild:{
type:Boolean},as:{}},emits:["select"],setup(e,{emit:t}){const n=e,r=SJ(t)
;return AJ(),(e,t)=>(Ub(),Hb(xm(G0),Mh(Kb({...n,...xm(r)})),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}}),_1=Qg({
__name:"DropdownMenuGroup",props:{asChild:{type:Boolean},as:{}},setup(e){
const t=e;return AJ(),(e,n)=>(Ub(),Hb(xm(o1),Mh(Kb(t)),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}}),T1=Qg({
__name:"DropdownMenuSeparator",props:{asChild:{type:Boolean},as:{}},setup(e){
const t=e;return AJ(),(e,n)=>(Ub(),Hb(xm(d1),Mh(Kb(t)),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}}),E1=Qg({
__name:"DropdownMenuCheckboxItem",props:{checked:{type:[Boolean,String]},
disabled:{type:Boolean},textValue:{},asChild:{type:Boolean},as:{}},
emits:["select","update:checked"],setup(e,{emit:t}){const n=e,r=SJ(t)
;return AJ(),(e,t)=>(Ub(),Hb(xm(e1),Mh(Kb({...n,...xm(r)})),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}}),A1=Qg({
__name:"DropdownMenuItemIndicator",props:{forceMount:{type:Boolean},asChild:{
type:Boolean},as:{}},setup(e){const t=e
;return AJ(),(e,n)=>(Ub(),Hb(xm(J0),Mh(Kb(t)),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}}),C1=Qg({
__name:"DropdownMenuLabel",props:{asChild:{type:Boolean},as:{}},setup(e){
const t=e;return AJ(),(e,n)=>(Ub(),Hb(xm(a1),Mh(Kb(t)),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}}),$1=Qg({
__name:"DropdownMenuRadioGroup",props:{modelValue:{},asChild:{type:Boolean},
as:{}},emits:["update:modelValue"],setup(e,{emit:t}){const n=e,r=SJ(t)
;return AJ(),(e,t)=>(Ub(),Hb(xm(c1),Mh(Kb({...n,...xm(r)})),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}}),P1=Qg({
__name:"DropdownMenuRadioItem",props:{value:{},disabled:{type:Boolean},
textValue:{},asChild:{type:Boolean},as:{}},emits:["select"],setup(e,{emit:t}){
const n=EJ(e,t);return AJ(),(e,t)=>(Ub(),Hb(xm(u1),Mh(Kb(xm(n))),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}}),D1=Qg({
__name:"DropdownMenuSub",props:{defaultOpen:{type:Boolean},open:{type:Boolean,
default:void 0}},emits:["update:open"],setup(e,{emit:t}){
const n=e,r=uJ(n,"open",t,{passive:void 0===n.open,
defaultValue:n.defaultOpen??!1});return AJ(),(e,t)=>(Ub(),Hb(xm(f1),{open:xm(r),
"onUpdate:open":t[0]||(t[0]=e=>vm(r)?r.value=e:null)},{
default:ig((()=>[kv(e.$slots,"default",{open:xm(r)})])),_:3},8,["open"]))}
}),I1=Qg({__name:"DropdownMenuSubContent",props:{forceMount:{type:Boolean},
loop:{type:Boolean},sideOffset:{},alignOffset:{},avoidCollisions:{type:Boolean},
collisionBoundary:{},collisionPadding:{},arrowPadding:{},sticky:{},
hideWhenDetached:{type:Boolean},updatePositionStrategy:{},prioritizePosition:{
type:Boolean},asChild:{type:Boolean},as:{}},
emits:["escapeKeyDown","pointerDownOutside","focusOutside","interactOutside","entryFocus","openAutoFocus","closeAutoFocus"],
setup(e,{emit:t}){const n=EJ(e,t);return AJ(),(e,t)=>(Ub(),Hb(xm(m1),iy(xm(n),{
style:{
"--radix-dropdown-menu-content-transform-origin":"var(--radix-popper-transform-origin)",
"--radix-dropdown-menu-content-available-width":"var(--radix-popper-available-width)",
"--radix-dropdown-menu-content-available-height":"var(--radix-popper-available-height)",
"--radix-dropdown-menu-trigger-width":"var(--radix-popper-anchor-width)",
"--radix-dropdown-menu-trigger-height":"var(--radix-popper-anchor-height)"}}),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}}),M1=Qg({
__name:"DropdownMenuSubTrigger",props:{disabled:{type:Boolean},textValue:{},
asChild:{type:Boolean},as:{}},setup(e){const t=e
;return AJ(),(e,n)=>(Ub(),Hb(xm(g1),Mh(Kb(t)),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}});function N1(e){
return!!Wh()&&(Xh(e),!0)}!function(){
if("function"==typeof matchMedia)matchMedia("(pointer:coarse)").matches}()
;const R1=new WeakMap,L1=(...e)=>{var t
;const n=e[0],r=null==(t=dy())?void 0:t.proxy
;if(null==r&&!dg())throw new Error("injectLocal must be called in setup")
;return r&&R1.has(r)&&n in R1.get(r)?R1.get(r)[n]:ug(...e)
},B1="undefined"!=typeof window&&"undefined"!=typeof document
;"undefined"!=typeof WorkerGlobalScope&&(globalThis,WorkerGlobalScope)
;const j1=e=>null!=e,U1=Object.prototype.toString,z1=e=>"[object Object]"===U1.call(e),F1=()=>{},Z1=Q1()
;function Q1(){var e,t
;return B1&&(null==(e=null==window?void 0:window.navigator)?void 0:e.userAgent)&&(/iP(?:ad|hone|od)/.test(window.navigator.userAgent)||(null==(t=null==window?void 0:window.navigator)?void 0:t.maxTouchPoints)>2&&/iPad|Macintosh/.test(null==window?void 0:window.navigator.userAgent))
}const H1=e=>e();function V1(e,t={}){let n,r,o=F1;const a=e=>{
clearTimeout(e),o(),o=F1};let i;return s=>{const l=km(e),c=km(t.maxWait)
;return n&&a(n),
l<=0||void 0!==c&&c<=0?(r&&(a(r),r=void 0),Promise.resolve(s())):new Promise(((e,u)=>{
o=t.rejectOnCancel?u:e,i=s,c&&!r&&(r=setTimeout((()=>{n&&a(n),r=void 0,e(i())
}),c)),n=setTimeout((()=>{r&&a(r),r=void 0,e(s())}),l)}))}}function q1(e){
return e.endsWith("rem")?16*Number.parseFloat(e):Number.parseFloat(e)}
function W1(e){return Array.isArray(e)?e:[e]}function X1(e,t,n={}){
const{eventFilter:r=H1,...o}=n;return mg(e,(a=r,i=t,function(...e){
return new Promise(((t,n)=>{Promise.resolve(a((()=>i.apply(this,e)),{fn:i,
thisArg:this,args:e})).then(t).catch(n)}))}),o);var a,i}
const G1=B1?window:void 0,Y1=B1?window.document:void 0;function K1(e){var t
;const n=km(e);return null!=(t=null==n?void 0:n.$el)?t:n}function J1(...e){
const t=[],n=()=>{t.forEach((e=>e())),t.length=0},r=Sy((()=>{
const t=W1(km(e[0])).filter((e=>null!=e))
;return t.every((e=>"string"!=typeof e))?t:void 0})),o=(a=()=>{var t,n
;return[null!=(n=null==(t=r.value)?void 0:t.map((e=>K1(e))))?n:[G1].filter((e=>null!=e)),W1(km(r.value?e[1]:e[0])),W1(xm(r.value?e[2]:e[1])),km(r.value?e[3]:e[2])]
},i=([e,r,o,a])=>{
if(n(),!(null==e?void 0:e.length)||!(null==r?void 0:r.length)||!(null==o?void 0:o.length))return
;const i=z1(a)?{...a}:a
;t.push(...e.flatMap((e=>r.flatMap((t=>o.map((n=>((e,t,n,r)=>(e.addEventListener(t,n,r),
()=>e.removeEventListener(t,n,r)))(e,t,n,i))))))))},s={flush:"post"},mg(a,i,{
...s,immediate:!0}));var a,i,s;return N1(n),()=>{o(),n()}}let e2=!1
;function t2(e,t,n={}){
const{window:r=G1,ignore:o=[],capture:a=!0,detectIframe:i=!1,controls:s=!1}=n
;if(!r)return s?{stop:F1,cancel:F1,trigger:F1}:F1;if(Z1&&!e2){e2=!0;const e={
passive:!0}
;Array.from(r.document.body.children).forEach((t=>t.addEventListener("click",F1,e))),
r.document.documentElement.addEventListener("click",F1,e)}let l=!0
;const c=e=>km(o).some((t=>{
if("string"==typeof t)return Array.from(r.document.querySelectorAll(t)).some((t=>t===e.target||e.composedPath().includes(t)))
;{const n=K1(t);return n&&(e.target===n||e.composedPath().includes(n))}}))
;const u=n=>{const r=K1(e);null!=n.target&&(r instanceof Element||!function(e){
const t=km(e);return t&&16===t.$.subTree.shapeFlag}(e)||!function(e,t){
const n=km(e),r=n.$.subTree&&n.$.subTree.children
;return!(null==r||!Array.isArray(r))&&r.some((e=>e.el===t.target||t.composedPath().includes(e.el)))
}(e,n))&&r&&r!==n.target&&!n.composedPath().includes(r)&&("detail"in n&&0===n.detail&&(l=!c(n)),
l?t(n):l=!0)};let d=!1;const p=[J1(r,"click",(e=>{d||(d=!0,setTimeout((()=>{d=!1
}),0),u(e))}),{passive:!0,capture:a}),J1(r,"pointerdown",(t=>{const n=K1(e)
;l=!c(t)&&!(!n||t.composedPath().includes(n))}),{passive:!0
}),i&&J1(r,"blur",(n=>{setTimeout((()=>{var o;const a=K1(e)
;"IFRAME"!==(null==(o=r.document.activeElement)?void 0:o.tagName)||(null==a?void 0:a.contains(r.document.activeElement))||t(n)
}),0)}),{passive:!0})].filter(Boolean),h=()=>p.forEach((e=>e()));return s?{
stop:h,cancel:()=>{l=!1},trigger:e=>{l=!0,u(e),l=!1}}:h}function n2(){
const e=ym(!1),t=dy();return t&&iv((()=>{e.value=!0}),t),e}function r2(e){
const t=n2();return Sy((()=>(t.value,Boolean(e()))))}function o2(e,t,n={}){
const{window:r=G1,document:o=(null==r?void 0:r.document),flush:a="sync"}=n
;if(!r||!o)return F1;let i;const s=e=>{null==i||i(),i=e},l=fg((()=>{
const n=K1(e);if(n){const{stop:e}=function(e,t,n={}){const{window:r=G1,...o}=n
;let a;const i=r2((()=>r&&"MutationObserver"in r)),s=()=>{
a&&(a.disconnect(),a=void 0)},l=mg(Sy((()=>{const t=W1(km(e)).map(K1).filter(j1)
;return new Set(t)})),(e=>{
s(),i.value&&e.size&&(a=new MutationObserver(t),e.forEach((e=>a.observe(e,o))))
}),{immediate:!0,flush:"post"}),c=()=>{l(),s()};return N1(c),{isSupported:i,
stop:c,takeRecords:()=>null==a?void 0:a.takeRecords()}}(o,(e=>{
e.map((e=>[...e.removedNodes])).flat().some((e=>e===n||e.contains(n)))&&t(e)}),{
window:r,childList:!0,subtree:!0});s(e)}}),{flush:a}),c=()=>{l(),s()}
;return N1(c),c}const a2=Symbol("vueuse-ssr-width");function i2(){
const e=dg()?L1(a2,null):null;return"number"==typeof e?e:void 0}
function s2(e,t={}){
const{window:n=G1,ssrWidth:r=i2()}=t,o=r2((()=>n&&"matchMedia"in n&&"function"==typeof n.matchMedia)),a=ym("number"==typeof r),i=ym(),s=ym(!1)
;return fg((()=>{if(a.value){a.value=!o.value;const t=km(e).split(",")
;s.value=t.some((e=>{
const t=e.includes("not all"),n=e.match(/\(\s*min-width:\s*(-?\d+(?:\.\d*)?[a-z]+\s*)\)/),o=e.match(/\(\s*max-width:\s*(-?\d+(?:\.\d*)?[a-z]+\s*)\)/)
;let a=Boolean(n||o);return n&&a&&(a=r>=q1(n[1])),o&&a&&(a=r<=q1(o[1])),t?!a:a
}))}else o.value&&(i.value=n.matchMedia(km(e)),s.value=i.value.matches)
})),J1(i,"change",(e=>{s.value=e.matches}),{passive:!0}),Sy((()=>s.value))}
function l2(e=null,t={}){
const{baseUrl:n="",rel:r="icon",document:o=Y1}=t,a=function(...e){
if(1!==e.length)return Pm(...e);const t=e[0]
;return"function"==typeof t?im(Em((()=>({get:t,set:F1})))):bm(t)}(e)
;return mg(a,((e,t)=>{"string"==typeof e&&e!==t&&(e=>{
const t=null==o?void 0:o.head.querySelectorAll(`link[rel*="${r}"]`)
;if(t&&0!==t.length)null==t||t.forEach((t=>t.href=`${n}${e}`));else{
const t=null==o?void 0:o.createElement("link")
;t&&(t.rel=r,t.href=`${n}${e}`,t.type=`image/${e.split(".").pop()}`,
null==o||o.head.append(t))}})(e)}),{immediate:!0}),a}const c2={
class:"custom-scroll min-h-0 flex-1"},u2={class:"flex flex-col p-0.75"},d2=Qg({
inheritAttrs:!1,__name:"ScalarDropdownMenu",props:{is:{}},setup(e){
const{cx:t}=zS()
;return(n,r)=>(Ub(),Hb(bv(e.is??"div"),Mh(Kb(xm(t)("relative flex w-56"))),{
default:ig((()=>[Gb("div",c2,[kv(n.$slots,"menu",{},(()=>[Gb("div",u2,[kv(n.$slots,"default")])])),kv(n.$slots,"backdrop",{},(()=>[Yb(xm(ZK))]))])])),
_:3},16))}}),p2=Symbol()
;const h2=["id","aria-activedescendant","aria-labelledby","onKeydown"],f2=Qg({
inheritAttrs:!1,__name:"ScalarDropdown",props:Nv({placement:{},offset:{
type:[Number,Object,Function]},resize:{type:Boolean},target:{},middleware:{},
teleport:{type:[Boolean,String]}},{open:{type:Boolean,default:!1},
openModifiers:{}}),emits:["update:open"],setup(e){
const t=bm(),n=bm(),r=Kv(e,"open"),{active:o}=function(){const e=bm()
;return cg(p2,e),{active:e}}(),a=Hg(),i=bm(a),s=Hg();async function l(){
r.value=!r.value,await Xm(),r.value&&n.value?.focus()}async function c(e){
["ArrowDown","ArrowUp"," ","Enter"].includes(e.key)&&(e.preventDefault(),
r.value||(r.value=!0),
await Xm(),n.value?.focus(),["ArrowDown"," ","Enter"].includes(e.key)?p(1):"ArrowUp"===e.key&&p(-1))
}async function u(){t.value?.targetRef?.focus(),r.value=!1}function d(){
if(!o.value||!n.value)return
;const e=n.value.querySelector(`#${o.value}[role="menuitem"]:not([aria-disabled="true"])`)
;e&&(e.click(),u())}function p(e){if(!r.value||!n.value)return
;const t=Array.from(n.value.querySelectorAll('[role="menuitem"]:not([aria-disabled="true"])'))
;if(0===t.length)return;const a=t.findIndex((e=>e.id===o.value));if(-1===a){
const n=t[e>0?0:t.length-1];return void(n?.id&&(o.value=n.id))}const i=a+e
;if(i<0||i>t.length-1)return;const s=t[i];s?.id&&(o.value=s.id)}
mg((()=>t.value?.targetRef),((e,t)=>{
e&&(e.id?i.value=e.id:(i.value=a,e.setAttribute("id",i.value)),
e.setAttribute("aria-haspopup","menu"),
e.setAttribute("aria-expanded",`${r.value}`),
r.value&&e.setAttribute("aria-controls",s),
e.addEventListener("click",l),e.addEventListener("keydown",c)),
t&&t!==e&&(t.id===a&&t.removeAttribute("id"),t.removeAttribute("aria-controls"),
t.removeAttribute("aria-haspopup"),
t.removeAttribute("aria-expanded"),t.removeEventListener("click",l),
t.removeEventListener("keydown",c))}),{immediate:!0}),mg(r,(e=>{
const n=t.value?.targetRef
;n&&(n.setAttribute("aria-expanded",`${e}`),e?n.setAttribute("aria-controls",s):n.removeAttribute("aria-controls"))
}),{immediate:!0}),t2(n,u,{ignore:[Sy((()=>t.value?.targetRef))]})
;const{cx:h}=zS();return(a,l)=>(Ub(),Hb(xm(FK),iy({ref_key:"floatingRef",ref:t
},a.$props,{placement:e.placement??"bottom-start"}),xv({
default:ig((()=>[kv(a.$slots,"default",{open:r.value})])),_:2},[r.value?{
name:"floating",fn:ig((({width:e})=>[Yb(d2,iy({style:{width:e}
},xm(h)("max-h-[inherit] max-w-[inherit]")),{menu:ig((()=>[Gb("div",{id:xm(s),
ref_key:"menuRef",ref:n,"aria-activedescendant":xm(o),"aria-labelledby":i.value,
class:"flex flex-col p-0.75 outline-none",role:"menu",tabindex:"-1",
onClick:BO(u,["stop"]),
onKeydown:[l[0]||(l[0]=UO(BO((e=>p(1)),["prevent","stop"]),["down"])),UO(BO(d,["prevent","stop"]),["enter"]),UO(BO(u,["prevent","stop"]),["escape"]),UO(BO(d,["prevent","stop"]),["space"]),UO(BO(u,["prevent","stop"]),["tab"]),l[1]||(l[1]=UO(BO((e=>p(-1)),["prevent","stop"]),["up"]))]
},[kv(a.$slots,"items",{open:r.value})],40,h2)])),_:3},16,["style"])])),key:"0"
}:void 0]),1040,["placement"]))}}),m2={key:1,
class:"rounded border bg-b-2 p-3 text-sm"},g2={key:0,
class:"mt-2 rounded border bg-b-1 p-2 font-code text-c-2"},v2=Qg({
__name:"ScalarErrorBoundary",setup(e){const t=bm(!1),n=bm()
;return fv(((e,r,o)=>(console.error("[ERROR]",e,o),
t.value=!0,n.value=e,!1))),(e,r)=>t.value?(Ub(),
Qb("div",m2,[r[0]||(r[0]=Gb("div",{class:"p-2"
},"Oops, something went wrong here.",-1)),n.value?(Ub(),
Qb("div",g2,Uh(n.value?.name)+": "+Uh(n.value?.message),1)):ny("",!0)])):kv(e.$slots,"default",{
key:0})}
}),b2=["B","kB","MB","GB","TB","PB","EB","ZB","YB"],y2=["B","KiB","MiB","GiB","TiB","PiB","EiB","ZiB","YiB"],O2=["b","kbit","Mbit","Gbit","Tbit","Pbit","Ebit","Zbit","Ybit"],w2=["b","kibit","Mibit","Gibit","Tibit","Pibit","Eibit","Zibit","Yibit"],x2=(e,t,n)=>{
let r=e
;return"string"==typeof t||Array.isArray(t)?r=e.toLocaleString(t,n):!0!==t&&void 0===n||(r=e.toLocaleString(void 0,n)),
r},k2=e=>{if("number"==typeof e)return Math.log10(e);const t=e.toString(10)
;return t.length+Math.log10(`0.${t.slice(0,15)}`)},S2=(e,t)=>{
if(void 0===t)return e
;if("number"!=typeof t||!Number.isSafeInteger(t)||t<0)throw new TypeError(`Expected fixedWidth to be a non-negative integer, got ${typeof t}: ${t}`)
;return 0===t?e:e.length<t?e.padStart(t," "):e};function _2(e,t){
if("bigint"!=typeof e&&!Number.isFinite(e))throw new TypeError(`Expected a finite number, got ${typeof e}: ${e}`)
;const n=(t={bits:!1,binary:!1,space:!0,nonBreakingSpace:!1,...t
}).bits?t.binary?w2:O2:t.binary?y2:b2,r=t.space?t.nonBreakingSpace?" ":" ":"",o="number"==typeof e?0===e:0n===e
;if(t.signed&&o){return S2(` 0${r}${n[0]}`,t.fixedWidth)}
const a=e<0,i=a?"-":t.signed?"+":"";a&&(e=-e);const s=(e=>{
const{minimumFractionDigits:t,maximumFractionDigits:n}=e
;if(void 0!==t||void 0!==n)return{...void 0!==t&&{minimumFractionDigits:t},
...void 0!==n&&{maximumFractionDigits:n},roundingMode:"trunc"}})(t);let l
;if(e<1){l=i+x2(e,t.locale,s)+r+n[0]}else{
const o=Math.min(Math.floor(t.binary?("number"==typeof(c=e)?Math.log(c):k2(c)*Math.log(10))/Math.log(1024):k2(e)/3),n.length-1)
;if(e=((e,t)=>{if("number"==typeof e)return e/t
;const n=e/BigInt(t),r=e%BigInt(t);return Number(n)+Number(r)/t
})(e,(t.binary?1024:1e3)**o),!s){
const t=Math.max(3,Math.floor(e).toString().length);e=e.toPrecision(t)}
l=i+x2(Number(e),t.locale,s)+r+n[o]}var c;return S2(l,t.fixedWidth)}const T2={
key:0,
class:"flex items-start justify-between gap-2 text-sm leading-none text-c-1 whitespace-nowrap font-medium"
},E2=Qg({inheritAttrs:!1,__name:"ScalarFormField",props:{is:{default:"label"}},
setup(e){const{cx:t}=zS()
;return(n,r)=>(Ub(),Hb(bv(e.is),Mh(Kb(xm(t)("flex flex-col gap-1.5 rounded"))),{
default:ig((()=>[n.$slots.label?(Ub(),
Qb("div",T2,[kv(n.$slots,"label")])):ny("",!0),kv(n.$slots,"default"),n.$slots.below?(Ub(),
Qb("span",{key:1,class:Ih(xm(t)("-mt-1.5 text-sm"))
},[kv(n.$slots,"below")],2)):ny("",!0)])),_:3},16))}}),A2=Qg({inheritAttrs:!1,
__name:"ScalarHeaderButton",props:{is:{default:"button"},active:{type:Boolean}},
setup(e){const t=jS({
base:"group/button flex items-center rounded  px-2.5 py-1.5 font-medium no-underline leading-3 ",
variants:{active:{true:"bg-b-3 cursor-default",
false:"bg-transparent hover:bg-b-3 cursor-pointer"}}}),{cx:n}=zS()
;return(r,o)=>(Ub(),Hb(bv(e.is),iy({type:"button"===e.is?"button":void 0
},xm(n)(xm(t)({active:e.active}))),{default:ig((()=>[kv(r.$slots,"default")])),
_:3},16,["type"]))}
}),C2=()=>"undefined"!=typeof navigator&&(navigator.userAgentData?.platform?navigator.userAgentData.platform.toLowerCase().includes("mac"):/Mac/.test(navigator.userAgent)),$2={
"⌘":"Command","^":"Control",ctrl:"Control","⌥":"Option",alt:"Alt","⇧":"Shift",
"⇪":"Caps Lock","↵":"Enter","←":"Left Arrow","→":"Right Arrow","↑":"Up Arrow",
"↓":"Down Arrow"},P2={Meta:"⌘",Shift:"⇧",Alt:"⌥",Control:"^"},D2={Meta:"ctrl",
Shift:"⇧",Alt:"alt",Control:"ctrl"};function I2(e,t){
return[...t.map((e=>function(e){const t=function(e){return"default"===e
}(e)?"Meta":e;return C2()?P2[t]:D2[t]}(e))),e]}function M2(e){
return e in $2?$2[e]:e}const N2={"aria-hidden":"true",class:"contents"},R2={
class:"sr-only"},L2=Qg({inheritAttrs:!1,__name:"ScalarHotkey",props:{hotkey:{},
modifier:{default:()=>["Meta"]}},setup(e){
const{cx:t}=zS(),n=Sy((()=>I2(e.hotkey,e.modifier)))
;return(e,r)=>(Ub(),Qb("div",Mh(Kb(xm(t)("border-(--scalar-background-3) inline-flex gap-0.5 overflow-hidden rounded border text-xxs rounded-b p-1 font-medium uppercase leading-none"))),[(Ub(!0),
Qb(Mb,null,wv(n.value,((e,t)=>(Ub(),Qb("div",{key:t
},[Gb("span",N2,Uh(e),1),Gb("span",R2,Uh(xm(M2)(e)),1)])))),128))],16))}}),B2={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function j2(e,t){return Ub(),Qb("svg",B2,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M5 11.988h14M12.006 5v14"},null,-1)])])}const U2={render:j2
},z2=Object.freeze(Object.defineProperty({__proto__:null,default:U2,render:j2
},Symbol.toStringTag,{value:"Module"})),F2={xmlns:"http://www.w3.org/2000/svg",
fill:"none",viewBox:"0 0 24 24"};function Z2(e,t){
return Ub(),Qb("svg",F2,[...t[0]||(t[0]=[Gb("path",{stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",
d:"M8.143 12h7.714M12 8.143v7.714M5.571 3H18.43A2.57 2.57 0 0 1 21 5.571V18.43A2.57 2.57 0 0 1 18.429 21H5.57A2.57 2.57 0 0 1 3 18.429V5.57A2.57 2.57 0 0 1 5.571 3"
},null,-1)])])}const Q2={render:Z2},H2=Object.freeze(Object.defineProperty({
__proto__:null,default:Q2,render:Z2},Symbol.toStringTag,{value:"Module"})),V2={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function q2(e,t){return Ub(),Qb("svg",V2,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M12 8v4m0 4h.01M22 12c0 5.523-4.477 10-10 10S2 17.523 2 12 6.477 2 12 2s10 4.477 10 10"
},null,-1)])])}const W2={render:q2},X2=Object.freeze(Object.defineProperty({
__proto__:null,default:W2,render:q2},Symbol.toStringTag,{value:"Module"})),G2={
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 24 24"};function Y2(e,t){
return Ub(),Qb("svg",G2,[...t[0]||(t[0]=[Gb("path",{fill:"none",
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M22 12H2m9.3-9.3L2 12l9.3 9.3"},null,-1)])])}const K2={render:Y2
},J2=Object.freeze(Object.defineProperty({__proto__:null,default:K2,render:Y2
},Symbol.toStringTag,{value:"Module"})),e4={xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 24 24"};function t4(e,t){
return Ub(),Qb("svg",e4,[...t[0]||(t[0]=[Gb("path",{fill:"none",
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M2 12h20m-9.3 9.3L22 12l-9.3-9.3"},null,-1)])])}const n4={render:t4
},r4=Object.freeze(Object.defineProperty({__proto__:null,default:n4,render:t4
},Symbol.toStringTag,{value:"Module"})),o4={xmlns:"http://www.w3.org/2000/svg",
fill:"none",viewBox:"0 0 24 24"};function a4(e,t){
return Ub(),Qb("svg",o4,[...t[0]||(t[0]=[Gb("path",{stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",
d:"M8 3H7a2 2 0 0 0-2 2v5a2 2 0 0 1-2 2 2 2 0 0 1 2 2v5c0 1.1.9 2 2 2h1m8 0h1a2 2 0 0 0 2-2v-5c0-1.1.9-2 2-2a2 2 0 0 1-2-2V5a2 2 0 0 0-2-2h-1"
},null,-1)])])}const i4={render:a4},s4=Object.freeze(Object.defineProperty({
__proto__:null,default:i4,render:a4},Symbol.toStringTag,{value:"Module"})),l4={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function c4(e,t){return Ub(),Qb("svg",l4,[...t[0]||(t[0]=[Gb("path",{
d:"M16.4 6.8v5.6H7.6m0-5.6v10.4"},null,-1),Gb("circle",{cx:"7.6",cy:"4.4",
r:"2.4"},null,-1),Gb("circle",{cx:"7.6",cy:"19.6",r:"2.4"
},null,-1),Gb("circle",{cx:"16.4",cy:"4.4",r:"2.4"},null,-1)])])}const u4={
render:c4},d4=Object.freeze(Object.defineProperty({__proto__:null,default:u4,
render:c4},Symbol.toStringTag,{value:"Module"})),p4={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function h4(e,t){return Ub(),Qb("svg",p4,[...t[0]||(t[0]=[Gb("path",{
d:"M12 22.125V4.712S9.545 1.985 1.268 1.875a.5.5 0 0 0-.366.15.52.52 0 0 0-.152.369v16.375a.515.515 0 0 0 .5.519C9.543 19.4 12 22.125 12 22.125"
},null,-1),Gb("path",{
d:"M9 11.18a21.3 21.3 0 0 0-5.26-1.055M9 15.375a21.3 21.3 0 0 0-5.26-1.055M15 11.18a21.3 21.3 0 0 1 5.26-1.055M15 15.375a21.3 21.3 0 0 1 5.26-1.055"
},null,-1),Gb("path",{
d:"M12 22.125V4.712s2.455-2.727 10.732-2.837a.5.5 0 0 1 .366.15.52.52 0 0 1 .152.369v16.375a.515.515 0 0 1-.5.519C14.457 19.4 12 22.125 12 22.125"
},null,-1)])])}const f4={render:h4},m4=Object.freeze(Object.defineProperty({
__proto__:null,default:f4,render:h4},Symbol.toStringTag,{value:"Module"})),g4={
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 24 24"};function v4(e,t){
return Ub(),Qb("svg",g4,[...t[0]||(t[0]=[Gb("path",{fill:"none",
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M21.4 4.6 10.6 19.4l-8-6.4"},null,-1)])])}const b4={render:v4
},y4=Object.freeze(Object.defineProperty({__proto__:null,default:b4,render:v4
},Symbol.toStringTag,{value:"Module"})),O4={xmlns:"http://www.w3.org/2000/svg",
fill:"none",viewBox:"0 0 24 24"};function w4(e,t){
return Ub(),Qb("svg",O4,[...t[0]||(t[0]=[Gb("path",{stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",d:"m18 10-6 6-6-6"
},null,-1)])])}const x4={render:w4},k4=Object.freeze(Object.defineProperty({
__proto__:null,default:x4,render:w4},Symbol.toStringTag,{value:"Module"})),S4={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function _4(e,t){return Ub(),Qb("svg",S4,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"m14 18-6-6 6-6"},null,-1)])])}const T4={render:_4
},E4=Object.freeze(Object.defineProperty({__proto__:null,default:T4,render:_4
},Symbol.toStringTag,{value:"Module"})),A4={xmlns:"http://www.w3.org/2000/svg",
fill:"none",viewBox:"0 0 24 24"};function C4(e,t){
return Ub(),Qb("svg",A4,[...t[0]||(t[0]=[Gb("path",{stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",d:"m9 18 6-6-6-6"
},null,-1)])])}const $4={render:C4},P4=Object.freeze(Object.defineProperty({
__proto__:null,default:$4,render:C4},Symbol.toStringTag,{value:"Module"})),D4={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function I4(e,t){return Ub(),Qb("svg",D4,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"m18 15-6-6-6 6"},null,-1)])])}const M4={render:I4
},N4=Object.freeze(Object.defineProperty({__proto__:null,default:M4,render:I4
},Symbol.toStringTag,{value:"Module"})),R4={xmlns:"http://www.w3.org/2000/svg",
fill:"none",viewBox:"0 0 24 24"};function L4(e,t){
return Ub(),Qb("svg",R4,[...t[0]||(t[0]=[Gb("path",{stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",
d:"M4 16c-1.1 0-2-.9-2-2V4c0-1.1.9-2 2-2h10c1.1 0 2 .9 2 2m-6 4h10a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H10a2 2 0 0 1-2-2V10a2 2 0 0 1 2-2"
},null,-1)])])}const B4={render:L4},j4=Object.freeze(Object.defineProperty({
__proto__:null,default:B4,render:L4},Symbol.toStringTag,{value:"Module"})),U4={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function z4(e,t){return Ub(),Qb("svg",U4,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M18 6 6 18M6 6l12 12"},null,-1)])])}const F4={render:z4
},Z4=Object.freeze(Object.defineProperty({__proto__:null,default:F4,render:z4
},Symbol.toStringTag,{value:"Module"})),Q4={xmlns:"http://www.w3.org/2000/svg",
fill:"none",viewBox:"0 0 24 24"};function H4(e,t){
return Ub(),Qb("svg",Q4,[...t[0]||(t[0]=[Gb("path",{stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",
d:"m9.273 9.273 5.454 5.454m0-5.454-5.454 5.454M5.57 3h12.86A2.57 2.57 0 0 1 21 5.571V18.43A2.57 2.57 0 0 1 18.429 21H5.57A2.57 2.57 0 0 1 3 18.429V5.57A2.57 2.57 0 0 1 5.571 3Z"
},null,-1)])])}const V4={render:H4},q4=Object.freeze(Object.defineProperty({
__proto__:null,default:V4,render:H4},Symbol.toStringTag,{value:"Module"})),W4={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function X4(e,t){return Ub(),Qb("svg",W4,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M4 16c-1.1 0-2-.9-2-2V4c0-1.1.9-2 2-2h10c1.1 0 2 .9 2 2m-3.121 8.879 4.242 4.242m0-4.242L12.88 17.12M10 8h10a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H10a2 2 0 0 1-2-2V10a2 2 0 0 1 2-2"
},null,-1)])])}const G4={render:X4},Y4=Object.freeze(Object.defineProperty({
__proto__:null,default:G4,render:X4},Symbol.toStringTag,{value:"Module"})),K4={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function J4(e,t){return Ub(),Qb("svg",K4,[...t[0]||(t[0]=[Gb("path",{
d:"M18.375 19.5a4.875 4.875 0 1 0-2.764-8.885A7.5 7.5 0 1 0 8.25 19.5z"
},null,-1)])])}const e8={render:J4},t8=Object.freeze(Object.defineProperty({
__proto__:null,default:e8,render:J4},Symbol.toStringTag,{value:"Module"})),n8={
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 24 24"};function r8(e,t){
return Ub(),Qb("svg",n8,[...t[0]||(t[0]=[Gb("path",{fill:"none",
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M21.75 9V6a1.5 1.5 0 0 0-1.5-1.5h-12V3a1.5 1.5 0 0 0-1.5-1.5h-4.5A1.5 1.5 0 0 0 .75 3v17.8a1.7 1.7 0 0 0 3.336.438l2.352-11.154A1.5 1.5 0 0 1 7.879 9za1.5 1.5 0 0 1 1.45 1.886l-2.2 10.5a1.5 1.5 0 0 1-1.45 1.114H2.447"
},null,-1),Gb("path",{fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",
d:"m12 13.5-2.25 2.25L12 18m4.5-4.5 2.25 2.25L16.5 18"},null,-1)])])}const o8={
render:r8},a8=Object.freeze(Object.defineProperty({__proto__:null,default:o8,
render:r8},Symbol.toStringTag,{value:"Module"})),i8={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function s8(e,t){return Ub(),Qb("svg",i8,[...t[0]||(t[0]=[Gb("path",{
d:"M10.546 2.438a1.957 1.957 0 0 0 2.908 0L14.4 1.4a1.959 1.959 0 0 1 3.41 1.413l-.071 1.4a1.96 1.96 0 0 0 2.051 2.054l1.4-.071a1.959 1.959 0 0 1 1.41 3.41l-1.042.94a1.96 1.96 0 0 0 0 2.909l1.042.94a1.959 1.959 0 0 1-1.413 3.41l-1.4-.071a1.96 1.96 0 0 0-2.056 2.056l.071 1.4A1.959 1.959 0 0 1 14.4 22.6l-.941-1.041a1.96 1.96 0 0 0-2.908 0L9.606 22.6A1.959 1.959 0 0 1 6.2 21.192l.072-1.4a1.96 1.96 0 0 0-2.056-2.056l-1.4.071A1.958 1.958 0 0 1 1.4 14.4l1.041-.94a1.96 1.96 0 0 0 0-2.909L1.4 9.606A1.958 1.958 0 0 1 2.809 6.2l1.4.071a1.96 1.96 0 0 0 2.058-2.06L6.2 2.81A1.959 1.959 0 0 1 9.606 1.4z"
},null,-1),Gb("path",{d:"M7.5 12.001a4.5 4.5 0 1 0 9 0 4.5 4.5 0 1 0-9 0"
},null,-1)])])}const l8={render:s8},c8=Object.freeze(Object.defineProperty({
__proto__:null,default:l8,render:s8},Symbol.toStringTag,{value:"Module"})),u8={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function d8(e,t){return Ub(),Qb("svg",u8,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M20.86 16.6c0 .32-.16.64-.47.72l-6.3 2.83a.93.93 0 0 1-.8-.08c-.23-.16-.38-.4-.38-.63V4.56c0-.24.15-.55.39-.63.24-.16.47-.16.79-.08l6.3 2.83c.31.16.47.4.47.71v9.22zM10.7 19.52a.77.77 0 0 1-.7-.08.72.72 0 0 1-.32-.63V5.35c0-.24.15-.56.4-.63.23-.16.46-.16.78-.08M7.43 18.73a.77.77 0 0 1-.7-.08.72.72 0 0 1-.32-.63V6.05c0-.23.16-.55.4-.63.23-.15.47-.15.78-.07m-3.43 12.6a.77.77 0 0 1-.7-.08.72.72 0 0 1-.32-.63V6.84c0-.23.16-.55.4-.63.23-.16.47-.16.78-.08"
},null,-1)])])}const p8={render:d8},h8=Object.freeze(Object.defineProperty({
__proto__:null,default:p8,render:d8},Symbol.toStringTag,{value:"Module"})),f8={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function m8(e,t){return Ub(),Qb("svg",f8,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M15.739 8.061c-2.02.404-4.041-1.01-4.445-3.03-.202-1.01 0-2.223.606-3.031C6.445 2 2 6.445 2 11.9s4.445 9.9 9.9 9.9 9.9-4.445 9.9-9.9v-.808c-1.616 1.212-4.04.808-5.253-.808-.606-.606-.808-1.415-.808-2.223"
},null,-1),Gb("path",{fill:"currentColor",
d:"M8.667 15.133a1.212 1.212 0 1 0 0-2.425 1.212 1.212 0 0 0 0 2.425m4.243 1.212a1.212 1.212 0 1 0 0-2.424 1.212 1.212 0 0 0 0 2.424M9.88 9.88a1.212 1.212 0 1 0 0-2.425 1.212 1.212 0 0 0 0 2.425"
},null,-1)])])}const g8={render:m8},v8=Object.freeze(Object.defineProperty({
__proto__:null,default:g8,render:m8},Symbol.toStringTag,{value:"Module"})),b8={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function y8(e,t){return Ub(),Qb("svg",b8,[...t[0]||(t[0]=[Gb("path",{
d:"M17.673 16.462C10.59 16.46 5.52 9.612 7.59 2.837.22 6.233-.71 16.333 5.917 21.016c5.864 4.144 14.064 1.34 16.163-5.526-1.38.64-2.884.972-4.407.972M11.996 3.484h4.866m-2.433-2.433v4.867m4.867 2.433h3.244m-1.622-1.622v3.244"
},null,-1)])])}const O8={render:y8},w8=Object.freeze(Object.defineProperty({
__proto__:null,default:O8,render:y8},Symbol.toStringTag,{value:"Module"})),x8={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function k8(e,t){return Ub(),Qb("svg",x8,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M3 6h18m-2 0v14c0 1-1 2-2 2H7c-1 0-2-1-2-2V6m3 0V4c0-1 1-2 2-2h4c1 0 2 1 2 2v2m-6 5v6m4-6v6"
},null,-1)])])}const S8={render:k8},_8=Object.freeze(Object.defineProperty({
__proto__:null,default:S8,render:k8},Symbol.toStringTag,{value:"Module"})),T8={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function E8(e,t){return Ub(),Qb("svg",T8,[...t[0]||(t[0]=[Gb("path",{
d:"M10.145 5.108a.584.584 0 0 1-.657-.37l-.24-.705a.51.51 0 0 0-.496-.35c-1.835.065-3.434.577-4.13.834a1.2 1.2 0 0 0-.6.474c-.75 1.142-3.085 5.242-3.02 11.944.003.4.169.78.485 1.025.716.556 2.259 1.576 4.702 2.314.358.108.75.004.962-.304.316-.462.597-1.04.796-1.494a.56.56 0 0 1 .669-.31c.87.248 1.993.439 3.39.439 1.393 0 2.512-.19 3.379-.437a.56.56 0 0 1 .669.31c.199.454.48 1.03.795 1.492.211.308.604.412.962.304 2.443-.738 3.986-1.758 4.703-2.314.315-.245.48-.626.485-1.025.063-6.652-2.236-10.74-3.003-11.917a1.25 1.25 0 0 0-.654-.5c-.75-.256-2.428-.763-4.094-.833a.505.505 0 0 0-.496.348l-.239.703a.586.586 0 0 1-.66.37 10.5 10.5 0 0 0-1.846-.15c-.827 0-1.461.08-1.862.152"
},null,-1),Gb("path",{
d:"M10 12.553c0 1.38-1.008 2.5-2.25 2.5-1.243 0-2.25-1.12-2.25-2.5 0-1.381 1.007-2.5 2.25-2.5 1.242 0 2.25 1.119 2.25 2.5m4 0c0 1.38 1.007 2.5 2.25 2.5 1.242 0 2.25-1.12 2.25-2.5 0-1.381-1.008-2.5-2.25-2.5-1.243 0-2.25 1.119-2.25 2.5"
},null,-1)])])}const A8={render:E8},C8=Object.freeze(Object.defineProperty({
__proto__:null,default:A8,render:E8},Symbol.toStringTag,{value:"Module"})),$8={
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 24 24"};function P8(e,t){
return Ub(),Qb("svg",$8,[...t[0]||(t[0]=[Gb("path",{fill:"none",
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M5.4 22.2h13c1.1 0 2-.9 2-2V3.6c0-1.1-.9-2-2-2h-9l-6 6v12.6c0 1.1.9 2 2 2"
},null,-1),Gb("path",{fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",
d:"M3.6 7.6h4c1.1 0 2-.9 2-2v-4zm9.4 0h4m-10 5h10M7 17.4h10"},null,-1)])])}
const D8={render:P8},I8=Object.freeze(Object.defineProperty({__proto__:null,
default:D8,render:P8},Symbol.toStringTag,{value:"Module"})),M8={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function N8(e,t){return Ub(),Qb("svg",M8,[...t[0]||(t[0]=[Gb("path",{
d:"M12.001 3.75v12m-4.5-4.5 4.5 4.5 4.5-4.5m6.75 4.5v1.5a3 3 0 0 1-3 3h-16.5a3 3 0 0 1-3-3v-1.5"
},null,-1)])])}const R8={render:N8},L8=Object.freeze(Object.defineProperty({
__proto__:null,default:R8,render:N8},Symbol.toStringTag,{value:"Module"})),B8={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function j8(e,t){return Ub(),Qb("svg",B8,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M7.42 16.58H3.25a.83.83 0 0 1-.83-.83V3.25a.83.83 0 0 1 .83-.83h12.5a.83.83 0 0 1 .83.83v4.17"
},null,-1),Gb("path",{stroke:"currentColor","stroke-linecap":"round",
"stroke-linejoin":"round",
d:"M8.25 7.42h12.5s.83 0 .83.83v12.5s0 .83-.83.83H8.25s-.83 0-.83-.83V8.25s0-.83.83-.83"
},null,-1)])])}const U8={render:j8},z8=Object.freeze(Object.defineProperty({
__proto__:null,default:U8,render:j8},Symbol.toStringTag,{value:"Module"})),F8={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function Z8(e,t){return Ub(),Qb("svg",F8,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M14 3H5.571A2.57 2.57 0 0 0 3 5.571V18.43A2.57 2.57 0 0 0 5.571 21H18.43A2.57 2.57 0 0 0 21 18.429V10m.96-5.35a1.845 1.845 0 0 0-2.61-2.61l-6.644 6.647a1.3 1.3 0 0 0-.328.543l-.864 2.849a.327.327 0 0 0 .408.407l2.849-.864c.205-.062.391-.174.543-.325l6.645-6.647Z"
},null,-1)])])}const Q8={render:Z8},H8=Object.freeze(Object.defineProperty({
__proto__:null,default:Q8,render:Z8},Symbol.toStringTag,{value:"Module"})),V8={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function q8(e,t){return Ub(),Qb("svg",V8,[...t[0]||(t[0]=[Gb("path",{
d:"M6 11c-.5 0-1 .4-1 1s.5 1 1 1 1-.4 1-1-.5-1-1-1m12 0c-.6 0-1 .4-1 1s.4 1 1 1 1-.4 1-1-.4-1-1-1m-6 0c-.6 0-1 .4-1 1s.4 1 1 1 1-.4 1-1-.4-1-1-1"
},null,-1)])])}const W8={render:q8},X8=Object.freeze(Object.defineProperty({
__proto__:null,default:W8,render:q8},Symbol.toStringTag,{value:"Module"})),G8={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function Y8(e,t){return Ub(),Qb("svg",G8,[...t[0]||(t[0]=[Gb("path",{
d:"M2.25 4.5h19.5s1.5 0 1.5 1.5v12s0 1.5-1.5 1.5H2.25s-1.5 0-1.5-1.5V6s0-1.5 1.5-1.5m13.437 5.475L19.5 13.5M8.313 9.975 4.5 13.5"
},null,-1),Gb("path",{
d:"m22.88 5.014-9.513 6.56a2.41 2.41 0 0 1-2.734 0L1.12 5.014"},null,-1)])])}
const K8={render:Y8},J8=Object.freeze(Object.defineProperty({__proto__:null,
default:K8,render:Y8},Symbol.toStringTag,{value:"Module"})),e6={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function t6(e,t){return Ub(),Qb("svg",e6,[...t[0]||(t[0]=[Gb("path",{
d:"M12 17.6c-.2 0-.4-.2-.4-.4s.2-.4.4-.4m0 .8c.2 0 .4-.2.4-.4s-.2-.4-.4-.4m0-3V5.6"
},null,-1),Gb("path",{
d:"M12 22c5.5 0 10-4.5 10-10S17.5 2 12 2 2 6.5 2 12s4.5 10 10 10"},null,-1)])])}
const n6={render:t6},r6=Object.freeze(Object.defineProperty({__proto__:null,
default:n6,render:t6},Symbol.toStringTag,{value:"Module"})),o6={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function a6(e,t){return Ub(),Qb("svg",o6,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"m18.59 15.3 2.9-2.91a1.32 1.32 0 0 0 0-1.87l-1.85-1.85a3.3 3.3 0 1 1-4.31-4.31L13.48 2.5a1.32 1.32 0 0 0-1.87 0l-2.9 2.91a3.3 3.3 0 1 0-3.3 3.3l-2.9 2.9a1.32 1.32 0 0 0 0 1.87l1.85 1.85a3.3 3.3 0 1 1 4.31 4.31l1.85 1.85a1.32 1.32 0 0 0 1.87 0l2.9-2.9a3.3 3.3 0 1 0 3.3-3.3Z"
},null,-1)])])}const i6={render:a6},s6=Object.freeze(Object.defineProperty({
__proto__:null,default:i6,render:a6},Symbol.toStringTag,{value:"Module"})),l6={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function c6(e,t){return Ub(),Qb("svg",l6,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M6.4 4H20v13.59M4 20 20 4"},null,-1)])])}const u6={render:c6
},d6=Object.freeze(Object.defineProperty({__proto__:null,default:u6,render:c6
},Symbol.toStringTag,{value:"Module"})),p6={xmlns:"http://www.w3.org/2000/svg",
fill:"none",viewBox:"0 0 24 24"};function h6(e,t){
return Ub(),Qb("svg",p6,[...t[0]||(t[0]=[Gb("path",{stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",
d:"M4 6h16M7.556 12h8.888m-6.222 6h3.556"},null,-1)])])}const f6={render:h6
},m6=Object.freeze(Object.defineProperty({__proto__:null,default:f6,render:h6
},Symbol.toStringTag,{value:"Module"})),g6={xmlns:"http://www.w3.org/2000/svg",
fill:"none",viewBox:"0 0 24 24"};function v6(e,t){
return Ub(),Qb("svg",g6,[...t[0]||(t[0]=[Gb("path",{stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",
d:"M20 20a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.9a2 2 0 0 1-1.69-.9L9.6 3.9A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13a2 2 0 0 0 2 2z"
},null,-1)])])}const b6={render:v6},y6=Object.freeze(Object.defineProperty({
__proto__:null,default:b6,render:v6},Symbol.toStringTag,{value:"Module"})),O6={
xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",viewBox:"0 0 1024 1024"}
;function w6(e,t){return Ub(),Qb("svg",O6,[...t[0]||(t[0]=[Gb("path",{
d:"M512 0a512 512 0 0 0-162 998c26 4 35-11 35-25l-1-95c-128 23-161-32-172-60-6-15-31-61-52-73-18-10-44-33-1-33 40-1 69 37 78 52 46 78 120 56 149 43 5-33 18-56 33-69-114-13-234-56-234-253 0-56 20-101 53-137-5-13-23-65 5-136 0 0 43-13 141 53a487 487 0 0 1 256 0c98-66 141-53 141-53 28 71 10 123 5 136 33 36 53 81 53 137 0 197-120 240-234 253 18 16 35 47 35 95l-1 140c0 14 9 30 35 25A512 512 0 0 0 512 0"
},null,-1)])])}const x6={render:w6},k6=Object.freeze(Object.defineProperty({
__proto__:null,default:x6,render:w6},Symbol.toStringTag,{value:"Module"})),S6={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function _6(e,t){return Ub(),Qb("svg",S6,[...t[0]||(t[0]=[Gb("path",{
d:"M16.643 22.94v-3.135a3.68 3.68 0 0 0-1.026-2.852c3.43-.382 7.036-1.682 7.036-7.648a5.94 5.94 0 0 0-1.64-4.097 5.54 5.54 0 0 0-.097-4.12s-1.29-.382-4.272 1.618a14.6 14.6 0 0 0-7.649 0c-2.982-2-4.272-1.617-4.272-1.617a5.54 5.54 0 0 0-.098 4.119 5.94 5.94 0 0 0-1.639 4.13c0 5.922 3.606 7.222 7.036 7.648a3.68 3.68 0 0 0-1.027 2.819v3.136m0-2.186c-3.277 1.064-6.009 0-7.648-3.278"
},null,-1)])])}const T6={render:_6},E6=Object.freeze(Object.defineProperty({
__proto__:null,default:T6,render:_6},Symbol.toStringTag,{value:"Module"})),A6={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function C6(e,t){return Ub(),Qb("svg",A6,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M22 12c0 5.523-4.477 10-10 10m10-10c0-5.523-4.477-10-10-10m10 10H2m10 10C6.477 22 2 17.523 2 12m10 10a14.5 14.5 0 0 1 0-20m0 20a14.5 14.5 0 0 0 0-20M2 12C2 6.477 6.477 2 12 2"
},null,-1)])])}const $6={render:C6},P6=Object.freeze(Object.defineProperty({
__proto__:null,default:$6,render:C6},Symbol.toStringTag,{value:"Module"})),D6={
xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",viewBox:"0 0 24 24"}
;function I6(e,t){return Ub(),Qb("svg",D6,[...t[0]||(t[0]=[Gb("path",{
d:"M23.93 10.67a.76.76 0 0 0-.75-.67H12.75a.76.76 0 0 0-.75.75v3.5a.76.76 0 0 0 .75.75h5.58A7 7 0 1 1 12 5a7 7 0 0 1 4.23 1.42.74.74 0 0 0 1-.07l2.47-2.49a.75.75 0 0 0 .22-.57.77.77 0 0 0-.27-.54A12 12 0 1 0 24 12a12 12 0 0 0-.07-1.33"
},null,-1)])])}const M6={render:I6},N6=Object.freeze(Object.defineProperty({
__proto__:null,default:M6,render:I6},Symbol.toStringTag,{value:"Module"})),R6={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function L6(e,t){return Ub(),Qb("svg",R6,[...t[0]||(t[0]=[Gb("path",{
d:"M9.2 9.2c0-.5.1-1 .4-1.5s.6-.8 1.1-1q.75-.3 1.5-.3c.75 0 1 .2 1.4.5s.7.7 1 1.2c.2.5.3 1 .2 1.5s-.3 1-.6 1.4-.8.7-1.2.9c-.255.128-.5.3-.7.5s-.3.5-.3.8v.9m0 3.5c-.2 0-.4-.2-.4-.4s.2-.4.4-.4.4.2.4.4-.2.4-.4.4"
},null,-1),Gb("path",{
d:"M12 22c5.524 0 10-4.476 10-10S17.524 2 12 2 2 6.476 2 12s4.476 10 10 10"
},null,-1)])])}const B6={render:L6},j6=Object.freeze(Object.defineProperty({
__proto__:null,default:B6,render:L6},Symbol.toStringTag,{value:"Module"})),U6={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function z6(e,t){return Ub(),Qb("svg",U6,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M9.88 14.12a3 3 0 1 1 4.24-4.24m-3.39 9.04q.632.079 1.27.08c7 0 10-7 10-7a13.2 13.2 0 0 0-1.67-2.68M6.61 17.39A13.5 13.5 0 0 1 2 12s3-7 10-7a9.74 9.74 0 0 1 5.39 1.61M2 22 22 2"
},null,-1)])])}const F6={render:z6},Z6=Object.freeze(Object.defineProperty({
__proto__:null,default:F6,render:z6},Symbol.toStringTag,{value:"Module"})),Q6={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function H6(e,t){return Ub(),Qb("svg",Q6,[...t[0]||(t[0]=[Gb("path",{
d:"M12.9 6.8v6.1h4.7"},null,-1),Gb("path",{
d:"M6.1 17.2c1.6 2.2 4.2 3.6 7.1 3.6 4.8 0 8.8-3.9 8.8-8.8s-3.9-8.8-8.8-8.8-8.8 4-8.8 8.8v1.7M2 11.3l2.4 2.4 2.4-2.4"
},null,-1)])])}const V6={render:H6},q6=Object.freeze(Object.defineProperty({
__proto__:null,default:V6,render:H6},Symbol.toStringTag,{value:"Module"})),W6={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function X6(e,t){return Ub(),Qb("svg",W6,[...t[0]||(t[0]=[Gb("path",{
d:"M22.1 9.2 12 1.5 1.8 9.2c-.2.2-.3.5-.4.7v11.7c0 .5.4.9.9.9h6.1v-4.9c0-1.9 1.6-3.5 3.5-3.5s3.5 1.6 3.5 3.5v4.9h6.1c.5 0 .9-.4.9-.9V9.9c0-.3-.1-.6-.4-.7z"
},null,-1)])])}const G6={render:X6},Y6=Object.freeze(Object.defineProperty({
__proto__:null,default:G6,render:X6},Symbol.toStringTag,{value:"Module"})),K6={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function J6(e,t){return Ub(),Qb("svg",K6,[...t[0]||(t[0]=[Gb("path",{
d:"M12 10.67v7.98M14.66 16 12 18.64 9.34 16"},null,-1),Gb("path",{
d:"M3.35 7.34h17.3s1.33 0 1.33 1.33v11.98s0 1.33-1.33 1.33H3.35s-1.33 0-1.33-1.33V8.67s0-1.33 1.33-1.33"
},null,-1),Gb("path",{
d:"m2.2 8 2.13-5.19a1.33 1.33 0 0 1 1.22-.79h12.9a1.33 1.33 0 0 1 1.22.8l2.08 5.1M12 7.34V2.02"
},null,-1)])])}const e3={render:J6},t3=Object.freeze(Object.defineProperty({
__proto__:null,default:e3,render:J6},Symbol.toStringTag,{value:"Module"})),n3={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function r3(e,t){return Ub(),Qb("svg",n3,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M12 22c5.523 0 10-4.477 10-10S17.523 2 12 2 2 6.477 2 12s4.477 10 10 10"
},null,-1),Gb("path",{stroke:"currentColor","stroke-linecap":"round",
"stroke-linejoin":"round",
d:"M12 17v-6 0a.5.5 0 0 0-.5-.5l-.5.001h-1M12 17h-2m2 0h2"},null,-1),Gb("path",{
fill:"currentColor","fill-rule":"evenodd",
d:"M10.75 7.5a1 1 0 1 1 2 0 1 1 0 0 1-2 0","clip-rule":"evenodd"},null,-1)])])}
const o3={render:r3},a3=Object.freeze(Object.defineProperty({__proto__:null,
default:o3,render:r3},Symbol.toStringTag,{value:"Module"})),i3={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function s3(e,t){return Ub(),Qb("svg",i3,[...t[0]||(t[0]=[Gb("path",{
d:"M12.82 14.51 15.36 12l1.76.47a1.56 1.56 0 0 0 1.51-.47 1.58 1.58 0 0 0 .37-1.49l-.47-1.75.82-.76 1.76.47A1.56 1.56 0 0 0 22.62 8 1.58 1.58 0 0 0 23 6.52l-.47-1.75a2.35 2.35 0 0 0-3.33-3.33l-9.71 9.74a6.29 6.29 0 1 0 3.33 3.33"
},null,-1),Gb("path",{d:"M4.26 17.84a1.9 1.9 0 1 0 3.8 0 1.9 1.9 0 1 0-3.8 0"
},null,-1)])])}const l3={render:s3},c3=Object.freeze(Object.defineProperty({
__proto__:null,default:l3,render:s3},Symbol.toStringTag,{value:"Module"})),u3={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function d3(e,t){return Ub(),Qb("svg",u3,[...t[0]||(t[0]=[Gb("path",{
d:"M16.35 16.5v1c0 1.1-.9 2-2 2H2.75c-1.1 0-2-.9-2-2v-11c0-1.1.9-2 2-2h11.6c1.1 0 2 .9 2 2v1M5.25 12h18m0 0-3 3.1m3-3.1-3-2.9"
},null,-1)])])}const p3={render:d3},h3=Object.freeze(Object.defineProperty({
__proto__:null,default:p3,render:d3},Symbol.toStringTag,{value:"Module"})),f3={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function m3(e,t){return Ub(),Qb("svg",f3,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M6.55 12a5.46 5.46 0 1 0 10.91.481A5.46 5.46 0 0 0 6.55 12m0 0H2m4.55 0H4.73m12.31 2.1a5.46 5.46 0 0 1-6.614-6.887M12 2v4.55m7.08-1.62-3.22 3.22M22 12h-4.54m1.62 7.08L16 16.01M12 22v-4m-7.07 1.08L8 16.01M4.93 4.93l3.22 3.22"
},null,-1)])])}const g3={render:m3},v3=Object.freeze(Object.defineProperty({
__proto__:null,default:g3,render:m3},Symbol.toStringTag,{value:"Module"})),b3={
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 24 24"};function y3(e,t){
return Ub(),Qb("svg",b3,[...t[0]||(t[0]=[Gb("path",{fill:"none",
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M7.501 12a4.5 4.5 0 1 0 9 0 4.5 4.5 0 1 0-9 0m4.5-10.5v3m0 15v3m10.5-10.5h-3m-15 0h-3m17.924-7.424-2.121 2.121M6.697 17.304l-2.121 2.121m14.849 0-2.121-2.121M6.697 6.697 4.576 4.576"
},null,-1)])])}const O3={render:y3},w3=Object.freeze(Object.defineProperty({
__proto__:null,default:O3,render:y3},Symbol.toStringTag,{value:"Module"})),x3={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function k3(e,t){return Ub(),Qb("svg",x3,[...t[0]||(t[0]=[Gb("path",{
d:"M13.5 18 12 19.5c-1 1-2.3 1.5-3.7 1.5s-2.7-.6-3.7-1.5c-1-1-1.5-2.3-1.5-3.7s.6-2.7 1.5-3.7l1.5-1.5M10.5 6 12 4.5c1-1 2.3-1.5 3.7-1.5s2.7.6 3.7 1.5c1 1 1.5 2.3 1.5 3.7s-.6 2.7-1.5 3.7l-1.5 1.5M9 15l6-6"
},null,-1)])])}const S3={render:k3},_3=Object.freeze(Object.defineProperty({
__proto__:null,default:S3,render:k3},Symbol.toStringTag,{value:"Module"})),T3={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function E3(e,t){return Ub(),Qb("svg",T3,[...t[0]||(t[0]=[Gb("path",{
d:"M12 17a1 1 0 1 0 0-2 1 1 0 0 0 0 2"},null,-1),Gb("path",{
d:"M5.778 10h12.444c.982 0 1.778.895 1.778 2v8c0 1.105-.796 2-1.778 2H5.778C4.796 22 4 21.105 4 20v-8c0-1.105.796-2 1.778-2M7 10V7a5 5 0 1 1 10 0v3"
},null,-1)])])}const A3={render:E3},C3=Object.freeze(Object.defineProperty({
__proto__:null,default:A3,render:E3},Symbol.toStringTag,{value:"Module"})),$3={
xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",viewBox:"0 0 593 593"}
;function P3(e,t){return Ub(),Qb("svg",$3,[...t[0]||(t[0]=[Gb("path",{
"fill-rule":"evenodd",
d:"M347 0c6 0 12 5 12 12v134l94-95c5-5 13-5 17 0l72 72c4 4 5 12 0 16v1l-95 94h134c7 0 12 5 12 12v101c0 7-5 12-12 12H447l95 94c4 5 5 13 0 17l-72 72c-4 4-12 5-16 0h-1l-94-95v134c0 7-5 12-12 12H246c-7 0-12-5-12-12v-70c0-22 9-43 24-59l130-130c14-14 14-37 0-51L259 142a84 84 0 0 1-25-59V12c0-7 5-12 12-12zM138 52h1l219 219c14 14 14 37 0 51L139 542c-4 5-12 5-17 0l-71-70c-4-5-5-12 0-17l95-96H12c-7 0-12-5-12-12V246c0-7 5-12 12-12h134l-95-94c-4-5-4-12 0-17l71-71c4-5 12-5 16 0"
},null,-1)])])}const D3={render:P3},I3=Object.freeze(Object.defineProperty({
__proto__:null,default:D3,render:P3},Symbol.toStringTag,{value:"Module"})),M3={
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 24 24"};function N3(e,t){
return Ub(),Qb("svg",M3,[...t[0]||(t[0]=[Gb("path",{fill:"none",
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"m.75 23.25 15-15m-5.25 0H8.25m15 0H21M21 3l-1.591 1.591M15.75 3V.75m0 15V13.5m-3.659-8.909L10.5 3M21 13.5l-1.591-1.591"
},null,-1)])])}const R3={render:N3},L3=Object.freeze(Object.defineProperty({
__proto__:null,default:R3,render:N3},Symbol.toStringTag,{value:"Module"})),B3={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function j3(e,t){return Ub(),Qb("svg",B3,[...t[0]||(t[0]=[Gb("path",{
fill:"currentColor",
d:"M3 16.142V8.245h2.323l2.322 2.903 2.323-2.903h2.322v7.897H9.968v-4.53l-2.323 2.904-2.322-2.903v4.529zm14.516 0-3.484-3.832h2.323V8.245h2.322v4.065H21z"
},null,-1)])])}const U3={render:j3},z3=Object.freeze(Object.defineProperty({
__proto__:null,default:U3,render:j3},Symbol.toStringTag,{value:"Module"})),F3={
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 24 24"};function Z3(e,t){
return Ub(),Qb("svg",F3,[...t[0]||(t[0]=[Gb("path",{fill:"none",
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M22 6.8H2m20 10.4H2"},null,-1)])])}const Q3={render:Z3
},H3=Object.freeze(Object.defineProperty({__proto__:null,default:Q3,render:Z3
},Symbol.toStringTag,{value:"Module"})),V3={xmlns:"http://www.w3.org/2000/svg",
fill:"none",viewBox:"0 0 24 24"};function q3(e,t){
return Ub(),Qb("svg",V3,[...t[0]||(t[0]=[Gb("path",{stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",
d:"m4.9 4.9 14.2 14.2M22 12c0 5.523-4.477 10-10 10S2 17.523 2 12 6.477 2 12 2s10 4.477 10 10"
},null,-1)])])}const W3={render:q3},X3=Object.freeze(Object.defineProperty({
__proto__:null,default:W3,render:q3},Symbol.toStringTag,{value:"Module"})),G3={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function Y3(e,t){return Ub(),Qb("svg",G3,[...t[0]||(t[0]=[Gb("path",{
d:"M17.333 5.34c1.39-.22 2.796-.334 4.205-.34.121 0 .238.043.329.122a.44.44 0 0 1 .133.314v13.73a.44.44 0 0 1-.133.306.46.46 0 0 1-.311.13C14.186 19.708 12 22 12 22m0 0V7.38S9.822 5.096 2.462 5a.5.5 0 0 0-.329.122.44.44 0 0 0-.133.314v13.73a.44.44 0 0 0 .133.306.46.46 0 0 0 .311.13C9.814 19.708 12 22 12 22"
},null,-1),Gb("path",{
d:"M12 22a5.67 5.67 0 0 1 1.367-3.135c.967-1.141 2.237-1.923 3.633-2.236V2.443a.45.45 0 0 0-.051-.21.4.4 0 0 0-.14-.154.47.47 0 0 0-.409-.054 6.44 6.44 0 0 0-3.033 2.063A5.86 5.86 0 0 0 12 7.205"
},null,-1)])])}const K3={render:Y3},J3=Object.freeze(Object.defineProperty({
__proto__:null,default:K3,render:Y3},Symbol.toStringTag,{value:"Module"})),e5={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function t5(e,t){return Ub(),Qb("svg",e5,[...t[0]||(t[0]=[Gb("path",{
d:"M17 3a2.85 2.85 0 0 1 2.064-1.007 2.87 2.87 0 0 1 2.14.834 2.83 2.83 0 0 1 .825 2.131A2.8 2.8 0 0 1 21 7L7.5 20.5 2 22l1.5-5.5z"
},null,-1)])])}const n5={render:t5},r5=Object.freeze(Object.defineProperty({
__proto__:null,default:n5,render:t5},Symbol.toStringTag,{value:"Module"})),o5={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function a5(e,t){return Ub(),Qb("svg",o5,[...t[0]||(t[0]=[Gb("path",{
d:"M6 6.663c0-1.582 1.75-2.538 3.082-1.682l8.301 5.337a2 2 0 0 1 0 3.364L9.082 19.02C7.75 19.875 6 18.919 6 17.337z"
},null,-1)])])}const i5={render:a5},s5=Object.freeze(Object.defineProperty({
__proto__:null,default:i5,render:a5},Symbol.toStringTag,{value:"Module"})),l5={
xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 24 24"};function c5(e,t){
return Ub(),Qb("svg",l5,[...t[0]||(t[0]=[Gb("path",{fill:"none",
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M5.25 14.248v4.5H.75m18-9v-4.5h4.5m-4.218-.003A9.752 9.752 0 0 1 8.246 21m-3.279-2.249A9.753 9.753 0 0 1 15.754 3"
},null,-1)])])}const u5={render:c5},d5=Object.freeze(Object.defineProperty({
__proto__:null,default:u5,render:c5},Symbol.toStringTag,{value:"Module"})),p5={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function h5(e,t){return Ub(),Qb("svg",p5,[...t[0]||(t[0]=[Gb("path",{
d:"M16.22 2.663a1.47 1.47 0 0 0-1.09 0L8.87 5.167c-.35.14-.74.14-1.09 0L1.982 2.848a.735.735 0 0 0-1.008.686V17.62c0 .601.366 1.142.924 1.365l5.88 2.352c.35.14.742.14 1.092 0l6.258-2.504c.35-.14.741-.14 1.092 0l5.796 2.315a.735.735 0 0 0 1.008-.686V6.38a1.47 1.47 0 0 0-.924-1.365ZM8.325 5.272v16.17m7.35-18.884v16.17"
},null,-1)])])}const f5={render:h5},m5=Object.freeze(Object.defineProperty({
__proto__:null,default:f5,render:h5},Symbol.toStringTag,{value:"Module"})),g5={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function v5(e,t){return Ub(),Qb("svg",g5,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M3 15c1.895 3 3.79 4 6.632 4s6.631-3 6.631-7-2.842-7-5.684-7-4.737 1.5-4.737 4 1.895 5 5.684 5S19.492 11.547 21 9"
},null,-1)])])}const b5={render:v5},y5=Object.freeze(Object.defineProperty({
__proto__:null,default:b5,render:v5},Symbol.toStringTag,{value:"Module"})),O5={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function w5(e,t){return Ub(),Qb("svg",O5,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M11 19a8 8 0 1 0 0-16 8 8 0 0 0 0 16m10 2-4.35-4.35"},null,-1)])])}const x5={
render:w5},k5=Object.freeze(Object.defineProperty({__proto__:null,default:x5,
render:w5},Symbol.toStringTag,{value:"Module"})),S5={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function _5(e,t){return Ub(),Qb("svg",S5,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M20 12a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v4a2 2 0 0 0 2 2m16 0H4m16 0a2 2 0 0 1 2 2v4a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-4a2 2 0 0 1 2-2"
},null,-1),Gb("path",{fill:"currentColor",
d:"M18 9a1 1 0 1 0 0-2 1 1 0 0 0 0 2m0 8a1 1 0 1 0 0-2 1 1 0 0 0 0 2"
},null,-1),Gb("path",{stroke:"currentColor","stroke-linecap":"round",
"stroke-linejoin":"round",d:"M6 8h4m-4 8h4"},null,-1)])])}const T5={render:_5
},E5=Object.freeze(Object.defineProperty({__proto__:null,default:T5,render:_5
},Symbol.toStringTag,{value:"Module"})),A5={xmlns:"http://www.w3.org/2000/svg",
fill:"none",viewBox:"0 0 24 24"};function C5(e,t){
return Ub(),Qb("svg",A5,[...t[0]||(t[0]=[Gb("path",{stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",
d:"M20 7H9m0 0a2 2 0 1 1-4 0 2 2 0 0 1 4 0m7 10H5m11 0a2 2 0 1 0 4 0 2 2 0 0 0-4 0"
},null,-1)])])}const $5={render:C5},P5=Object.freeze(Object.defineProperty({
__proto__:null,default:$5,render:C5},Symbol.toStringTag,{value:"Module"})),D5={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function I5(e,t){return Ub(),Qb("svg",D5,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M2 12s3-7 10-7 10 7 10 7-3 7-10 7-10-7-10-7"},null,-1),Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M12 15a3 3 0 1 0 0-6 3 3 0 0 0 0 6"},null,-1)])])}const M5={render:I5
},N5=Object.freeze(Object.defineProperty({__proto__:null,default:M5,render:I5
},Symbol.toStringTag,{value:"Module"})),R5={xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 24 24"};function L5(e,t){
return Ub(),Qb("svg",R5,[...t[0]||(t[0]=[Gb("path",{fill:"none",
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M2 5.4h20M2 12h20M2 18.6h13.3"},null,-1)])])}const B5={render:L5
},j5=Object.freeze(Object.defineProperty({__proto__:null,default:B5,render:L5
},Symbol.toStringTag,{value:"Module"})),U5={xmlns:"http://www.w3.org/2000/svg",
viewBox:"0 0 24 24"};function z5(e,t){
return Ub(),Qb("svg",U5,[...t[0]||(t[0]=[Gb("path",{fill:"none",
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M13 15h5M6 9l4 3-4 3"},null,-1),Gb("path",{fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",
d:"M21 2.8H3.1c-.7 0-1.4.6-1.4 1.4v15.6c0 .7.6 1.4 1.4 1.4H21c.7 0 1.4-.6 1.4-1.4V4.2c0-.8-.5-1.4-1.3-1.4z"
},null,-1)])])}const F5={render:z5},Z5=Object.freeze(Object.defineProperty({
__proto__:null,default:F5,render:z5},Symbol.toStringTag,{value:"Module"})),Q5={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function H5(e,t){return Ub(),Qb("svg",Q5,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"m19.5 5.75-1.51 14.34a1.67 1.67 0 0 1-1.66 1.5H7.67A1.67 1.67 0 0 1 6 20.08L4.5 5.75m-2.08 0h19.16m-13.33 0v-2.5a.83.83 0 0 1 .83-.83h5.84a.83.83 0 0 1 .83.83v2.5M12 9.5v8.75m3.75-8.75-.42 8.75M8.25 9.5l.42 8.75"
},null,-1)])])}const V5={render:H5},q5=Object.freeze(Object.defineProperty({
__proto__:null,default:V5,render:H5},Symbol.toStringTag,{value:"Module"})),W5={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function X5(e,t){return Ub(),Qb("svg",W5,[...t[0]||(t[0]=[Gb("path",{
d:"M12 17a1 1 0 1 0 0-2 1 1 0 0 0 0 2"},null,-1),Gb("path",{
d:"M5.778 10h12.444c.982 0 1.778.895 1.778 2v8c0 1.105-.796 2-1.778 2H5.778C4.796 22 4 21.105 4 20v-8c0-1.105.796-2 1.778-2M17 10V7a5 5 0 0 0-9.33-2.5"
},null,-1)])])}const G5={render:X5},Y5=Object.freeze(Object.defineProperty({
__proto__:null,default:G5,render:X5},Symbol.toStringTag,{value:"Module"})),K5={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function J5(e,t){return Ub(),Qb("svg",K5,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M4.9 19.1c-3.038-3.038-3.71-7.592-2.015-11.3M7.8 16.2c-1.397-1.397-1.945-3.346-1.646-5.2M16.2 7.8c2.3 2.3 2.3 6.1 0 8.5m2.9-11.4C23 8.8 23 15.1 19.1 19m-8.423-8.5a2 2 0 0 1 2.75 2.901M22 22 2 2"
},null,-1)])])}const e7={render:J5},t7=Object.freeze(Object.defineProperty({
__proto__:null,default:e7,render:J5},Symbol.toStringTag,{value:"Module"})),n7={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function r7(e,t){return Ub(),Qb("svg",n7,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M12 4.33v15.32m5.37-9.95L12 4.33 6.63 9.7"},null,-1)])])}const o7={render:r7
},a7=Object.freeze(Object.defineProperty({__proto__:null,default:o7,render:r7
},Symbol.toStringTag,{value:"Module"})),i7={xmlns:"http://www.w3.org/2000/svg",
fill:"none",stroke:"currentColor","stroke-linecap":"round",
"stroke-linejoin":"round",viewBox:"0 0 24 24"};function s7(e,t){
return Ub(),Qb("svg",i7,[...t[0]||(t[0]=[Gb("path",{
d:"M3.5 22.2c.3-4.5 4-8 8.5-8s8.2 3.5 8.5 8z"},null,-1),Gb("circle",{cx:"12",
cy:"6.2",r:"4.5"},null,-1)])])}const l7={render:s7
},c7=Object.freeze(Object.defineProperty({__proto__:null,default:l7,render:s7
},Symbol.toStringTag,{value:"Module"})),u7={xmlns:"http://www.w3.org/2000/svg",
fill:"none",stroke:"currentColor","stroke-linecap":"round",
"stroke-linejoin":"round",viewBox:"0 0 24 24"};function d7(e,t){
return Ub(),Qb("svg",u7,[...t[0]||(t[0]=[Gb("path",{
d:"M11.101 1.488H4.83a1 1 0 0 0-1 1v6.614m9.069 13.41h6.272a1 1 0 0 0 1-1v-6.614"
},null,-1),Gb("path",{
d:"m1.23 6.5 2.6 2.6 2.601-2.6m16.339 11-2.6-2.6-2.601 2.6M5.505 18.546a2.551 2.551 0 1 0 0-5.103 2.551 2.551 0 0 0 0 5.103m4.277 3.965c-.559-1.83-2.29-3.202-4.276-3.202-1.988 0-3.718 1.372-4.277 3.202m17.264-15.92a2.551 2.551 0 1 0 0-5.103 2.551 2.551 0 0 0 0 5.103m4.277 3.965c-.559-1.83-2.289-3.202-4.276-3.202s-3.718 1.372-4.276 3.202"
},null,-1)])])}const p7={render:d7},h7=Object.freeze(Object.defineProperty({
__proto__:null,default:p7,render:d7},Symbol.toStringTag,{value:"Module"})),f7={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function m7(e,t){return Ub(),Qb("svg",f7,[...t[0]||(t[0]=[Gb("path",{
d:"M3.375 7.875a4.125 4.125 0 1 0 8.25 0 4.125 4.125 0 1 0-8.25 0M.75 20.25a6.75 6.75 0 0 1 13.5 0m.001-15.834a4.125 4.125 0 1 1-.006 6.914M15 13.667a6.757 6.757 0 0 1 8.25 6.583"
},null,-1)])])}const g7={render:m7},v7=Object.freeze(Object.defineProperty({
__proto__:null,default:g7,render:m7},Symbol.toStringTag,{value:"Module"})),b7={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function y7(e,t){return Ub(),Qb("svg",b7,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"m5.246 12.069-2.74 1.569a1 1 0 0 0 .001 1.74l8.5 4.87a2 2 0 0 0 2 0l8.5-4.87a.999.999 0 0 0 0-1.74l-2.702-1.548m-5.798 3.158a2 2 0 0 1-2 0l-8.5-4.87a1 1 0 0 1 0-1.74l8.5-4.87a2 2 0 0 1 2 0l8.5 4.87a1 1 0 0 1 0 1.74z"
},null,-1)])])}const O7={render:y7},w7=Object.freeze(Object.defineProperty({
__proto__:null,default:O7,render:y7},Symbol.toStringTag,{value:"Module"})),x7={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function k7(e,t){return Ub(),Qb("svg",x7,[...t[0]||(t[0]=[Gb("path",{
d:"M2.97 2.771 13.908 5.88a3.77 3.77 0 0 1 2.592 3.5v10.51a2.052 2.052 0 0 1-2.6 2.167l-9.048-2.46a3.7 3.7 0 0 1-2.6-3.457V4.688a2.75 2.75 0 0 1 2.67-2.813H18.75a3 3 0 0 1 3 3v8.953a3.073 3.073 0 0 1-3.11 3.047H16.5"
},null,-1),Gb("path",{
d:"M12.375 13.875a.375.375 0 0 1 0-.75m0 .75a.375.375 0 0 0 0-.75m9.375-3.75H16.5"
},null,-1)])])}const S7={render:k7},_7=Object.freeze(Object.defineProperty({
__proto__:null,default:S7,render:k7},Symbol.toStringTag,{value:"Module"})),T7={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function E7(e,t){return Ub(),Qb("svg",T7,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M4.9 19.1C1 15.2 1 8.8 4.9 4.9m2.9 11.3c-2.3-2.3-2.3-6.1 0-8.5m8.4.1c2.3 2.3 2.3 6.1 0 8.5m2.9-11.4C23 8.8 23 15.1 19.1 19M14 12a2 2 0 1 1-4 0 2 2 0 0 1 4 0"
},null,-1)])])}const A7={render:E7},C7=Object.freeze(Object.defineProperty({
__proto__:null,default:A7,render:E7},Symbol.toStringTag,{value:"Module"})),$7={
xmlns:"http://www.w3.org/2000/svg",fill:"none",stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",viewBox:"0 0 24 24"}
;function P7(e,t){return Ub(),Qb("svg",$7,[...t[0]||(t[0]=[Gb("path",{
d:"M20.25 3.75v19.5M3.75 3.75h16.5m-16.5 19.5V3.75m16.5 19.5H3.75m16.5-19.5H3.75l1.5-3h13.5zM.75 23.25h22.5m-9-2.25a2.25 2.25 0 0 0-4.5 0v2.25h4.5zM7.5 7.13a.37.37 0 1 1 0-.75m0 .75a.37.37 0 1 0 0-.75m4.5.75a.38.38 0 0 1 0-.75m0 .75a.38.38 0 0 0 0-.75m4.5.75a.38.38 0 0 1 0-.75m0 .75a.38.38 0 0 0 0-.75m-9 5.25a.38.38 0 0 1 0-.76m0 .76a.38.38 0 0 0 0-.76m4.5.76a.38.38 0 0 1 0-.76m0 .76a.38.38 0 0 0 0-.76m4.5.76a.38.38 0 0 1 0-.76m0 .76a.38.38 0 0 0 0-.76m-9 5.26a.38.38 0 0 1 0-.75m0 .75a.38.38 0 0 0 0-.75m4.5.75a.38.38 0 0 1 0-.75m0 .75a.38.38 0 0 0 0-.75m4.5.75a.38.38 0 0 1 0-.75m0 .75a.38.38 0 0 0 0-.75"
},null,-1)])])}const D7={render:P7},I7=Object.freeze(Object.defineProperty({
__proto__:null,default:D7,render:P7},Symbol.toStringTag,{value:"Module"})),M7={
xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",viewBox:"0 0 24 24"}
;function N7(e,t){return Ub(),Qb("svg",M7,[...t[0]||(t[0]=[Gb("path",{
d:"M9.931 12.645h4.138l-2.07-4.908m0-7.737L.68 3.982l1.726 14.771L12 24l9.596-5.242L23.32 3.984zm7.064 18.31h-2.638l-1.422-3.503H8.996l-1.422 3.504h-2.64L12 2.65z"
},null,-1)])])}const R7={render:N7},L7=Object.freeze(Object.defineProperty({
__proto__:null,default:R7,render:N7},Symbol.toStringTag,{value:"Module"})),B7={
xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",viewBox:"0 0 24 24"}
;function j7(e,t){return Ub(),Qb("svg",B7,[...t[0]||(t[0]=[Gb("path",{
d:"M16.074 16.86c-.72.616-2.157 1.035-3.812 1.035-2.032 0-3.735-.632-4.187-1.483-.161.488-.198 1.046-.198 1.402 0 0-.106 1.75 1.111 2.968 0-.632.513-1.145 1.145-1.145 1.083 0 1.082.945 1.081 1.712v.069c0 1.164.711 2.161 1.723 2.582a2.35 2.35 0 0 1-.236-1.029c0-1.11.652-1.523 1.41-2.003.602-.383 1.272-.807 1.733-1.66a3.1 3.1 0 0 0 .378-1.494 3.1 3.1 0 0 0-.148-.954M15.551.6c.196.244.296.572.496 1.229l4.368 14.347a18.2 18.2 0 0 0-5.222-1.768L12.35 4.8a.37.37 0 0 0-.71.002l-2.81 9.603a18.2 18.2 0 0 0-5.245 1.771L7.974 1.827c.2-.656.3-.984.497-1.227a1.6 1.6 0 0 1 .654-.484C9.415 0 9.757 0 10.443 0h3.135c.686 0 1.03 0 1.32.117A1.6 1.6 0 0 1 15.55.6z"
},null,-1)])])}const U7={render:j7},z7=Object.freeze(Object.defineProperty({
__proto__:null,default:U7,render:j7},Symbol.toStringTag,{value:"Module"})),F7={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function Z7(e,t){return Ub(),Qb("svg",F7,[...t[0]||(t[0]=[Gb("path",{
fill:"currentColor","fill-rule":"evenodd",
d:"M6.335.83a.75.75 0 0 0-.67 0L1.667 2.827a.75.75 0 0 0-.417.672V18c0 .271.146.52.382.654l7.989 4.493a.75.75 0 0 0 .747.007l8-4.5A.75.75 0 0 0 18.75 18v-4.537l3.585-1.792A.75.75 0 0 0 22.75 11V6a.75.75 0 0 0-.417-.672l-3.998-1.999a.75.75 0 0 0-.67 0l-3.997 1.999a.7.7 0 0 0-.246.194.75.75 0 0 0-.172.478v4.561l-2.5 1.407V3.5a.75.75 0 0 0-.43-.678L6.336.829Zm7.686 11.019 2.38 1.19-6.422 3.612-2.38-1.19zm3.229-.063-2.5-1.25V7.215l2.5 1.25zm1.5 0 2.5-1.25V7.215l-2.5 1.25zm-9.5 1.025V4.714l-2.5 1.25v8.254zm-1.005 4.65.743.372c.17.091.262.153.262.183v3.202l-6.5-3.657V4.714l2.5 1.25V15.5a.75.75 0 0 0 .415.67s1.122.591 2.108 1.064zm2.505.478 6.5-3.657v3.28l-6.5 3.656v-3.28ZM6 4.66 3.677 3.5 6 2.339 8.323 3.5zM20.323 6 18 4.839 15.677 6 18 7.161z",
"clip-rule":"evenodd"},null,-1)])])}const Q7={render:Z7
},H7=Object.freeze(Object.defineProperty({__proto__:null,default:Q7,render:Z7
},Symbol.toStringTag,{value:"Module"})),V7={xmlns:"http://www.w3.org/2000/svg",
fill:"currentColor",viewBox:"0 0 24 24"};function q7(e,t){
return Ub(),Qb("svg",V7,[...t[0]||(t[0]=[Gb("path",{
d:"M11.573 0a5 5 0 0 0-.359.007L10.85.04c-3.407.307-6.6 2.146-8.622 4.972a11.9 11.9 0 0 0-2.119 5.243c-.096.659-.108.854-.108 1.747s.012 1.089.108 1.748c.652 4.506 3.86 8.292 8.209 9.695.779.25 1.6.422 2.534.525.363.04 1.935.04 2.299 0 1.611-.178 2.977-.577 4.323-1.264.207-.106.247-.134.219-.158-.02-.013-.9-1.193-1.955-2.62l-1.919-2.592-2.404-3.558a339 339 0 0 0-2.422-3.556c-.009-.002-.018 1.579-.023 3.51-.007 3.38-.01 3.515-.052 3.595a.43.43 0 0 1-.206.214c-.075.037-.14.044-.495.044H7.81l-.108-.068a.44.44 0 0 1-.157-.171l-.05-.106.006-4.703.007-4.705.072-.092a.7.7 0 0 1 .174-.143c.096-.047.134-.051.54-.051.478 0 .558.018.682.154a467 467 0 0 1 2.895 4.361l4.735 7.17 1.9 2.879.096-.063a12.3 12.3 0 0 0 2.466-2.163 11.94 11.94 0 0 0 2.824-6.134c.096-.66.108-.854.108-1.748 0-.893-.012-1.088-.108-1.747-.652-4.506-3.859-8.292-8.208-9.695a12.6 12.6 0 0 0-2.499-.523A33 33 0 0 0 11.573 0m4.068 7.217c.347 0 .408.005.486.047a.47.47 0 0 1 .237.277c.018.06.023 1.365.018 4.304l-.006 4.218-.744-1.14-.746-1.14v-3.066c0-1.982.01-3.097.023-3.15a.48.48 0 0 1 .233-.296c.096-.05.13-.054.5-.054z"
},null,-1)])])}const W7={render:q7},X7=Object.freeze(Object.defineProperty({
__proto__:null,default:W7,render:q7},Symbol.toStringTag,{value:"Module"})),G7={
xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",viewBox:"0 0 24 24"}
;function Y7(e,t){return Ub(),Qb("svg",G7,[...t[0]||(t[0]=[Gb("path",{
d:"M14.23 12.004a2.236 2.236 0 0 1-2.235 2.236 2.236 2.236 0 0 1-2.236-2.236 2.236 2.236 0 0 1 2.235-2.236 2.236 2.236 0 0 1 2.236 2.236m2.648-10.69c-1.346 0-3.107.96-4.888 2.622-1.78-1.653-3.542-2.602-4.887-2.602-.41 0-.783.093-1.106.278-1.375.793-1.683 3.264-.973 6.365C1.98 8.917 0 10.42 0 12.004c0 1.59 1.99 3.097 5.043 4.03-.704 3.113-.39 5.588.988 6.38.32.187.69.275 1.102.275 1.345 0 3.107-.96 4.888-2.624 1.78 1.654 3.542 2.603 4.887 2.603.41 0 .783-.09 1.106-.275 1.374-.792 1.683-3.263.973-6.365C22.02 15.096 24 13.59 24 12.004c0-1.59-1.99-3.097-5.043-4.032.704-3.11.39-5.587-.988-6.38a2.17 2.17 0 0 0-1.092-.278zm-.005 1.09v.006c.225 0 .406.044.558.127.666.382.955 1.835.73 3.704-.054.46-.142.945-.25 1.44a23.5 23.5 0 0 0-3.107-.534A24 24 0 0 0 12.769 4.7c1.592-1.48 3.087-2.292 4.105-2.295zm-9.77.02c1.012 0 2.514.808 4.11 2.28-.686.72-1.37 1.537-2.02 2.442a23 23 0 0 0-3.113.538 15 15 0 0 1-.254-1.42c-.23-1.868.054-3.32.714-3.707.19-.09.4-.127.563-.132zm4.882 3.05q.684.704 1.36 1.564c-.44-.02-.89-.034-1.345-.034q-.691-.001-1.36.034c.44-.572.895-1.096 1.345-1.565zM12 8.1c.74 0 1.477.034 2.202.093q.61.874 1.183 1.86.557.961 1.018 1.946c-.308.655-.646 1.31-1.013 1.95-.38.66-.773 1.288-1.18 1.87a25.6 25.6 0 0 1-4.412.005 27 27 0 0 1-1.183-1.86q-.557-.961-1.018-1.946a25 25 0 0 1 1.013-1.954c.38-.66.773-1.286 1.18-1.868A25 25 0 0 1 12 8.098zm-3.635.254c-.24.377-.48.763-.704 1.16q-.336.585-.635 1.174c-.265-.656-.49-1.31-.676-1.947.64-.15 1.315-.283 2.015-.386zm7.26 0q1.044.153 2.006.387c-.18.632-.405 1.282-.66 1.933a26 26 0 0 0-1.345-2.32zm3.063.675q.727.226 1.375.498c1.732.74 2.852 1.708 2.852 2.476-.005.768-1.125 1.74-2.857 2.475-.42.18-.88.342-1.355.493a24 24 0 0 0-1.1-2.98c.45-1.017.81-2.01 1.085-2.964zm-13.395.004c.278.96.645 1.957 1.1 2.98a23 23 0 0 0-1.086 2.964c-.484-.15-.944-.318-1.37-.5-1.732-.737-2.852-1.706-2.852-2.474s1.12-1.742 2.852-2.476c.42-.18.88-.342 1.356-.494m11.678 4.28c.265.657.49 1.312.676 1.948-.64.157-1.316.29-2.016.39a26 26 0 0 0 1.341-2.338zm-9.945.02c.2.392.41.783.64 1.175q.345.586.705 1.143a22 22 0 0 1-2.006-.386c.18-.63.406-1.282.66-1.933zM17.92 16.32c.112.493.2.968.254 1.423.23 1.868-.054 3.32-.714 3.708-.147.09-.338.128-.563.128-1.012 0-2.514-.807-4.11-2.28.686-.72 1.37-1.536 2.02-2.44 1.107-.118 2.154-.3 3.113-.54zm-11.83.01c.96.234 2.006.415 3.107.532.66.905 1.345 1.727 2.035 2.446-1.595 1.483-3.092 2.295-4.11 2.295a1.2 1.2 0 0 1-.553-.132c-.666-.38-.955-1.834-.73-3.703.054-.46.142-.944.25-1.438zm4.56.64q.661.032 1.345.034.691.001 1.36-.034c-.44.572-.895 1.095-1.345 1.565q-.684-.706-1.36-1.565"
},null,-1)])])}const K7={render:Y7},J7=Object.freeze(Object.defineProperty({
__proto__:null,default:K7,render:Y7},Symbol.toStringTag,{value:"Module"})),e9={
xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",viewBox:"0 0 24 24"}
;function t9(e,t){return Ub(),Qb("svg",e9,[...t[0]||(t[0]=[Gb("path",{
d:"M23.94 3a.5.5 0 0 0-.44-.25h-2.31l-8.55 13.91a.75.75 0 0 1-1.28 0L2.81 2.77H.5A.5.5 0 0 0 .06 3a.54.54 0 0 0 0 .51l11.5 19a.51.51 0 0 0 .86 0l11.5-19a.54.54 0 0 0 .02-.51"
},null,-1),Gb("path",{
d:"m12 14.84 7.43-12.07H16a.47.47 0 0 0-.43.25L12 9.26 8.43 3A.47.47 0 0 0 8 2.77H4.57Z"
},null,-1)])])}const n9={render:t9},r9=Object.freeze(Object.defineProperty({
__proto__:null,default:n9,render:t9},Symbol.toStringTag,{value:"Module"})),o9={
xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",viewBox:"0 0 128 128"}
;function a9(e,t){return Ub(),Qb("svg",o9,[...t[0]||(t[0]=[Gb("path",{
d:"m117.5 33.5.3-.2c-.6-1.1-1.5-2.1-2.4-2.6L67.1 2.9c-.8-.5-1.9-.7-3.1-.7s-2.3.3-3.1.7l-48 27.9c-1.7 1-2.9 3.5-2.9 5.4v55.7c0 1.1.2 2.3.9 3.4l-.2.1c.5.8 1.2 1.5 1.9 1.9l48.2 27.9c.8.5 1.9.7 3.1.7s2.3-.3 3.1-.7l48-27.9c1.7-1 2.9-3.5 2.9-5.4V36.1c.1-.8 0-1.7-.4-2.6M64 88.5c9.1 0 17.1-5 21.3-12.4l12.9 7.6c-6.8 11.8-19.6 19.8-34.2 19.8-21.8 0-39.5-17.7-39.5-39.5S42.2 24.5 64 24.5c14.7 0 27.5 8.1 34.3 20l-13 7.5C81.1 44.5 73.1 39.5 64 39.5c-13.5 0-24.5 11-24.5 24.5s11 24.5 24.5 24.5"
},null,-1)])])}const i9={render:a9},s9=Object.freeze(Object.defineProperty({
__proto__:null,default:i9,render:a9},Symbol.toStringTag,{value:"Module"})),l9={
xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",viewBox:"0 0 128 128"}
;function c9(e,t){return Ub(),Qb("svg",l9,[...t[0]||(t[0]=[Gb("path",{
d:"M60.952.266C27.377.266.065 28.77.065 63.806s27.318 63.54 60.887 63.54c33.576 0 60.893-28.505 60.893-63.54S94.528.266 60.952.266m0 6.117c30.39 0 55.025 25.712 55.025 57.423 0 2.482-.167 4.924-.46 7.321-1.495 6.214-4.194 10.358-7.412 13.19-4.941 4.336-11.524 5.738-17.62 5.733a41 41 0 0 1-4.973-.289C97.506 77.4 99.336 57.866 89.864 43.315 80.39 28.763 62.315 23.338 46.882 30.416a24 24 0 0 0-1.68-1.114c-2.41-1.413-7.439-3.482-13.837-3.505-5.361-.022-10.615 1.568-15.133 4.58C26.554 15.317 43.21 6.386 60.952 6.394zM51.341 84.6c.894-4.07 3.343-10.431 5.548-15.655.623-1.481 1.23-2.872 1.777-4.104 3.451 12.822 5.635 20.449 9.546 25.65a18 18 0 0 0 1.913 2.114 28 28 0 0 1-9.173 1.56 28.2 28.2 0 0 1-10.023-1.86q-.098-1.227-.103-2.459a24.5 24.5 0 0 1 .515-5.24zm-7.444 3.77c-7.555-5.703-12.031-14.84-12.04-24.57.008-9.88 4.625-19.138 12.375-24.813 1.637.984 3.121 2.143 4.34 3.477 2.395 2.56 5.077 8.214 6.94 13.082.51 1.312.965 2.567 1.36 3.709C50.16 73.502 45.685 80.608 43.898 88.37zm21.802-18.226c-1.501-4.037-2.374-7.079-2.379-7.084l-.005-.012c-2.747-10.984-5.592-21.025-11.497-28.052a28 28 0 0 1 9.134-1.55c16.06.022 29.074 13.602 29.095 30.36-.007 9.673-4.432 18.764-11.914 24.474a15 15 0 0 1-2.184-.78c-1.137-.514-2.812-2.267-4.329-4.698-2.313-3.635-4.437-8.622-5.927-12.653zm-4.747 51.08c-30.39 0-55.025-25.707-55.025-57.424 0-2.086.114-4.144.32-6.173 4.508-16 15.338-21.92 25.595-22.02 2.08-.007 4.117.282 6.068.774-13.182 12.081-15.74 32.487-5.979 47.7 9.762 15.213 28.817 20.518 44.544 12.403 2.78 1.023 5.96 1.633 9.812 2.137 1.447.186 3.007.277 4.665.277a61.6 61.6 0 0 0 14.997-2.087c-10.29 15.308-27.088 24.417-45.007 24.407z"
},null,-1)])])}const u9={render:c9},d9=Object.freeze(Object.defineProperty({
__proto__:null,default:u9,render:c9},Symbol.toStringTag,{value:"Module"})),p9={
xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",viewBox:"0 0 128 128"}
;function h9(e,t){return Ub(),Qb("svg",p9,[...t[0]||(t[0]=[Gb("path",{
d:"m117.5 33.5.3-.2c-.6-1.1-1.5-2.1-2.4-2.6L67.1 2.9c-.8-.5-1.9-.7-3.1-.7s-2.3.3-3.1.7l-48 27.9c-1.7 1-2.9 3.5-2.9 5.4v55.7c0 1.1.2 2.3.9 3.4l-.2.1c.5.8 1.2 1.5 1.9 1.9l48.2 27.9c.8.5 1.9.7 3.1.7s2.3-.3 3.1-.7l48-27.9c1.7-1 2.9-3.5 2.9-5.4V36.1c.1-.8 0-1.7-.4-2.6m-53.5 70c-21.8 0-39.5-17.7-39.5-39.5S42.2 24.5 64 24.5c14.7 0 27.5 8.1 34.3 20l-13 7.5C81.1 44.5 73.1 39.5 64 39.5c-13.5 0-24.5 11-24.5 24.5s11 24.5 24.5 24.5c9.1 0 17.1-5 21.3-12.4l12.9 7.6c-6.8 11.8-19.6 19.8-34.2 19.8M115 62h-3.2l-.9 4h4.1v5h-5l-1.2 6h-4.9l1.2-6h-3.8l-1.2 6h-4.8l1.2-6H94v-5h3.5l.9-4H94v-5h5.3l1.2-6h4.9l-1.2 6h3.8l1.2-6h4.8l-1.2 6h2.2zm-12.7 4h3.8l.9-4h-3.8z"
},null,-1)])])}const f9={render:h9},m9=Object.freeze(Object.defineProperty({
__proto__:null,default:f9,render:h9},Symbol.toStringTag,{value:"Module"})),g9={
xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",viewBox:"0 0 24 24"}
;function v9(e,t){return Ub(),Qb("svg",g9,[...t[0]||(t[0]=[Gb("path",{
d:"M1.5 0h21l-1.91 21.563L11.977 24l-8.565-2.438zm17.09 4.413L5.41 4.41l.213 2.622 10.125.002-.255 2.716h-6.64l.24 2.573h6.182l-.366 3.523-2.91.804-2.956-.81-.188-2.11h-2.61l.29 3.855L12 19.288l5.373-1.53z"
},null,-1)])])}const b9={render:v9},y9=Object.freeze(Object.defineProperty({
__proto__:null,default:b9,render:v9},Symbol.toStringTag,{value:"Module"})),O9={
xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",viewBox:"0 0 50 50"}
;function w9(e,t){return Ub(),Qb("svg",O9,[...t[0]||(t[0]=[Gb("path",{
d:"m7.91 9.32.09.09V35.3l-5.09-5.09a6.22 6.22 0 0 1-1.27-6.92zM35.3 8H9.41l-.09-.09 13.97-6.27a6.22 6.22 0 0 1 6.92 1.27zm2.29 31H11.71l-.54-.54A4 4 0 0 1 10 35.63V11.41zm-23.88 2H39v6c0 .55-.45 1-1 1H21.1c-.27 0-.52-.11-.71-.29l-4.7-4.7.02-.02zM48 21.1V38c0 .55-.45 1-1 1h-6.58L11.41 10h24.22c1.07 0 2.07.42 2.83 1.17l4.53 4.54.02-.02 4.7 4.7c.18.19.29.44.29.71"
},null,-1)])])}const x9={render:w9},k9=Object.freeze(Object.defineProperty({
__proto__:null,default:x9,render:w9},Symbol.toStringTag,{value:"Module"})),S9={
xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",viewBox:"0 0 128 128"}
;function _9(e,t){return Ub(),Qb("svg",S9,[...t[0]||(t[0]=[Gb("path",{
d:"M0 64.5 60.7 3.8v30.4L30.4 64.5l30.4 30.4v30.4zm39.1 0 21.7-21.7v43.4zm88.9 0L65.1 3.8v30.4l30.4 30.4-30.4 30.3v30.4z"
},null,-1)])])}const T9={render:_9},E9=Object.freeze(Object.defineProperty({
__proto__:null,default:T9,render:_9},Symbol.toStringTag,{value:"Module"})),A9={
xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",viewBox:"0 0 128 128"}
;function C9(e,t){return Ub(),Qb("svg",A9,[...t[0]||(t[0]=[Gb("path",{
d:"M108.2 64.8c-.1-.1-.2-.2-.4-.2l-.1-.1c-.1-.1-.2-.1-.2-.2l-.1-.1c-.1 0-.2-.1-.2-.1l-.2-.1c-.1 0-.2-.1-.2-.1l-.2-.1c-.1 0-.2-.1-.2-.1-.1 0-.1 0-.2-.1l-.3-.1c-.1 0-.1 0-.2-.1l-.3-.1h-.1l-.4-.1h-.2c-.1 0-.2 0-.3-.1h-2.3c-.6-13.3.6-26.8-2.8-39.6 12.9-4.6 2.8-22.3-8.4-14.4-7.4-6.4-17.6-7.8-28.3-7.8-10.5.7-20.4 2.9-27.4 8.4-2.8-1.4-5.5-1.8-7.9-1.1v.1c-.1 0-.3.1-.4.2-.1 0-.3.1-.4.2h-.1c-.1 0-.2.1-.4.2h-.1l-.3.2h-.1l-.3.2h-.1l-.3.2s-.1 0-.1.1l-.3.2s-.1 0-.1.1l-.3.2s-.1 0-.1.1l-.3.2-.1.1c-.1.1-.2.1-.2.2l-.1.1-.2.2-.1.1c-.1.1-.1.2-.2.2l-.1.1c-.1.1-.1.2-.2.2l-.1.1c-.1.1-.1.2-.2.2l-.1.1c-.1.1-.1.2-.2.2l-.1.1c-.1.1-.1.2-.2.2l-.1.1-.1.3s0 .1-.1.1l-.1.3s0 .1-.1.1l-.1.3s0 .1-.1.1l-.1.3s0 .1-.1.1c.4.3.4.4.4.4v.1l-.1.3v.1c0 .1 0 .2-.1.3v3.1c0 .1 0 .2.1.3v.1l.1.3v.1l.1.3s0 .1.1.1l.1.3s0 .1.1.1l.1.3s0 .1.1.1l.2.3s0 .1.1.1l.2.3s0 .1.1.1l.2.3.1.1.3.3.3.3h.1c1 .9 2 1.6 4 2.2v-.2C23 37.3 26.5 50 26.7 63c-.6 0-.7.4-1.7.5h-.5c-.1 0-.3 0-.5.1-.1 0-.3 0-.4.1l-.4.1h-.1l-.4.1h-.1l-.3.1h-.1l-.3.1s-.1 0-.1.1l-.3.1-.2.1c-.1 0-.2.1-.2.1l-.2.1-.2.1c-.1 0-.2.1-.2.1l-.2.1-.4.3c-.1.1-.2.2-.3.2l-.4.4-.1.1c-.1.2-.3.4-.4.5l-.2.3-.3.6-.1.3v.3c0 .5.2.9.9 1.2.2 3.7 3.9 2 5.6.8l.1-.1c.2-.2.5-.3.6-.3h.1l.2-.1c.1 0 .1 0 .2-.1.2-.1.4-.1.5-.2.1 0 .1-.1.1-.2l.1-.1c.1-.2.2-.6.2-1.2l.1-1.3v1.8c-.5 13.1-4 30.7 3.3 42.5 1.3 2.1 2.9 3.9 4.7 5.4h-.5c-.2.2-.5.4-.8.6l-.9.6-.3.2-.6.4-.9.7-1.1 1c-.2.2-.3.4-.4.5l-.4.6-.2.3c-.1.2-.2.4-.2.6l-.1.3q-.3 1.2.6 2.7l.4.4h.2c.1 0 .2 0 .4.1.2.4 1.2 2.5 3.9.9 2.8-1.5 4.7-4.6 8.1-5.1l-.5-.6c5.9 2.8 12.8 4 19 4.2 8.7.3 18.6-.9 26.5-5.2 2.2.7 3.9 3.9 5.8 5.4l.1.1.1.1.1.1.1.1s.1 0 .1.1c0 0 .1 0 .1.1 0 0 .1 0 .1.1h2.1s.1 0 .1-.1h.1s.1 0 .1-.1h.1s.1 0 .1-.1c0 0 .1 0 .1-.1l.1-.1s.1 0 .1-.1l.1-.1h.1l.2-.2.2-.1h.1l.1-.1h.1l.1-.1.1-.1.1-.1.1-.1.1-.1.1-.1.1-.1v-.1s0-.1.1-.1v-.1s0-.1.1-.1v-.1s0-.1.1-.1v-1.4s-.3 0-.3-.1l-.3-.1v-.1l.3-.1s.2 0 .2-.1l.1-.1v-2.1s0-.1-.1-.1v-.1s0-.1-.1-.1v-.1s0-.1-.1-.1c0 0 0-.1-.1-.1 0 0 0-.1-.1-.1 0 0 0-.1-.1-.1 0 0 0-.1-.1-.1 0 0 0-.1-.1-.1 0 0 0-.1-.1-.1 0 0 0-.1-.1-.1 0 0 0-.1-.1-.1 0 0 0-.1-.1-.1 0 0 0-.1-.1-.1 0 0 0-.1-.1-.1 0 0 0-.1-.1-.1 0 0 0-.1-.1-.1l-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1v-.1l-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1-.1c2-1.9 3.8-4.2 5.1-6.9 5.9-11.8 4.9-26.2 4.1-39.2h.1c.1 0 .2.1.2.1h.3s.1 0 .1.1h.1s.1 0 .1.1l.2.1c1.7 1.2 5.4 2.9 5.6-.8 1.6.6-.3-1.8-1.3-2.5M36 23C32.8 7 58.4 4 59.3 19.6c.8 13-20 16.3-23.3 3.4m36.1 15c-1.3 1.4-2.7 1.2-4.1.7 0 1.9.4 3.9.1 5.9-.5.9-1.5 1-2.3 1.4-1.2-.2-2.1-.9-2.6-2l-.2-.1c-3.9 5.2-6.3-1.1-5.2-5-1.2.1-2.2-.2-3-1.5-1.4-2.6.7-5.8 3.4-6.3.7 3 8.7 2.6 10.1-.2 3.1 1.5 6.5 4.3 3.8 7.1m-7-17.5c-.9-13.8 20.3-17.5 23.4-4 3.5 15-20.8 18.9-23.4 4M41.7 17c-1.9 0-3.5 1.7-3.5 3.8s1.6 3.8 3.5 3.8 3.5-1.7 3.5-3.8-1.5-3.8-3.5-3.8m1.6 5.7c-.5 0-.8-.4-.8-1 0-.5.4-1 .8-1 .5 0 .8.4.8 1 0 .5-.3 1-.8 1m27.8-6.6c-1.9 0-3.4 1.7-3.4 3.8s1.5 3.8 3.4 3.8 3.4-1.7 3.4-3.8-1.5-3.8-3.4-3.8m1.6 5.6c-.4 0-.8-.4-.8-1 0-.5.4-1 .8-1s.8.4.8 1-.4 1-.8 1"
},null,-1)])])}const $9={render:C9},P9=Object.freeze(Object.defineProperty({
__proto__:null,default:$9,render:C9},Symbol.toStringTag,{value:"Module"})),D9={
xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",viewBox:"0 0 24 24"}
;function I9(e,t){return Ub(),Qb("svg",D9,[...t[0]||(t[0]=[Gb("path",{
d:"M1.5 0h21l-1.91 21.563L11.977 24l-8.564-2.438zm7.031 9.75-.232-2.718 10.059.003.23-2.622L5.412 4.41l.698 8.01h9.126l-.326 3.426-2.91.804-2.955-.81-.188-2.11H6.248l.33 4.171L12 19.351l5.379-1.443.744-8.157z"
},null,-1)])])}const M9={render:I9},N9=Object.freeze(Object.defineProperty({
__proto__:null,default:M9,render:I9},Symbol.toStringTag,{value:"Module"})),R9={
xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",viewBox:"0 0 128 128"}
;function L9(e,t){return Ub(),Qb("svg",R9,[...t[0]||(t[0]=[Gb("path",{
d:"M111.7 29.7 128 64l-16.3 34.3H16.3L0 64l16.3-34.3zm-5.5 5.7H20L6.3 64l13.6 28.6h86.3L119.8 64zm-76.3 19v8h9.2v-8.1h4.8v20.4h-4.7v-8.4H30v8.4h-4.8V54.4zm34.3 0v3.8h-6.5v16.5H53V58.2h-6.5v-3.8zm18.3 0v3.8H76v16.5h-4.7V58.2h-6.5v-3.8zm16.1.9c1.2.5 2.3 1.4 3.1 2.6.7 1.2 1.1 2.5 1 3.9.1 1.4-.3 2.7-1 3.9-.7 1.1-1.8 2-3.1 2.6-1.5.6-3.1.9-4.7.9h-4.1v5.6H85V54.4h8.9c1.6 0 3.2.3 4.7.9m-5.1 2.9h-3.8v7.1h3.8q2.1 0 3.3-.9c.8-.6 1.2-1.6 1.1-2.6 0-1.1-.3-2.1-1.1-2.6-.8-.7-1.9-1-3.3-1"
},null,-1)])])}const B9={render:L9},j9=Object.freeze(Object.defineProperty({
__proto__:null,default:B9,render:L9},Symbol.toStringTag,{value:"Module"})),U9={
xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",viewBox:"0 0 24 24"}
;function z9(e,t){return Ub(),Qb("svg",U9,[...t[0]||(t[0]=[Gb("path",{
d:"M11.26 15.27c3.37-.15 7.15-1.09 7-2.21a26 26 0 0 1-4.76.59c-3.62.16-6.58-.24-6.61-.9 0-.2.24-.4.69-.58-2.39-.64-3.67.53-3.69 1.22-.1 1.45 3.22 2.06 7.37 1.88m5.91 1.64a23 23 0 0 1-4.07.5c-3.09.14-5.61-.21-5.64-.77 0-.17.21-.34.59-.49-2-.55-3.13.45-3.15 1-.05 1.24 2.78 1.77 6.33 1.61 2.87-.1 6.25-1 5.94-1.85M3.61 20.8a.93.93 0 0 1 .29-.65c-2.09.1-2.54 1.13-2.51 1.76.07 1.39 4.67 2.31 10 2.05 4.44-.22 9.16-1 9.16-2.34a26.3 26.3 0 0 1-7.2 1.23c-5.35.26-9.67-.66-9.74-2.05"
},null,-1),Gb("path",{
d:"M22.4 12.65c-.55-1.48-2.67-2.34-4.74-1.57a2.47 2.47 0 0 0-1 .81c1.94-.56 3.83 0 4.34 1.41.45 1.21-.3 2.64-1.72 3.54a1.37 1.37 0 0 0 .92-.13c2.25-1.05 2.8-2.58 2.2-4.06m-9.88-1.38s-3.1-2.19-1.92-4.35S14.37 2.43 13.38 0c0 0 .12 1-3.12 3.91s-2.14 6.33 2.26 7.36"
},null,-1),Gb("path",{
d:"M15.17 4.83s-4.24 1.51-2.83 3.53c1 1.43 2.13 2 1.42 4 0 0 2.83-1.51.71-3.53s.7-4 .7-4M8.69 19.26c-1.6-.43-2.46.35-2.47.81 0 1 2.18 1.39 5 1.27 2.26-.11 4.73-.95 4.67-1.49a16.6 16.6 0 0 1-3.2.4c-2.43.11-4.41-.16-4.43-.61-.04-.13.13-.26.43-.38"
},null,-1)])])}const F9={render:z9},Z9=Object.freeze(Object.defineProperty({
__proto__:null,default:F9,render:z9},Symbol.toStringTag,{value:"Module"})),Q9={
xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",viewBox:"0 0 24 24"}
;function H9(e,t){return Ub(),Qb("svg",Q9,[...t[0]||(t[0]=[Gb("path",{
d:"M0 0h24v24H0zm22.034 18.276c-.175-1.095-.888-2.015-3.003-2.873-.736-.345-1.554-.585-1.797-1.14-.091-.33-.105-.51-.046-.705.15-.646.915-.84 1.515-.66.39.12.75.42.976.9 1.034-.676 1.034-.676 1.755-1.125-.27-.42-.404-.601-.586-.78-.63-.705-1.469-1.065-2.834-1.034l-.705.089c-.676.165-1.32.525-1.71 1.005-1.14 1.291-.811 3.541.569 4.471 1.365 1.02 3.361 1.244 3.616 2.205.24 1.17-.87 1.545-1.966 1.41-.811-.18-1.26-.586-1.755-1.336l-1.83 1.051c.21.48.45.689.81 1.109 1.74 1.756 6.09 1.666 6.871-1.004.029-.09.24-.705.074-1.65zm-8.983-7.245h-2.248c0 1.938-.009 3.864-.009 5.805 0 1.232.063 2.363-.138 2.711-.33.689-1.18.601-1.566.48-.396-.196-.597-.466-.83-.855-.063-.105-.11-.196-.127-.196l-1.825 1.125c.305.63.75 1.172 1.324 1.517.855.51 2.004.675 3.207.405.783-.226 1.458-.691 1.811-1.411.51-.93.402-2.07.397-3.346.012-2.054 0-4.109 0-6.179z"
},null,-1)])])}const V9={render:H9},q9=Object.freeze(Object.defineProperty({
__proto__:null,default:V9,render:H9},Symbol.toStringTag,{value:"Module"})),W9={
xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",viewBox:"0 0 24 24"}
;function X9(e,t){return Ub(),Qb("svg",W9,[...t[0]||(t[0]=[Gb("path",{
d:"M4.56 18.71c-1.41-4-.65-8.94 1.77-11.48A5.47 5.47 0 0 1 12 5.71h.15a.8.8 0 0 1 .22.12c4 1.65 4.28 8.57 1.28 11.41a4.15 4.15 0 0 0 3.08-1.35c2.12-2.23 2.76-6.62 1.49-10.22A7.75 7.75 0 0 0 12.81.54H12a11.5 11.5 0 0 0-5.42 21.6 10 10 0 0 1-2.02-3.43"
},null,-1),Gb("path",{
d:"M23.5 12a11.49 11.49 0 0 0-6.09-10.14 9.9 9.9 0 0 1 2 3.43c1.41 4 .65 9-1.77 11.5a5.42 5.42 0 0 1-4 1.75A6.5 6.5 0 0 1 12 18.3h-.15a.8.8 0 0 1-.22-.12c-4-1.65-4.29-8.57-1.29-11.41a4.14 4.14 0 0 0-3.11 1.32c-2.12 2.22-2.76 6.61-1.49 10.2a7.77 7.77 0 0 0 5.45 5.17H12A11.5 11.5 0 0 0 23.5 12"
},null,-1)])])}const G9={render:X9},Y9=Object.freeze(Object.defineProperty({
__proto__:null,default:G9,render:X9},Symbol.toStringTag,{value:"Module"})),K9={
xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",viewBox:"0 0 128 128"}
;function J9(e,t){return Ub(),Qb("svg",K9,[...t[0]||(t[0]=[Gb("path",{
d:"M0 0h61.4L0 60.4zm0 128L128 0H64.6L0 63.7zm128 0L64.6 66.6 3.3 128z"
},null,-1)])])}const eee={render:J9},tee=Object.freeze(Object.defineProperty({
__proto__:null,default:eee,render:J9},Symbol.toStringTag,{value:"Module"
})),nee={xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",
viewBox:"0 0 24 24"};function ree(e,t){
return Ub(),Qb("svg",nee,[...t[0]||(t[0]=[Gb("path",{
d:"M21.75 5.52 13 .28a2 2 0 0 0-2 0L2.25 5.52a2 2 0 0 0-1 1.69v9.58a2 2 0 0 0 1 1.69l2.62 1.57a3.12 3.12 0 0 0 4.73-2.68V8.12a1 1 0 0 0-2 0v9.25a1.13 1.13 0 0 1-.57 1 1.14 1.14 0 0 1-1.13 0l-2.61-1.58V7.24L12 2l8.73 5.21v9.55L12 22l-1.7-1a1 1 0 1 0-1 1.71l1.72 1a2 2 0 0 0 2 0l8.74-5.24a2 2 0 0 0 1-1.69V7.21a2 2 0 0 0-1.01-1.69"
},null,-1),Gb("path",{
d:"M15.51 14.76a9.3 9.3 0 0 1-2.24 0 .85.85 0 0 1-.75-.85 1 1 0 0 0-2 0A2.87 2.87 0 0 0 13 16.75a12 12 0 0 0 1.36.08 12 12 0 0 0 1.37-.08 2.87 2.87 0 0 0 2.5-2.84A2.68 2.68 0 0 0 16 11.26l-2.91-.49a.69.69 0 0 1-.58-.68.85.85 0 0 1 .75-.85 9.3 9.3 0 0 1 2.24 0 .85.85 0 0 1 .75.85 1 1 0 0 0 2 0 2.87 2.87 0 0 0-2.5-2.84 12.5 12.5 0 0 0-2.73 0 2.87 2.87 0 0 0-2.51 2.84 2.68 2.68 0 0 0 2.25 2.65l2.91.49a.68.68 0 0 1 .58.68.85.85 0 0 1-.74.85"
},null,-1)])])}const oee={render:ree},aee=Object.freeze(Object.defineProperty({
__proto__:null,default:oee,render:ree},Symbol.toStringTag,{value:"Module"
})),iee={xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",
viewBox:"0 0 128 128"};function see(e,t){
return Ub(),Qb("svg",iee,[...t[0]||(t[0]=[Gb("path",{
d:"M63.877 125.392c-32.671 0-60.37-27.594-60.627-60.469a59.94 59.94 0 0 1 17.506-42.759 60.94 60.94 0 0 1 43.279-18.36 60.08 60.08 0 0 1 42.647 17.71 60.15 60.15 0 0 1 18.157 42.522c.151 33.604-26.864 61.021-60.469 61.363h-.493zm.19-118.406a57.77 57.77 0 0 0-41.01 17.427 56.78 56.78 0 0 0-16.63 40.484c.236 31.159 26.495 57.286 57.43 57.286h.414c31.863-.29 57.504-26.266 57.385-58.128a56.97 56.97 0 0 0-17.217-40.273A56.7 56.7 0 0 0 64.068 6.986z"
},null,-1),Gb("path",{
d:"M16.89 82.383V46.865h8.64v3.183h-4.583v29.218h4.584v3.183zm29.323-18.111c0 6.478-3.933 10.167-9.26 10.167s-8.877-4.156-8.877-9.831c0-5.939 3.722-10.121 9.167-10.121s8.97 4.36 8.97 9.785m-14.415.29c0 3.932 1.973 7.05 5.36 7.05s5.333-3.183 5.333-7.195c0-3.643-1.796-7.083-5.334-7.083s-5.392 3.328-5.392 7.307zm17.407-9.404c1.69-.29 3.407-.434 5.123-.428a9.17 9.17 0 0 1 5.537 1.223 4.06 4.06 0 0 1 2.006 3.61 4.48 4.48 0 0 1-3.183 4.183c2.269.46 3.9 2.46 3.9 4.775a5.02 5.02 0 0 1-1.861 3.978c-1.368 1.21-3.643 1.796-7.162 1.796a34 34 0 0 1-4.327-.257zm3.499 7.622h1.795c2.433 0 3.801-1.145 3.801-2.782s-1.368-2.644-3.61-2.644a9.8 9.8 0 0 0-2.006.145zm0 8.878c.618.065 1.243.092 1.86.078 2.263 0 4.262-.861 4.262-3.182s-1.94-3.183-4.373-3.183h-1.75zM69.54 54.901h3.517v12.554c0 5.334-2.577 7.116-6.365 7.116a9.3 9.3 0 0 1-2.973-.507l.428-2.834c.703.224 1.44.335 2.183.349 2.006 0 3.183-.921 3.183-4.262l.026-12.416zm13.527 10.456v2.434h-7.32v-2.434zm17.091 8.273a12.3 12.3 0 0 1-4.978.862c-6.129 0-9.851-3.834-9.851-9.707-.283-5.353 3.827-9.923 9.18-10.206.375-.02.757-.02 1.131.006a11.1 11.1 0 0 1 4.775.862l-.783 2.801a9.5 9.5 0 0 0-3.788-.75c-3.932 0-6.76 2.467-6.76 7.116 0 4.235 2.499 6.971 6.734 6.971a9.8 9.8 0 0 0 3.834-.717zM111.2 46.766v35.61h-8.641v-3.182h4.583V49.949h-4.583v-3.183h8.64z"
},null,-1)])])}const lee={render:see},cee=Object.freeze(Object.defineProperty({
__proto__:null,default:lee,render:see},Symbol.toStringTag,{value:"Module"
})),uee={xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",
viewBox:"0 0 128 128"};function dee(e,t){
return Ub(),Qb("svg",uee,[...t[0]||(t[0]=[Gb("path",{
d:"M65.004 115.355c-.461-.894-1.004-2.796-1.356-3.601-.378-.711-1.46-2.692-1.984-3.332-1.164-1.332-1.437-1.438-1.809-3.23-.628-3.067-2.148-8.462-4.042-12.227-1.004-2-2.626-3.606-4.067-5.07-1.246-1.247-4.121-3.31-4.668-3.227-4.766.894-6.226 5.586-8.457 9.27-1.27 2.062-2.516 3.769-3.52 5.937-.898 1.98-.812 4.23-2.331 5.938a15.4 15.4 0 0 0-3.333 5.855c-.195.453-.546 4.957-1.003 6.016l7.02-.438c6.585.461 4.687 2.961 14.858 2.438l16.098-.54a25 25 0 0 0-1.433-3.792zM111.793 8.254H16.207C7.312 8.23.086 15.457.086 24.352v35.105c2.352-.812 5.578-5.75 6.668-6.934 1.789-2.062 2.16-4.77 3.059-6.378 2.062-3.793 2.433-6.477 7.101-6.477 2.164 0 3.063.516 4.5 2.516.996 1.332 2.79 3.957 3.602 5.668 1.004 1.98 2.523 4.582 3.254 5.125.515.351.972.722 1.433.894.707.27 1.356-.27 1.902-.629.622-.539.895-1.52 1.52-2.953.895-2.086 1.813-4.418 2.332-5.312.914-1.461 1.273-3.254 2.25-4.067 1.461-1.246 3.441-1.355 3.957-1.437 2.98-.625 4.336 1.437 5.777 2.707.973.894 2.243 2.605 3.246 4.851.708 1.793 1.606 3.52 2.067 4.5.351.98 1.266 2.606 1.789 4.582.543 1.711 1.809 3.067 2.352 3.961 0 0 .812 2.164 5.476 4.145a35 35 0 0 0 4.336 1.52c2.066.734 4.047.644 6.563.374 1.789 0 2.793-2.625 3.601-4.683.438-1.254.98-4.774 1.25-5.758.27-.996-.437-1.707.192-2.625.722-.977 1.164-1.082 1.519-2.332.914-2.793 5.957-2.875 8.832-2.875 2.414 0 2.063 2.332 6.125 1.52 2.336-.434 4.586.273 7.023.995 2.063.543 4.043 1.168 5.204 2.524.73.898 2.629 5.312.73 5.476.164.188.36.645.625.817-.46 1.707-2.25.46-3.332.27-1.355-.27-2.332 0-3.684.624-2.335.996-5.668.918-7.726 2.625-1.715 1.438-1.715 4.582-2.543 6.371 0 0-2.254 5.696-6.996 9.192-1.278.914-3.715 3.058-8.918 3.871-2.356.355-4.586.355-7.024.27-1.164-.079-2.332-.079-3.52-.079-.706 0-3.062-.109-2.96.164l-.27.645c.024.29.063.602.164.895.102.515.102.976.192 1.437 0 .98-.086 2.063 0 3.066.082 2.063.894 3.957 1.004 6.102.078 2.355 1.246 4.875 2.414 6.77.46.707 1.086.789 1.355 1.71.352.98 0 2.141.188 3.227.625 4.227 1.875 8.73 3.773 12.61v.078c2.332-.352 4.77-1.247 7.836-1.684 5.664-.832 13.5-.461 18.54-.914 12.796-1.168 19.706 5.226 31.148 2.601V24.336c-.063-8.895-7.293-16.102-16.207-16.102zM64.086 83.855q0-.28 0 0m-34.457 14.75c.894-1.98 1.433-4.125 2.144-6.101.73-1.899 1.813-4.61 3.684-5.582-.246-.274-3.957-.375-4.934-.461-1.082-.086-2.171-.273-3.25-.438a135 135 0 0 1-6.125-1.265c-1.168-.274-5.21-1.715-6.02-2.067-2.085-.894-3.421-3.52-4.96-3.246-.977.188-1.98.54-2.605 1.54-.543.812-.731 2.242-1.083 3.226-.437 1.086-1.168 2.164-1.707 3.25-1.277 1.875-3.332 3.582-4.23 5.484-.191.457-.27.895-.457 1.356v21.683c1.082.188 2.16.371 3.328.73 8.996 2.438 11.164 2.606 19.98 1.63l.813-.11c.625-1.437 1.188-6.207 1.629-7.644.352-1.164.812-2.063.996-3.14.164-1.09 0-2.173-.102-3.15-.171-2.628 1.895-3.519 2.899-5.69zm0 0"
},null,-1)])])}const pee={render:dee},hee=Object.freeze(Object.defineProperty({
__proto__:null,default:pee,render:dee},Symbol.toStringTag,{value:"Module"
})),fee={xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",
viewBox:"0 0 24 24"};function mee(e,t){
return Ub(),Qb("svg",fee,[...t[0]||(t[0]=[Gb("path",{
d:"M7.01 10.207h-.944l-.515 2.648h.838q.834 0 1.242-.314.408-.315.55-1.049.137-.705-.124-.995-.262-.29-1.047-.29M12 5.688C5.373 5.688 0 8.514 0 12s5.373 6.313 12 6.313S24 15.486 24 12s-5.373-6.312-12-6.312m-3.26 7.451c-.261.25-.575.438-.917.551q-.505.163-1.285.164H5.357l-.327 1.681H3.652l1.23-6.326h2.65q1.195 0 1.744.628.549.627.33 1.752a2.8 2.8 0 0 1-.305.847q-.215.383-.561.703m4.024.715.543-2.799q.094-.478-.068-.651-.16-.174-.687-.174H11.46l-.704 3.625H9.388l1.23-6.327h1.367l-.327 1.682h1.218q1.15 0 1.586.401c.436.401.378.7.263 1.299l-.572 2.944zm7.597-2.265a2.8 2.8 0 0 1-.305.847q-.214.383-.561.703a2.44 2.44 0 0 1-.917.551q-.504.163-1.286.164h-1.18l-.327 1.682h-1.378l1.23-6.326h2.649q1.195 0 1.744.628.55.626.331 1.751m-2.595-1.382h-.943l-.516 2.648h.838q.835 0 1.242-.314.407-.315.551-1.049.137-.705-.125-.995c-.262-.29-.524-.29-1.047-.29"
},null,-1)])])}const gee={render:mee},vee=Object.freeze(Object.defineProperty({
__proto__:null,default:gee,render:mee},Symbol.toStringTag,{value:"Module"
})),bee={xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",
viewBox:"0 0 121 121"};function yee(e,t){
return Ub(),Qb("svg",bee,[...t[0]||(t[0]=[Gb("path",{"fill-rule":"evenodd",
d:"M73.7 58.9c-1.5-1.8-3.2-3.9-5-5.9C58.5 41.7 48.4 30.3 38 19.2c-4.7-5.1-6.2-10-.6-15.1C43-.9 48.5-.4 53.7 5.3 68.1 21.2 82.4 37.2 97 52.9c5.5 5.9 4.2 9.9-1.8 14.2-23 16.7-46 33.5-68.9 50.4-5.1 3.8-10.1 4.8-14.2-.9-4.6-6.2-.3-9.9 4.4-13.3 17-12.4 34-24.8 50.9-37.4 2.5-1.7 5.9-2.8 6.3-7m7.3 59.8c-6.2 0-12.4.2-18.6-.1-4.9-.2-7.9-3-7.8-8.2.1-4.9 2.5-8.6 7.5-8.7 13.5-.4 27.1-.3 40.7 0 4.3.1 7.5 2.9 7.5 7.4 0 5.1-2.7 9.1-8.2 9.5-7.2.4-14.2.1-21.1.1",
"clip-rule":"evenodd"},null,-1)])])}const Oee={render:yee
},wee=Object.freeze(Object.defineProperty({__proto__:null,default:Oee,render:yee
},Symbol.toStringTag,{value:"Module"})),xee={xmlns:"http://www.w3.org/2000/svg",
fill:"currentColor",viewBox:"0 0 24 24"};function kee(e,t){
return Ub(),Qb("svg",xee,[...t[0]||(t[0]=[Gb("path",{
d:"m14.25.18.9.2.73.26.59.3.45.32.34.34.25.34.16.33.1.3.04.26.02.2-.01.13V8.5l-.05.63-.13.55-.21.46-.26.38-.3.31-.33.25-.35.19-.35.14-.33.1-.3.07-.26.04-.21.02H8.77l-.69.05-.59.14-.5.22-.41.27-.33.32-.27.35-.2.36-.15.37-.1.35-.07.32-.04.27-.02.21v3.06H3.17l-.21-.03-.28-.07-.32-.12-.35-.18-.36-.26-.36-.36-.35-.46-.32-.59-.28-.73-.21-.88-.14-1.05-.05-1.23.06-1.22.16-1.04.24-.87.32-.71.36-.57.4-.44.42-.33.42-.24.4-.16.36-.1.32-.05.24-.01h.16l.06.01h8.16v-.83H6.18l-.01-2.75-.02-.37.05-.34.11-.31.17-.28.25-.26.31-.23.38-.2.44-.18.51-.15.58-.12.64-.1.71-.06.77-.04.84-.02 1.27.05zm-6.3 1.98-.23.33-.08.41.08.41.23.34.33.22.41.09.41-.09.33-.22.23-.34.08-.41-.08-.41-.23-.33-.33-.22-.41-.09-.41.09zm13.09 3.95.28.06.32.12.35.18.36.27.36.35.35.47.32.59.28.73.21.88.14 1.04.05 1.23-.06 1.23-.16 1.04-.24.86-.32.71-.36.57-.4.45-.42.33-.42.24-.4.16-.36.09-.32.05-.24.02-.16-.01h-8.22v.82h5.84l.01 2.76.02.36-.05.34-.11.31-.17.29-.25.25-.31.24-.38.2-.44.17-.51.15-.58.13-.64.09-.71.07-.77.04-.84.01-1.27-.04-1.07-.14-.9-.2-.73-.25-.59-.3-.45-.33-.34-.34-.25-.34-.16-.33-.1-.3-.04-.25-.02-.2.01-.13v-5.34l.05-.64.13-.54.21-.46.26-.38.3-.32.33-.24.35-.2.35-.14.33-.1.3-.06.26-.04.21-.02.13-.01h5.84l.69-.05.59-.14.5-.21.41-.28.33-.32.27-.35.2-.36.15-.36.1-.35.07-.32.04-.28.02-.21V6.07h2.09l.14.01zm-6.47 14.25-.23.33-.08.41.08.41.23.33.33.23.41.08.41-.08.33-.23.23-.33.08-.41-.08-.41-.23-.33-.33-.23-.41-.08-.41.08z"
},null,-1)])])}const See={render:kee},_ee=Object.freeze(Object.defineProperty({
__proto__:null,default:See,render:kee},Symbol.toStringTag,{value:"Module"
})),Tee={xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",
viewBox:"0 0 128 128"};function Eee(e,t){
return Ub(),Qb("svg",Tee,[...t[0]||(t[0]=[Gb("path",{
d:"M64 14.648c-35.346 0-64 19.19-64 42.863C0 78.275 22.046 95.589 51.316 99.53V86.699c-15.55-4.89-26.166-14.693-26.166-25.991 0-16.183 21.779-29.303 48.646-29.303 26.866 0 46.693 8.975 46.693 29.303 0 10.486-5.273 17.95-14.066 22.72 1.204.908 2.22 2.072 2.904 3.419l.388.655C121.025 79.772 128 69.189 128 57.51c0-23.672-28.654-42.863-64-42.863zm20.1 74.88c-2.612.257-5.322.41-8.114.462l.002 9.63a88 88 0 0 0 12.474-2.492l-.501-.941c-.68-1.268-1.347-2.543-2.033-3.807a41 41 0 0 0-1.828-2.851z"
},null,-1),Gb("path",{"fill-rule":"evenodd",
d:"M97.469 81.036s3.874 1.169 6.124 2.307c.78.396 2.132 1.184 3.106 2.22a8.4 8.4 0 0 1 1.42 2.04l15.266 25.74-24.674.01-11.537-21.666s-2.363-4.06-3.817-5.237c-1.213-.982-1.73-1.331-2.929-1.331h-5.862l.004 28.219-21.834.009V41.263h43.845s19.97.36 19.97 19.359S97.47 81.035 97.47 81.035zm-9.497-24.137-13.218-.009-.006 12.257 13.224-.004s6.124-.019 6.124-6.235c0-6.34-6.124-6.01-6.124-6.01z"
},null,-1)])])}const Aee={render:Eee},Cee=Object.freeze(Object.defineProperty({
__proto__:null,default:Aee,render:Eee},Symbol.toStringTag,{value:"Module"
})),$ee={xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",
viewBox:"0 0 24 24"};function Pee(e,t){
return Ub(),Qb("svg",$ee,[...t[0]||(t[0]=[Gb("path",{
d:"M20.156.083c3.033.525 3.893 2.598 3.829 4.77L24 4.822 22.635 22.71 4.89 23.926h.016C3.433 23.864.15 23.729 0 19.139l1.645-3 2.819 6.586.503 1.172 2.805-9.144-.03.007.016-.03 9.255 2.956-1.396-5.431-.99-3.9 8.82-.569-.615-.51L16.5 2.114 20.159.073zM5.13 5.073c3.561-3.533 8.157-5.621 9.922-3.84 1.762 1.777-.105 6.105-3.673 9.636-3.563 3.532-8.103 5.734-9.864 3.957-1.766-1.777.045-6.217 3.612-9.75z"
},null,-1)])])}const Dee={render:Pee},Iee=Object.freeze(Object.defineProperty({
__proto__:null,default:Dee,render:Pee},Symbol.toStringTag,{value:"Module"
})),Mee={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function Nee(e,t){return Ub(),Qb("svg",Mee,[...t[0]||(t[0]=[Gb("path",{
fill:"currentColor",
d:"m21.863 11.755-.839-.52-.024-.244.722-.673a.288.288 0 0 0-.096-.482l-.923-.345-.072-.239.575-.799a.288.288 0 0 0-.187-.455l-.973-.158-.117-.218.409-.897a.286.286 0 0 0-.273-.409l-.987.034-.157-.188.228-.962a.287.287 0 0 0-.348-.348l-.96.227-.19-.157.034-.986a.287.287 0 0 0-.409-.273l-.897.409-.218-.118-.158-.972a.288.288 0 0 0-.454-.189l-.8.575-.238-.071-.345-.923a.288.288 0 0 0-.482-.096L13.01 3l-.245-.023-.52-.84a.29.29 0 0 0-.49 0l-.52.84q-.123.01-.245.023l-.673-.722a.29.29 0 0 0-.482.096l-.345.923q-.12.034-.237.072l-.8-.576a.288.288 0 0 0-.455.188l-.158.973q-.11.057-.22.118l-.895-.41a.287.287 0 0 0-.409.273l.034.988-.19.156-.96-.227a.29.29 0 0 0-.348.348l.227.962-.157.188-.987-.034a.288.288 0 0 0-.273.409l.409.897a7 7 0 0 0-.117.22l-.972.156a.288.288 0 0 0-.189.455l.575.8-.071.237-.923.346a.29.29 0 0 0-.096.482L3 10.99l-.024.244-.84.52a.29.29 0 0 0 0 .492l.84.519q.01.123.025.245l-.723.673a.29.29 0 0 0 .096.482l.922.345q.035.12.073.237l-.576.8a.29.29 0 0 0 .188.454l.973.158q.056.11.117.22l-.41.896a.288.288 0 0 0 .274.409l.987-.035q.076.096.156.19l-.227.961a.287.287 0 0 0 .348.347l.961-.226.19.156-.035.987a.288.288 0 0 0 .41.273l.896-.41q.108.06.219.119l.158.971a.288.288 0 0 0 .455.19l.799-.577q.118.038.237.072l.345.923a.287.287 0 0 0 .482.096L10.99 21q.121.014.244.025l.52.839a.29.29 0 0 0 .492 0l.519-.84q.123-.01.245-.024l.674.722a.287.287 0 0 0 .48-.096l.346-.923q.12-.034.238-.072l.8.576a.29.29 0 0 0 .454-.189l.158-.972.219-.117.896.409a.288.288 0 0 0 .41-.273l-.035-.988a7 7 0 0 0 .19-.155l.96.226a.287.287 0 0 0 .348-.347l-.226-.961.155-.19.988.035a.29.29 0 0 0 .272-.41l-.409-.896q.06-.108.117-.219l.973-.158a.287.287 0 0 0 .188-.454l-.575-.8.072-.237.922-.345a.286.286 0 0 0 .096-.482L21 13.011l.025-.245.839-.52a.29.29 0 0 0 0-.49Zm-5.619 6.965a.595.595 0 0 1 .25-1.163.595.595 0 0 1-.25 1.163m-.286-1.93a.54.54 0 0 0-.642.417l-.299 1.391a7.3 7.3 0 0 1-3.017.65c-1.1 0-2.144-.243-3.08-.679l-.299-1.39a.54.54 0 0 0-.643-.417l-1.228.263a7 7 0 0 1-.635-.748h5.976c.068 0 .113-.012.113-.074V14.09c0-.062-.046-.074-.113-.074h-1.747v-1.34h1.89c.172 0 .922.049 1.162 1.007.075.295.24 1.254.352 1.561.113.344.57 1.032 1.059 1.032h2.977a1 1 0 0 0 .108-.01q-.31.421-.677.794l-1.256-.27Zm-8.265 1.9a.594.594 0 1 1-.014-1.17.594.594 0 0 1 .014 1.171ZM5.427 9.5a.594.594 0 1 1-1.086.481.594.594 0 0 1 1.086-.481m-.697 1.65 1.28-.569a.543.543 0 0 0 .274-.715l-.263-.597h1.036v4.672h-2.09a7.3 7.3 0 0 1-.237-2.792Zm5.614-.454V9.32h2.468c.128 0 .9.148.9.725 0 .48-.592.652-1.08.652zm8.969 1.24q0 .273-.02.542h-.75c-.076 0-.106.05-.106.123v.345c0 .81-.457.987-.858 1.032-.381.043-.805-.16-.857-.394-.225-1.265-.6-1.536-1.192-2.003.735-.467 1.5-1.155 1.5-2.077 0-.996-.683-1.623-1.148-1.93-.652-.43-1.375-.517-1.57-.517h-7.76a7.3 7.3 0 0 1 4.091-2.308l.915.959a.54.54 0 0 0 .765.018l1.024-.98a7.32 7.32 0 0 1 5.006 3.566l-.7 1.583a.543.543 0 0 0 .275.715l1.35.6q.034.357.035.726m-7.754-8.004a.595.595 0 1 1 .82.86.595.595 0 0 1-.82-.86m6.951 5.595a.594.594 0 1 1 1.086.481.594.594 0 0 1-1.086-.481"
},null,-1)])])}const Ree={render:Nee},Lee=Object.freeze(Object.defineProperty({
__proto__:null,default:Ree,render:Nee},Symbol.toStringTag,{value:"Module"
})),Bee={xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",
viewBox:"0 0 24 24"};function jee(e,t){
return Ub(),Qb("svg",Bee,[...t[0]||(t[0]=[Gb("path",{
d:"M4.589 24c4.537 0 13.81-1.516 14.821-3v-5.729c-.957 1.408-10.284 2.912-14.821 2.912zm0-7.635c4.537 0 13.81-1.516 14.821-3V7.636c-.957 1.408-10.284 2.912-14.821 2.912zm0-7.636c4.537 0 13.81-1.516 14.821-3V0C18.453 1.408 9.126 2.912 4.589 2.912z"
},null,-1)])])}const Uee={render:jee},zee=Object.freeze(Object.defineProperty({
__proto__:null,default:Uee,render:jee},Symbol.toStringTag,{value:"Module"
})),Fee={xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",
viewBox:"0 0 17 17"};function Zee(e,t){
return Ub(),Qb("svg",Fee,[...t[0]||(t[0]=[Gb("path",{
d:"m2.4 11.4 5.1-4.6-5.1-4.7L.7 3.7l3.4 3v.1l-3.4 3zm14.2 3.3v-2.2h-8v2.2z"
},null,-1)])])}const Qee={render:Zee},Hee=Object.freeze(Object.defineProperty({
__proto__:null,default:Qee,render:Zee},Symbol.toStringTag,{value:"Module"
})),Vee={xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",
viewBox:"0 0 128 128"};function qee(e,t){
return Ub(),Qb("svg",Vee,[...t[0]||(t[0]=[Gb("path",{
d:"M117.3 87.3c.2-.6.4-1.3.5-1.9 7-28-10.1-61.2-39.2-78.6C91.4 24 97 44.9 92 63.2c-.4 1.6-1 3.2-1.6 4.7-.6-.4-1.5-.9-2.5-1.5 0 0-28.9-17.9-60.2-49.4-.9-.8 16.7 25 36.6 46.1-9.4-5.3-35.5-24.3-52-39.4 2 3.4 4.4 6.7 7.1 9.8C33.1 51 51.2 72.6 72.7 89.2c-15.2 9.3-36.6 10-57.9 0C9.5 86.7 4.6 83.7 0 80.3c9 14.4 22.9 26.9 39.9 34.2 20.2 8.7 40.3 8.1 55.2.1.1 0 .1-.1.2-.1.7-.4 1.3-.7 2-1.1 7.2-3.7 21.3-7.4 28.9 7.4 1.7 3.6 5.7-15.6-8.9-33.5"
},null,-1)])])}const Wee={render:qee},Xee=Object.freeze(Object.defineProperty({
__proto__:null,default:Wee,render:qee},Symbol.toStringTag,{value:"Module"
})),Gee={xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",
viewBox:"0 0 24 24"};function Yee(e,t){
return Ub(),Qb("svg",Gee,[...t[0]||(t[0]=[Gb("path",{
d:"M1.125 0C.502 0 0 .502 0 1.125v21.75C0 23.498.502 24 1.125 24h21.75c.623 0 1.125-.502 1.125-1.125V1.125C24 .502 23.498 0 22.875 0zm17.363 9.75q.918 0 1.627.111a6.4 6.4 0 0 1 1.306.34v2.458a4 4 0 0 0-.643-.361 5 5 0 0 0-.717-.26 5.5 5.5 0 0 0-1.426-.2q-.45 0-.819.086a2.1 2.1 0 0 0-.623.242q-.254.156-.393.374a.9.9 0 0 0-.14.49q0 .294.156.529.156.234.443.444c.287.21.423.276.696.41q.41.203.926.416.705.296 1.266.628.561.333.963.753.402.418.614.957.213.538.214 1.253 0 .986-.373 1.656a3 3 0 0 1-1.012 1.085 4.4 4.4 0 0 1-1.487.596q-.85.18-1.79.18a10 10 0 0 1-1.84-.164 5.5 5.5 0 0 1-1.512-.493v-2.63a5.03 5.03 0 0 0 3.237 1.2q.5 0 .872-.09.373-.09.623-.25.249-.162.373-.38a1.02 1.02 0 0 0-.074-1.089 2.1 2.1 0 0 0-.537-.5 5.6 5.6 0 0 0-.807-.444 28 28 0 0 0-1.007-.436q-1.377-.575-2.053-1.405t-.676-2.005q0-.92.369-1.582.368-.662 1.004-1.089a4.5 4.5 0 0 1 1.47-.629 7.5 7.5 0 0 1 1.77-.201m-15.113.188h9.563v2.166H9.506v9.646H6.789v-9.646H3.375z"
},null,-1)])])}const Kee={render:Yee},Jee=Object.freeze(Object.defineProperty({
__proto__:null,default:Kee,render:Yee},Symbol.toStringTag,{value:"Module"
})),ete={xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 24 24"}
;function tte(e,t){return Ub(),Qb("svg",ete,[...t[0]||(t[0]=[Gb("path",{
fill:"none",stroke:"currentColor","stroke-linecap":"round",
"stroke-linejoin":"round",
d:"M7.8 4.6 1.4 11c-.6.6-.6 1.6 0 2l6.2 6.2m8.6-14.6 6.2 6.2c.6.6.6 1.6 0 2l-6.2 6.6"
},null,-1)])])}const nte={render:tte},rte=Object.freeze(Object.defineProperty({
__proto__:null,default:nte,render:tte},Symbol.toStringTag,{value:"Module"
})),ote={xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",
viewBox:"0 0 24 24"};function ate(e,t){
return Ub(),Qb("svg",ote,[...t[0]||(t[0]=[Gb("path",{
d:"M23.55 10.91 13.09.45a1.55 1.55 0 0 0-2.18 0L8.46 2.9 11 5.48a2.06 2.06 0 0 1 1-.23 2.25 2.25 0 0 1 2.25 2.25 2.2 2.2 0 0 1-.22 1l2.19 2.2a2 2 0 1 1-1.06 1.06L13 9.52a1 1 0 0 1-.21.09v5.54a2 2 0 1 1-1.5 0V9.61A2.24 2.24 0 0 1 9.75 7.5a2.2 2.2 0 0 1 .22-1L7.4 4 .45 11a1.55 1.55 0 0 0 0 2.18l10.46 10.37a1.55 1.55 0 0 0 2.18 0l10.46-10.46a1.55 1.55 0 0 0 0-2.18"
},null,-1)])])}const ite={render:ate},ste=Object.freeze(Object.defineProperty({
__proto__:null,default:ite,render:ate},Symbol.toStringTag,{value:"Module"
})),lte={xmlns:"http://www.w3.org/2000/svg",fill:"currentColor",
viewBox:"0 0 24 24"};function cte(e,t){
return Ub(),Qb("svg",lte,[...t[0]||(t[0]=[Gb("path",{
d:"M12.001 4.8q-4.8 0-6 4.8 1.8-2.4 4.2-1.8c.913.228 1.565.89 2.288 1.624C13.666 10.618 15.027 12 18.001 12q4.8 0 6-4.8-1.8 2.4-4.2 1.8c-.913-.228-1.565-.89-2.288-1.624C16.337 6.182 14.976 4.8 12.001 4.8m-6 7.2q-4.8 0-6 4.8 1.8-2.4 4.2-1.8c.913.228 1.565.89 2.288 1.624 1.177 1.194 2.538 2.576 5.512 2.576q4.8 0 6-4.8-1.8 2.4-4.2 1.8c-.913-.228-1.565-.89-2.288-1.624C10.337 13.382 8.976 12 6.001 12"
},null,-1)])])}const ute={render:cte},dte=Object.freeze(Object.defineProperty({
__proto__:null,default:ute,render:cte},Symbol.toStringTag,{value:"Module"
})),pte={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function hte(e,t){return Ub(),Qb("svg",pte,[...t[0]||(t[0]=[Gb("path",{
fill:"currentColor","fill-rule":"evenodd",
d:"M2 11.997C2 20.066 3.934 22 11.997 22 20.066 22 22 20.066 22 11.997 22 3.934 20.06 2 11.997 2S2 3.934 2 11.997m4.034 2.081 3.129-7.132a2.96 2.96 0 0 1 2.828-1.848c1.285 0 2.302.649 2.834 1.848l3.135 7.132c.14.343.263.796.263 1.182 0 1.77-1.243 3.012-3.012 3.012-.606 0-1.084-.153-1.567-.306a5.1 5.1 0 0 0-1.653-.325c-.643 0-1.157.16-1.665.325-.49.153-.968.306-1.55.306A2.89 2.89 0 0 1 5.76 15.26c0-.392.122-.839.27-1.182zm5.963-5.889L8.905 15.2c.919-.429 1.972-.637 3.092-.637 1.084 0 2.18.208 3.06.637z",
"clip-rule":"evenodd"},null,-1)])])}const fte={render:hte
},mte=Object.freeze(Object.defineProperty({__proto__:null,default:fte,render:hte
},Symbol.toStringTag,{value:"Module"})),gte={xmlns:"http://www.w3.org/2000/svg",
fill:"none",viewBox:"0 0 24 24"};function vte(e,t){return Ub(),Qb("svg",gte)}
const bte={render:vte},yte=Object.freeze(Object.defineProperty({__proto__:null,
default:bte,render:vte},Symbol.toStringTag,{value:"Module"})),Ote={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function wte(e,t){
return Ub(),Qb("svg",Ote,[...t[0]||(t[0]=[ty('<path fill="#fff" fill-rule="evenodd" d="M11.9 7.2h8.4v3.4h-8.4z" clip-rule="evenodd"></path><path fill="#3ECC5F" fill-rule="evenodd" d="M4.3 18.3c-.74 0-1.384-.403-1.73-1a2 2 0 0 0 1.73 3h2v-2z" clip-rule="evenodd"></path><path fill="#3ECC5F" fill-rule="evenodd" d="M13.298 7.738 20.3 7.3v-1a2 2 0 0 0-2-2h-9l-.25-.433a.29.29 0 0 0-.5 0L8.3 4.3l-.25-.433a.29.29 0 0 0-.5 0L7.3 4.3l-.25-.433a.29.29 0 0 0-.5 0L6.3 4.3h-.006l-.415-.414a.29.29 0 0 0-.482.13l-.137.51-.52-.14a.29.29 0 0 0-.353.354l.139.52-.51.136a.29.29 0 0 0-.13.483l.414.415V6.3l-.433.25a.29.29 0 0 0 0 .5l.433.25-.433.25a.29.29 0 0 0 0 .5l.433.25-.433.25a.29.29 0 0 0 0 .5l.433.25-.433.25a.29.29 0 0 0 0 .5l.433.25-.433.25a.29.29 0 0 0 0 .5l.433.25-.433.25a.29.29 0 0 0 0 .5l.433.25-.433.25a.29.29 0 0 0 0 .5l.433.25-.433.25a.29.29 0 0 0 0 .5l.433.25-.433.25a.29.29 0 0 0 0 .5l.433.25-.433.25a.29.29 0 0 0 0 .5l.433.25-.433.25a.29.29 0 0 0 0 .5l.433.25-.433.25a.29.29 0 0 0 0 .5l.433.25a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-8l-7.002-.438a1.065 1.065 0 0 1 0-2.124" clip-rule="evenodd"></path><path fill="#3ECC5F" fill-rule="evenodd" d="M16.3 20.3h3v-4h-3z" clip-rule="evenodd"></path><path fill="#44D860" fill-rule="evenodd" d="M21.3 17.8q-.033.002-.064.006l-.012-.045a.5.5 0 1 0-.494-.857l-.033-.034a.496.496 0 0 0-.299-.788.5.5 0 0 0-.56.293l-.044-.011q.005-.031.006-.064a.5.5 0 0 0-1 0q.002.033.006.064l-.044.011a.5.5 0 1 0-.859.495 2 2 0 1 0 3.333 1.924q.031.005.064.006a.5.5 0 1 0 0-1" clip-rule="evenodd"></path><path fill="#3ECC5F" fill-rule="evenodd" d="M17.3 14.3h3v-2h-3z" clip-rule="evenodd"></path><path fill="#44D860" fill-rule="evenodd" d="M21.3 13.55a.25.25 0 1 0 0-.5l-.032.003-.006-.022a.25.25 0 0 0-.096-.481.25.25 0 0 0-.15.052l-.018-.017a.25.25 0 0 0-.005-.308.25.25 0 0 0-.424.06 1 1 0 1 0 0 1.925.25.25 0 0 0 .48-.098.25.25 0 0 0-.05-.149l.016-.017a.25.25 0 0 0 .31-.005.25.25 0 0 0-.063-.424l.006-.022z" clip-rule="evenodd"></path><path fill="#000" fill-rule="evenodd" d="M8.3 7.55a.25.25 0 0 1-.25-.25.75.75 0 0 0-1.5 0 .25.25 0 0 1-.5 0 1.25 1.25 0 0 1 2.5 0 .25.25 0 0 1-.25.25" clip-rule="evenodd"></path><path fill="#FFFF50" fill-rule="evenodd" d="M12.3 20.3h6a2 2 0 0 0 2-2v-7h-6a2 2 0 0 0-2 2z" clip-rule="evenodd"></path><path fill="#000" fill-rule="evenodd" d="M18.802 14.4h-5.004a.1.1 0 0 1 0-.2h5.004a.1.1 0 1 1 0 .2m0 2h-5.004a.1.1 0 0 1 0-.2h5.004a.1.1 0 1 1 0 .2m0 2h-5.004a.1.1 0 0 1 0-.2h5.004a.1.1 0 1 1 0 .2m0-4.981h-5.004a.1.1 0 0 1 0-.2h5.004a.1.1 0 1 1 0 .2m0 1.981h-5.004a.1.1 0 0 1 0-.2h5.004a.1.1 0 1 1 0 .2m0 2h-5.004a.1.1 0 0 1 0-.2h5.004a.1.1 0 1 1 0 .2M20.3 8.161h-.003c-.31.01-.456.32-.585.592-.134.285-.238.47-.409.465-.189-.007-.297-.22-.411-.446-.132-.26-.282-.554-.596-.543-.305.01-.452.28-.581.517-.138.253-.232.406-.412.4-.193-.008-.295-.181-.414-.382-.132-.224-.285-.475-.593-.467-.3.01-.447.239-.577.44-.137.213-.233.343-.416.336-.198-.007-.3-.151-.417-.318-.133-.187-.282-.4-.59-.39-.293.01-.44.198-.57.363-.123.156-.219.28-.422.272a.1.1 0 0 0-.008.2c.302.01.455-.18.588-.349.117-.15.219-.278.419-.285.192-.008.283.111.42.304.13.184.276.392.572.402.31.01.46-.221.592-.426.119-.184.22-.342.415-.349.18-.006.277.135.415.368.13.22.276.47.579.48.312.01.463-.262.594-.503.114-.21.222-.406.412-.413.18-.004.273.16.411.433.13.255.276.544.583.556h.017c.306 0 .452-.308.58-.58.114-.24.222-.468.407-.477z" clip-rule="evenodd"></path><path fill="#3ECC5F" fill-rule="evenodd" d="M10.3 20.3h4v-4h-4z" clip-rule="evenodd"></path><path fill="#D8D8D8" d="m20.276 9.922-7.778 2.084a.2.2 0 0 0-.141.245l.76 2.837a.2.2 0 0 0 .245.141l7.777-2.084a.2.2 0 0 0 .142-.245l-.76-2.836a.2.2 0 0 0-.245-.142"></path><path fill="#4A4A4A" d="m14.845 13.56-.278.074a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .122.07l.279-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.123-.07m.559-.15-.278.074a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .122.07l.279-.074a.1.1 0 0 0 .07-.122l-.074-.279a.1.1 0 0 0-.123-.07m.559-.15-.278.074a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .122.07l.279-.074a.1.1 0 0 0 .07-.122l-.074-.279a.1.1 0 0 0-.123-.07m.559-.15-.278.074a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .122.071l.279-.075a.1.1 0 0 0 .07-.122l-.074-.278a.1.1 0 0 0-.123-.071m.559-.15-.278.075a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .122.07l.279-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.123-.071m.559-.15-.278.075a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .122.07l.279-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.123-.07Zm.56-.15-.28.075a.1.1 0 0 0-.07.123l.075.278a.1.1 0 0 0 .122.07l.279-.074a.1.1 0 0 0 .07-.122l-.074-.279a.1.1 0 0 0-.123-.07Zm.558-.15-.278.075a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .122.071l.279-.075a.1.1 0 0 0 .07-.122l-.074-.279a.1.1 0 0 0-.123-.07Zm.559-.15-.278.075a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .122.071l.279-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.123-.071Z"></path><path fill="#4A4A4A" fill-rule="evenodd" d="m13.082 14.032 1.187-.318a.1.1 0 0 1 .122.07l.075.279a.1.1 0 0 1-.07.122l-1.187.318a.1.1 0 0 1-.123-.07l-.075-.279a.1.1 0 0 1 .071-.122m6.533-1.75 1.187-.319a.1.1 0 0 1 .122.07l.075.28a.1.1 0 0 1-.07.122l-1.188.318a.1.1 0 0 1-.122-.07l-.075-.28a.1.1 0 0 1 .071-.122Zm-6.835.621.453-.121a.1.1 0 0 1 .122.07l.075.279a.1.1 0 0 1-.07.122l-.454.121a.1.1 0 0 1-.122-.07l-.075-.279a.1.1 0 0 1 .07-.122Z" clip-rule="evenodd"></path><path fill="#4A4A4A" d="m13.792 12.632-.279.074a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .123.071l.278-.075a.1.1 0 0 0 .07-.122l-.074-.278a.1.1 0 0 0-.122-.071m.558-.15-.278.075a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .123.07l.278-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.122-.071Zm.56-.15-.279.075a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .123.07l.278-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.122-.07Zm.559-.15-.279.075a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .123.07l.278-.074a.1.1 0 0 0 .07-.122l-.074-.279a.1.1 0 0 0-.122-.07Zm.559-.149-.279.074a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .123.071l.278-.075a.1.1 0 0 0 .07-.122l-.074-.279a.1.1 0 0 0-.122-.07m.559-.15-.279.075a.1.1 0 0 0-.07.122l.074.278a.1.1 0 0 0 .123.071l.278-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.122-.071m.559-.15-.279.075a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .123.07l.278-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.122-.07Zm.559-.15-.279.075a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .123.07l.278-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.122-.07Zm.559-.149-.279.074a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .122.07l.279-.074a.1.1 0 0 0 .07-.122l-.074-.279a.1.1 0 0 0-.122-.07m.559-.15-.279.074a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .123.071l.278-.075a.1.1 0 0 0 .07-.122l-.074-.278a.1.1 0 0 0-.122-.071m.559-.15-.279.075a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .123.07l.278-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.122-.071m.558-.15-.278.075a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .122.07l.279-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.122-.07Zm.56-.15-.279.075a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .122.07l.279-.074a.1.1 0 0 0 .07-.122l-.074-.279a.1.1 0 0 0-.122-.07Z"></path><path fill="#4A4A4A" fill-rule="evenodd" d="m20.483 10.771-.454.122a.1.1 0 0 1-.122-.071l-.075-.278a.1.1 0 0 1 .071-.123l.453-.121a.1.1 0 0 1 .123.07l.074.279a.1.1 0 0 1-.07.122" clip-rule="evenodd"></path><path fill="#4A4A4A" d="m19.47 11.042.279-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.122-.07l-.279.074a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .123.07Zm-.558.15.278-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.122-.071l-.279.074a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .122.071Zm-.56.15.279-.075a.1.1 0 0 0 .07-.122l-.074-.279a.1.1 0 0 0-.122-.07l-.279.074a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .122.071m-.558.15.278-.075a.1.1 0 0 0 .07-.122l-.074-.279a.1.1 0 0 0-.122-.07l-.279.074a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .123.07Zm-.559.15.278-.075a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.122-.07l-.279.074a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .123.07Zm-.559.149.278-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.122-.071l-.279.075a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .123.07m-.559.15.278-.075a.1.1 0 0 0 .07-.122l-.074-.278a.1.1 0 0 0-.122-.071l-.279.074a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .123.071m-.559.149.278-.074a.1.1 0 0 0 .07-.122l-.074-.279a.1.1 0 0 0-.122-.07l-.279.074a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .123.07m-.559.15.278-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.122-.07l-.279.074a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .123.07m-.559.15.278-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.122-.07l-.279.074a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .123.07m-.56.15.28-.074a.1.1 0 0 0 .07-.123l-.075-.278a.1.1 0 0 0-.122-.071l-.279.075a.1.1 0 0 0-.07.122l.074.278a.1.1 0 0 0 .123.071Zm-.558.15.278-.075a.1.1 0 0 0 .07-.122l-.074-.279a.1.1 0 0 0-.122-.07l-.279.074a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .123.071m-.559.15.278-.075a.1.1 0 0 0 .071-.122l-.075-.279a.1.1 0 0 0-.122-.07l-.278.074a.1.1 0 0 0-.071.123l.074.278a.1.1 0 0 0 .123.07Z"></path><path fill="#4A4A4A" d="m19.47 11.042.279-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.122-.07l-.279.074a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .123.07Zm-.558.15.278-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.122-.071l-.279.074a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .122.071Zm-.56.15.279-.075a.1.1 0 0 0 .07-.122l-.074-.279a.1.1 0 0 0-.122-.07l-.279.074a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .122.071m-.558.15.278-.075a.1.1 0 0 0 .07-.122l-.074-.279a.1.1 0 0 0-.122-.07l-.279.074a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .123.07Zm-.559.15.278-.075a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.122-.07l-.279.074a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .123.07Zm-.559.149.278-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.122-.071l-.279.075a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .123.07m-.559.15.278-.075a.1.1 0 0 0 .07-.122l-.074-.278a.1.1 0 0 0-.122-.071l-.279.074a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .123.071m-.559.149.278-.074a.1.1 0 0 0 .07-.122l-.074-.279a.1.1 0 0 0-.122-.07l-.279.074a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .123.07m-.559.15.278-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.122-.07l-.279.074a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .123.07m-.559.15.278-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.122-.07l-.279.074a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .123.07m-.56.15.28-.074a.1.1 0 0 0 .07-.123l-.075-.278a.1.1 0 0 0-.122-.071l-.279.075a.1.1 0 0 0-.07.122l.074.278a.1.1 0 0 0 .123.071Zm-.558.15.278-.075a.1.1 0 0 0 .07-.122l-.074-.279a.1.1 0 0 0-.122-.07l-.279.074a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .123.071m-.559.15.278-.075a.1.1 0 0 0 .071-.122l-.075-.279a.1.1 0 0 0-.122-.07l-.278.074a.1.1 0 0 0-.071.123l.074.278a.1.1 0 0 0 .123.07Z"></path><path fill="#4A4A4A" fill-rule="evenodd" d="m12.93 13.462.645-.173a.1.1 0 0 1 .122.07l.075.28a.1.1 0 0 1-.07.122l-.646.173a.1.1 0 0 1-.123-.071l-.074-.278a.1.1 0 0 1 .07-.123Z" clip-rule="evenodd"></path><path fill="#4A4A4A" d="m14.151 13.135-.278.074a.1.1 0 0 0-.071.123l.075.278a.1.1 0 0 0 .122.07l.279-.074a.1.1 0 0 0 .07-.122l-.074-.279a.1.1 0 0 0-.123-.07m.559-.15-.278.074a.1.1 0 0 0-.071.123l.075.278a.1.1 0 0 0 .122.071l.279-.075a.1.1 0 0 0 .07-.122l-.074-.278a.1.1 0 0 0-.123-.071m.56-.15-.28.075a.1.1 0 0 0-.07.122l.075.279a.1.1 0 0 0 .122.07l.279-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.123-.071Zm.558-.15-.278.075a.1.1 0 0 0-.071.122l.075.279a.1.1 0 0 0 .122.07l.278-.074a.1.1 0 0 0 .071-.123l-.074-.278a.1.1 0 0 0-.123-.07Zm.559-.149-.278.074a.1.1 0 0 0-.071.123l.075.278a.1.1 0 0 0 .122.07l.279-.074a.1.1 0 0 0 .07-.122l-.074-.279a.1.1 0 0 0-.123-.07m.559-.15-.278.074a.1.1 0 0 0-.071.123l.075.278a.1.1 0 0 0 .122.071l.279-.075a.1.1 0 0 0 .07-.122l-.074-.279a.1.1 0 0 0-.123-.07m.559-.15-.278.074a.1.1 0 0 0-.071.123l.075.278a.1.1 0 0 0 .122.071l.278-.074a.1.1 0 0 0 .071-.123l-.074-.278a.1.1 0 0 0-.123-.071m.559-.15-.279.075a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .123.07l.278-.074a.1.1 0 0 0 .071-.123l-.075-.278a.1.1 0 0 0-.122-.07Zm.559-.15-.279.075a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .123.07l.278-.074a.1.1 0 0 0 .071-.122l-.075-.279a.1.1 0 0 0-.122-.07Zm.559-.149-.278.074a.1.1 0 0 0-.071.123l.074.278a.1.1 0 0 0 .123.07l.278-.074a.1.1 0 0 0 .071-.122l-.075-.279a.1.1 0 0 0-.122-.07m.558-.15-.277.074a.1.1 0 0 0-.071.123l.074.278a.1.1 0 0 0 .123.071l.278-.075a.1.1 0 0 0 .071-.122l-.075-.279a.1.1 0 0 0-.122-.07Z"></path><path fill="#4A4A4A" fill-rule="evenodd" d="m20.039 11.557.61-.164a.1.1 0 0 1 .123.071l.074.279a.1.1 0 0 1-.07.122l-.61.164a.1.1 0 0 1-.123-.071l-.075-.278a.1.1 0 0 1 .07-.123z" clip-rule="evenodd"></path><path fill="#4A4A4A" d="m13.517 14.54-.279.075a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .123.07l.278-.074a.1.1 0 0 0 .071-.123l-.075-.278a.1.1 0 0 0-.122-.07Zm.559-.15-.279.075a.1.1 0 0 0-.07.122l.074.279a.1.1 0 0 0 .123.07l.278-.074a.1.1 0 0 0 .071-.123l-.075-.278a.1.1 0 0 0-.122-.07Zm.559-.15-.279.075a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .123.07l.278-.074a.1.1 0 0 0 .071-.122l-.075-.279a.1.1 0 0 0-.122-.07Zm.559-.15-.279.075a.1.1 0 0 0-.07.123l.074.278a.1.1 0 0 0 .123.071l.278-.075a.1.1 0 0 0 .07-.122l-.074-.278a.1.1 0 0 0-.122-.071Z"></path><path fill="#4A4A4A" fill-rule="evenodd" d="m15.474 14.016 2.69-.72a.1.1 0 0 1 .122.07l.074.278a.1.1 0 0 1-.07.123l-2.69.72a.1.1 0 0 1-.122-.07l-.074-.279a.1.1 0 0 1 .07-.122m2.97-.796.348-.093a.1.1 0 0 1 .123.07l.074.279a.1.1 0 0 1-.07.122l-.349.094a.1.1 0 0 1-.122-.071l-.075-.279a.1.1 0 0 1 .07-.122Z" clip-rule="evenodd"></path><path fill="#4A4A4A" d="m19.351 12.977-.278.075a.1.1 0 0 0-.071.122l.075.279a.1.1 0 0 0 .122.07l.279-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.123-.071m.559-.15-.278.075a.1.1 0 0 0-.071.122l.075.279a.1.1 0 0 0 .122.07l.279-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.123-.07Zm1.048-.281-.278.075a.1.1 0 0 0-.071.122l.075.279a.1.1 0 0 0 .122.07l.279-.074a.1.1 0 0 0 .07-.123l-.074-.278a.1.1 0 0 0-.123-.07Zm-.845.442-.028-.104a.1.1 0 0 1 .07-.123l.28-.074a.1.1 0 0 1 .122.07l.027.105zm.49-.057.028.105a.1.1 0 0 1-.07.122l-.279.075a.1.1 0 0 1-.122-.07l-.028-.105zm-.344-2.893-7.652 2.05a.108.108 0 1 0 .057.21l7.65-2.05a.108.108 0 1 0-.055-.21"></path><path fill="#D8D8D8" d="m13.075 12-.3.08a.072.072 0 1 0 .037.14l.3-.08a.072.072 0 1 0-.037-.14m.603-.162-.3.081a.072.072 0 1 0 .037.14l.3-.08a.072.072 0 1 0-.037-.14Zm.464-.124-.3.08a.072.072 0 1 0 .037.14l.3-.08a.072.072 0 1 0-.037-.14m.464-.124-.3.08a.072.072 0 0 0 .038.14l.3-.08a.072.072 0 0 0-.038-.14m.464-.125-.3.081a.072.072 0 0 0 .037.14l.3-.08a.072.072 0 0 0-.037-.14Zm.58-.155-.3.08a.072.072 0 0 0 .037.14l.3-.08a.072.072 0 1 0-.037-.14m.464-.124-.3.08a.072.072 0 0 0 .037.14l.3-.08a.072.072 0 1 0-.038-.14Zm.464-.125-.3.081a.072.072 0 1 0 .037.14l.3-.08a.072.072 0 1 0-.037-.14Zm.464-.124-.3.08a.072.072 0 0 0 .038.14l.3-.08a.072.072 0 1 0-.037-.14Zm.58-.155-.3.08a.072.072 0 0 0 .037.14l.3-.08a.072.072 0 0 0-.038-.14Zm.464-.125-.3.081a.072.072 0 0 0 .037.14l.3-.08a.072.072 0 0 0-.037-.14Zm.464-.124-.3.08a.072.072 0 0 0 .038.14l.3-.08a.072.072 0 1 0-.037-.14Zm.58-.155-.3.08a.072.072 0 1 0 .037.14l.3-.08a.072.072 0 1 0-.038-.14Zm.464-.125-.301.08a.072.072 0 1 0 .037.14l.301-.08a.072.072 0 1 0-.037-.14m.464-.124-.301.08a.072.072 0 0 0 .037.14l.302-.08a.072.072 0 0 0-.038-.14" opacity=".136"></path><path fill="#44D860" fill-rule="evenodd" d="M16.3 17.8q-.033.002-.064.006l-.012-.045a.5.5 0 1 0-.494-.857l-.033-.034a.496.496 0 0 0-.299-.788.5.5 0 0 0-.56.293l-.044-.011q.005-.031.006-.064a.5.5 0 0 0-1 0q.002.033.006.064l-.044.011a.5.5 0 1 0-.859.495 2 2 0 1 0 3.333 1.924q.031.005.064.006a.5.5 0 1 0 0-1" clip-rule="evenodd"></path><path fill="#3ECC5F" fill-rule="evenodd" d="M10.3 14.3h4v-2h-4z" clip-rule="evenodd"></path><path fill="#44D860" fill-rule="evenodd" d="M15.3 13.55a.25.25 0 1 0 0-.5l-.032.003-.006-.022a.25.25 0 0 0-.096-.481.25.25 0 0 0-.15.052l-.018-.017a.25.25 0 0 0-.005-.308.25.25 0 0 0-.424.06 1 1 0 1 0 0 1.925.25.25 0 0 0 .48-.098.25.25 0 0 0-.05-.149l.016-.017a.25.25 0 0 0 .31-.005.25.25 0 0 0-.063-.424l.006-.022z" clip-rule="evenodd"></path><path fill="#000" fill-rule="evenodd" d="M16.3 6.175a.3.3 0 0 1-.096-.019.3.3 0 0 1-.081-.054.3.3 0 0 1-.054-.081.26.26 0 0 1 0-.192.26.26 0 0 1 .092-.112.3.3 0 0 1 .09-.037.26.26 0 0 1 .188.037l.038.031a.26.26 0 0 1 .073.177.25.25 0 0 1-.154.231.3.3 0 0 1-.096.02Zm2-.125a.26.26 0 0 1-.208-.11.26.26 0 0 1-.042-.139.26.26 0 0 1 .11-.209.3.3 0 0 1 .091-.037.26.26 0 0 1 .188.037l.038.031a.26.26 0 0 1 .054.273l-.023.043-.031.038a.26.26 0 0 1-.177.073" clip-rule="evenodd"></path>',29)])])
}const xte={render:wte},kte=Object.freeze(Object.defineProperty({__proto__:null,
default:xte,render:wte},Symbol.toStringTag,{value:"Module"})),Ste={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function _te(e,t){return Ub(),Qb("svg",Ste,[...t[0]||(t[0]=[Gb("path",{
fill:"#512BD4",d:"M22 2H2v20h20z"},null,-1),Gb("path",{fill:"#fff",
d:"M5.565 14.778a.5.5 0 0 1-.361-.142.47.47 0 0 1-.148-.344.47.47 0 0 1 .148-.348.5.5 0 0 1 .36-.145q.216 0 .365.145a.46.46 0 0 1 .152.348.46.46 0 0 1-.152.344.5.5 0 0 1-.364.142m5.653-.08h-.92l-2.421-3.82a1.7 1.7 0 0 1-.152-.301h-.021q.028.166.028.714v3.407h-.813V9.5h.98l2.34 3.73q.148.232.19.319h.015a5 5 0 0 1-.036-.7V9.5h.81zm3.96 0h-2.846V9.5h2.732v.732h-1.89v1.472h1.742v.728h-1.743v1.537h2.005zm4.044-4.466h-1.456v4.466h-.842v-4.466h-1.453V9.5h3.751z"
},null,-1)])])}const Tte={render:_te},Ete=Object.freeze(Object.defineProperty({
__proto__:null,default:Tte,render:_te},Symbol.toStringTag,{value:"Module"
})),Ate={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function Cte(e,t){
return Ub(),Qb("svg",Ate,[...t[0]||(t[0]=[ty('<path fill="#333" fill-rule="evenodd" d="M18.578 20.398A9.98 9.98 0 0 0 22 12.866c0-5.523-4.477-10-10-10s-10 4.477-10 10a9.97 9.97 0 0 0 3.24 7.369l.01-.064 13.123-4.297z" clip-rule="evenodd"></path><path fill="#CCC" d="m9.419 4.067-1.774-.264.265-.081q.242-.076.444-.228l.042-.032a1.22 1.22 0 0 0 .466-.778l.02-.124q.032-.202-.003-.403a.073.073 0 0 1 .1-.08l.072.03q.136.056.263.132l.302.182c.4.242.752.558 1.036.931l.2.264a1.33 1.33 0 0 0 .618.45l.14.05-.732.03a8 8 0 0 1-1.46-.08Z"></path><path fill="#CCC" d="m8.966 5.64.526-.962a.03.03 0 0 0 0-.03l-.179-.378a.68.68 0 0 0-.614-.388l-.05-.002a4.7 4.7 0 0 1-1.017-.148l-.065-.017a4 4 0 0 1-.79-.297l-.111-.055a3 3 0 0 1-.474-.3l-.147-.115a.1.1 0 0 0-.14.02 1 1 0 0 0-.185.47l-.027.235a2 2 0 0 0-.004.379l.065.734c.049.547.237 1.071.548 1.524l.066.097q.144.209.331.38a.1.1 0 0 0 .064.027A2.28 2.28 0 0 0 8.966 5.64"></path><path fill="#EDEDED" d="m6.976 6.832.625-.27a.45.45 0 1 0-.458-.769l-.148.117a1 1 0 0 0-.097.094l-.356.428a.15.15 0 0 0 .009.203l.11.126a.275.275 0 0 0 .315.071"></path><path fill="#B2B2B2" d="m7.78 3.758-.018.006.057.018c.247.08.504.125.763.138a.1.1 0 0 0 .038-.005l.118-.034.059-.02-.374-.08a.3.3 0 0 1-.134-.066.063.063 0 0 1 0-.096l.056-.046a.6.6 0 0 0 .157-.2c-.216.171-.46.301-.721.385Z"></path><path fill="#fff" d="M9.92 10.578 4.825 19.69a.078.078 0 0 1-.124.017l-.102-.103-.43-.488-.274-.354a8 8 0 0 1-.693-1.067l-.04-.072a8 8 0 0 1-.536-1.24l-.137-.412a5.55 5.55 0 0 1-.139-2.295l.005-.032a5.7 5.7 0 0 1 .24-.988l.226-.669.17-.356a5 5 0 0 1 1.067-1.473l.215-.204a3.8 3.8 0 0 1 1.576-.897 3 3 0 0 1-.422.084l-.281.033-.215.02-.235.04-.234.021-.156.017-.113.007c-.036.002-.053-.044-.024-.065l.157-.076a2.65 2.65 0 0 0 1.19-1.135l.174-.271a2.6 2.6 0 0 1 .808-.802l.067-.043q.182-.115.385-.187l.615-.217a.43.43 0 0 0 .253-.236l.009-.022a.34.34 0 0 0-.083-.38l-.108-.099-.018-.02-.696-.926-.555-.764a.97.97 0 0 1-.184-.517.04.04 0 0 1 .056-.038l.6.288a2.38 2.38 0 0 0 1.666.148q.195-.053.394-.075l.276-.028a5.7 5.7 0 0 1 2.064.17l.058.016.656.236a3 3 0 0 1 1.785 1.756l.138.536a2.17 2.17 0 0 0 .863 1.246l.35.244q.232.162.483.287l.775.388a.062.062 0 0 1 .022.093 2.1 2.1 0 0 1-.82.644l-.449.195a4 4 0 0 1-.55.193l-.33.088a5.5 5.5 0 0 1-1.417.188h-.79a1.3 1.3 0 0 1-.477-.091 1.3 1.3 0 0 0-1.615.576Z"></path><path fill="#666" d="m12.593 7.292.344.004c.047 0 .057-.065.013-.079a1.4 1.4 0 0 1-.212-.087l-.269-.139a2.8 2.8 0 0 1-.51-.338l-.053-.044q-.18-.15-.323-.334l-.06-.078a.034.034 0 0 0-.062.023c.04.598.533 1.065 1.132 1.072"></path><path fill="#CCC" d="m5.212 19.834 5.824-5.195a7.8 7.8 0 0 0 1.417-1.677l.035-.057a2.3 2.3 0 0 0 .237-1.239l-.052-.587a1.66 1.66 0 0 0-.424-.97.1.1 0 0 0-.036-.02l-.936-.192a4.2 4.2 0 0 0-2.092-.086l-.037.008-.544.127a6.74 6.74 0 0 0-3.94 2.63l-.023.034a6.4 6.4 0 0 0-.665 1.168l-.032.074a6.07 6.07 0 0 0-.441 3.31l.054.367a3.7 3.7 0 0 0 .932 1.96l.297.324a.304.304 0 0 0 .426.021"></path><path fill="#5E5E5E" d="m10.31 12.9-.018.01c-.492.281-.756.811-.73 1.377.007.16.168.308.323.264l.285-.081a2.6 2.6 0 0 0 1.001-.539l.829-.713.246-.182a6.6 6.6 0 0 1 4.979-1.209c.054.009.056.086.002.097l-.207.043-.095.033a1 1 0 0 0-.48.359.04.04 0 0 0 .044.062l.068-.021a3.2 3.2 0 0 1 1.184-.132l.157.012a2.86 2.86 0 0 1 2.159 1.137l.192.256c.57.758.812 1.714.67 2.652l-.074.49a4.7 4.7 0 0 1-.713 1.87l-.027.04-.41.547-.449.508-.411.395q-.566.542-1.227.962l-.14.088-.266.127c-.069.033-.126-.061-.065-.107l.37-.352.077-.08c.206-.216.355-.482.431-.77l.035-.134a.715.715 0 0 0-.549-.886.7.7 0 0 0-.583.146l-.367.299-.649.53a8 8 0 0 1-1.376.902l-.67.345-1.133.43-.238.064a8 8 0 0 1-1.263.235l-.316.032H9.891l-1.348-.146-.73-.158a4.55 4.55 0 0 1-1.91-.917l-.563-.458a3.02 3.02 0 0 1-1.177-2.168l-.034-.45.04-.631a4.6 4.6 0 0 1 1.956-3.483l.12-.084a5.2 5.2 0 0 1 1.646-.763l.396-.105a3.4 3.4 0 0 1 1.577-.042l.413.086c.104.022.126.16.034.212Z"></path>',9)])])
}const $te={render:Cte},Pte=Object.freeze(Object.defineProperty({__proto__:null,
default:$te,render:Cte},Symbol.toStringTag,{value:"Module"})),Dte={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function Ite(e,t){return Ub(),Qb("svg",Dte,[...t[0]||(t[0]=[Gb("path",{
fill:"currentColor",
d:"m16.378 12.034-4.148-5.53h.507c.369 0 .738.185.968.461l3.272 4.286 3.226-4.24c.322-.322.691-.507 1.06-.507h.553l-4.194 5.53L22 17.841h-.553c-.369 0-.737-.185-.968-.507l-3.456-4.516-3.456 4.516c-.23.322-.6.46-.968.46h-.553zm-13.456.461v.369c0 1.935 1.29 3.686 3.18 4.147a4.15 4.15 0 0 0 4.654-2.258c.138-.23.368-.415.645-.415h.46a5.07 5.07 0 0 1-4.792 3.687C4.212 18.025 2 15.583 2 12.541v-1.29c0-2.489 1.751-4.747 4.24-5.207a5.07 5.07 0 0 1 5.898 5.069v1.382zm0-.921h8.295v-.461a4.148 4.148 0 0 0-5.07-4.056c-1.935.461-3.225 2.212-3.225 4.378z"
},null,-1)])])}const Mte={render:Ite},Nte=Object.freeze(Object.defineProperty({
__proto__:null,default:Mte,render:Ite},Symbol.toStringTag,{value:"Module"
})),Rte={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function Lte(e,t){return Ub(),Qb("svg",Rte,[...t[0]||(t[0]=[Gb("path",{
fill:"currentColor",
d:"M12 2a10 10 0 1 0 0 20 10 10 0 0 0 0-20m-.7 4.5h6.3L11.3 11h4.3l-9.2 6.4 2-4.4 1-2 2-4.5z"
},null,-1)])])}const Bte={render:Lte},jte=Object.freeze(Object.defineProperty({
__proto__:null,default:Bte,render:Lte},Symbol.toStringTag,{value:"Module"
})),Ute={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function zte(e,t){return Ub(),Qb("svg",Ute,[...t[0]||(t[0]=[Gb("path",{
fill:"currentColor",
d:"M23.241 7.492 24 5.536l-.031-.125-7.479 1.971c.798-1.158.524-2.08.524-2.08s-2.386 1.525-4.193 1.486c-1.807-.04-2.386-.525-5.155.36-2.769.883-3.551 3.59-4.357 4.177-.798.579-3.309 2.51-3.309 2.51l2.269-.727s-.642.61-1.964 2.386v.008c.211.297 1.142 1.525 2.065 1.26.102-.032.22-.087.352-.15.415.236.97.462 1.573.525 0 0-.407-.47-.751-1.017l.281-.18-.047.031.869.313-.094-.813h.008l.844.313-.101-.744.32-.156.884-3.348 3.661-2.503-.289.735c-.743 1.823-2.136 2.253-2.136 2.253l-.578.227c-.438.508-.618.634-.767 2.354.352-.093.68-.11.986-.03 1.564.422 2.104 2.307 1.681 2.831-.101.125-.352.352-.672.61H7.76l-.008.516-.062.055h-.65l-.007.5-.173.126c-.602.016-1.376-.516-1.376-.516.008.485.406 1.228.406 1.228l.07-.04-.062.048s1.627 1.08 2.652.68c.908-.36 3.262-2.214 5.296-3.09l6.149-1.627.813-2.096-4.685 1.236V13.14l5.499-1.448.814-2.104-6.313 1.666V9.37zm-11.163 3.997 1.463-.383.016.07-.454 1.181-1.51.4zm.5 2.527-1.509.399.493-1.268 1.455-.383.023.07zm1.972-.423-1.51.4.493-1.268 1.455-.383.024.07z"
},null,-1)])])}const Fte={render:zte},Zte=Object.freeze(Object.defineProperty({
__proto__:null,default:Fte,render:zte},Symbol.toStringTag,{value:"Module"
})),Qte={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function Hte(e,t){return Ub(),Qb("svg",Qte,[...t[0]||(t[0]=[Gb("path",{
fill:"currentColor",
d:"M1.81 10.714c-.046 0-.058-.023-.034-.058l.245-.316c.023-.035.082-.058.128-.058h4.17c.047 0 .059.035.035.07l-.198.304c-.024.035-.082.07-.117.07zM.048 11.789c-.047 0-.059-.024-.035-.059l.245-.315c.023-.035.082-.059.128-.059h5.327c.047 0 .07.036.058.07l-.093.28c-.012.048-.058.07-.105.07zm2.826 1.074c-.046 0-.058-.035-.035-.07l.164-.292c.023-.035.07-.07.117-.07h2.336c.047 0 .07.035.07.082l-.023.28c0 .047-.047.082-.082.082l-2.546-.012Zm12.125-2.36-1.962.515c-.175.046-.187.058-.339-.117a1.6 1.6 0 0 0-.549-.444 2.03 2.03 0 0 0-2.114.175 2.49 2.49 0 0 0-1.192 2.22c.012.934.655 1.705 1.577 1.833.795.106 1.46-.175 1.986-.77l.316-.433h-2.255c-.245 0-.304-.151-.222-.35.152-.362.432-.97.596-1.273a.32.32 0 0 1 .292-.187h4.252c-.024.315-.024.63-.07.946a5 5 0 0 1-.958 2.29 4.87 4.87 0 0 1-3.33 1.985 4.14 4.14 0 0 1-3.141-.77A3.67 3.67 0 0 1 6.4 13.528a4.58 4.58 0 0 1 .993-3.422 5.2 5.2 0 0 1 3.27-2.021c1.099-.199 2.15-.07 3.096.572.62.409 1.063.97 1.355 1.647.07.105.024.164-.117.199Z"
},null,-1),Gb("path",{fill:"currentColor",
d:"M18.865 16.963a4.38 4.38 0 0 1-2.85-1.028 3.67 3.67 0 0 1-1.262-2.254 4.46 4.46 0 0 1 .946-3.528 4.9 4.9 0 0 1 3.27-1.95 4.32 4.32 0 0 1 3.33.595 3.63 3.63 0 0 1 1.647 2.605 4.51 4.51 0 0 1-1.343 3.96 5.35 5.35 0 0 1-2.804 1.495c-.315.058-.63.07-.934.105m2.78-4.719c-.012-.152-.012-.268-.035-.385a1.93 1.93 0 0 0-2.383-1.554c-1.087.245-1.787.935-2.044 2.033-.21.91.233 1.834 1.074 2.207.643.28 1.285.246 1.904-.07a2.56 2.56 0 0 0 1.484-2.23Z"
},null,-1)])])}const Vte={render:Hte},qte=Object.freeze(Object.defineProperty({
__proto__:null,default:Vte,render:Hte},Symbol.toStringTag,{value:"Module"
})),Wte={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function Xte(e,t){return Ub(),Qb("svg",Wte,[...t[0]||(t[0]=[Gb("path",{
fill:"#FF5B11",
d:"M12.371 1.736q.08-.01.141.04a76 76 0 0 1 4.217 5.662 28 28 0 0 1 2.49 4.659q1.64 4.374-1.707 7.61-2.928 2.475-6.747 1.928-4.564-.93-6.205-5.281a7.4 7.4 0 0 1-.28-2.891 17.3 17.3 0 0 1 1.204-4.9 7.3 7.3 0 0 1 1.044-1.767q.525.625 1.004 1.285.222.232.462.442a38 38 0 0 1 4.377-6.787",
opacity:".993"},null,-1),Gb("path",{fill:"#FF9758",
d:"M12.09 5.962a42.5 42.5 0 0 1 3.996 5.462q.56.959.924 2.008.758 2.982-1.627 4.92-2.306 1.622-5.06.963-2.97-.921-3.433-3.996a4.25 4.25 0 0 1 .2-1.887c.297-.754.66-1.48 1.085-2.168L9.38 9.495q1.367-1.758 2.71-3.534Z"
},null,-1)])])}const Gte={render:Xte},Yte=Object.freeze(Object.defineProperty({
__proto__:null,default:Gte,render:Xte},Symbol.toStringTag,{value:"Module"
})),Kte={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function Jte(e,t){return Ub(),Qb("svg",Kte,[...t[0]||(t[0]=[Gb("path",{
fill:"#FF2D20",
d:"M21.217 6.8a.3.3 0 0 1 .012.076v4.078a.3.3 0 0 1-.15.26l-3.424 1.969v3.907a.3.3 0 0 1-.147.259l-7.15 4.111q-.023.014-.05.024l-.021.007a.3.3 0 0 1-.152 0l-.024-.01c-.017-.007-.033-.011-.048-.02l-7.142-4.112a.3.3 0 0 1-.15-.26V4.857q0-.043.012-.079c0-.01.007-.016.01-.023a.2.2 0 0 1 .019-.048l.021-.026.024-.036.03-.024.034-.023L6.492 2.54a.29.29 0 0 1 .298 0l3.573 2.053.033.024.029.024.026.036.022.023.019.048c0 .01.007.017.01.024a.4.4 0 0 1 .009.08v7.643l2.978-1.713v-3.91c0-.023.003-.052.01-.076l.01-.026.018-.047.022-.024.026-.036.029-.024.033-.023L17.21 4.56a.3.3 0 0 1 .298 0l3.57 2.058.034.024c.01.01.022.014.029.024q.017.015.026.035l.021.024c.01.017.015.03.02.048l.009.023zm-.58 3.98V7.392l-1.252.719-1.727.994v3.393l2.978-1.713zm-3.576 6.138v-3.395l-1.7.971-4.85 2.77v3.425l6.55-3.77ZM3.366 5.37v11.548l6.55 3.769V17.26l-3.421-1.934h-.003l-.03-.024c-.01-.01-.022-.014-.03-.024-.011-.01-.018-.024-.025-.03l-.024-.032-.014-.038q-.009-.015-.015-.033l-.007-.043-.002-.033V7.08l-1.728-.994-1.253-.716zm3.276-2.23L3.666 4.857 6.64 6.569l2.976-1.713-2.974-1.713zM8.19 13.833l1.727-.992V5.37l-1.247.718-1.727.995v7.47l1.249-.72zm9.169-8.667-2.974 1.713 2.974 1.713 2.974-1.713zm-.297 3.943-1.728-.995-1.249-.718v3.385l1.727.995 1.25.72v-3.39zm-6.845 7.639 4.365-2.491 2.182-1.244L13.79 11.3l-3.426 1.972-3.117 1.796z"
},null,-1)])])}const ene={render:Jte},tne=Object.freeze(Object.defineProperty({
__proto__:null,default:ene,render:Jte},Symbol.toStringTag,{value:"Module"
})),nne={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function rne(e,t){
return Ub(),Qb("svg",nne,[...t[0]||(t[0]=[ty('<g fill="#EDB641" clip-path="url(#a)"><path d="m5.33 10.983.419 1.29H7.11l-1.1.796.42 1.29-1.101-.797-1.09.791.419-1.29-1.1-.796H4.92l.42-1.289-.011.005Zm1.954-4.245.362 1.111h1.169l-.944.687.362 1.111-.949-.681-.943.681.351-1.111-.943-.687h1.169l.361-1.11h.005ZM1.31 13.504l.21.65h.68l-.55.409.21.65-.55-.404-.556.404.21-.65-.551-.404h.681l.21-.65.005-.005Z"></path><path d="M9.197 15.684a19 19 0 0 0 2.505-1.378 22.6 22.6 0 0 0 3.092-2.6l-.613-.408-.534-.362 1.692-.063.545-.02.147-.525.461-1.635.587 1.588.189.514.545-.027 1.693-.062-1.332 1.048-.43.335.19.514.586 1.588-1.41-.944-.45-.298-.43.335-1.331 1.048.23-.812.231-.818.026-.105a21 21 0 0 1-5.24 2.815c-.315.104-.63.188-.944.267zm-3.186 1.242a16.1 16.1 0 0 0 8.081-2.494l-.535 1.923 3.145-2.479 3.328 2.222-1.384-3.752 3.144-2.474-4.003.158-1.384-3.758-1.09 3.852-3.999.157 2.317 1.546c-1.52 1.384-5.346 4.34-10.413 4.538A14 14 0 0 1 0 16.11s2.52.953 6.016.817h-.005Z"></path><path d="M16.408 4.412a7.588 7.588 0 0 0-7.242 9.862q.495-.25.943-.508a6.53 6.53 0 0 1 6.3-8.306 6.54 6.54 0 1 1-4.916 10.848c-.351.136-.703.262-1.059.367a7.588 7.588 0 1 0 5.974-12.263"></path></g><defs><clipPath id="a"><path fill="#fff" d="M0 0h24v24H0z"></path></clipPath></defs>',2)])])
}const one={render:rne},ane=Object.freeze(Object.defineProperty({__proto__:null,
default:one,render:rne},Symbol.toStringTag,{value:"Module"})),ine={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function sne(e,t){return Ub(),Qb("svg",ine,[...t[0]||(t[0]=[Gb("path",{
fill:"#E0234E","fill-rule":"evenodd",
d:"M13.776 2.04c-.144 0-.279.03-.403.071.264.176.409.409.48.672.006.036.016.062.021.098q.009.046.01.093c.021.455-.118.511-.216.78-.15.346-.109.718.072 1.017a.6.6 0 0 0 .062.114c-.196-1.307.894-1.503 1.095-1.91.016-.357-.279-.595-.511-.76a1.14 1.14 0 0 0-.61-.176Zm1.643.294c-.021.118-.005.087-.01.15-.006.04-.006.092-.01.134q-.016.063-.037.124a1 1 0 0 1-.042.124c-.02.041-.035.077-.056.118-.016.021-.026.042-.042.062l-.03.047a2 2 0 0 1-.078.103c-.03.031-.057.067-.093.093v.005c-.031.026-.062.057-.098.083-.108.082-.233.145-.346.222-.036.026-.073.046-.103.078a1 1 0 0 0-.099.082c-.036.031-.062.062-.093.098-.025.031-.056.067-.077.104q-.039.052-.072.108c-.021.041-.036.077-.057.119-.016.041-.031.077-.042.119a2 2 0 0 0-.036.129c-.005.02-.005.046-.01.067-.005.02-.005.041-.01.062 0 .041-.005.088-.005.129q-.001.046.005.093 0 .06.015.13.01.06.026.123l.041.124c.01.026.026.052.037.072l-1.188-.46a13 13 0 0 0-.6-.154l-.325-.078a10 10 0 0 0-.94-.14c-.01 0-.016-.004-.026-.004a9 9 0 0 0-1.601-.021c-.315.02-.63.062-.945.114q-.116.017-.233.04-.232.048-.465.104l-.232.062c-.077.031-.15.067-.222.098l-.17.078c-.01.005-.021.005-.026.01-.052.026-.098.047-.145.073a2 2 0 0 0-.196.098c-.036.015-.072.036-.104.051a3 3 0 0 0-.305.18c-.035.027-.071.048-.103.073-.005.005-.01.005-.015.01a1 1 0 0 0-.098.073l-.01.01-.078.062c-.01.005-.02.016-.03.02l-.078.068c-.006.01-.016.016-.021.02-.031.032-.062.058-.093.088-.005 0-.005.006-.01.011a2 2 0 0 0-.094.088c-.005.005-.005.01-.01.01a1 1 0 0 0-.077.083c-.01.01-.026.02-.036.03q-.04.047-.088.094c-.005.01-.016.015-.02.025-.042.042-.078.083-.12.124l-.015.016q-.123.134-.264.253-.14.125-.289.227a3.2 3.2 0 0 1-.635.351 4 4 0 0 1-.336.124c-.217.047-.439.135-.63.15-.041 0-.088.01-.129.016l-.129.03-.124.047a1 1 0 0 0-.124.057c-.036.026-.077.046-.114.072a1 1 0 0 0-.103.088 1 1 0 0 0-.103.093c-.031.036-.062.067-.088.103-.026.042-.057.078-.078.12a1 1 0 0 0-.072.118q-.032.067-.057.134l-.046.134a1 1 0 0 0-.026.124c0 .006-.005.011-.005.016-.01.047-.01.108-.016.14q-.009.05-.01.103a.5.5 0 0 0 .026.165q.014.046.036.093v.005a1 1 0 0 0 .057.093 1 1 0 0 0 .067.093q.042.044.088.083.045.045.098.082c.124.109.155.145.315.228q.038.02.083.041c.005 0 .01.005.015.005q-.001.013.005.026.01.062.026.124a1 1 0 0 0 .041.124c.016.03.026.062.042.093q.007.016.015.026l.062.113.078.109q.042.051.088.098.045.043.098.088s.005.005.01.005a1 1 0 0 0 .207.14 1 1 0 0 0 .118.056.6.6 0 0 0 .104.036c.005.005.01.005.02.01.021.006.047.011.068.016-.016.279-.021.543.02.635.047.104.274-.211.501-.573-.03.357-.051.775 0 .899.057.129.367-.274.636-.718 3.662-.847 7.003 1.684 7.354 5.258-.067-.558-.754-.868-1.069-.79-.155.382-.418.873-.841 1.177.037-.345.02-.693-.052-1.033a3.3 3.3 0 0 1-.64 1.302c-.491.036-.982-.202-1.24-.558-.02-.015-.026-.046-.042-.067a1 1 0 0 1-.04-.108.4.4 0 0 1-.032-.109q-.006-.052-.005-.114v-.077a1 1 0 0 1 .026-.109 1 1 0 0 1 .036-.108c.02-.036.036-.072.062-.108.088-.248.088-.45-.072-.569a.6.6 0 0 0-.099-.051c-.02-.006-.046-.016-.067-.021l-.041-.015a1 1 0 0 0-.109-.026.4.4 0 0 0-.108-.016 1 1 0 0 0-.114-.01c-.025 0-.051.005-.077.005a.4.4 0 0 0-.114.015q-.054.007-.108.021a1 1 0 0 0-.109.036l-.103.047c-.03.015-.062.036-.098.052-1.203.784-.486 2.623.336 3.155-.31.057-.625.124-.713.191l-.01.01q.334.202.697.347.415.134.837.248v.005a5 5 0 0 0 1.301.093c2.288-.16 4.163-1.9 4.504-4.194l.031.134c.015.093.036.191.046.29v.005q.014.07.021.134v.02q.009.072.01.135.01.085.01.17v.083c0 .026.006.057.006.083 0 .03-.005.062-.005.093v.072c0 .036-.005.067-.005.103q.001.029-.006.067c0 .036-.005.073-.005.114q-.006.022-.005.046l-.015.12q.001.022-.005.046c-.006.051-.016.098-.021.15v.01c-.01.046-.02.098-.031.144v.016l-.031.14c0 .005-.005.015-.005.02a1 1 0 0 1-.036.14v.015q-.025.076-.042.145-.006.009-.005.01l-.046.155c-.021.052-.037.098-.057.15s-.036.103-.057.15l-.062.15h-.005c-.021.046-.041.097-.067.144l-.016.036c-.005.005-.005.01-.01.015a4.9 4.9 0 0 1-1.451 1.736q-.063.04-.125.088c-.01.01-.026.015-.036.026q-.053.038-.113.077l.015.031h.005l.217-.03h.005q.202-.033.403-.073a1 1 0 0 0 .114-.026l.072-.015c.036-.006.072-.016.109-.021.03-.01.062-.016.093-.026a10 10 0 0 0 1.497-.496 8.3 8.3 0 0 1-3.207 2.619 8.5 8.5 0 0 0 1.761-.305 8.25 8.25 0 0 0 4.881-3.9 8.2 8.2 0 0 1-1.39 3.321c.501-.33.964-.714 1.38-1.146a8.2 8.2 0 0 0 2.174-4.39c.177.817.227 1.657.15 2.49 3.73-5.202.31-10.594-1.12-12.015-.006-.01-.01-.015-.01-.026-.006.006-.006.006-.006.011 0-.005 0-.005-.005-.01q-.002.092-.01.186a7 7 0 0 1-.052.345 8 8 0 0 1-.088.341 4 4 0 0 1-.124.33q-.072.162-.155.316a4 4 0 0 1-.398.573c-.077.093-.16.176-.242.259a3 3 0 0 1-.15.129l-.12.103c-.092.072-.185.14-.288.201a4 4 0 0 1-.305.176 9 9 0 0 1-.325.145 3.6 3.6 0 0 1-.682.186c-.12.02-.238.03-.351.04a4 4 0 0 1-.248.011c-.12 0-.238-.01-.351-.02a3 3 0 0 1-.352-.052 3 3 0 0 1-.346-.088h-.005c.114-.01.227-.02.341-.041a3.7 3.7 0 0 0 1.317-.501q.148-.099.29-.207.138-.108.263-.232c.087-.078.165-.165.242-.253q.117-.14.217-.28c.01-.015.02-.035.031-.05q.08-.125.15-.249a3.6 3.6 0 0 0 .367-.981c.02-.119.041-.233.052-.346.01-.119.02-.238.02-.351q-.001-.125-.01-.248-.017-.178-.041-.346a4 4 0 0 0-.078-.346c-.036-.109-.072-.222-.114-.331a3.5 3.5 0 0 0-.527-.91 11 11 0 0 0-.237-.262 3 3 0 0 0-.134-.13 9 9 0 0 0-.718-.506 1 1 0 0 0-.104-.051 2 2 0 0 0-.49-.217",
"clip-rule":"evenodd"},null,-1)])])}const lne={render:sne
},cne=Object.freeze(Object.defineProperty({__proto__:null,default:lne,render:sne
},Symbol.toStringTag,{value:"Module"})),une={xmlns:"http://www.w3.org/2000/svg",
fill:"none",viewBox:"0 0 24 24"};function dne(e,t){
return Ub(),Qb("svg",une,[...t[0]||(t[0]=[Gb("path",{fill:"currentColor",
d:"M11.345 2.005c-.043.004-.18.018-.303.028-2.84.256-5.501 1.788-7.187 4.144a9.9 9.9 0 0 0-1.765 4.369c-.08.549-.09.711-.09 1.456s.01.907.09 1.456c.543 3.755 3.216 6.91 6.84 8.08.65.208 1.334.351 2.112.437.303.033 1.613.033 1.916 0 1.343-.149 2.48-.48 3.603-1.053.172-.088.205-.112.182-.131a191 191 0 0 1-1.629-2.184l-1.599-2.16-2.004-2.965a284 284 0 0 0-2.017-2.964 161 161 0 0 0-.02 2.925c-.006 2.816-.008 2.93-.043 2.996a.36.36 0 0 1-.172.178c-.063.031-.117.037-.412.037h-.339l-.09-.056a.4.4 0 0 1-.13-.143l-.042-.088.004-3.92.006-3.92.06-.077a.5.5 0 0 1 .145-.12c.08-.038.112-.042.45-.042.399 0 .465.016.569.129.03.031 1.114 1.665 2.412 3.634l3.946 5.975 1.583 2.399.08-.053a10.3 10.3 0 0 0 2.055-1.802 9.95 9.95 0 0 0 2.354-5.112c.08-.549.09-.711.09-1.456s-.01-.907-.09-1.456c-.543-3.755-3.216-6.91-6.84-8.08a10.5 10.5 0 0 0-2.083-.435c-.187-.02-1.48-.041-1.642-.026m4.094 6.048c.094.047.17.137.197.231.016.05.02 1.138.016 3.587l-.006 3.515-.62-.95-.621-.95V10.93c0-1.652.008-2.58.02-2.625a.4.4 0 0 1 .193-.247c.08-.04.11-.045.416-.045.29 0 .34.004.405.04"
},null,-1)])])}const pne={render:dne},hne=Object.freeze(Object.defineProperty({
__proto__:null,default:pne,render:dne},Symbol.toStringTag,{value:"Module"
})),fne={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function mne(e,t){
return Ub(),Qb("svg",fne,[...t[0]||(t[0]=[ty('<path fill="url(#a)" fill-rule="evenodd" d="M19.608 5.51C16.023 1.308 9.712.808 5.51 4.392 1.308 7.977.808 14.288 4.392 18.49c3.585 4.202 9.896 4.702 14.098 1.118 4.202-3.585 4.702-9.896 1.118-14.098m-4.982 5.249c.385 0 .631.417.438.75l-.056.096-3.774 6.21a.39.39 0 0 1-.33.185h-.36a.378.378 0 0 1-.366-.472l1.024-3.959a.5.5 0 0 0-.484-.625H9.145a.5.5 0 0 1-.484-.625l1.545-5.978a.46.46 0 0 1 .448-.34l.067.001h1.584a.5.5 0 0 1 .496.568l-.01.071-.604 3.533a.5.5 0 0 0 .493.585z" clip-rule="evenodd"></path><defs><radialGradient id="a" cx="0" cy="0" r="1" gradientTransform="matrix(19.5 0 0 198.851 4 12)" gradientUnits="userSpaceOnUse"><stop stop-color="#31B2F3"></stop><stop offset=".474" stop-color="#F27CEC"></stop><stop offset="1" stop-color="#FD6641"></stop></radialGradient></defs>',2)])])
}const gne={render:mne},vne=Object.freeze(Object.defineProperty({__proto__:null,
default:gne,render:mne},Symbol.toStringTag,{value:"Module"})),bne={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function yne(e,t){return Ub(),Qb("svg",bne,[...t[0]||(t[0]=[Gb("path",{
fill:"#00DC82",
d:"M13.32 19.333h8.14c.26 0 .508-.09.733-.22.226-.129.457-.29.587-.513s.22-.476.22-.733c0-.258-.09-.51-.22-.734l-5.5-9.46a1.34 1.34 0 0 0-.513-.513 1.8 1.8 0 0 0-.807-.22c-.26 0-.508.09-.733.22-.216.12-.393.298-.514.513l-1.393 2.42L10.533 5.4c-.13-.223-.288-.458-.513-.587s-.474-.146-.733-.146c-.26 0-.509.018-.734.146-.24.146-.441.347-.586.587l-6.82 11.733c-.13.223-.147.476-.147.734 0 .257.017.51.147.733s.361.384.586.513c.225.13.474.22.734.22H7.6c2.034 0 3.515-.912 4.547-2.64l2.493-4.326 1.32-2.274 4.033 6.894H14.64zm-5.793-2.346H3.933l5.354-9.24L12 12.367l-1.797 3.132c-.687 1.122-1.468 1.488-2.676 1.488"
},null,-1)])])}const One={render:yne},wne=Object.freeze(Object.defineProperty({
__proto__:null,default:One,render:yne},Symbol.toStringTag,{value:"Module"
})),xne={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function kne(e,t){
return Ub(),Qb("svg",xne,[...t[0]||(t[0]=[ty('<path fill="#93D500" d="M7.285 13.5H2.007l.003.077.009.15.004.063.014.171.004.039a8.8 8.8 0 0 0 .387 1.871q0 .005.003.011l.058.173.016.044.08.216.048.124a5 5 0 0 0 .078.189l.052.117.031.07.066.14.022.046.079.16.012.024q.045.088.093.175l.004.008.02.036 4.508-2.715.017-.01a3.6 3.6 0 0 1-.33-1.179"></path><path fill="#4D5A31" d="m8.582 15.923-.013.013-3.717 3.717.057.053.105.094.055.048.127.107.034.029a8 8 0 0 0 .324.254l.006.004q.336.252.695.47l.025.016.137.08.084.048.08.045q.072.04.145.078a8 8 0 0 0 .431.21l.132-.32 1.87-4.54.007-.017a3.6 3.6 0 0 1-.584-.389"></path><path fill="#6BA43A" d="M8.195 15.553a3 3 0 0 1-.212-.262 4 4 0 0 1-.2-.296L3.27 17.713q.104.174.215.338l.007.012.003.005.007.01v.002l.019.026.001.002q.119.174.242.342l.006.007.005.007.11.142.015.019q.057.073.117.145l.028.034.155.181.094.105.053.058.024.026.07.075.028.03.125.127 3.723-3.723a3 3 0 0 1-.122-.13"></path><path fill="#4D5A31" d="m13.13 15.921-.124.096.009.016 2.714 4.506a8 8 0 0 0 1.134-.886l-3.718-3.717z"></path><path fill="#93D500" d="m15.335 20.576-.092-.153-2.534-4.206a4 4 0 0 1-.316.167 3.6 3.6 0 0 1-2.567.2c-.057-.017-.113-.04-.169-.06s-.113-.037-.168-.06L7.62 21.003l-.073.178-.063.152.014.006.016.006.004.002.133.05.167.065.085.032a9 9 0 0 0 1.88.442l.075.008.142.016.036.003.174.014.06.004.153.01.094.003.122.004.217.003a9 9 0 0 0 1.495-.126l.154-.028.088-.017.09-.02.15-.032.028-.007a9 9 0 0 0 2.124-.791l.13-.074.157-.088.107-.06.001-.001.002-.001h.001l.001-.001.002-.001.006-.004.034-.02zm-6.75-10.21.123-.097-.009-.015-2.714-4.506q-.189.123-.372.256a9 9 0 0 0-.762.629L8.57 10.35z"></path><path fill="#4D5A31" d="M4.594 6.88q-.064.065-.124.13l-.123.128a9 9 0 0 0-.753.933l-.032.046-.076.112-.104.16a8.83 8.83 0 0 0-1.375 4.397l-.005.178-.003.179h5.266q.002-.09.008-.179c.006-.089.004-.119.01-.178a3.57 3.57 0 0 1 .794-1.917q.059-.069.12-.133c.04-.044.077-.09.12-.133L4.594 6.881Zm10.864-1.306q-.01-.008-.021-.013l-.14-.083-.082-.047-.082-.046-.143-.077-.023-.012a9 9 0 0 0-.95-.426l-.024-.01a9 9 0 0 0-1.987-.498l-.074-.01-.075-.008-.143-.016-.04-.004-.17-.014-.066-.004-.146-.009-.078-.003v5.278c.27.028.54.086.8.174l3.884-3.884a9 9 0 0 0-.44-.288"></path><path fill="#6BA43A" d="M10.679 4.29q-.09 0-.179.003a9 9 0 0 0-1.113.115l-.024.004-.155.029-.087.016a6 6 0 0 0-.24.052l-.028.006a9 9 0 0 0-2.125.792l-.13.074-.156.087-.115.066h-.002l-.008.005-.03.017v.001l.093.153 2.625 4.359a4 4 0 0 1 .316-.167 3.6 3.6 0 0 1 1.536-.35V4.285q-.09.001-.178.004Z"></path><path fill="#4D5A31" d="M19.704 12.708a10 10 0 0 0-.05-.61l-.002-.014-.001-.007-.027-.201v-.006a9 9 0 0 0-.273-1.245l-.002-.008-.059-.19-.008-.025-.057-.17-.016-.046-.054-.147-.027-.07a5 5 0 0 0-.086-.216l-.04-.094-.052-.12-.03-.068-.066-.142-.021-.043-.08-.162-.012-.022-.093-.177-.003-.006a9 9 0 0 0-.504-.818l-3.886 3.886q.132.392.174.8h5.278q0-.04-.003-.08Z"></path><path fill="#6BA43A" d="M14.45 13.143q-.002.09-.01.179-.001.09-.01.178a3.57 3.57 0 0 1-.793 1.918c-.037.046-.08.088-.12.133-.04.044-.077.09-.12.132l3.723 3.723q.063-.064.124-.13l.123-.128q.415-.448.754-.935l.027-.039.082-.12.07-.108.034-.052a8.83 8.83 0 0 0 1.377-4.573l.003-.178z"></path><path fill="#424143" d="M21.279 2.722a2.467 2.467 0 0 0-3.953 2.84l-5.374 5.373a2.467 2.467 0 1 0 1.114 1.113l5.373-5.373a2.466 2.466 0 0 0 2.84-3.953"></path>',10)])])
}const Sne={render:kne},_ne=Object.freeze(Object.defineProperty({__proto__:null,
default:Sne,render:kne},Symbol.toStringTag,{value:"Module"})),Tne={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function Ene(e,t){return Ub(),Qb("svg",Tne,[...t[0]||(t[0]=[Gb("path",{
stroke:"#21FA90","stroke-linecap":"round","stroke-linejoin":"round",
d:"M5.038 13.757v3.814m1.496-4.566 3.04 1.761 4.534-2.627V6.885L9.574 4.258 5.038 6.885v4.56m1.496 1.56v1.668m0-1.668 1.49-.91"
},null,-1),Gb("path",{stroke:"#00050B","stroke-linecap":"round",
"stroke-linejoin":"round","stroke-width":".885",
d:"m21.719 10.719 1.839 1.09v1.09l-1.84 1.091M2.834 8.13.774 9.322v5.326l2.016 1.167m3.744 1.07v1.183l3.021 1.674 2.32-1.358-.02-2.471m2.282-1.387v1.3L16.31 17.1l3.175-1.9v-5.186L16.36 8.217"
},null,-1)])])}const Ane={render:Ene},Cne=Object.freeze(Object.defineProperty({
__proto__:null,default:Ane,render:Ene},Symbol.toStringTag,{value:"Module"
})),$ne={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function Pne(e,t){return Ub(),Qb("svg",$ne,[...t[0]||(t[0]=[Gb("path",{
fill:"#61DAFB",
d:"M12.5 14.014a1.783 1.783 0 1 0 0-3.565 1.783 1.783 0 0 0 0 3.565"
},null,-1),Gb("path",{stroke:"#61DAFB","stroke-width":".87",
d:"M12.5 15.884c5.283 0 9.565-1.635 9.565-3.652S17.783 8.58 12.5 8.58s-9.565 1.635-9.565 3.652 4.282 3.652 9.565 3.652Z"
},null,-1),Gb("path",{stroke:"#61DAFB","stroke-width":".87",
d:"M9.337 14.058c2.642 4.575 6.199 7.466 7.946 6.457 1.746-1.008 1.021-5.534-1.62-10.11C13.02 5.832 9.464 2.94 7.717 3.949s-1.021 5.535 1.62 10.11Z"
},null,-1),Gb("path",{stroke:"#61DAFB","stroke-width":".87",
d:"M9.337 10.406c-2.641 4.575-3.366 9.1-1.62 10.11 1.747 1.008 5.304-1.883 7.946-6.458s3.366-9.101 1.62-10.11c-1.747-1.009-5.305 1.883-7.946 6.458Z"
},null,-1)])])}const Dne={render:Pne},Ine=Object.freeze(Object.defineProperty({
__proto__:null,default:Dne,render:Pne},Symbol.toStringTag,{value:"Module"
})),Mne={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function Nne(e,t){return Ub(),Qb("svg",Mne,[...t[0]||(t[0]=[Gb("path",{
fill:"currentColor",
d:"m21.863 11.755-.839-.52-.024-.244.722-.673a.288.288 0 0 0-.096-.482l-.923-.345-.072-.239.575-.799a.288.288 0 0 0-.187-.455l-.973-.158-.117-.218.409-.897a.286.286 0 0 0-.273-.409l-.987.034-.157-.188.228-.962a.287.287 0 0 0-.348-.348l-.96.227-.19-.157.034-.986a.287.287 0 0 0-.409-.273l-.897.409-.218-.118-.158-.972a.288.288 0 0 0-.454-.189l-.8.575-.238-.071-.345-.923a.288.288 0 0 0-.482-.096L13.01 3l-.245-.023-.52-.84a.29.29 0 0 0-.49 0l-.52.84q-.123.01-.245.023l-.673-.722a.29.29 0 0 0-.482.096l-.345.923q-.12.034-.237.072l-.8-.576a.288.288 0 0 0-.455.188l-.158.973q-.11.057-.22.118l-.895-.41a.287.287 0 0 0-.409.273l.034.988-.19.156-.96-.227a.29.29 0 0 0-.348.348l.227.962-.157.188-.987-.034a.288.288 0 0 0-.273.409l.409.897a7 7 0 0 0-.117.22l-.972.156a.288.288 0 0 0-.189.455l.575.8-.071.237-.923.346a.29.29 0 0 0-.096.482L3 10.99l-.024.244-.84.52a.29.29 0 0 0 0 .492l.84.519q.01.123.025.245l-.723.673a.29.29 0 0 0 .096.482l.922.345q.035.12.073.237l-.576.8a.29.29 0 0 0 .188.454l.973.158q.056.11.117.22l-.41.896a.288.288 0 0 0 .274.409l.987-.035q.076.096.156.19l-.227.961a.287.287 0 0 0 .348.347l.961-.226.19.156-.035.987a.288.288 0 0 0 .41.273l.896-.41q.108.06.219.119l.158.971a.288.288 0 0 0 .455.19l.799-.577q.118.038.237.072l.345.923a.287.287 0 0 0 .482.096L10.99 21q.121.014.244.025l.52.839a.29.29 0 0 0 .492 0l.519-.84q.123-.01.245-.024l.674.722a.287.287 0 0 0 .48-.096l.346-.923q.12-.034.238-.072l.8.576a.29.29 0 0 0 .454-.189l.158-.972.219-.117.896.409a.288.288 0 0 0 .41-.273l-.035-.988a7 7 0 0 0 .19-.155l.96.226a.287.287 0 0 0 .348-.347l-.226-.961.155-.19.988.035a.29.29 0 0 0 .272-.41l-.409-.896q.06-.108.117-.219l.973-.158a.287.287 0 0 0 .188-.454l-.575-.8.072-.237.922-.345a.286.286 0 0 0 .096-.482L21 13.011l.025-.245.839-.52a.29.29 0 0 0 0-.49Zm-5.619 6.965a.595.595 0 0 1 .25-1.163.595.595 0 0 1-.25 1.163m-.286-1.93a.54.54 0 0 0-.642.417l-.299 1.391a7.3 7.3 0 0 1-3.017.65c-1.1 0-2.144-.243-3.08-.679l-.299-1.39a.54.54 0 0 0-.643-.417l-1.228.263a7 7 0 0 1-.635-.748h5.976c.068 0 .113-.012.113-.074V14.09c0-.062-.046-.074-.113-.074h-1.747v-1.34h1.89c.172 0 .922.049 1.162 1.007.075.295.24 1.254.352 1.561.113.344.57 1.032 1.059 1.032h2.977a1 1 0 0 0 .108-.01q-.31.421-.677.794l-1.256-.27Zm-8.265 1.9a.594.594 0 1 1-.014-1.17.594.594 0 0 1 .014 1.171ZM5.427 9.5a.594.594 0 1 1-1.086.481.594.594 0 0 1 1.086-.481m-.697 1.65 1.28-.569a.543.543 0 0 0 .274-.715l-.263-.597h1.036v4.672h-2.09a7.3 7.3 0 0 1-.237-2.792Zm5.614-.454V9.32h2.468c.128 0 .9.148.9.725 0 .48-.592.652-1.08.652zm8.969 1.24q0 .273-.02.542h-.75c-.076 0-.106.05-.106.123v.345c0 .81-.457.987-.858 1.032-.381.043-.805-.16-.857-.394-.225-1.265-.6-1.536-1.192-2.003.735-.467 1.5-1.155 1.5-2.077 0-.996-.683-1.623-1.148-1.93-.652-.43-1.375-.517-1.57-.517h-7.76a7.3 7.3 0 0 1 4.091-2.308l.915.959a.54.54 0 0 0 .765.018l1.024-.98a7.32 7.32 0 0 1 5.006 3.566l-.7 1.583a.543.543 0 0 0 .275.715l1.35.6q.034.357.035.726m-7.754-8.004a.595.595 0 1 1 .82.86.595.595 0 0 1-.82-.86m6.951 5.595a.594.594 0 1 1 1.086.481.594.594 0 0 1-1.086-.481"
},null,-1)])])}const Rne={render:Nne},Lne=Object.freeze(Object.defineProperty({
__proto__:null,default:Rne,render:Nne},Symbol.toStringTag,{value:"Module"
})),Bne={xmlns:"http://www.w3.org/2000/svg",fill:"green",viewBox:"-2 0 24 24"}
;function jne(e,t){return Ub(),Qb("svg",Bne,[...t[0]||(t[0]=[Gb("path",{
fill:"#FF3E00",
d:"M18.664 3.171c-2.219-3.185-6.61-4.13-9.788-2.104L3.29 4.625A6.42 6.42 0 0 0 .398 8.917a6.74 6.74 0 0 0 .666 4.332 6.4 6.4 0 0 0-.959 2.369 6.85 6.85 0 0 0 1.166 5.175c2.219 3.194 6.61 4.137 9.782 2.11l5.586-3.557a6.42 6.42 0 0 0 2.892-4.292 6.74 6.74 0 0 0-.666-4.332 6.4 6.4 0 0 0 .959-2.369 6.94 6.94 0 0 0-1.16-5.182"
},null,-1),Gb("path",{fill:"#fff",
d:"M8.327 21.099a4.435 4.435 0 0 1-4.76-1.75 4.16 4.16 0 0 1-.7-3.122q.05-.261.133-.517l.105-.318.286.182a7.1 7.1 0 0 0 2.186 1.095l.208.063-.02.201c-.025.293.055.585.223.83a1.305 1.305 0 0 0 1.779.379l5.581-3.521a1.18 1.18 0 0 0 .524-.783 1.23 1.23 0 0 0-.211-.923 1.305 1.305 0 0 0-1.78-.379l-2.12 1.35q-.53.321-1.135.488a4.435 4.435 0 0 1-4.76-1.75 4.16 4.16 0 0 1-.7-3.122 3.84 3.84 0 0 1 1.736-2.573l5.581-3.559a4.3 4.3 0 0 1 1.134-.485 4.435 4.435 0 0 1 4.76 1.751c.641.908.893 2.03.7 3.122a4 4 0 0 1-.132.517l-.105.318-.287-.182a7.1 7.1 0 0 0-2.186-1.095l-.207-.063.019-.202a1.27 1.27 0 0 0-.223-.83 1.305 1.305 0 0 0-1.779-.378L6.6 9.363a1.18 1.18 0 0 0-.523.783c-.056.323.019.655.21.923a1.305 1.305 0 0 0 1.78.38l2.121-1.35c.352-.214.732-.38 1.134-.485a4.435 4.435 0 0 1 4.76 1.75 4.16 4.16 0 0 1 .7 3.122 3.8 3.8 0 0 1-1.736 2.563l-5.58 3.559c-.353.214-.732.38-1.135.489"
},null,-1)])])}const Une={render:jne},zne=Object.freeze(Object.defineProperty({
__proto__:null,default:Une,render:jne},Symbol.toStringTag,{value:"Module"
})),Fne={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function Zne(e,t){return Ub(),Qb("svg",Fne,[...t[0]||(t[0]=[Gb("path",{
fill:"#41B883",d:"m14.31 4.34-2.31 4-2.31-4H2l10 17.32L22 4.34z"
},null,-1),Gb("path",{fill:"#34495E",
d:"m14.31 4.34-2.31 4-2.31-4H6l6 10.392L18 4.34z"},null,-1)])])}const Qne={
render:Zne},Hne=Object.freeze(Object.defineProperty({__proto__:null,default:Qne,
render:Zne},Symbol.toStringTag,{value:"Module"})),Vne=Object.assign({
"../icons/Add.svg":z2,"../icons/AddTab.svg":H2,"../icons/Alert.svg":X2,
"../icons/ArrowLeft.svg":J2,"../icons/ArrowRight.svg":r4,
"../icons/Brackets.svg":s4,"../icons/Branch.svg":d4,"../icons/Changelog.svg":m4,
"../icons/Checkmark.svg":y4,"../icons/ChevronDown.svg":k4,
"../icons/ChevronLeft.svg":E4,"../icons/ChevronRight.svg":P4,
"../icons/ChevronUp.svg":N4,"../icons/Clipboard.svg":j4,"../icons/Close.svg":Z4,
"../icons/CloseTab.svg":q4,"../icons/CloseTabs.svg":Y4,"../icons/Cloud.svg":t8,
"../icons/CodeFolder.svg":a8,"../icons/Cog.svg":c8,"../icons/Collection.svg":h8,
"../icons/Cookie.svg":v8,"../icons/DarkMode.svg":w8,"../icons/Delete.svg":_8,
"../icons/Discord.svg":C8,"../icons/DocsPage.svg":I8,"../icons/Download.svg":L8,
"../icons/Duplicate.svg":z8,"../icons/Edit.svg":H8,"../icons/Ellipses.svg":X8,
"../icons/Email.svg":J8,"../icons/Error.svg":r6,"../icons/Example.svg":s6,
"../icons/ExternalLink.svg":d6,"../icons/FilterList.svg":m6,
"../icons/Folder.svg":y6,"../icons/GitHub.svg":k6,"../icons/GitHubLine.svg":E6,
"../icons/Globe.svg":P6,"../icons/Google.svg":N6,"../icons/Help.svg":j6,
"../icons/Hide.svg":Z6,"../icons/History.svg":q6,"../icons/House.svg":Y6,
"../icons/Import.svg":t3,"../icons/Info.svg":a3,"../icons/Key.svg":c3,
"../icons/Leave.svg":h3,"../icons/LightDarkModeToggle.svg":v3,
"../icons/LightMode.svg":w3,"../icons/Link.svg":_3,"../icons/Lock.svg":C3,
"../icons/Logo.svg":I3,"../icons/Magic.svg":L3,"../icons/Markdown.svg":z3,
"../icons/Menu.svg":H3,"../icons/NotAllowed.svg":X3,"../icons/Page.svg":J3,
"../icons/Pencil.svg":r5,"../icons/Play.svg":s5,"../icons/Refresh.svg":d5,
"../icons/Roadmap.svg":m5,"../icons/Scribble.svg":y5,"../icons/Search.svg":k5,
"../icons/Server.svg":E5,"../icons/Settings.svg":P5,"../icons/Show.svg":N5,
"../icons/Sort.svg":j5,"../icons/Terminal.svg":Z5,"../icons/Trash.svg":q5,
"../icons/Unlock.svg":Y5,"../icons/Unwatch.svg":t7,"../icons/Upload.svg":a7,
"../icons/User.svg":c7,"../icons/UserSwitch.svg":h7,"../icons/Users.svg":v7,
"../icons/Versions.svg":w7,"../icons/Wallet.svg":_7,"../icons/Watch.svg":C7,
"../icons/Workspace.svg":I7,"../icons/programming-framework-angular.svg":L7,
"../icons/programming-framework-astro.svg":z7,
"../icons/programming-framework-laravel.svg":H7,
"../icons/programming-framework-nextdotjs.svg":X7,
"../icons/programming-framework-react.svg":J7,
"../icons/programming-framework-vuedotjs.svg":r9,
"../icons/programming-language-c.svg":s9,
"../icons/programming-language-clojure.svg":d9,
"../icons/programming-language-csharp.svg":m9,
"../icons/programming-language-css3.svg":y9,
"../icons/programming-language-dart.svg":k9,
"../icons/programming-language-fsharp.svg":E9,
"../icons/programming-language-go.svg":P9,
"../icons/programming-language-html5.svg":N9,
"../icons/programming-language-http.svg":j9,
"../icons/programming-language-java.svg":Z9,
"../icons/programming-language-javascript.svg":q9,
"../icons/programming-language-json.svg":Y9,
"../icons/programming-language-kotlin.svg":tee,
"../icons/programming-language-node.svg":aee,
"../icons/programming-language-objc.svg":cee,
"../icons/programming-language-ocaml.svg":hee,
"../icons/programming-language-php.svg":vee,
"../icons/programming-language-powershell.svg":wee,
"../icons/programming-language-python.svg":_ee,
"../icons/programming-language-r.svg":Cee,
"../icons/programming-language-ruby.svg":Iee,
"../icons/programming-language-rust.svg":Lee,
"../icons/programming-language-scala.svg":zee,
"../icons/programming-language-shell.svg":Hee,
"../icons/programming-language-swift.svg":Xee,
"../icons/programming-language-typescript.svg":Jee,
"../icons/programming-script-code.svg":rte,
"../icons/programming-tool-git.svg":ste,
"../icons/programming-tool-tailwindcss.svg":dte}),qne=Object.assign({
"../logos/Adonisjs.svg":mte,"../logos/Astro.svg":yte,
"../logos/Docusaurus.svg":kte,"../logos/Dotnet.svg":Ete,
"../logos/Elysiajs.svg":Pte,"../logos/Express.svg":Nte,
"../logos/Fastapi.svg":jte,"../logos/Fastify.svg":Zte,"../logos/Go.svg":qte,
"../logos/Hono.svg":Yte,"../logos/Laravel.svg":tne,"../logos/Litestar.svg":ane,
"../logos/Nestjs.svg":cne,"../logos/Nextjs.svg":hne,"../logos/Nitro.svg":vne,
"../logos/Nuxt.svg":wne,"../logos/Openapi.svg":_ne,
"../logos/Platformatic.svg":Cne,"../logos/React.svg":Ine,
"../logos/Rust.svg":Lne,"../logos/Svelte.svg":zne,"../logos/Vue.svg":Hne
}),Wne=jS({variants:{size:{xs:"size-3",sm:"size-3.5",md:"size-4",lg:"size-5",
xl:"size-6","2xl":"size-8","3xl":"size-10",full:"size-full"}},defaultVariants:{
size:"full"}}),Xne=Qg({inheritAttrs:!1,__name:"ScalarIcon",props:{icon:{},
logo:{},size:{},thickness:{},label:{}},setup(e){nO((e=>({c07589c2:r.value})))
;const t=e,{cx:n}=zS(),r=Sy((()=>t.thickness??"2")),o=Sy((()=>t.label?{
"aria-label":t.label}:{"aria-hidden":!0,role:"presentation"
})),a=Sy((()=>t.icon?(e=>{const t=`../icons/${e}.svg`
;return Vne[t]?Vne[t]:(console.warn(`Could not find icon: ${e}`),null)
})(t.icon):t.logo?(e=>{const t=`../logos/${e}.svg`
;return qne[t]?qne[t]:(console.warn(`Could not find icon: ${e}`),null)
})(t.logo):void 0));return(t,r)=>(Ub(),Hb(bv(a.value),Mh(Kb({
...xm(n)("scalar-icon",xm(Wne)({size:e.size})),...o.value})),null,16))}
}),Gne=HS(Xne,[["__scopeId","data-v-b651bb23"]]),Yne=Qg({inheritAttrs:!1,
__name:"ScalarIconLegacyAdapter",props:{icon:{type:[Object,Function]},label:{},
weight:{},logo:{},size:{},thickness:{}},setup(e){const{cx:t}=zS()
;return(n,r)=>"string"==typeof e.icon?(Ub(),Hb(Gne,iy({key:0},{...n.$props,
...n.$attrs},{icon:e.icon}),null,16,["icon"])):(Ub(),Hb(bv(e.icon),iy({key:1,
label:e.label,weight:e.weight},xm(t)(xm(Wne)({size:e.size
}))),null,16,["label","weight"]))}
}),Kne="scalar-tooltip",Jne="scalar-tooltip",ere=bm(),tre=bm(),nre=bm(),{floatingStyles:rre}=jK(Sy((()=>xm(nre.value?.targetRef))),tre,{
placement:Sy((()=>xm(nre.value?.placement))),whileElementsMounted:TK,
middleware:Sy((()=>[CK(),AK()]))});function ore(e){(function(e){
const t=xm(nre.value?.targetRef)
;if(e instanceof MouseEvent&&e.relatedTarget instanceof Element&&t){
const n=function(e){const t=[];let n=e.parentElement
;for(;n;)t.push(n),n=n.parentElement;return t}(e.relatedTarget)
;return e.relatedTarget.id!==Kne&&!n.some((e=>e.id===Kne))&&e.relatedTarget!==t}
return!0})(e)&&(ire(),nre.value=void 0)}function are(e){
"Escape"===e.key&&(e.stopPropagation(),ore(e))}function ire(){
ere.value&&(clearTimeout(ere.value),ere.value=void 0)}function sre(e){
function t(t){const r=xm(e.delay)??300
;ire(),r>0?ere.value=setTimeout((()=>n()),r):n()}function n(t){
ire(),document.addEventListener("keydown",are,{once:!0,capture:!0}),nre.value=e}
!function(){if(typeof document>"u"||typeof window>"u"||tre.value)return
;const e=document.getElementById(Kne)
;e?tre.value=e:(tre.value=document.createElement("div"),
tre.value.role="tooltip",
tre.value.id=Kne,tre.value.classList.add(Jne),tre.value.classList.add("scalar-app"),
tre.value.style.setProperty("display","none"),
tre.value.addEventListener("mouseleave",ore),
document.body.appendChild(tre.value))}(),mg((()=>xm(e.targetRef)),((e,r)=>{
r&&(r.removeEventListener("mouseenter",t),
r.removeEventListener("mouseleave",ore),
r.removeEventListener("focus",n),r.removeEventListener("blur",ore),
r.removeAttribute("aria-describedby")),
e&&(e.addEventListener("mouseenter",t),e.addEventListener("mouseleave",ore),
e.addEventListener("focus",n),
e.addEventListener("blur",ore),e.setAttribute("aria-describedby",Kne))}),{
immediate:!0})}mg(rre,(()=>{
tre.value&&(tre.value.style.position=rre.value.position,
tre.value.style.top=rre.value.top,
tre.value.style.left=rre.value.left,tre.value.style.transform=rre.value.transform??"",
tre.value.style.willChange=rre.value.willChange??"")})),mg(nre,(e=>{
if(tre.value)if(e){const t=xm(e?.contentTarget)??"textContent"
;tre.value[t]=xm(e?.content)??"";const n=xm(e?.offset)??4
;tre.value.style.setProperty("--scalar-tooltip-offset",`${n}px`),
tre.value.style.setProperty("display","block")
}else tre.value.innerHTML="",tre.value.style.removeProperty("--scalar-tooltip-offset"),
tre.value.style.setProperty("display","none")}),{deep:!0})
;const lre=["aria-disabled"],cre={key:0,class:"sr-only"},ure=Qg({
inheritAttrs:!1,__name:"ScalarIconButton",props:{label:{},icon:{
type:[Object,Function]},disabled:{type:Boolean},variant:{default:"ghost"},size:{
default:"md"},thickness:{},weight:{},tooltip:{type:[Boolean,String,Object]}},
setup(e){const t=jS({
base:"scalar-icon-button grid aspect-square cursor-pointer rounded",variants:{
size:{xxs:"size-3.5 p-0.5",xs:"size-5 p-1",sm:"size-6 p-1",md:"size-10 p-3",
full:"size-full"},disabled:{true:"cursor-not-allowed shadow-none"},variant:FS},
compoundVariants:[{size:"md",variant:"ghost",
class:"size-8 p-2 m-1 -outline-offset-2 rounded-lg"}]}),{cx:n}=zS(),r=qg("ref")
;return sre({content:Sy((()=>e.label)),offset:Sy((()=>"ghost"===e.variant?0:4)),
placement:Sy((()=>"boolean"==typeof e.tooltip?void 0:e.tooltip)),
targetRef:Sy((()=>e.tooltip?r.value:void 0))}),(r,o)=>(Ub(),Qb("button",iy({
ref:"ref","aria-disabled":e.disabled,type:"button"},xm(n)(xm(t)({size:e.size,
variant:e.variant,disabled:e.disabled}))),[Yb(xm(Yne),{icon:e.icon,
thickness:e.thickness,weight:e.weight
},null,8,["icon","thickness","weight"]),e.tooltip?ny("",!0):(Ub(),
Qb("span",cre,Uh(e.label),1))],16,lre))}}),dre=Qg({__name:"ScalarListboxItem",
props:{option:{},multiselect:{type:Boolean}},setup(e){const t=jS({
base:["group/item","flex min-w-0 items-center gap-1.5 rounded px-2 py-1.5 text-left","truncate bg-transparent text-c-1","cursor-pointer hover:bg-b-2"],
variants:{selected:{true:"text-c-1"},active:{true:"bg-b-2"},disabled:{
true:"pointer-events-none opacity-50"}}});return(n,r)=>(Ub(),Hb(xm(ck),{
as:"template",disabled:e.option.disabled,value:e.option},{
default:ig((({active:n,selected:r})=>[Gb("li",{class:Ih(xm(US)(xm(t)({active:n,
selected:r,disabled:e.option.disabled})))},[Yb(KG,{multiselect:e.multiselect,
selected:r},null,8,["multiselect","selected"]),Gb("span",{
class:Ih(["inline-block min-w-0 flex-1 truncate",e.option.color?e.option.color:"text-c-1"])
},Uh(e.option.label),3)],2)])),_:1},8,["disabled","value"]))}}),pre={
class:"custom-scroll min-h-0 flex-1"},hre=Qg({inheritAttrs:!1,
__name:"ScalarListbox",props:{options:{},id:{},label:{},multiple:{type:Boolean},
modelValue:{},placement:{},offset:{type:[Number,Object,Function]},resize:{
type:Boolean},target:{},middleware:{},teleport:{type:[Boolean,String]}},
emits:["update:modelValue"],setup(e){const{cx:t}=zS()
;return(n,r)=>(Ub(),Hb(xm(ak),{modelValue:e.modelValue,multiple:e.multiple,
"onUpdate:modelValue":r[0]||(r[0]=e=>n.$emit("update:modelValue",e))},{
default:ig((({open:r})=>[e.label?(Ub(),Hb(xm(ik),{key:0,class:"sr-only"},{
default:ig((()=>[ey(Uh(e.label),1)])),_:1})):ny("",!0),Yb(xm(FK),iy(n.$props,{
placement:e.placement??"bottom-start"}),{
floating:ig((({width:n})=>[r?(Ub(),Qb("div",iy({key:0,style:{width:n}
},xm(t)("relative flex max-h-[inherit] w-40 max-w-[inherit] rounded text-sm")),[Gb("div",pre,[Yb(xm(lk),{
class:"flex flex-col gap-0.75 p-0.75 -outline-offset-1"},{
default:ig((()=>[(Ub(!0),Qb(Mb,null,wv(e.options,(t=>(Ub(),Hb(dre,{key:t.id,
multiselect:e.multiple,option:t},null,8,["multiselect","option"])))),128))])),
_:1})]),Yb(xm(ZK))],16)):ny("",!0)])),default:ig((()=>[Yb(xm(sk),{id:e.id,
as:"template"},{default:ig((()=>[kv(n.$slots,"default",{open:r})])),_:2
},1032,["id"])])),_:2},1040,["placement"])])),_:3},8,["modelValue","multiple"]))
}}),fre=["innerHTML"],mre=Qg({inheritAttrs:!1,__name:"ScalarMarkdown",props:{
value:{},withImages:{type:Boolean,default:!1},withAnchors:{type:Boolean,
default:!1},transform:{type:Function},transformType:{},clamp:{},anchorPrefix:{}
},setup(e,{expose:t}){const{cx:n}=zS();t({el:qg("div")});const r=t=>{
if(!e.withAnchors)return e.transform?.(t)||t
;const n=(t.children?.[0]?.value||"").toLowerCase().replace(/\s+/g,"-"),r=e.anchorPrefix?`${e.anchorPrefix}/description/${n}`:n
;return t.data={hProperties:{id:r}},e.transform?e.transform(t):t
},o=Sy((()=>function(e,t){
const n=t?.removeTags??[],r=[...$U.tagNames??[],...t?.allowTags??[]].filter((e=>!n.includes(e)))
;return XR().use(qQ).use(OQ).use(vH,{transform:t?.transform,
type:t?.transformType}).use(pH,{allowDangerousHtml:!0}).use(gH).use(AU).use(BU,{
...$U,clobberPrefix:"",tagNames:r,attributes:{...$U.attributes,abbr:["title"],
"*":[...$U.attributes?.["*"]??[],"className"]},
strip:["script","style","object","embed","form"]}).use(nj,{languages:hj,
detect:!0}).use(Aj,{target:"_blank"}).use(nU).use(LR).processSync(e).toString()
}(e.value??"",{removeTags:e.withImages?[]:["img","picture"],
transform:e.withAnchors&&"heading"===e.transformType?r:e.transform,
transformType:e.transformType})));return(t,r)=>(Ub(),Qb("div",iy({ref:"div"
},xm(n)("markdown",{"line-clamp-(--markdown-clamp)":!!e.clamp}),{style:{
"--markdown-clamp":e.clamp},innerHTML:o.value}),null,16,fre))}
}),gre=["aria-controls","aria-expanded"],vre=Qg({inheritAttrs:!1,
__name:"ScalarMarkdownSummary",props:Nv({value:{},withImages:{type:Boolean},
withAnchors:{type:Boolean},transform:{type:Function},transformType:{},clamp:{
default:1},anchorPrefix:{},controlled:{type:Boolean}},{modelValue:{type:Boolean,
default:!1},modelModifiers:{}}),emits:["update:modelValue"],setup(e){
const t=function(e,t){const n={}
;for(const r in e)t.includes(r)||Object.defineProperty(n,r,{enumerable:!0,
get:()=>e[r]});return n
}(e,["clamp"]),n=Hg(),r=Kv(e,"modelValue"),o=qg("scalar-markdown"),a=bm(!1)
;function i(){const e=o.value?.el
;e&&(a.value=e.scrollHeight>e.clientHeight||e.scrollWidth>e.clientWidth)}
!function(e,t,n={}){const{window:r=G1,...o}=n;let a
;const i=r2((()=>r&&"ResizeObserver"in r)),s=()=>{a&&(a.disconnect(),a=void 0)
},l=mg(Sy((()=>{const t=km(e);return Array.isArray(t)?t.map((e=>K1(e))):[K1(t)]
})),(e=>{if(s(),i.value&&r){a=new ResizeObserver(t)
;for(const t of e)t&&a.observe(t,o)}}),{immediate:!0,flush:"post"}),c=()=>{
s(),l()};N1(c)}((()=>o.value?.el),i),iv(i);const{cx:s}=zS()
;return(o,i)=>(Ub(),Qb("div",Mh(Kb(xm(s)("group/summary flex gap-0.5",r.value?"flex-col":"flex-row items-baseline"))),[Yb(mre,iy(t,{
id:xm(n),ref:"scalar-markdown",clamp:r.value?void 0:e.clamp,class:{
"markdown-summary truncate":!r.value}
}),null,16,["id","clamp","class"]),e.controlled||!a.value&&!r.value?ny("",!0):(Ub(),
Qb("button",{key:0,"aria-controls":xm(n),"aria-expanded":r.value,
class:Ih(["whitespace-nowrap font-medium hover:underline",{"self-end":r.value
}]),type:"button",onClick:i[0]||(i[0]=e=>r.value=!r.value)
},[kv(o.$slots,"button",{open:r.value
},(()=>[ey(Uh(r.value?" Show Less":"More"),1)]))],10,gre))],16))}}),bre={
Root:y1,Trigger:O1,Portal:w1,Content:x1,Arrow:k1,Item:S1,Group:_1,Separator:T1,
CheckboxItem:E1,ItemIndicator:A1,Label:C1,RadioGroup:$1,RadioItem:P1,Sub:D1,
SubContent:I1,SubTrigger:M1},yre={class:"h-5 w-auto"},Ore={class:"sr-only"
},wre=Qg({__name:"ScalarMenuButton",props:{open:{type:Boolean}},
setup:e=>(t,n)=>(Ub(),Hb(xm(A2),{class:"gap-0.75 px-2"},{
default:ig((()=>[Gb("div",yre,[kv(t.$slots,"logo",{},(()=>[Yb(xm(Gne),{
icon:"Logo"
})]))]),Gb("span",Ore,[kv(t.$slots,"label",{},(()=>[ey(Uh(e.open?"Close Menu":"Open Menu"),1)]))]),Yb(xm(L_),{
class:Ih(["shrink-0 text-c-3 group-hover/button:text-c-1 size-3.5",e.open?"rotate-180":""]),
weight:"bold"},null,8,["class"])])),_:3}))}),xre=Qg({
__name:"ScalarDropdownButton",props:{is:{default:"button"},active:{type:Boolean
},disabled:{type:Boolean}},setup(e){const t=jS({
base:["block h-8 min-w-0 gap-1.5 rounded px-2.5 py-1.5 text-left","truncate  no-underline text-sm text-c-1","cursor-pointer hover:bg-b-2"],
variants:{disabled:{true:"pointer-events-none text-c-3"},active:{true:""}},
compoundVariants:[{disabled:!1,active:!0,class:"bg-b-2"}]})
;return(n,r)=>(Ub(),Hb(bv(e.is),{"aria-disabled":e.disabled,
class:Ih(["item",xm(US)("scalar-dropdown-item",xm(t)({active:e.active,
disabled:e.disabled}))]),type:"button"===e.is?"button":void 0},{
default:ig((()=>[kv(n.$slots,"default",{},void 0,!0)])),_:3
},8,["aria-disabled","class","type"]))}
}),kre=HS(xre,[["__scopeId","data-v-6660bbc5"]]),Sre={key:1,class:"size-3"
},_re=Qg({inheritAttrs:!1,__name:"ScalarMenuLink",props:{is:{
default:()=>bre.Item},icon:{type:[Object,Function]},strong:{type:Boolean}},
setup(e){const{cx:t}=zS()
;return(n,r)=>(Ub(),Hb(xm(kre),iy(xm(t)("flex items-center"),{is:e.is,as:"a"}),{
default:ig((()=>[e.icon?(Ub(),Hb(xm(Yne),{key:0,
class:Ih([e.strong?"text-c-1":"text-c-2","string"==typeof e.icon?"size-3":"size-3.5 -mx-0.25"]),
icon:e.icon,thickness:e.strong?"2.5":"2",weight:e.strong?"bold":"regular"
},null,8,["class","icon","thickness","weight"])):(Ub(),Qb("div",Sre)),Gb("div",{
class:Ih(["flex items-center flex-1 min-w-0 truncate",e.strong?"font-medium":"font-normal"])
},[kv(n.$slots,"default")],2)])),_:3},16,["is"]))}}),Tre=Qg({inheritAttrs:!1,
__name:"ScalarMenuProduct",props:{is:{default:"a"},selected:{type:Boolean},
icon:{type:[Object,Function]}},setup(e){const{cx:t}=zS(),n=jS({base:"gap-1.5",
variants:{selected:{true:"pointer-events-none bg-b-2 dark:bg-b-3",
false:"cursor-pointer hover:bg-b-2 dark:hover:bg-b-3"}}})
;return(r,o)=>(Ub(),Hb(xm(_re),iy({is:e.is,icon:e.icon,strong:"",target:"_blank"
},xm(t)(xm(n)({selected:e.selected}))),{
default:ig((()=>[kv(r.$slots,"default")])),_:3},16,["is","icon"]))}}),Ere=Qg({
inheritAttrs:!1,__name:"ScalarMenuProducts",props:{selected:{},hrefs:{}},
emits:["open"],setup(e){const{cx:t}=zS()
;return(n,r)=>(Ub(),Qb("div",Mh(Kb(xm(t)("flex flex-col"))),[Yb(Tre,{
href:e.hrefs?.dashboard??"https://dashboard.scalar.com",icon:xm(lA),
selected:"dashboard"===e.selected,
onClick:r[0]||(r[0]=e=>n.$emit("open",e,"dashboard"))},{
default:ig((()=>[...r[3]||(r[3]=[ey(" Dashboard ",-1)])])),_:1
},8,["href","icon","selected"]),Yb(Tre,{
href:e.hrefs?.docs??"https://docs.scalar.com",icon:xm(g_),
selected:"docs"===e.selected,onClick:r[1]||(r[1]=e=>n.$emit("open",e,"docs"))},{
default:ig((()=>[...r[4]||(r[4]=[ey(" Docs ",-1)])])),_:1
},8,["href","icon","selected"]),Yb(Tre,{
href:e.hrefs?.client??"https://client.scalar.com",icon:xm(c_),
selected:"client"===e.selected,
onClick:r[2]||(r[2]=e=>n.$emit("open",e,"client"))},{
default:ig((()=>[...r[5]||(r[5]=[ey(" Client ",-1)])])),_:1
},8,["href","icon","selected"])],16))}}),Are={
class:"-mx-0.75 my-0.75 h-border bg-border"}
;const Cre=HS({},[["render",function(e,t,n,r,o,a){return Ub(),Qb("div",Are)
}]]),$re=Qg({inheritAttrs:!1,__name:"ScalarMenuSection",
setup:e=>(e,t)=>(Ub(),Qb(Mb,null,[Yb(xm(Cre)),kv(e.$slots,"default")],64))
}),Pre=Qg({__name:"ScalarMenuResources",setup:e=>(e,t)=>(Ub(),Hb($re,null,{
title:ig((()=>[...t[0]||(t[0]=[ey("Resources",-1)])])),default:ig((()=>[Yb(_re,{
href:"mailto:support@scalar.com",icon:xm(_T),target:"_blank"},{
default:ig((()=>[...t[1]||(t[1]=[ey(" Sales & Support ",-1)])])),_:1
},8,["icon"]),Yb(_re,{href:"https://scalar.com/terms-and-conditions",
icon:xm(iE),target:"_blank"},{
default:ig((()=>[...t[2]||(t[2]=[ey(" Terms & Conditions ",-1)])])),_:1
},8,["icon"]),Yb(_re,{href:"https://scalar.com/privacy-policy",icon:xm(k_),
target:"_blank"},{
default:ig((()=>[...t[3]||(t[3]=[ey(" Privacy Policy ",-1)])])),_:1
},8,["icon"])])),_:1}))}),Dre=Qg({inheritAttrs:!1,__name:"ScalarMenu",setup(e){
const t=bm(!1);function n(){t.value=!1}return(e,r)=>(Ub(),Hb(xm(bre).Root,{
open:t.value,"onUpdate:open":r[0]||(r[0]=e=>t.value=e)},{
default:ig((()=>[Yb(xm(bre).Trigger,{asChild:""},{
default:ig((()=>[kv(e.$slots,"button",{open:t.value},(()=>[Yb(wre,{
class:"min-w-0",open:t.value},xv({_:2},[e.$slots.logo?{name:"logo",
fn:ig((()=>[kv(e.$slots,"logo")])),key:"0"}:void 0,e.$slots.label?{name:"label",
fn:ig((()=>[kv(e.$slots,"label")])),key:"1"}:void 0]),1032,["open"])]))])),_:3
}),Yb(xm(bre).Content,iy({align:"start",as:xm(d2),
class:"max-h-radix-popper z-context",sideOffset:5},e.$attrs),{
default:ig((()=>[kv(e.$slots,"products",{close:n
},(()=>[Yb(Ere)])),kv(e.$slots,"profile",{close:n}),kv(e.$slots,"sections",{
close:n},(()=>[Yb(Pre)]))])),_:3},16,["as"])])),_:3},8,["open"]))}}),Ire=Qg({
__name:"ScalarMenuSupport",setup:e=>(e,t)=>(Ub(),Hb($re,null,{
title:ig((()=>[...t[0]||(t[0]=[ey("Resources",-1)])])),default:ig((()=>[Yb(_re,{
href:"https://discord.gg/scalar",icon:xm(bT),target:"_blank"},{
default:ig((()=>[...t[1]||(t[1]=[ey(" Discord ",-1)])])),_:1
},8,["icon"]),Yb(_re,{href:"https://github.com/scalar/scalar",icon:xm(ME),
target:"_blank"},{default:ig((()=>[...t[2]||(t[2]=[ey(" GitHub ",-1)])])),_:1
},8,["icon"])])),_:1}))}),Mre={
class:"flex h-full items-center gap-1 flex-1 truncate"},Nre=Qg({inheritAttrs:!1,
__name:"ScalarMenuWorkspacePicker",props:Nv({workspaceOptions:{}},{
modelValue:{},modelModifiers:{}}),
emits:Nv(["createWorkspace"],["update:modelValue"]),setup(e,{emit:t}){
const n=t,r=Kv(e,"modelValue");return(t,o)=>(Ub(),Hb(xm(bre).Sub,null,{
default:ig((()=>[Yb(_re,iy({is:xm(bre).SubTrigger,icon:xm(SC)},t.$attrs),{
default:ig((()=>[o[2]||(o[2]=Gb("div",null,"Change workspace",-1)),Yb(xm(Q_),{
class:"ml-auto text-c-2 -mr-0.25 size-3",weight:"bold"})])),_:1
},16,["is","icon"]),Yb(xm(bre).Portal,null,{
default:ig((()=>[Yb(xm(bre).SubContent,{as:xm(d2),
class:"max-h-radix-popper z-context-plus",sideOffset:3},{
default:ig((()=>[Yb(xm(bre).RadioGroup,{modelValue:r.value,
"onUpdate:modelValue":o[0]||(o[0]=e=>r.value=e),class:"contents"},{
default:ig((()=>[(Ub(!0),
Qb(Mb,null,wv(e.workspaceOptions,(e=>(Ub(),Hb(xm(bre).RadioItem,{key:e.id,
as:xm(kre),class:"group/item flex items-center",value:e.id},{
default:ig((()=>[Gb("div",Mre,Uh(e.label),1),Yb(xm(KG),{class:"ml-auto",
selected:e.id===r.value},null,8,["selected"])])),_:2
},1032,["as","value"])))),128))])),_:1},8,["modelValue"]),Yb(xm(bre).Item,{
as:xm(kre),class:"flex items-center",
onClick:o[1]||(o[1]=e=>n("createWorkspace"))},{default:ig((()=>[Yb(xm(uC),{
class:"bg-b-3 -ml-0.75 rounded p-1 size-5 text-c-3",weight:"bold"
}),o[3]||(o[3]=ey(" Create workspace ",-1))])),_:1},8,["as"])])),_:1
},8,["as"])])),_:1})])),_:1}))}}),Rre=Qg({inheritAttrs:!1,
__name:"ScalarPopover",props:{focus:{type:Boolean},placement:{},offset:{
type:[Number,Object,Function]},resize:{type:Boolean},target:{},middleware:{},
teleport:{type:[Boolean,String]}},setup(e){const{cx:t}=zS()
;return(n,r)=>(Ub(),Hb(xm(_k),{as:"template"},{
default:ig((({open:r})=>[Yb(xm(FK),Mh(Kb(n.$props)),{
floating:ig((({width:o,height:a})=>[Yb(xm(Ek),iy({focus:e.focus,style:{width:o,
height:a}},xm(t)("relative flex flex-col p-0.75")),{
default:ig((({close:e})=>[kv(n.$slots,"popover",{close:()=>e(),open:r
}),kv(n.$slots,"backdrop",{open:r},(()=>[Yb(xm(ZK))]))])),_:2
},1040,["focus","style"])])),default:ig((()=>[Yb(xm(Tk),{as:"template"},{
default:ig((()=>[kv(n.$slots,"default",{open:r})])),_:2},1024)])),_:2},1040)])),
_:3}))}}),Lre=["aria-label"],Bre=Qg({inheritAttrs:!1,__name:"ScalarSearchInput",
props:Nv({loader:{},label:{}},{modelValue:{},modelModifiers:{}}),
emits:["update:modelValue"],setup(e){const t=Kv(e,"modelValue"),n=bm(null)
;function r(){t.value="",n.value&&n.value.focus()}
const{stylingAttrsCx:o,otherAttrs:a}=zS()
;return(i,s)=>(Ub(),Qb("label",Mh(Kb(xm(o)("flex items-center text-lg font-medium h-10 pl-3 pr-1 py-2 gap-2.25"))),[Yb(xm(ZA),{
class:"text-sidebar-c-search size-4"}),sg(Gb("input",iy({ref_key:"inputRef",
ref:n},xm(a),{"onUpdate:modelValue":s[0]||(s[0]=e=>t.value=e),
"aria-label":e.label??"Enter search query",autocapitalize:"off",
autocomplete:"off",autocorrect:"off",
class:"flex-1 appearance-none rounded border-none bg-transparent outline-none",
placeholder:"Search...",spellcheck:"false",type:"search"
}),null,16,Lre),[[TO,t.value]]),e.loader&&e.loader.isActive?(Ub(),Hb(xm(VS),{
key:0,class:"self-center",loader:e.loader,size:"md"
},null,8,["loader"])):t.value?(Ub(),Hb(xm(ure),{key:1,class:"p-0 size-5",
icon:xm(I$),label:"Clear Search",weight:"bold",onClick:BO(r,["stop","prevent"])
},null,8,["icon"])):ny("",!0)],16))}}),jre=["aria-selected"],Ure={key:0,
class:"flex h-fit items-center text-sm font-medium text-c-3 group-hover:text-c-1"
},zre={class:"flex min-w-0 flex-1 flex-col gap-0.75"},Fre={
class:"flex items-center gap-1"},Zre={
class:"flex-1 truncate zoomed:!whitespace-normal break-words text-base font-medium"
},Qre={key:0,class:"text-base text-c-2"},Hre={key:0,
class:"truncate zoomed:!whitespace-normal break-words text-base text-c-2"
},Vre=Qg({inheritAttrs:!1,__name:"ScalarSearchResultItem",props:{icon:{
type:[Object,Function]},selected:{type:Boolean}},setup(e){const{cx:t}=zS()
;return(n,r)=>(Ub(),Qb("a",iy({"aria-selected":e.selected,role:"option",
tabindex:"-1"
},xm(t)("group flex cursor-pointer gap-2 rounded px-2 py-1.5 no-underline hover:bg-b-2",{
"bg-b-2":e.selected
})),[e.icon?(Ub(),Qb("div",Ure,[kv(n.$slots,"icon",{},(()=>[e.icon?(Ub(),
Hb(xm(Yne),{key:0,class:"size-4",icon:e.icon
},null,8,["icon"])):ny("",!0)])),r[0]||(r[0]=Gb("span",null," ",-1))])):ny("",!0),Gb("div",zre,[Gb("div",Fre,[Gb("div",Zre,[kv(n.$slots,"default")]),n.$slots.addon?(Ub(),
Qb("div",Qre,[kv(n.$slots,"addon")])):ny("",!0)]),n.$slots.description?(Ub(),
Qb("div",Hre,[kv(n.$slots,"description")])):ny("",!0)])],16,jre))}}),qre=Qg({
inheritAttrs:!1,__name:"ScalarSearchResultList",props:{noResults:{type:Boolean}
},setup(e){const{cx:t}=zS();return(n,r)=>(Ub(),Qb("div",iy({role:"listbox"
},xm(t)("flex flex-col")),[e.noResults?kv(n.$slots,"noResults",{key:0
},(()=>[r[0]||(r[0]=Gb("div",{class:"flex flex-col items-center gap-2 px-3 py-4"
},[Gb("div",{class:"text-base font-medium text-c-2",role:"alert"
}," No results found ")],-1))])):ny("",!0),kv(n.$slots,"default")],16))}
}),Wre=Qg({inheritAttrs:!1,__name:"ScalarSidebar",setup(e){const{cx:t}=zS()
;return(e,n)=>(Ub(),
Qb("aside",Mh(Kb(xm(t)("flex flex-col border-r bg-sidebar-b-1 border-sidebar-border w-72"))),[kv(e.$slots,"default")],16))
}}),Xre=Qg({inheritAttrs:!1,__name:"ScalarSidebarIndent",props:{indent:{
default:0},selected:{type:Boolean,default:!1},disabled:{type:Boolean}},setup(e){
const t=Sy((()=>Array.from({length:e.indent},((e,t)=>t)))),{cx:n}=zS()
;return(r,o)=>(Ub(),
Qb("div",Mh(Kb(xm(n)("scalar-sidebar-indent flex justify-center",{
"mr-[calc(20px-var(--scalar-sidebar-indent))]":e.indent>0,
"scalar-sidebar-indent-selected":e.selected
}))),[(Ub(!0),Qb(Mb,null,wv(t.value,((n,r)=>(Ub(),Qb("div",{key:n,
class:"relative w-[var(--scalar-sidebar-indent)]"},[o[0]||(o[0]=Gb("div",{
class:"scalar-sidebar-indent-border absolute left-2 inset-y-0 w-border bg-sidebar-indent-border"
},null,-1)),r===t.value.length-1?(Ub(),Qb("div",{key:0,
class:Ih(["absolute left-2 inset-y-0 w-border",e.disabled?"":e.selected?"bg-sidebar-indent-border-active":"group-hover/button:bg-sidebar-indent-border-hover"])
},null,2)):ny("",!0)])))),128))],16))}
}),Gre=HS(Xre,[["__scopeId","data-v-3e080c68"]]),Yre={key:0,
class:"h-[1lh] *:size-4 mr-1"},Kre={class:"group/button-label flex-1 min-w-0"
},Jre=Qg({inheritAttrs:!1,__name:"ScalarSidebarButton",props:{is:{default:"a"},
icon:{type:[Object,Function]},active:{type:Boolean},selected:{type:Boolean},
disabled:{type:Boolean},indent:{default:0}},setup(e){const t=jS({
base:["group/button peer/button flex items-stretch rounded p-2","font-sidebar text-base/5  text-sidebar-c-2 no-underline wrap-break-word"],
variants:{active:{true:"text-sidebar-c-active font-sidebar-active"},disabled:{
true:"cursor-auto"},selected:{
true:"cursor-auto bg-sidebar-b-active text-sidebar-c-active font-sidebar-active"
}},compoundVariants:[{selected:!1,disabled:!1,active:!1,
class:"hover:bg-sidebar-b-hover hover:text-sidebar-c-hover"},{selected:!1,
disabled:!1,active:!0,class:"hover:bg-sidebar-b-hover"}],defaultVariants:{
selected:!1,disabled:!1,active:!1}}),{cx:n}=zS()
;return(r,o)=>(Ub(),Hb(bv(e.is),iy({"aria-selected":e.selected,
type:"button"===e.is?"button":void 0},xm(n)(xm(t)({selected:e.selected,
disabled:e.disabled,active:e.active}))),{
default:ig((()=>[kv(r.$slots,"indent",{},(()=>[Yb(Gre,{class:"-my-2",
disabled:e.disabled,indent:e.indent,selected:e.selected
},null,8,["disabled","indent","selected"])])),e.icon||r.$slots.icon?(Ub(),
Qb("div",Yre,[kv(r.$slots,"icon",{},(()=>[e.icon?(Ub(),Hb(xm(Yne),{key:0,
icon:e.icon
},null,8,["icon"])):ny("",!0)]))])):ny("",!0),Gb("div",Kre,[kv(r.$slots,"default")]),kv(r.$slots,"aside")])),
_:3},16,["aria-selected","type"]))}}),eoe={class:"flex items-center"},toe={
class:"flex-1 min-w-0 flex items-center text-sm text-sidebar-c-2"},noe=Qg({
inheritAttrs:!1,__name:"ScalarSidebarFooter",setup(e){const{cx:t}=zS()
;return(e,n)=>(Ub(),
Qb("div",Mh(Kb(xm(t)("flex flex-col gap-3 p-3 border-t border-sidebar-border"))),[kv(e.$slots,"default"),Gb("div",eoe,[Gb("div",toe,[kv(e.$slots,"description",{},(()=>[n[0]||(n[0]=Gb("a",{
class:"no-underline hover:underline",href:"https://www.scalar.com",
target:"_blank"
}," Powered by Scalar ",-1))]))]),kv(e.$slots,"toggle",{},(()=>[Yb(xm(HG))]))])],16))
}}),roe={class:"sr-only"},ooe=Qg({inheritAttrs:!1,
__name:"ScalarSidebarGroupToggle",props:{is:{default:"div"},open:{type:Boolean,
default:!1},icon:{type:[Object,Function]}},setup(e){const t=jS({
base:"size-4 flex items-center justify-center transition-transform duration-100",
variants:{open:{true:"rotate-90"}},defaultVariants:{open:!1}}),{cx:n}=zS()
;return(r,o)=>(Ub(),Hb(bv(e.is),iy({type:"button"===e.is?"button":void 0
},xm(n)(xm(t)({open:e.open}))),{default:ig((()=>[kv(r.$slots,"default",{
open:e.open},(()=>[e.icon?(Ub(),Hb(xm(Yne),{key:0,icon:e.icon
},null,8,["icon"])):(Ub(),Hb(xm(Q_),{key:1,class:"size-3",weight:"bold"
}))])),Gb("span",roe,[kv(r.$slots,"label",{open:e.open
},(()=>[ey(Uh(e.open?"Close":"Open")+" Group ",1)]))])])),_:3},16,["type"]))}
}),aoe=Symbol(),ioe=(e={})=>{const{increment:t=!1,reset:n=!1}=e,r=ug(aoe,0)
;return cg(aoe,n?0:t&&r<6?r+1:r),{level:r}},soe={
class:"group/group-button relative flex flex-col leading-5"
},loe=["aria-expanded"],coe={key:0,class:"size-4"},uoe={key:0,
class:"group/items flex flex-col gap-px"},doe=Qg({inheritAttrs:!1,
__name:"ScalarSidebarGroup",props:Nv({is:{default:"li"},icon:{
type:[Object,Function]},active:{type:Boolean},selected:{type:Boolean},disabled:{
type:Boolean},indent:{},controlled:{type:Boolean},discrete:{type:Boolean}},{
open:{type:Boolean,default:!1},openModifiers:{}}),
emits:Nv(["click","toggle"],["update:open"]),setup(e,{emit:t}){
const n=t,r=Kv(e,"open"),{level:o}=ioe({increment:!0}),{cx:a}=zS(),i=t=>{
n("click",t),!e.controlled&&!e.discrete&&(r.value=!r.value)},s=t=>{
n("toggle",t),!e.controlled&&e.discrete&&(r.value=!r.value)};return(t,n)=>(Ub(),
Hb(bv(e.is),Mh(Kb(xm(a)("group/item flex flex-col gap-px"))),{
default:ig((()=>[Gb("div",soe,[kv(t.$slots,"before",{open:r.value
}),kv(t.$slots,"button",{level:xm(o),open:r.value
},(()=>[e.discrete?(Ub(),Qb("button",{key:0,type:"button",
"aria-expanded":r.value,
class:Ih(["absolute top-[1lh] -translate-y-1/2 p-0.75 rounded left-[calc(4px+var(--scalar-sidebar-indent)*var(--scalar-sidebar-level))]",e.selected?"text-sidebar-c-1  hover:bg-sidebar-b-1 hover:text-sidebar-c-1":"text-c-3 hover:bg-sidebar-b-hover hover:text-sidebar-c-hover"]),
style:Ah({"--scalar-sidebar-level":xm(o)}),onClick:s},[kv(t.$slots,"icon",{
open:r.value},(()=>[Yb(ooe,{icon:e.icon,open:r.value},{
label:ig((()=>[ey(Uh(r.value?"Close":"Open")+" ",1),kv(t.$slots,"default",{
open:r.value})])),_:3},8,["icon","open"])]))],14,loe)):ny("",!0),Yb(Jre,{
is:"button",active:e.active,"aria-expanded":r.value,disabled:e.disabled,
indent:xm(o),selected:e.selected,onClick:i},xv({indent:ig((()=>[Yb(Gre,{
class:"mr-0 -my-2",indent:xm(o),selected:e.selected
},null,8,["indent","selected"])])),
icon:ig((()=>[e.discrete?(Ub(),Qb("div",coe)):kv(t.$slots,"icon",{key:1,
open:r.value},(()=>[Yb(ooe,{class:"text-c-3",icon:e.icon,open:r.value
},null,8,["icon","open"])]))])),default:ig((()=>[kv(t.$slots,"default",{
open:r.value})])),_:2},[t.$slots.aside?{name:"aside",
fn:ig((()=>[kv(t.$slots,"aside",{open:r.value})])),key:"0"
}:void 0]),1032,["active","aria-expanded","disabled","indent","selected"])])),kv(t.$slots,"after",{
open:r.value})]),r.value?(Ub(),Qb("ul",uoe,[kv(t.$slots,"items",{open:r.value
})])):ny("",!0)])),_:3},16))}}),poe=Qg({inheritAttrs:!1,
__name:"ScalarSidebarItem",props:{is:{},icon:{type:[Object,Function]},active:{
type:Boolean},selected:{type:Boolean},disabled:{type:Boolean},indent:{}},
setup(e){const t=e,{level:n}=ioe(),{cx:r}=zS()
;return(o,a)=>(Ub(),Qb("li",Mh(Kb(xm(r)("group/item flex flex-col"))),[kv(o.$slots,"before"),kv(o.$slots,"button",{
level:xm(n)},(()=>[Yb(Jre,iy(t,{indent:e.indent??xm(n)}),xv({_:2
},[o.$slots.default?{name:"default",fn:ig((()=>[kv(o.$slots,"default")])),
key:"0"}:void 0,o.$slots.icon?{name:"icon",fn:ig((()=>[kv(o.$slots,"icon")])),
key:"1"}:void 0,o.$slots.aside?{name:"aside",
fn:ig((()=>[kv(o.$slots,"aside")])),key:"2"
}:void 0]),1040,["indent"])])),kv(o.$slots,"after")],16))}
}),hoe=Symbol(),foe=Qg({inheritAttrs:!1,__name:"ScalarSidebarItems",props:{is:{
default:"ul"}},setup(e){const{open:t}=(()=>{
const e=bm([]),t=Sy((()=>e.value.some((e=>e.value))));return cg(hoe,e),{open:t}
})(),{cx:n}=zS()
;return(r,o)=>(Ub(),Hb(bv(e.is),Mh(Kb(xm(n)("group/items relative flex flex-col p-3 gap-px transition-transform duration-300",xm(t)?"-translate-x-full":"translate-x-0"))),{
default:ig((()=>[kv(r.$slots,"default")])),_:3},16))}}),moe=Qg({inheritAttrs:!1,
__name:"ScalarSidebarSpacer",props:{indent:{default:0}},setup(e){
const{cx:t}=zS()
;return(n,r)=>(Ub(),Qb("div",Mh(Kb(xm(t)("flex px-2 h-1"))),[Yb(Gre,{
indent:e.indent},null,8,["indent"])],16))}}),goe={
class:"flex-1 text-left leading-none"},voe={key:0,
class:"uppercase text-sidebar-c-2 bg-b-2 leading-none py-1 px-1.25 rounded"
},boe=Qg({inheritAttrs:!1,__name:"ScalarSidebarSearchButton",setup(e){
const{cx:t}=zS();return(e,n)=>(Ub(),Qb("button",iy({role:"search",type:"button"
},xm(t)("flex items-center rounded border text-base h-8 gap-1 pl-2 pr-1","bg-sidebar-b-search border-sidebar-border-search text-sidebar-c-search")),[Yb(xm(ZA),{
class:"size-4"
}),Gb("span",goe,[kv(e.$slots,"default",{},(()=>[n[0]||(n[0]=ey("Search...",-1))]))]),e.$slots.shortcut?(Ub(),
Qb("span",voe,[n[1]||(n[1]=Gb("span",{class:"sr-only"
},"Keyboard Shortcut:",-1)),Gb("kbd",null,[kv(e.$slots,"shortcut")])])):ny("",!0)],16))
}}),yoe={class:"flex flex-col gap-px"},Ooe=Qg({inheritAttrs:!1,
__name:"ScalarSidebarSection",props:{is:{default:"li"},icon:{
type:[Object,Function]},active:{type:Boolean},selected:{type:Boolean},disabled:{
type:Boolean},indent:{}},setup(e){const{level:t}=ioe({increment:!1}),{cx:n}=zS()
;return(r,o)=>(Ub(),
Hb(bv(e.is),Mh(Kb(xm(n)("group/item group/sidebar-section contents"))),{
default:ig((()=>[Yb(moe,{class:"group/spacer-before h-3",indent:xm(t)
},null,8,["indent"]),Yb(Jre,{is:"div",class:"text-sm/5 py-1.75 font-bold",
disabled:"",icon:e.icon,indent:xm(t)},{
default:ig((()=>[kv(r.$slots,"default")])),_:3
},8,["icon","indent"]),Gb("ul",yoe,[kv(r.$slots,"items")]),Yb(moe,{
class:"group/spacer-after h-3",indent:xm(t)},null,8,["indent"])])),_:3},16))}
}),woe=["id"],xoe=Qg({inheritAttrs:!1,__name:"ScalarTeleportRoot",props:{id:{}},
setup(e){const t=(e=>{const t=e??`scalar-teleport-${BX()}`
;return cg(UK,`#${t}`),t})(e.id)
;return(e,n)=>(Ub(),Qb(Mb,null,[kv(e.$slots,"default"),Gb("div",{id:xm(t),
class:"scalar-teleport-root contents"},null,8,woe)],64))}}),koe={
class:"flex flex-1 relative"},Soe={key:0,
class:"select-none whitespace-nowrap text-sm text-transparent"
},_oe=["aria-readonly","readonly"],Toe={key:1,
class:"absolute inset-0 select-none overflow-hidden whitespace-nowrap text-sm"
},Eoe={key:0,class:"text-c-2"},Aoe={class:"text-transparent"},Coe={key:1,
class:"text-c-2"},$oe=Qg({inheritAttrs:!1,__name:"ScalarTextInput",props:Nv({
readonly:{type:Boolean}},{modelValue:{},modelModifiers:{}}),
emits:["update:modelValue"],setup(e){
const t=Kv(e,"modelValue"),n=bm(),{stylingAttrsCx:r,otherAttrs:o}=zS()
;function a(){e.readonly?n.value?.select():n.value?.focus()}return iv((()=>{
"autofocus"in o.value&&n.value?.focus()})),(i,s)=>(Ub(),Hb(xm(R$),iy({is:"div"
},xm(r)("cursor-text text-c-1",e.readonly?"":"focus-within:bg-b-1"),{onClick:a
}),{
default:ig((()=>[Gb("div",koe,[i.$slots.prefix?(Ub(),Qb("span",Soe,[kv(i.$slots,"prefix")])):ny("",!0),sg(Gb("input",iy({
ref_key:"input",ref:n,"onUpdate:modelValue":s[0]||(s[0]=e=>t.value=e),
"aria-readonly":e.readonly||void 0,
class:"z-1 min-w-0 flex-1 border-none bg-transparent text-sm placeholder:font-[inherit] focus-within:outline-none",
readonly:e.readonly
},xm(o)),null,16,_oe),[[MO,t.value]]),i.$slots.prefix||i.$slots.suffix?(Ub(),
Qb("div",Toe,[i.$slots.prefix?(Ub(),
Qb("span",Eoe,[kv(i.$slots,"prefix")])):ny("",!0),Gb("span",Aoe,Uh(t.value||i.$attrs.placeholder),1),i.$slots.suffix?(Ub(),
Qb("span",Coe,[kv(i.$slots,"suffix")])):ny("",!0)])):ny("",!0)]),kv(i.$slots,"aside")])),
_:3},16))}
}),Poe=["--scalar-color-1","--scalar-color-2","--scalar-color-3","--scalar-background-1","--scalar-background-2","--scalar-background-3","--scalar-color-accent"]
;function Doe(e,t){const n=[...t.matchAll(new RegExp(`(${e}): ([^;]+);`,"gm"))]
;return 0===n.length?{}:Object.fromEntries(n.map((e=>[e[1],e[2]])))}
function Ioe(e){return e?{...Doe("--scalar-color-[1-3]",e),
...Doe("--scalar-background-[1-3]",e),...Doe("--scalar-color-accent",e)}:{}}
const Moe=Qg({inheritAttrs:!1,__name:"ScalarThemeSwatches",props:{css:{}},
setup(e){const{colors:t}=function(e){return{colors:Sy((()=>({
light:Ioe(km(e).match(/\.light-mode[^{]*{[^}]*}/m)?.[0]),
dark:Ioe(km(e).match(/\.dark-mode[^{]*{[^}]*}/m)?.[0])})))}
}((()=>e.css)),{cx:n}=zS();return(e,r)=>(Ub(),Qb("div",iy({style:{
"--bg-light":xm(t).light["--scalar-background-1"],
"--bg-dark":xm(t).dark["--scalar-background-1"]}
},xm(n)("flex *:size-3 overflow-hidden rounded","bg-(--bg-light) dark:bg-(--bg-dark)")),[(Ub(!0),
Qb(Mb,null,wv(xm(Poe),(e=>(Ub(),Qb("div",{key:e,
class:"bg-(--bg-light) dark:bg-(--bg-dark)",style:Ah({
"--bg-light":xm(t).light[e],"--bg-dark":xm(t).dark[e]})},null,4)))),128))],16))}
}),Noe=["aria-checked","aria-disabled"],Roe={key:0,class:"sr-only"},Loe=Qg({
__name:"ScalarToggle",props:Nv({disabled:{type:Boolean},label:{}},{modelValue:{
type:Boolean,default:!1},modelModifiers:{}}),emits:["update:modelValue"],
setup(e){const t=e,n=Kv(e,"modelValue");function r(){
t.disabled||(n.value=!n.value)}const o=jS({
base:"relative h-3.5 min-w-6 w-6 cursor-pointer rounded-full bg-b-3 transition-colors duration-300",
variants:{checked:{true:"bg-c-accent"},disabled:{
true:"cursor-not-allowed opacity-40"}}});return(t,a)=>(Ub(),Qb("button",{
"aria-checked":n.value,"aria-disabled":e.disabled,class:Ih(xm(US)(xm(o)({
checked:n.value,disabled:e.disabled}))),role:"switch",type:"button",onClick:r
},[Gb("div",{
class:Ih(["absolute left-px top-px flex h-3 w-3 items-center justify-center rounded-full bg-b-1 text-c-accent transition-transform duration-300",{
"translate-x-2.5":n.value}])
},null,2),e.label?(Ub(),Qb("span",Roe,Uh(e.label),1)):ny("",!0)],10,Noe))}
}),Boe={class:"flex-1 text-left min-w-0 truncate"},joe=Qg({inheritAttrs:!1,
__name:"ScalarToggleInput",props:{modelValue:{type:Boolean},modelModifiers:{}},
emits:["update:modelValue"],setup(e){
const t=Kv(e,"modelValue"),{stylingAttrsCx:n,otherAttrs:r}=zS()
;return(e,o)=>(Ub(),Hb(xm(R$),iy({is:"label"
},xm(n)("cursor-pointer gap-2 hover:bg-b-2",{"text-c-1":t.value})),{
default:ig((()=>[Gb("div",Boe,[kv(e.$slots,"default")]),Yb(Loe,iy({
modelValue:t.value,"onUpdate:modelValue":o[0]||(o[0]=e=>t.value=e),
class:"shrink-0"},xm(r)),null,16,["modelValue"])])),_:3},16))}}),Uoe=Qg({
__name:"ScalarTooltip",props:{content:{default:""},delay:{default:()=>300},
placement:{default:"top"},offset:{default:()=>4}},setup(e){const t=bm(null)
;return sre({content:Sy((()=>e.content)),delay:Sy((()=>e.delay)),
placement:Sy((()=>e.placement)),offset:Sy((()=>e.offset)),
targetRef:Sy((()=>t.value?.children?.[0]||t.value||void 0))
}),(e,n)=>(Ub(),Qb("div",{ref_key:"wrapperRef",ref:t,class:Ih({
contents:!!e.$slots.default})},[kv(e.$slots,"default")],2))}}),zoe=Qg({
__name:"ScalarVirtualText",props:{text:{},lineHeight:{default:20},
containerClass:{default:""},contentClass:{default:""},lineClass:{default:""}},
setup(e){
const t=e,n=bm(null),r=bm(null),o=bm(0),a=bm(0),i=Sy((()=>t.text.split("\n"))),s=Sy((()=>i.value.length*t.lineHeight)),l=Sy((()=>Math.floor(o.value/t.lineHeight))),c=Sy((()=>Math.min(Math.ceil((o.value+a.value)/t.lineHeight),i.value.length))),u=Sy((()=>{
const e=Math.max(0,l.value-10),t=Math.min(i.value.length,c.value+10)
;return i.value.slice(e,t)})),d=Sy((()=>({height:`${s.value}px`,
transform:`translateY(${Math.max(0,l.value-10)*t.lineHeight}px)`
}))),p=()=>n.value&&(o.value=n.value.scrollTop),h=()=>n.value&&(a.value=n.value.clientHeight)
;return iv((()=>{h(),window.addEventListener("resize",h)})),cv((()=>{
window.removeEventListener("resize",h)})),fg((()=>{
r.value&&(r.value.style.transform=`translateY(${Math.max(0,l.value-10)*t.lineHeight}px)`)
})),(o,a)=>(Ub(),Qb("div",{ref_key:"containerRef",ref:n,
class:Ih(["scalar-virtual-text overflow-auto",e.containerClass]),onScroll:p
},[Gb("code",{ref_key:"contentRef",ref:r,
class:Ih(["scalar-virtual-text-content",e.contentClass]),style:Ah(d.value)
},[(Ub(!0),Qb(Mb,null,wv(u.value,((n,r)=>(Ub(),Qb("div",{key:l.value+r,
class:Ih(["scalar-virtual-text-line",e.lineClass]),style:Ah({
height:`${t.lineHeight}px`,lineHeight:`${t.lineHeight}px`})
},Uh(n),7)))),128))],6)],34))}}),Foe={path:/[\/\.-]/,property:/[A-Z\_\.-]/
},Zoe=Qg({inheritAttrs:!1,__name:"ScalarWrappingText",props:{text:{default:""},
preset:{default:"path"},regex:{}},setup(e){const t=Sy((()=>{
const t=new RegExp(e.regex??Foe[e.preset],"g")
;return e.text.replace(t,"⁠$&").split("⁠").filter(Boolean)}))
;return(e,n)=>(Ub(!0),Qb(Mb,null,wv(t.value,((e,t)=>(Ub(),Qb(Mb,{key:t
},[n[0]||(n[0]=Gb("wbr",null,null,-1)),ey(Uh(e),1)],64)))),128))}}),Qoe=Qg({
__name:"ScalarDropdownItem",props:{id:{default:()=>Hg()},disabled:{type:Boolean}
},emits:["click"],setup(e){const{active:t}=function(){const e=ug(p2)
;return e||console.warn("useDropdownItem must be used within a ScalarDropdown"),
{active:e}}();return(n,r)=>(Ub(),Hb(kre,{id:e.id,active:xm(t)===e.id,
disabled:e.disabled,role:"menuitem",tabindex:"-1",
onClick:r[0]||(r[0]=e=>n.$emit("click",e)),
onMouseenter:r[1]||(r[1]=n=>t.value=e.id)},{
default:ig((()=>[kv(n.$slots,"default",{},void 0,!0)])),_:3
},8,["id","active","disabled"]))}
}),Hoe=HS(Qoe,[["__scopeId","data-v-3402682d"]]),Voe={
class:"flex min-w-0 flex-col gap-3"},qoe={class:"contents"},Woe={
class:"text-base font-medium text-c-1"}
;const Xoe=HS({},[["render",function(e,t,n,r,o,a){
return Ub(),Qb("fieldset",Voe,[Gb("legend",qoe,[Gb("span",Woe,[kv(e.$slots,"label")])]),kv(e.$slots,"default")])
}]]);function Goe(){return am({isValid:!1,isInvalid:!1,isLoading:!1,isActive:!1,
start(){this.isLoading=!0,this.isActive=!0,this.isInvalid=!1,this.isValid=!1},
validate(e={}){const{duration:t=1100,persist:n=!1}=e
;this.isLoading=!1,this.isInvalid=!1,this.isValid=!0,this.isActive=!0
;const r=n?t:t-300
;return new Promise((e=>setTimeout(n?()=>e():()=>this.clear().then((()=>e())),r)))
},invalidate(e={}){const{duration:t=1100,persist:n=!1}=e??{}
;this.isLoading=!1,this.isValid=!1,this.isInvalid=!0,this.isActive=!0
;const r=n?t:t-300
;return new Promise((e=>setTimeout(n?()=>e():()=>this.clear().then((()=>e())),r)))
},clear(e={}){const{duration:t=300}=e
;return this.isValid=!1,this.isInvalid=!1,this.isLoading=!1,new Promise((e=>{
setTimeout((()=>{this.isActive=!1,e()}),t)}))}})}const Yoe={key:0,
class:"close-button z-10 fixed right-2 top-2"};function Koe(){return am({
open:!1,show(){this.open=!0},hide(){this.open=!1}})}const Joe=Qg({
__name:"ScalarModal",props:{state:{},title:{},bodyClass:{},maxWidth:{},size:{
default:"md"},variant:{}},emits:["close"],setup(e,{emit:t}){const n=t,r=jS({
base:["scalar-modal","flex flex-col relative mb-0 rounded-lg bg-b-1 p-0 text-left leading-snug text-c-1 opacity-0 w-[calc(100vw-12px)] md:w-[calc(100vw-16px)] lg:w-[calc(100vw-32px)]"].join(" "),
variants:{size:{xxs:"mt-[20svh] max-h-[60svh] max-w-[360px]",
xs:"mt-[20svh] max-h-[60svh] max-w-[480px]",
sm:"mt-[20svh] max-h-[60svh] max-w-[540px]",
md:"mt-[20svh] max-h-[60svh] max-w-[640px]",
lg:"m-auto max-h-[80svh] max-w-[800px]",
xl:"m-auto max-h-[90svh] max-w-[1000px]",
full:"full-size-styles max-h-dvh mt-0 lg:w-full"},variant:{
form:"scalar-modal-form",
search:"scalar-modal-search mt-[15svh] max-h-[60svh] max-w-[540px]",
error:"scalar-modal-error"}}}),o=jS({
base:["scalar-modal-body","relative flex-1 min-h-0 p-3"].join(" "),variants:{
variant:{form:"overflow-visible",
search:"flex flex-col !m-0 overflow-hidden p-0",error:"overflow-y-scroll"},
size:{xxs:"",xs:"",sm:"",md:"",lg:"",xl:"m-0 p-0",full:" rounded-none"}}})
;return(t,a)=>(Ub(),Hb(xm(Ux),{open:e.state.open,onClose:a[1]||(a[1]=()=>{
e.state.hide(),n("close")})},{default:ig((()=>[Gb("div",{
class:Ih(xm(US)("full"===e.size?"scalar-modal-layout-full":"scalar-modal-layout","fixed left-0 top-0 flex items-start justify-center","z-overlay h-dvh w-dvw","bg-backdrop opacity-0 dark:bg-backdrop-dark","full"===e.size&&"flex"))
},[Yb(xm(zx),{class:Ih(xm(r)({size:e.size,variant:e.variant})),style:Ah({
maxWidth:e.maxWidth})},{default:ig((()=>[e.title?(Ub(),Hb(xm(Fx),{key:0,
class:"scalar-modal-header m-0 -mb-1 rounded-lg pt-3 px-3 text-left text-sm font-medium text-c-1"
},{default:ig((()=>[ey(Uh(e.title),1)])),_:1})):ny("",!0),"full"===e.size?(Ub(),
Qb("div",{key:1,class:Ih(e.bodyClass)
},[kv(t.$slots,"default",{},void 0,!0)],2)):(Ub(),Qb("div",{key:2,
class:Ih(xm(US)(xm(o)({size:e.size,variant:e.variant}),e.bodyClass))
},[kv(t.$slots,"default",{},void 0,!0)],2))])),_:3
},8,["class","style"]),"full"===e.size?(Ub(),Qb("div",Yoe,[Yb(xm(ure),{
class:"hover:bg-b-3 focus:outline-none",icon:xm(I$),label:"Close modal",
onClick:a[0]||(a[0]=t=>e.state.hide())},null,8,["icon"])])):ny("",!0)],2)])),_:3
},8,["open"]))}
}),eae=HS(Joe,[["__scopeId","data-v-c36b47da"]]),tae="scalar-app",nae="headlessui-portal-root",rae=e=>{
!e||e.classList.contains(tae)||e.classList.add(tae)},oae=()=>{
rae(document.getElementById(nae))
;const e=new MutationObserver((e=>e.forEach((({addedNodes:e})=>e.forEach((e=>{
(e=>null!==e&&e instanceof HTMLElement)(e)&&e.id===nae&&rae(e)}))))))
;return e.observe(document.body,{childList:!0}),e},aae=["href"],iae=Qg({
__name:"OpenApiClientButton",props:{buttonSource:{},source:{
default:"api-reference"},isDevelopment:{type:Boolean},integration:{},url:{}},
setup(e){const t=Sy((()=>{
const t=e.url??(typeof window<"u"?window.location.href:void 0);if(!t)return
;const n=HH(t);if(!n?.length)return
;const r=new URL(e.isDevelopment?"http://localhost:5065":"https://client.scalar.com")
;if(r.searchParams.set("url",n),
null!==e.integration&&r.searchParams.set("integration",e.integration??"vue"),
r.searchParams.set("utm_source","api-reference"),
r.searchParams.set("utm_medium","button"),
r.searchParams.set("utm_campaign",e.buttonSource),"gitbook"===e.source){
r.searchParams.set("utm_source","gitbook")
;const e=document.querySelector("img.dark\\:block[alt='Logo']"),t=document.querySelector("img.dark\\:hidden[alt='Logo']")
;e&&e instanceof HTMLImageElement&&r.searchParams.set("dark_logo",encodeURIComponent(e.src)),
t&&t instanceof HTMLImageElement&&r.searchParams.set("light_logo",encodeURIComponent(t.src))
}return r.toString()}));return(e,n)=>t.value?(Ub(),Qb("a",{key:0,
class:"open-api-client-button",href:t.value,target:"_blank"},[Yb(xm(Gne),{
icon:"ExternalLink",size:"xs",thickness:"2.5"
}),n[0]||(n[0]=ey(" Open API Client ",-1))],8,aae)):ny("",!0)}}),sae=(e,t)=>{
const n=e.__vccOpts||e;for(const[r,o]of t)n[r]=o;return n
},lae=sae(iae,[["__scopeId","data-v-f016469d"]]);let cae=[],uae=[]
;function dae(e){if(e<768)return!1;for(let t=0,n=cae.length;;){let r=t+n>>1
;if(e<cae[r])n=r;else{if(!(e>=uae[r]))return!0;t=r+1}if(t==n)return!1}}
function pae(e){return e>=127462&&e<=127487}(()=>{
let e="lc,34,7n,7,7b,19,,,,2,,2,,,20,b,1c,l,g,,2t,7,2,6,2,2,,4,z,,u,r,2j,b,1m,9,9,,o,4,,9,,3,,5,17,3,3b,f,,w,1j,,,,4,8,4,,3,7,a,2,t,,1m,,,,2,4,8,,9,,a,2,q,,2,2,1l,,4,2,4,2,2,3,3,,u,2,3,,b,2,1l,,4,5,,2,4,,k,2,m,6,,,1m,,,2,,4,8,,7,3,a,2,u,,1n,,,,c,,9,,14,,3,,1l,3,5,3,,4,7,2,b,2,t,,1m,,2,,2,,3,,5,2,7,2,b,2,s,2,1l,2,,,2,4,8,,9,,a,2,t,,20,,4,,2,3,,,8,,29,,2,7,c,8,2q,,2,9,b,6,22,2,r,,,,,,1j,e,,5,,2,5,b,,10,9,,2u,4,,6,,2,2,2,p,2,4,3,g,4,d,,2,2,6,,f,,jj,3,qa,3,t,3,t,2,u,2,1s,2,,7,8,,2,b,9,,19,3,3b,2,y,,3a,3,4,2,9,,6,3,63,2,2,,1m,,,7,,,,,2,8,6,a,2,,1c,h,1r,4,1c,7,,,5,,14,9,c,2,w,4,2,2,,3,1k,,,2,3,,,3,1m,8,2,2,48,3,,d,,7,4,,6,,3,2,5i,1m,,5,ek,,5f,x,2da,3,3x,,2o,w,fe,6,2x,2,n9w,4,,a,w,2,28,2,7k,,3,,4,,p,2,5,,47,2,q,i,d,,12,8,p,b,1a,3,1c,,2,4,2,2,13,,1v,6,2,2,2,2,c,,8,,1b,,1f,,,3,2,2,5,2,,,16,2,8,,6m,,2,,4,,fn4,,kh,g,g,g,a6,2,gt,,6a,,45,5,1ae,3,,2,5,4,14,3,4,,4l,2,fx,4,ar,2,49,b,4w,,1i,f,1k,3,1d,4,2,2,1x,3,10,5,,8,1q,,c,2,1g,9,a,4,2,,2n,3,2,,,2,6,,4g,,3,8,l,2,1l,2,,,,,m,,e,7,3,5,5f,8,2,3,,,n,,29,,2,6,,,2,,,2,,2,6j,,2,4,6,2,,2,r,2,2d,8,2,,,2,2y,,,,2,6,,,2t,3,2,4,,5,77,9,,2,6t,,a,2,,,4,,40,4,2,2,4,,w,a,14,6,2,4,8,,9,6,2,3,1a,d,,2,ba,7,,6,,,2a,m,2,7,,2,,2,3e,6,3,,,2,,7,,,20,2,3,,,,9n,2,f0b,5,1n,7,t4,,1r,4,29,,f5k,2,43q,,,3,4,5,8,8,2,7,u,4,44,3,1iz,1j,4,1e,8,,e,,m,5,,f,11s,7,,h,2,7,,2,,5,79,7,c5,4,15s,7,31,7,240,5,gx7k,2o,3k,6o".split(",").map((e=>e?parseInt(e,36):1))
;for(let t=0,n=0;t<e.length;t++)(t%2?uae:cae).push(n+=e[t])})();const hae=8205
;function fae(e,t,n=!0,r=!0){return(n?mae:gae)(e,t,r)}function mae(e,t,n){
if(t==e.length)return t;t&&bae(e.charCodeAt(t))&&yae(e.charCodeAt(t-1))&&t--
;let r=vae(e,t);for(t+=Oae(r);t<e.length;){let o=vae(e,t)
;if(r==hae||o==hae||n&&dae(o))t+=Oae(o),r=o;else{if(!pae(o))break;{let n=0,r=t-2
;for(;r>=0&&pae(vae(e,r));)n++,r-=2;if(n%2==0)break;t+=2}}}return t}
function gae(e,t,n){for(;t>0;){let r=mae(e,t-2,n);if(r<t)return r;t--}return 0}
function vae(e,t){let n=e.charCodeAt(t);if(!yae(n)||t+1==e.length)return n
;let r=e.charCodeAt(t+1);return bae(r)?r-56320+(n-55296<<10)+65536:n}
function bae(e){return e>=56320&&e<57344}function yae(e){
return e>=55296&&e<56320}function Oae(e){return e<65536?1:2}class wae{lineAt(e){
if(e<0||e>this.length)throw new RangeError(`Invalid position ${e} in document of length ${this.length}`)
;return this.lineInner(e,!1,1,0)}line(e){
if(e<1||e>this.lines)throw new RangeError(`Invalid line number ${e} in ${this.lines}-line document`)
;return this.lineInner(e,!0,1,0)}replace(e,t,n){[e,t]=$ae(this,e,t);let r=[]
;return this.decompose(0,e,r,2),
n.length&&n.decompose(0,n.length,r,3),this.decompose(t,this.length,r,1),
kae.from(r,this.length-(t-e)+n.length)}append(e){
return this.replace(this.length,this.length,e)}slice(e,t=this.length){
[e,t]=$ae(this,e,t);let n=[];return this.decompose(e,t,n,0),kae.from(n,t-e)}
eq(e){if(e==this)return!0;if(e.length!=this.length||e.lines!=this.lines)return!1
;let t=this.scanIdentical(e,1),n=this.length-this.scanIdentical(e,-1),r=new Tae(this),o=new Tae(e)
;for(let a=t,i=t;;){
if(r.next(a),o.next(a),a=0,r.lineBreak!=o.lineBreak||r.done!=o.done||r.value!=o.value)return!1
;if(i+=r.value.length,r.done||i>=n)return!0}}iter(e=1){return new Tae(this,e)}
iterRange(e,t=this.length){return new Eae(this,e,t)}iterLines(e,t){let n
;if(null==e)n=this.iter();else{null==t&&(t=this.lines+1);let r=this.line(e).from
;n=this.iterRange(r,Math.max(r,t==this.lines+1?this.length:t<=1?0:this.line(t-1).to))
}return new Aae(n)}toString(){return this.sliceString(0)}toJSON(){let e=[]
;return this.flatten(e),e}constructor(){}static of(e){
if(0==e.length)throw new RangeError("A document must have at least one line")
;return 1!=e.length||e[0]?e.length<=32?new xae(e):kae.from(xae.split(e,[])):wae.empty
}}class xae extends wae{constructor(e,t=function(e){let t=-1
;for(let n of e)t+=n.length+1;return t}(e)){super(),this.text=e,this.length=t}
get lines(){return this.text.length}get children(){return null}
lineInner(e,t,n,r){for(let o=0;;o++){let a=this.text[o],i=r+a.length
;if((t?n:i)>=e)return new Cae(r,i,n,a);r=i+1,n++}}decompose(e,t,n,r){
let o=e<=0&&t>=this.length?this:new xae(_ae(this.text,e,t),Math.min(t,this.length)-Math.max(0,e))
;if(1&r){let e=n.pop(),t=Sae(o.text,e.text.slice(),0,o.length)
;if(t.length<=32)n.push(new xae(t,e.length+o.length));else{let e=t.length>>1
;n.push(new xae(t.slice(0,e)),new xae(t.slice(e)))}}else n.push(o)}
replace(e,t,n){if(!(n instanceof xae))return super.replace(e,t,n)
;[e,t]=$ae(this,e,t)
;let r=Sae(this.text,Sae(n.text,_ae(this.text,0,e)),t),o=this.length+n.length-(t-e)
;return r.length<=32?new xae(r,o):kae.from(xae.split(r,[]),o)}
sliceString(e,t=this.length,n="\n"){[e,t]=$ae(this,e,t);let r=""
;for(let o=0,a=0;o<=t&&a<this.text.length;a++){let i=this.text[a],s=o+i.length
;o>e&&a&&(r+=n),e<s&&t>o&&(r+=i.slice(Math.max(0,e-o),t-o)),o=s+1}return r}
flatten(e){for(let t of this.text)e.push(t)}scanIdentical(){return 0}
static split(e,t){let n=[],r=-1
;for(let o of e)n.push(o),r+=o.length+1,32==n.length&&(t.push(new xae(n,r)),
n=[],r=-1);return r>-1&&t.push(new xae(n,r)),t}}class kae extends wae{
constructor(e,t){super(),this.children=e,this.length=t,this.lines=0
;for(let n of e)this.lines+=n.lines}lineInner(e,t,n,r){for(let o=0;;o++){
let a=this.children[o],i=r+a.length,s=n+a.lines-1
;if((t?s:i)>=e)return a.lineInner(e,t,n,r);r=i+1,n=s+1}}decompose(e,t,n,r){
for(let o=0,a=0;a<=t&&o<this.children.length;o++){
let i=this.children[o],s=a+i.length;if(e<=s&&t>=a){
let o=r&((a<=e?1:0)|(s>=t?2:0))
;a>=e&&s<=t&&!o?n.push(i):i.decompose(e-a,t-a,n,o)}a=s+1}}replace(e,t,n){
if([e,t]=$ae(this,e,t),
n.lines<this.lines)for(let r=0,o=0;r<this.children.length;r++){
let a=this.children[r],i=o+a.length;if(e>=o&&t<=i){
let s=a.replace(e-o,t-o,n),l=this.lines-a.lines+s.lines
;if(s.lines<l>>4&&s.lines>l>>6){let o=this.children.slice()
;return o[r]=s,new kae(o,this.length-(t-e)+n.length)}return super.replace(o,i,s)
}o=i+1}return super.replace(e,t,n)}sliceString(e,t=this.length,n="\n"){
[e,t]=$ae(this,e,t);let r="";for(let o=0,a=0;o<this.children.length&&a<=t;o++){
let i=this.children[o],s=a+i.length
;a>e&&o&&(r+=n),e<s&&t>a&&(r+=i.sliceString(e-a,t-a,n)),a=s+1}return r}
flatten(e){for(let t of this.children)t.flatten(e)}scanIdentical(e,t){
if(!(e instanceof kae))return 0
;let n=0,[r,o,a,i]=t>0?[0,0,this.children.length,e.children.length]:[this.children.length-1,e.children.length-1,-1,-1]
;for(;;r+=t,o+=t){if(r==a||o==i)return n;let s=this.children[r],l=e.children[o]
;if(s!=l)return n+s.scanIdentical(l,t);n+=s.length+1}}
static from(e,t=e.reduce(((e,t)=>e+t.length+1),-1)){let n=0
;for(let p of e)n+=p.lines;if(n<32){let n=[];for(let t of e)t.flatten(n)
;return new xae(n,t)}let r=Math.max(32,n>>5),o=r<<1,a=r>>1,i=[],s=0,l=-1,c=[]
;function u(e){let t
;if(e.lines>o&&e instanceof kae)for(let n of e.children)u(n);else e.lines>a&&(s>a||!s)?(d(),
i.push(e)):e instanceof xae&&s&&(t=c[c.length-1])instanceof xae&&e.lines+t.lines<=32?(s+=e.lines,
l+=e.length+1,
c[c.length-1]=new xae(t.text.concat(e.text),t.length+1+e.length)):(s+e.lines>r&&d(),
s+=e.lines,l+=e.length+1,c.push(e))}function d(){
0!=s&&(i.push(1==c.length?c[0]:kae.from(c,l)),l=-1,s=c.length=0)}
for(let p of e)u(p);return d(),1==i.length?i[0]:new kae(i,t)}}
function Sae(e,t,n=0,r=1e9){for(let o=0,a=0,i=!0;a<e.length&&o<=r;a++){
let s=e[a],l=o+s.length
;l>=n&&(l>r&&(s=s.slice(0,r-o)),o<n&&(s=s.slice(n-o)),i?(t[t.length-1]+=s,
i=!1):t.push(s)),o=l+1}return t}function _ae(e,t,n){return Sae(e,[""],t,n)}
wae.empty=new xae([""],0);class Tae{constructor(e,t=1){
this.dir=t,this.done=!1,this.lineBreak=!1,
this.value="",this.nodes=[e],this.offsets=[t>0?1:(e instanceof xae?e.text.length:e.children.length)<<1]
}nextInner(e,t){for(this.done=this.lineBreak=!1;;){
let n=this.nodes.length-1,r=this.nodes[n],o=this.offsets[n],a=o>>1,i=r instanceof xae?r.text.length:r.children.length
;if(a==(t>0?i:0)){if(0==n)return this.done=!0,this.value="",this
;t>0&&this.offsets[n-1]++,this.nodes.pop(),this.offsets.pop()
}else if((1&o)==(t>0?0:1)){
if(this.offsets[n]+=t,0==e)return this.lineBreak=!0,this.value="\n",this;e--
}else if(r instanceof xae){let o=r.text[a+(t<0?-1:0)]
;if(this.offsets[n]+=t,o.length>Math.max(0,e))return this.value=0==e?o:t>0?o.slice(e):o.slice(0,o.length-e),
this;e-=o.length}else{let o=r.children[a+(t<0?-1:0)]
;e>o.length?(e-=o.length,this.offsets[n]+=t):(t<0&&this.offsets[n]--,
this.nodes.push(o),
this.offsets.push(t>0?1:(o instanceof xae?o.text.length:o.children.length)<<1))}
}}next(e=0){
return e<0&&(this.nextInner(-e,-this.dir),e=this.value.length),this.nextInner(e,this.dir)
}}class Eae{constructor(e,t,n){
this.value="",this.done=!1,this.cursor=new Tae(e,t>n?-1:1),
this.pos=t>n?e.length:0,this.from=Math.min(t,n),this.to=Math.max(t,n)}
nextInner(e,t){
if(t<0?this.pos<=this.from:this.pos>=this.to)return this.value="",
this.done=!0,this;e+=Math.max(0,t<0?this.pos-this.to:this.from-this.pos)
;let n=t<0?this.pos-this.from:this.to-this.pos;e>n&&(e=n),n-=e
;let{value:r}=this.cursor.next(e)
;return this.pos+=(r.length+e)*t,this.value=r.length<=n?r:t<0?r.slice(r.length-n):r.slice(0,n),
this.done=!this.value,this}next(e=0){
return e<0?e=Math.max(e,this.from-this.pos):e>0&&(e=Math.min(e,this.to-this.pos)),
this.nextInner(e,this.cursor.dir)}get lineBreak(){
return this.cursor.lineBreak&&""!=this.value}}class Aae{constructor(e){
this.inner=e,this.afterBreak=!0,this.value="",this.done=!1}next(e=0){
let{done:t,lineBreak:n,value:r}=this.inner.next(e)
;return t&&this.afterBreak?(this.value="",
this.afterBreak=!1):t?(this.done=!0,this.value=""):n?this.afterBreak?this.value="":(this.afterBreak=!0,
this.next()):(this.value=r,this.afterBreak=!1),this}get lineBreak(){return!1}}
"undefined"!=typeof Symbol&&(wae.prototype[Symbol.iterator]=function(){
return this.iter()
},Tae.prototype[Symbol.iterator]=Eae.prototype[Symbol.iterator]=Aae.prototype[Symbol.iterator]=function(){
return this});class Cae{constructor(e,t,n,r){
this.from=e,this.to=t,this.number=n,this.text=r}get length(){
return this.to-this.from}}function $ae(e,t,n){
return[t=Math.max(0,Math.min(e.length,t)),Math.max(t,Math.min(e.length,n))]}
function Pae(e,t,n=!0,r=!0){return fae(e,t,n,r)}function Dae(e,t){
let n=e.charCodeAt(t);if(!(r=n,r>=55296&&r<56320&&t+1!=e.length))return n;var r
;let o=e.charCodeAt(t+1);return function(e){return e>=56320&&e<57344
}(o)?o-56320+(n-55296<<10)+65536:n}function Iae(e){
return e<=65535?String.fromCharCode(e):(e-=65536,
String.fromCharCode(55296+(e>>10),56320+(1023&e)))}function Mae(e){
return e<65536?1:2}const Nae=/\r\n?|\n/;var Rae=function(e){
return e[e.Simple=0]="Simple",
e[e.TrackDel=1]="TrackDel",e[e.TrackBefore=2]="TrackBefore",
e[e.TrackAfter=3]="TrackAfter",e}(Rae||(Rae={}));class Lae{constructor(e){
this.sections=e}get length(){let e=0
;for(let t=0;t<this.sections.length;t+=2)e+=this.sections[t];return e}
get newLength(){let e=0;for(let t=0;t<this.sections.length;t+=2){
let n=this.sections[t+1];e+=n<0?this.sections[t]:n}return e}get empty(){
return 0==this.sections.length||2==this.sections.length&&this.sections[1]<0}
iterGaps(e){for(let t=0,n=0,r=0;t<this.sections.length;){
let o=this.sections[t++],a=this.sections[t++];a<0?(e(n,r,o),r+=o):r+=a,n+=o}}
iterChangedRanges(e,t=!1){zae(this,e,t)}get invertedDesc(){let e=[]
;for(let t=0;t<this.sections.length;){
let n=this.sections[t++],r=this.sections[t++];r<0?e.push(n,r):e.push(r,n)}
return new Lae(e)}composeDesc(e){return this.empty?e:e.empty?this:Zae(this,e)}
mapDesc(e,t=!1){return e.empty?this:Fae(this,e,t)}mapPos(e,t=-1,n=Rae.Simple){
let r=0,o=0;for(let a=0;a<this.sections.length;){
let i=this.sections[a++],s=this.sections[a++],l=r+i;if(s<0){
if(l>e)return o+(e-r);o+=i}else{
if(n!=Rae.Simple&&l>=e&&(n==Rae.TrackDel&&r<e&&l>e||n==Rae.TrackBefore&&r<e||n==Rae.TrackAfter&&l>e))return null
;if(l>e||l==e&&t<0&&!i)return e==r||t<0?o:o+s;o+=s}r=l}
if(e>r)throw new RangeError(`Position ${e} is out of range for changeset of length ${r}`)
;return o}touchesRange(e,t=e){for(let n=0,r=0;n<this.sections.length&&r<=t;){
let o=r+this.sections[n++]
;if(this.sections[n++]>=0&&r<=t&&o>=e)return!(r<e&&o>t)||"cover";r=o}return!1}
toString(){let e="";for(let t=0;t<this.sections.length;){
let n=this.sections[t++],r=this.sections[t++];e+=(e?" ":"")+n+(r>=0?":"+r:"")}
return e}toJSON(){return this.sections}static fromJSON(e){
if(!Array.isArray(e)||e.length%2||e.some((e=>"number"!=typeof e)))throw new RangeError("Invalid JSON representation of ChangeDesc")
;return new Lae(e)}static create(e){return new Lae(e)}}class Bae extends Lae{
constructor(e,t){super(e),this.inserted=t}apply(e){
if(this.length!=e.length)throw new RangeError("Applying change set to a document with the wrong length")
;return zae(this,((t,n,r,o,a)=>e=e.replace(r,r+(n-t),a)),!1),e}mapDesc(e,t=!1){
return Fae(this,e,t,!0)}invert(e){let t=this.sections.slice(),n=[]
;for(let r=0,o=0;r<t.length;r+=2){let a=t[r],i=t[r+1];if(i>=0){t[r]=i,t[r+1]=a
;let s=r>>1;for(;n.length<s;)n.push(wae.empty)
;n.push(a?e.slice(o,o+a):wae.empty)}o+=a}return new Bae(t,n)}compose(e){
return this.empty?e:e.empty?this:Zae(this,e,!0)}map(e,t=!1){
return e.empty?this:Fae(this,e,t,!0)}iterChanges(e,t=!1){zae(this,e,t)}
get desc(){return Lae.create(this.sections)}filter(e){
let t=[],n=[],r=[],o=new Qae(this);e:for(let a=0,i=0;;){
let s=a==e.length?1e9:e[a++];for(;i<s||i==s&&0==o.len;){if(o.done)break e
;let e=Math.min(o.len,s-i);jae(r,e,-1);let a=-1==o.ins?-1:0==o.off?o.ins:0
;jae(t,e,a),a>0&&Uae(n,t,o.text),o.forward(e),i+=e}let l=e[a++];for(;i<l;){
if(o.done)break e;let e=Math.min(o.len,l-i)
;jae(t,e,-1),jae(r,e,-1==o.ins?-1:0==o.off?o.ins:0),o.forward(e),i+=e}}return{
changes:new Bae(t,n),filtered:Lae.create(r)}}toJSON(){let e=[]
;for(let t=0;t<this.sections.length;t+=2){
let n=this.sections[t],r=this.sections[t+1]
;r<0?e.push(n):0==r?e.push([n]):e.push([n].concat(this.inserted[t>>1].toJSON()))
}return e}static of(e,t,n){let r=[],o=[],a=0,i=null;function s(e=!1){
if(!e&&!r.length)return;a<t&&jae(r,t-a,-1);let n=new Bae(r,o)
;i=i?i.compose(n.map(i)):n,r=[],o=[],a=0}return function e(l){
if(Array.isArray(l))for(let t of l)e(t);else if(l instanceof Bae){
if(l.length!=t)throw new RangeError(`Mismatched change set length (got ${l.length}, expected ${t})`)
;s(),i=i?i.compose(l.map(i)):l}else{let{from:e,to:i=e,insert:c}=l
;if(e>i||e<0||i>t)throw new RangeError(`Invalid change range ${e} to ${i} (in doc of length ${t})`)
;let u=c?"string"==typeof c?wae.of(c.split(n||Nae)):c:wae.empty,d=u.length
;if(e==i&&0==d)return;e<a&&s(),e>a&&jae(r,e-a,-1),jae(r,i-e,d),Uae(o,r,u),a=i}
}(e),s(!i),i}static empty(e){return new Bae(e?[e,-1]:[],[])}static fromJSON(e){
if(!Array.isArray(e))throw new RangeError("Invalid JSON representation of ChangeSet")
;let t=[],n=[];for(let r=0;r<e.length;r++){let o=e[r]
;if("number"==typeof o)t.push(o,-1);else{
if(!Array.isArray(o)||"number"!=typeof o[0]||o.some(((e,t)=>t&&"string"!=typeof e)))throw new RangeError("Invalid JSON representation of ChangeSet")
;if(1==o.length)t.push(o[0],0);else{for(;n.length<r;)n.push(wae.empty)
;n[r]=wae.of(o.slice(1)),t.push(o[0],n[r].length)}}}return new Bae(t,n)}
static createSet(e,t){return new Bae(e,t)}}function jae(e,t,n,r=!1){
if(0==t&&n<=0)return;let o=e.length-2
;o>=0&&n<=0&&n==e[o+1]?e[o]+=t:o>=0&&0==t&&0==e[o]?e[o+1]+=n:r?(e[o]+=t,
e[o+1]+=n):e.push(t,n)}function Uae(e,t,n){if(0==n.length)return
;let r=t.length-2>>1;if(r<e.length)e[e.length-1]=e[e.length-1].append(n);else{
for(;e.length<r;)e.push(wae.empty);e.push(n)}}function zae(e,t,n){
let r=e.inserted;for(let o=0,a=0,i=0;i<e.sections.length;){
let s=e.sections[i++],l=e.sections[i++];if(l<0)o+=s,a+=s;else{
let c=o,u=a,d=wae.empty
;for(;c+=s,u+=l,l&&r&&(d=d.append(r[i-2>>1])),!(n||i==e.sections.length||e.sections[i+1]<0);)s=e.sections[i++],
l=e.sections[i++];t(o,c,a,u,d),o=c,a=u}}}function Fae(e,t,n,r=!1){
let o=[],a=r?[]:null,i=new Qae(e),s=new Qae(t);for(let l=-1;;){
if(i.done&&s.len||s.done&&i.len)throw new Error("Mismatched change set lengths")
;if(-1==i.ins&&-1==s.ins){let e=Math.min(i.len,s.len)
;jae(o,e,-1),i.forward(e),s.forward(e)
}else if(s.ins>=0&&(i.ins<0||l==i.i||0==i.off&&(s.len<i.len||s.len==i.len&&!n))){
let e=s.len;for(jae(o,s.ins,-1);e;){let t=Math.min(i.len,e)
;i.ins>=0&&l<i.i&&i.len<=t&&(jae(o,0,i.ins),
a&&Uae(a,o,i.text),l=i.i),i.forward(t),e-=t}s.next()}else{if(!(i.ins>=0)){
if(i.done&&s.done)return a?Bae.createSet(o,a):Lae.create(o)
;throw new Error("Mismatched change set lengths")}{let e=0,t=i.len
;for(;t;)if(-1==s.ins){let n=Math.min(t,s.len);e+=n,t-=n,s.forward(n)}else{
if(!(0==s.ins&&s.len<t))break;t-=s.len,s.next()}
jae(o,e,l<i.i?i.ins:0),a&&l<i.i&&Uae(a,o,i.text),l=i.i,i.forward(i.len-t)}}}}
function Zae(e,t,n=!1){let r=[],o=n?[]:null,a=new Qae(e),i=new Qae(t)
;for(let s=!1;;){if(a.done&&i.done)return o?Bae.createSet(r,o):Lae.create(r)
;if(0==a.ins)jae(r,a.len,0,s),a.next();else if(0!=i.len||i.done){
if(a.done||i.done)throw new Error("Mismatched change set lengths");{
let e=Math.min(a.len2,i.len),t=r.length;if(-1==a.ins){
let t=-1==i.ins?-1:i.off?0:i.ins;jae(r,e,t,s),o&&t&&Uae(o,r,i.text)
}else-1==i.ins?(jae(r,a.off?0:a.len,e,s),
o&&Uae(o,r,a.textBit(e))):(jae(r,a.off?0:a.len,i.off?0:i.ins,s),
o&&!i.off&&Uae(o,r,i.text))
;s=(a.ins>e||i.ins>=0&&i.len>e)&&(s||r.length>t),a.forward2(e),i.forward(e)}
}else jae(r,0,i.ins,s),o&&Uae(o,r,i.text),i.next()}}class Qae{constructor(e){
this.set=e,this.i=0,this.next()}next(){let{sections:e}=this.set
;this.i<e.length?(this.len=e[this.i++],
this.ins=e[this.i++]):(this.len=0,this.ins=-2),this.off=0}get done(){
return-2==this.ins}get len2(){return this.ins<0?this.len:this.ins}get text(){
let{inserted:e}=this.set,t=this.i-2>>1;return t>=e.length?wae.empty:e[t]}
textBit(e){let{inserted:t}=this.set,n=this.i-2>>1
;return n>=t.length&&!e?wae.empty:t[n].slice(this.off,null==e?void 0:this.off+e)
}forward(e){e==this.len?this.next():(this.len-=e,this.off+=e)}forward2(e){
-1==this.ins?this.forward(e):e==this.ins?this.next():(this.ins-=e,this.off+=e)}}
class Hae{constructor(e,t,n){this.from=e,this.to=t,this.flags=n}get anchor(){
return 32&this.flags?this.to:this.from}get head(){
return 32&this.flags?this.from:this.to}get empty(){return this.from==this.to}
get assoc(){return 8&this.flags?-1:16&this.flags?1:0}get bidiLevel(){
let e=7&this.flags;return 7==e?null:e}get goalColumn(){let e=this.flags>>6
;return 16777215==e?void 0:e}map(e,t=-1){let n,r
;return this.empty?n=r=e.mapPos(this.from,t):(n=e.mapPos(this.from,1),
r=e.mapPos(this.to,-1)),n==this.from&&r==this.to?this:new Hae(n,r,this.flags)}
extend(e,t=e){if(e<=this.anchor&&t>=this.anchor)return Vae.range(e,t)
;let n=Math.abs(e-this.anchor)>Math.abs(t-this.anchor)?e:t
;return Vae.range(this.anchor,n)}eq(e,t=!1){
return!(this.anchor!=e.anchor||this.head!=e.head||t&&this.empty&&this.assoc!=e.assoc)
}toJSON(){return{anchor:this.anchor,head:this.head}}static fromJSON(e){
if(!e||"number"!=typeof e.anchor||"number"!=typeof e.head)throw new RangeError("Invalid JSON representation for SelectionRange")
;return Vae.range(e.anchor,e.head)}static create(e,t,n){return new Hae(e,t,n)}}
class Vae{constructor(e,t){this.ranges=e,this.mainIndex=t}map(e,t=-1){
return e.empty?this:Vae.create(this.ranges.map((n=>n.map(e,t))),this.mainIndex)}
eq(e,t=!1){
if(this.ranges.length!=e.ranges.length||this.mainIndex!=e.mainIndex)return!1
;for(let n=0;n<this.ranges.length;n++)if(!this.ranges[n].eq(e.ranges[n],t))return!1
;return!0}get main(){return this.ranges[this.mainIndex]}asSingle(){
return 1==this.ranges.length?this:new Vae([this.main],0)}addRange(e,t=!0){
return Vae.create([e].concat(this.ranges),t?0:this.mainIndex+1)}
replaceRange(e,t=this.mainIndex){let n=this.ranges.slice()
;return n[t]=e,Vae.create(n,this.mainIndex)}toJSON(){return{
ranges:this.ranges.map((e=>e.toJSON())),main:this.mainIndex}}static fromJSON(e){
if(!e||!Array.isArray(e.ranges)||"number"!=typeof e.main||e.main>=e.ranges.length)throw new RangeError("Invalid JSON representation for EditorSelection")
;return new Vae(e.ranges.map((e=>Hae.fromJSON(e))),e.main)}static single(e,t=e){
return new Vae([Vae.range(e,t)],0)}static create(e,t=0){
if(0==e.length)throw new RangeError("A selection needs at least one range")
;for(let n=0,r=0;r<e.length;r++){let o=e[r]
;if(o.empty?o.from<=n:o.from<n)return Vae.normalized(e.slice(),t);n=o.to}
return new Vae(e,t)}static cursor(e,t=0,n,r){
return Hae.create(e,e,(0==t?0:t<0?8:16)|(null==n?7:Math.min(6,n))|(null!=r?r:16777215)<<6)
}static range(e,t,n,r){let o=(null!=n?n:16777215)<<6|(null==r?7:Math.min(6,r))
;return t<e?Hae.create(t,e,48|o):Hae.create(e,t,(t>e?8:0)|o)}
static normalized(e,t=0){let n=e[t]
;e.sort(((e,t)=>e.from-t.from)),t=e.indexOf(n);for(let r=1;r<e.length;r++){
let n=e[r],o=e[r-1];if(n.empty?n.from<=o.to:n.from<o.to){
let a=o.from,i=Math.max(n.to,o.to)
;r<=t&&t--,e.splice(--r,2,n.anchor>n.head?Vae.range(i,a):Vae.range(a,i))}}
return new Vae(e,t)}}function qae(e,t){
for(let n of e.ranges)if(n.to>t)throw new RangeError("Selection points outside of document")
}let Wae=0;class Xae{constructor(e,t,n,r,o){
this.combine=e,this.compareInput=t,this.compare=n,this.isStatic=r,this.id=Wae++,
this.default=e([]),this.extensions="function"==typeof o?o(this):o}get reader(){
return this}static define(e={}){
return new Xae(e.combine||(e=>e),e.compareInput||((e,t)=>e===t),e.compare||(e.combine?(e,t)=>e===t:Gae),!!e.static,e.enables)
}of(e){return new Yae([],this,0,e)}compute(e,t){
if(this.isStatic)throw new Error("Can't compute a static facet")
;return new Yae(e,this,1,t)}computeN(e,t){
if(this.isStatic)throw new Error("Can't compute a static facet")
;return new Yae(e,this,2,t)}from(e,t){
return t||(t=e=>e),this.compute([e],(n=>t(n.field(e))))}}function Gae(e,t){
return e==t||e.length==t.length&&e.every(((e,n)=>e===t[n]))}class Yae{
constructor(e,t,n,r){
this.dependencies=e,this.facet=t,this.type=n,this.value=r,this.id=Wae++}
dynamicSlot(e){var t
;let n=this.value,r=this.facet.compareInput,o=this.id,a=e[o]>>1,i=2==this.type,s=!1,l=!1,c=[]
;for(let u of this.dependencies)"doc"==u?s=!0:"selection"==u?l=!0:1&(null!==(t=e[u.id])&&void 0!==t?t:1)||c.push(e[u.id])
;return{create:e=>(e.values[a]=n(e),1),update(e,t){
if(s&&t.docChanged||l&&(t.docChanged||t.selection)||Jae(e,c)){let t=n(e)
;if(i?!Kae(t,e.values[a],r):!r(t,e.values[a]))return e.values[a]=t,1}return 0},
reconfigure:(e,t)=>{let s,l=t.config.address[o];if(null!=l){let o=fie(t,l)
;if(this.dependencies.every((n=>n instanceof Xae?t.facet(n)===e.facet(n):!(n instanceof nie)||t.field(n,!1)==e.field(n,!1)))||(i?Kae(s=n(e),o,r):r(s=n(e),o)))return e.values[a]=o,
0}else s=n(e);return e.values[a]=s,1}}}}function Kae(e,t,n){
if(e.length!=t.length)return!1
;for(let r=0;r<e.length;r++)if(!n(e[r],t[r]))return!1;return!0}
function Jae(e,t){let n=!1;for(let r of t)1&hie(e,r)&&(n=!0);return n}
function eie(e,t,n){
let r=n.map((t=>e[t.id])),o=n.map((e=>e.type)),a=r.filter((e=>!(1&e))),i=e[t.id]>>1
;function s(e){let n=[];for(let t=0;t<r.length;t++){let a=fie(e,r[t])
;if(2==o[t])for(let e of a)n.push(e);else n.push(a)}return t.combine(n)}return{
create(e){for(let t of r)hie(e,t);return e.values[i]=s(e),1},update(e,n){
if(!Jae(e,a))return 0;let r=s(e)
;return t.compare(r,e.values[i])?0:(e.values[i]=r,1)},reconfigure(e,o){
let a=Jae(e,r),l=o.config.facets[t.id],c=o.facet(t)
;if(l&&!a&&Gae(n,l))return e.values[i]=c,0;let u=s(e)
;return t.compare(u,c)?(e.values[i]=c,0):(e.values[i]=u,1)}}}
const tie=Xae.define({static:!0});class nie{constructor(e,t,n,r,o){
this.id=e,this.createF=t,
this.updateF=n,this.compareF=r,this.spec=o,this.provides=void 0}
static define(e){
let t=new nie(Wae++,e.create,e.update,e.compare||((e,t)=>e===t),e)
;return e.provide&&(t.provides=e.provide(t)),t}create(e){
let t=e.facet(tie).find((e=>e.field==this))
;return((null==t?void 0:t.create)||this.createF)(e)}slot(e){let t=e[this.id]>>1
;return{create:e=>(e.values[t]=this.create(e),1),update:(e,n)=>{
let r=e.values[t],o=this.updateF(r,n)
;return this.compareF(r,o)?0:(e.values[t]=o,1)},
reconfigure:(e,n)=>null!=n.config.address[this.id]?(e.values[t]=n.field(this),
0):(e.values[t]=this.create(e),1)}}init(e){return[this,tie.of({field:this,
create:e})]}get extension(){return this}}const rie=4,oie=3,aie=2,iie=1
;function sie(e){return t=>new cie(t,e)}const lie={highest:sie(0),high:sie(iie),
default:sie(aie),low:sie(oie),lowest:sie(rie)};class cie{constructor(e,t){
this.inner=e,this.prec=t}}class uie{of(e){return new die(this,e)}reconfigure(e){
return uie.reconfigure.of({compartment:this,extension:e})}get(e){
return e.config.compartments.get(this)}}class die{constructor(e,t){
this.compartment=e,this.inner=t}}class pie{constructor(e,t,n,r,o,a){
for(this.base=e,
this.compartments=t,this.dynamicSlots=n,this.address=r,this.staticValues=o,
this.facets=a,
this.statusTemplate=[];this.statusTemplate.length<n.length;)this.statusTemplate.push(0)
}staticFacet(e){let t=this.address[e.id]
;return null==t?e.default:this.staticValues[t>>1]}static resolve(e,t,n){
let r=[],o=Object.create(null),a=new Map;for(let d of function(e,t,n){
let r=[[],[],[],[],[]],o=new Map;function a(e,i){let s=o.get(e);if(null!=s){
if(s<=i)return;let t=r[s].indexOf(e)
;t>-1&&r[s].splice(t,1),e instanceof die&&n.delete(e.compartment)}if(o.set(e,i),
Array.isArray(e))for(let t of e)a(t,i);else if(e instanceof die){
if(n.has(e.compartment))throw new RangeError("Duplicate use of compartment in extensions")
;let r=t.get(e.compartment)||e.inner;n.set(e.compartment,r),a(r,i)
}else if(e instanceof cie)a(e.inner,e.prec);else if(e instanceof nie)r[i].push(e),
e.provides&&a(e.provides,i);else if(e instanceof Yae)r[i].push(e),
e.facet.extensions&&a(e.facet.extensions,aie);else{let t=e.extension
;if(!t)throw new Error(`Unrecognized extension value in extension set (${e}). This sometimes happens because multiple instances of @codemirror/state are loaded, breaking instanceof checks.`)
;a(t,i)}}return a(e,aie),r.reduce(((e,t)=>e.concat(t)))
}(e,t,a))d instanceof nie?r.push(d):(o[d.facet.id]||(o[d.facet.id]=[])).push(d)
;let i=Object.create(null),s=[],l=[]
;for(let d of r)i[d.id]=l.length<<1,l.push((e=>d.slot(e)))
;let c=null==n?void 0:n.config.facets;for(let d in o){
let e=o[d],t=e[0].facet,r=c&&c[d]||[]
;if(e.every((e=>0==e.type)))if(i[t.id]=s.length<<1|1,
Gae(r,e))s.push(n.facet(t));else{let r=t.combine(e.map((e=>e.value)))
;s.push(n&&t.compare(r,n.facet(t))?n.facet(t):r)}else{
for(let t of e)0==t.type?(i[t.id]=s.length<<1|1,
s.push(t.value)):(i[t.id]=l.length<<1,l.push((e=>t.dynamicSlot(e))))
;i[t.id]=l.length<<1,l.push((n=>eie(n,t,e)))}}let u=l.map((e=>e(i)))
;return new pie(e,a,u,i,s,o)}}function hie(e,t){if(1&t)return 2
;let n=t>>1,r=e.status[n]
;if(4==r)throw new Error("Cyclic dependency between fields and/or facets")
;if(2&r)return r;e.status[n]=4;let o=e.computeSlot(e,e.config.dynamicSlots[n])
;return e.status[n]=2|o}function fie(e,t){
return 1&t?e.config.staticValues[t>>1]:e.values[t>>1]}
const mie=Xae.define(),gie=Xae.define({combine:e=>e.some((e=>e)),static:!0
}),vie=Xae.define({combine:e=>e.length?e[0]:void 0,static:!0
}),bie=Xae.define(),yie=Xae.define(),Oie=Xae.define(),wie=Xae.define({
combine:e=>!!e.length&&e[0]});class xie{constructor(e,t){
this.type=e,this.value=t}static define(){return new kie}}class kie{of(e){
return new xie(this,e)}}class Sie{constructor(e){this.map=e}of(e){
return new _ie(this,e)}}class _ie{constructor(e,t){this.type=e,this.value=t}
map(e){let t=this.type.map(this.value,e)
;return void 0===t?void 0:t==this.value?this:new _ie(this.type,t)}is(e){
return this.type==e}static define(e={}){return new Sie(e.map||(e=>e))}
static mapEffects(e,t){if(!e.length)return e;let n=[];for(let r of e){
let e=r.map(t);e&&n.push(e)}return n}}
_ie.reconfigure=_ie.define(),_ie.appendConfig=_ie.define();class Tie{
constructor(e,t,n,r,o,a){
this.startState=e,this.changes=t,this.selection=n,this.effects=r,
this.annotations=o,
this.scrollIntoView=a,this._doc=null,this._state=null,n&&qae(n,t.newLength),
o.some((e=>e.type==Tie.time))||(this.annotations=o.concat(Tie.time.of(Date.now())))
}static create(e,t,n,r,o,a){return new Tie(e,t,n,r,o,a)}get newDoc(){
return this._doc||(this._doc=this.changes.apply(this.startState.doc))}
get newSelection(){
return this.selection||this.startState.selection.map(this.changes)}get state(){
return this._state||this.startState.applyTransaction(this),this._state}
annotation(e){for(let t of this.annotations)if(t.type==e)return t.value}
get docChanged(){return!this.changes.empty}get reconfigured(){
return this.startState.config!=this.state.config}isUserEvent(e){
let t=this.annotation(Tie.userEvent)
;return!(!t||!(t==e||t.length>e.length&&t.slice(0,e.length)==e&&"."==t[e.length]))
}}function Eie(e,t){let n=[];for(let r=0,o=0;;){let a,i
;if(r<e.length&&(o==t.length||t[o]>=e[r]))a=e[r++],i=e[r++];else{
if(!(o<t.length))return n;a=t[o++],i=t[o++]}
!n.length||n[n.length-1]<a?n.push(a,i):n[n.length-1]<i&&(n[n.length-1]=i)}}
function Aie(e,t,n){var r;let o,a,i
;return n?(o=t.changes,a=Bae.empty(t.changes.length),
i=e.changes.compose(t.changes)):(o=t.changes.map(e.changes),
a=e.changes.mapDesc(t.changes,!0),i=e.changes.compose(o)),{changes:i,
selection:t.selection?t.selection.map(a):null===(r=e.selection)||void 0===r?void 0:r.map(o),
effects:_ie.mapEffects(e.effects,o).concat(_ie.mapEffects(t.effects,a)),
annotations:e.annotations.length?e.annotations.concat(t.annotations):t.annotations,
scrollIntoView:e.scrollIntoView||t.scrollIntoView}}function Cie(e,t,n){
let r=t.selection,o=Die(t.annotations)
;return t.userEvent&&(o=o.concat(Tie.userEvent.of(t.userEvent))),{
changes:t.changes instanceof Bae?t.changes:Bae.of(t.changes||[],n,e.facet(vie)),
selection:r&&(r instanceof Vae?r:Vae.single(r.anchor,r.head)),
effects:Die(t.effects),annotations:o,scrollIntoView:!!t.scrollIntoView}}
function $ie(e,t,n){let r=Cie(e,t.length?t[0]:{},e.doc.length)
;t.length&&!1===t[0].filter&&(n=!1);for(let a=1;a<t.length;a++){
!1===t[a].filter&&(n=!1);let o=!!t[a].sequential
;r=Aie(r,Cie(e,t[a],o?r.changes.newLength:e.doc.length),o)}
let o=Tie.create(e,r.changes,r.selection,r.effects,r.annotations,r.scrollIntoView)
;return function(e){let t=e.startState,n=t.facet(Oie),r=e
;for(let o=n.length-1;o>=0;o--){let a=n[o](e)
;a&&Object.keys(a).length&&(r=Aie(r,Cie(t,a,e.changes.newLength),!0))}
return r==e?e:Tie.create(t,e.changes,e.selection,r.effects,r.annotations,r.scrollIntoView)
}(n?function(e){let t=e.startState,n=!0;for(let o of t.facet(bie)){let t=o(e)
;if(!1===t){n=!1;break}Array.isArray(t)&&(n=!0===n?t:Eie(n,t))}if(!0!==n){
let r,o;if(!1===n)o=e.changes.invertedDesc,r=Bae.empty(t.doc.length);else{
let t=e.changes.filter(n)
;r=t.changes,o=t.filtered.mapDesc(t.changes).invertedDesc}
e=Tie.create(t,r,e.selection&&e.selection.map(o),_ie.mapEffects(e.effects,o),e.annotations,e.scrollIntoView)
}let r=t.facet(yie);for(let o=r.length-1;o>=0;o--){let n=r[o](e)
;e=n instanceof Tie?n:Array.isArray(n)&&1==n.length&&n[0]instanceof Tie?n[0]:$ie(t,Die(n),!1)
}return e}(o):o)}
Tie.time=xie.define(),Tie.userEvent=xie.define(),Tie.addToHistory=xie.define(),
Tie.remote=xie.define();const Pie=[];function Die(e){
return null==e?Pie:Array.isArray(e)?e:[e]}var Iie=function(e){
return e[e.Word=0]="Word",e[e.Space=1]="Space",e[e.Other=2]="Other",e
}(Iie||(Iie={}))
;const Mie=/[\u00df\u0587\u0590-\u05f4\u0600-\u06ff\u3040-\u309f\u30a0-\u30ff\u3400-\u4db5\u4e00-\u9fcc\uac00-\ud7af]/
;let Nie;try{Nie=new RegExp("[\\p{Alphabetic}\\p{Number}_]","u")}catch(g5e){}
function Rie(e){return t=>{if(!/\S/.test(t))return Iie.Space;if(function(e){
if(Nie)return Nie.test(e);for(let t=0;t<e.length;t++){let n=e[t]
;if(/\w/.test(n)||n>""&&(n.toUpperCase()!=n.toLowerCase()||Mie.test(n)))return!0
}return!1}(t))return Iie.Word
;for(let n=0;n<e.length;n++)if(t.indexOf(e[n])>-1)return Iie.Word
;return Iie.Other}}class Lie{constructor(e,t,n,r,o,a){
this.config=e,this.doc=t,this.selection=n,
this.values=r,this.status=e.statusTemplate.slice(),
this.computeSlot=o,a&&(a._state=this)
;for(let i=0;i<this.config.dynamicSlots.length;i++)hie(this,i<<1)
;this.computeSlot=null}field(e,t=!0){let n=this.config.address[e.id]
;if(null!=n)return hie(this,n),fie(this,n)
;if(t)throw new RangeError("Field is not present in this state")}update(...e){
return $ie(this,e,!0)}applyTransaction(e){
let t,n=this.config,{base:r,compartments:o}=n
;for(let i of e.effects)i.is(uie.reconfigure)?(n&&(o=new Map,
n.compartments.forEach(((e,t)=>o.set(t,e))),
n=null),o.set(i.value.compartment,i.value.extension)):i.is(_ie.reconfigure)?(n=null,
r=i.value):i.is(_ie.appendConfig)&&(n=null,r=Die(r).concat(i.value))
;if(n)t=e.startState.values.slice();else{
n=pie.resolve(r,o,this),t=new Lie(n,this.doc,this.selection,n.dynamicSlots.map((()=>null)),((e,t)=>t.reconfigure(e,this)),null).values
}let a=e.startState.facet(gie)?e.newSelection:e.newSelection.asSingle()
;new Lie(n,e.newDoc,a,t,((t,n)=>n.update(t,e)),e)}replaceSelection(e){
return"string"==typeof e&&(e=this.toText(e)),this.changeByRange((t=>({changes:{
from:t.from,to:t.to,insert:e},range:Vae.cursor(t.from+e.length)})))}
changeByRange(e){
let t=this.selection,n=e(t.ranges[0]),r=this.changes(n.changes),o=[n.range],a=Die(n.effects)
;for(let i=1;i<t.ranges.length;i++){
let n=e(t.ranges[i]),s=this.changes(n.changes),l=s.map(r)
;for(let e=0;e<i;e++)o[e]=o[e].map(l);let c=r.mapDesc(s,!0)
;o.push(n.range.map(c)),
r=r.compose(l),a=_ie.mapEffects(a,l).concat(_ie.mapEffects(Die(n.effects),c))}
return{changes:r,selection:Vae.create(o,t.mainIndex),effects:a}}changes(e=[]){
return e instanceof Bae?e:Bae.of(e,this.doc.length,this.facet(Lie.lineSeparator))
}toText(e){return wae.of(e.split(this.facet(Lie.lineSeparator)||Nae))}
sliceDoc(e=0,t=this.doc.length){return this.doc.sliceString(e,t,this.lineBreak)}
facet(e){let t=this.config.address[e.id]
;return null==t?e.default:(hie(this,t),fie(this,t))}toJSON(e){let t={
doc:this.sliceDoc(),selection:this.selection.toJSON()};if(e)for(let n in e){
let r=e[n]
;r instanceof nie&&null!=this.config.address[r.id]&&(t[n]=r.spec.toJSON(this.field(e[n]),this))
}return t}static fromJSON(e,t={},n){
if(!e||"string"!=typeof e.doc)throw new RangeError("Invalid JSON representation for EditorState")
;let r=[];if(n)for(let o in n)if(Object.prototype.hasOwnProperty.call(e,o)){
let t=n[o],a=e[o];r.push(t.init((e=>t.spec.fromJSON(a,e))))}return Lie.create({
doc:e.doc,selection:Vae.fromJSON(e.selection),
extensions:t.extensions?r.concat([t.extensions]):r})}static create(e={}){
let t=pie.resolve(e.extensions||[],new Map),n=e.doc instanceof wae?e.doc:wae.of((e.doc||"").split(t.staticFacet(Lie.lineSeparator)||Nae)),r=e.selection?e.selection instanceof Vae?e.selection:Vae.single(e.selection.anchor,e.selection.head):Vae.single(0)
;return qae(r,n.length),
t.staticFacet(gie)||(r=r.asSingle()),new Lie(t,n,r,t.dynamicSlots.map((()=>null)),((e,t)=>t.create(e)),null)
}get tabSize(){return this.facet(Lie.tabSize)}get lineBreak(){
return this.facet(Lie.lineSeparator)||"\n"}get readOnly(){return this.facet(wie)
}phrase(e,...t){
for(let n of this.facet(Lie.phrases))if(Object.prototype.hasOwnProperty.call(n,e)){
e=n[e];break}return t.length&&(e=e.replace(/\$(\$|\d*)/g,((e,n)=>{
if("$"==n)return"$";let r=+(n||1);return!r||r>t.length?e:t[r-1]}))),e}
languageDataAt(e,t,n=-1){let r=[]
;for(let o of this.facet(mie))for(let a of o(this,t,n))Object.prototype.hasOwnProperty.call(a,e)&&r.push(a[e])
;return r}charCategorizer(e){
return Rie(this.languageDataAt("wordChars",e).join(""))}wordAt(e){
let{text:t,from:n,length:r}=this.doc.lineAt(e),o=this.charCategorizer(e),a=e-n,i=e-n
;for(;a>0;){let e=Pae(t,a,!1);if(o(t.slice(e,a))!=Iie.Word)break;a=e}for(;i<r;){
let e=Pae(t,i);if(o(t.slice(i,e))!=Iie.Word)break;i=e}
return a==i?null:Vae.range(a+n,i+n)}}function Bie(e,t,n={}){let r={}
;for(let o of e)for(let e of Object.keys(o)){let t=o[e],a=r[e]
;if(void 0===a)r[e]=t;else if(a===t||void 0===t);else{
if(!Object.hasOwnProperty.call(n,e))throw new Error("Config merge conflict for field "+e)
;r[e]=n[e](a,t)}}for(let o in t)void 0===r[o]&&(r[o]=t[o]);return r}
Lie.allowMultipleSelections=gie,Lie.tabSize=Xae.define({
combine:e=>e.length?e[0]:4
}),Lie.lineSeparator=vie,Lie.readOnly=wie,Lie.phrases=Xae.define({compare(e,t){
let n=Object.keys(e),r=Object.keys(t)
;return n.length==r.length&&n.every((n=>e[n]==t[n]))}
}),Lie.languageData=mie,Lie.changeFilter=bie,
Lie.transactionFilter=yie,Lie.transactionExtender=Oie,
uie.reconfigure=_ie.define();class jie{eq(e){return this==e}range(e,t=e){
return Uie.create(e,t,this)}}
jie.prototype.startSide=jie.prototype.endSide=0,jie.prototype.point=!1,
jie.prototype.mapMode=Rae.TrackDel;let Uie=class e{constructor(e,t,n){
this.from=e,this.to=t,this.value=n}static create(t,n,r){return new e(t,n,r)}}
;function zie(e,t){return e.from-t.from||e.value.startSide-t.value.startSide}
class Fie{constructor(e,t,n,r){
this.from=e,this.to=t,this.value=n,this.maxPoint=r}get length(){
return this.to[this.to.length-1]}findIndex(e,t,n,r=0){let o=n?this.to:this.from
;for(let a=r,i=o.length;;){if(a==i)return a
;let r=a+i>>1,s=o[r]-e||(n?this.value[r].endSide:this.value[r].startSide)-t
;if(r==a)return s>=0?a:i;s>=0?i=r:a=r+1}}between(e,t,n,r){
for(let o=this.findIndex(t,-1e9,!0),a=this.findIndex(n,1e9,!1,o);o<a;o++)if(!1===r(this.from[o]+e,this.to[o]+e,this.value[o]))return!1
}map(e,t){let n=[],r=[],o=[],a=-1,i=-1;for(let s=0;s<this.value.length;s++){
let l,c,u=this.value[s],d=this.from[s]+e,p=this.to[s]+e;if(d==p){
let e=t.mapPos(d,u.startSide,u.mapMode);if(null==e)continue
;if(l=c=e,u.startSide!=u.endSide&&(c=t.mapPos(d,u.endSide),c<l))continue
}else if(l=t.mapPos(d,u.startSide),
c=t.mapPos(p,u.endSide),l>c||l==c&&u.startSide>0&&u.endSide<=0)continue
;(c-l||u.endSide-u.startSide)<0||(a<0&&(a=l),
u.point&&(i=Math.max(i,c-l)),n.push(u),r.push(l-a),o.push(c-a))}return{
mapped:n.length?new Fie(r,o,n,i):null,pos:a}}}class Zie{constructor(e,t,n,r){
this.chunkPos=e,this.chunk=t,this.nextLayer=n,this.maxPoint=r}
static create(e,t,n,r){return new Zie(e,t,n,r)}get length(){
let e=this.chunk.length-1
;return e<0?0:Math.max(this.chunkEnd(e),this.nextLayer.length)}get size(){
if(this.isEmpty)return 0;let e=this.nextLayer.size
;for(let t of this.chunk)e+=t.value.length;return e}chunkEnd(e){
return this.chunkPos[e]+this.chunk[e].length}update(e){
let{add:t=[],sort:n=!1,filterFrom:r=0,filterTo:o=this.length}=e,a=e.filter
;if(0==t.length&&!a)return this
;if(n&&(t=t.slice().sort(zie)),this.isEmpty)return t.length?Zie.of(t):this
;let i=new Vie(this,null,-1).goto(0),s=0,l=[],c=new Qie
;for(;i.value||s<t.length;)if(s<t.length&&(i.from-t[s].from||i.startSide-t[s].value.startSide)>=0){
let e=t[s++];c.addInner(e.from,e.to,e.value)||l.push(e)
}else 1==i.rangeIndex&&i.chunkIndex<this.chunk.length&&(s==t.length||this.chunkEnd(i.chunkIndex)<t[s].from)&&(!a||r>this.chunkEnd(i.chunkIndex)||o<this.chunkPos[i.chunkIndex])&&c.addChunk(this.chunkPos[i.chunkIndex],this.chunk[i.chunkIndex])?i.nextChunk():((!a||r>i.to||o<i.from||a(i.from,i.to,i.value))&&(c.addInner(i.from,i.to,i.value)||l.push(Uie.create(i.from,i.to,i.value))),
i.next())
;return c.finishInner(this.nextLayer.isEmpty&&!l.length?Zie.empty:this.nextLayer.update({
add:l,filter:a,filterFrom:r,filterTo:o}))}map(e){
if(e.empty||this.isEmpty)return this;let t=[],n=[],r=-1
;for(let a=0;a<this.chunk.length;a++){
let o=this.chunkPos[a],i=this.chunk[a],s=e.touchesRange(o,o+i.length)
;if(!1===s)r=Math.max(r,i.maxPoint),
t.push(i),n.push(e.mapPos(o));else if(!0===s){let{mapped:a,pos:s}=i.map(o,e)
;a&&(r=Math.max(r,a.maxPoint),t.push(a),n.push(s))}}let o=this.nextLayer.map(e)
;return 0==t.length?o:new Zie(n,t,o||Zie.empty,r)}between(e,t,n){
if(!this.isEmpty){for(let r=0;r<this.chunk.length;r++){
let o=this.chunkPos[r],a=this.chunk[r]
;if(t>=o&&e<=o+a.length&&!1===a.between(o,e-o,t-o,n))return}
this.nextLayer.between(e,t,n)}}iter(e=0){return qie.from([this]).goto(e)}
get isEmpty(){return this.nextLayer==this}static iter(e,t=0){
return qie.from(e).goto(t)}static compare(e,t,n,r,o=-1){
let a=e.filter((e=>e.maxPoint>0||!e.isEmpty&&e.maxPoint>=o)),i=t.filter((e=>e.maxPoint>0||!e.isEmpty&&e.maxPoint>=o)),s=Hie(a,i,n),l=new Xie(a,s,o),c=new Xie(i,s,o)
;n.iterGaps(((e,t,n)=>Gie(l,e,c,t,n,r))),n.empty&&0==n.length&&Gie(l,0,c,0,0,r)}
static eq(e,t,n=0,r){null==r&&(r=999999999)
;let o=e.filter((e=>!e.isEmpty&&t.indexOf(e)<0)),a=t.filter((t=>!t.isEmpty&&e.indexOf(t)<0))
;if(o.length!=a.length)return!1;if(!o.length)return!0
;let i=Hie(o,a),s=new Xie(o,i,0).goto(n),l=new Xie(a,i,0).goto(n);for(;;){
if(s.to!=l.to||!Yie(s.active,l.active)||s.point&&(!l.point||!s.point.eq(l.point)))return!1
;if(s.to>r)return!0;s.next(),l.next()}}static spans(e,t,n,r,o=-1){
let a=new Xie(e,null,o).goto(t),i=t,s=a.openStart;for(;;){let e=Math.min(a.to,n)
;if(a.point){
let n=a.activeForPoint(a.to),o=a.pointFrom<t?n.length+1:a.point.startSide<0?n.length:Math.min(n.length,s)
;r.point(i,e,a.point,n,o,a.pointRank),s=Math.min(a.openEnd(e),n.length)
}else e>i&&(r.span(i,e,a.active,s),s=a.openEnd(e))
;if(a.to>n)return s+(a.point&&a.to>n?1:0);i=a.to,a.next()}}static of(e,t=!1){
let n=new Qie;for(let r of e instanceof Uie?[e]:t?function(e){
if(e.length>1)for(let t=e[0],n=1;n<e.length;n++){let r=e[n]
;if(zie(t,r)>0)return e.slice().sort(zie);t=r}return e
}(e):e)n.add(r.from,r.to,r.value);return n.finish()}static join(e){
if(!e.length)return Zie.empty;let t=e[e.length-1]
;for(let n=e.length-2;n>=0;n--)for(let r=e[n];r!=Zie.empty;r=r.nextLayer)t=new Zie(r.chunkPos,r.chunk,t,Math.max(r.maxPoint,t.maxPoint))
;return t}}Zie.empty=new Zie([],[],null,-1),Zie.empty.nextLayer=Zie.empty
;class Qie{finishChunk(e){
this.chunks.push(new Fie(this.from,this.to,this.value,this.maxPoint)),
this.chunkPos.push(this.chunkStart),
this.chunkStart=-1,this.setMaxPoint=Math.max(this.setMaxPoint,this.maxPoint),
this.maxPoint=-1,e&&(this.from=[],this.to=[],this.value=[])}constructor(){
this.chunks=[],
this.chunkPos=[],this.chunkStart=-1,this.last=null,this.lastFrom=-1e9,
this.lastTo=-1e9,
this.from=[],this.to=[],this.value=[],this.maxPoint=-1,this.setMaxPoint=-1,
this.nextLayer=null}add(e,t,n){
this.addInner(e,t,n)||(this.nextLayer||(this.nextLayer=new Qie)).add(e,t,n)}
addInner(e,t,n){let r=e-this.lastTo||n.startSide-this.last.endSide
;if(r<=0&&(e-this.lastFrom||n.startSide-this.last.startSide)<0)throw new Error("Ranges must be added sorted by `from` position and `startSide`")
;return!(r<0)&&(250==this.from.length&&this.finishChunk(!0),
this.chunkStart<0&&(this.chunkStart=e),
this.from.push(e-this.chunkStart),this.to.push(t-this.chunkStart),
this.last=n,this.lastFrom=e,
this.lastTo=t,this.value.push(n),n.point&&(this.maxPoint=Math.max(this.maxPoint,t-e)),
!0)}addChunk(e,t){
if((e-this.lastTo||t.value[0].startSide-this.last.endSide)<0)return!1
;this.from.length&&this.finishChunk(!0),
this.setMaxPoint=Math.max(this.setMaxPoint,t.maxPoint),
this.chunks.push(t),this.chunkPos.push(e);let n=t.value.length-1
;return this.last=t.value[n],this.lastFrom=t.from[n]+e,this.lastTo=t.to[n]+e,!0}
finish(){return this.finishInner(Zie.empty)}finishInner(e){
if(this.from.length&&this.finishChunk(!1),0==this.chunks.length)return e
;let t=Zie.create(this.chunkPos,this.chunks,this.nextLayer?this.nextLayer.finishInner(e):e,this.setMaxPoint)
;return this.from=null,t}}function Hie(e,t,n){let r=new Map
;for(let a of e)for(let e=0;e<a.chunk.length;e++)a.chunk[e].maxPoint<=0&&r.set(a.chunk[e],a.chunkPos[e])
;let o=new Set;for(let a of t)for(let e=0;e<a.chunk.length;e++){
let t=r.get(a.chunk[e])
;null==t||(n?n.mapPos(t):t)!=a.chunkPos[e]||(null==n?void 0:n.touchesRange(t,t+a.chunk[e].length))||o.add(a.chunk[e])
}return o}class Vie{constructor(e,t,n,r=0){
this.layer=e,this.skip=t,this.minPoint=n,this.rank=r}get startSide(){
return this.value?this.value.startSide:0}get endSide(){
return this.value?this.value.endSide:0}goto(e,t=-1e9){
return this.chunkIndex=this.rangeIndex=0,this.gotoInner(e,t,!1),this}
gotoInner(e,t,n){for(;this.chunkIndex<this.layer.chunk.length;){
let t=this.layer.chunk[this.chunkIndex]
;if(!(this.skip&&this.skip.has(t)||this.layer.chunkEnd(this.chunkIndex)<e||t.maxPoint<this.minPoint))break
;this.chunkIndex++,n=!1}if(this.chunkIndex<this.layer.chunk.length){
let r=this.layer.chunk[this.chunkIndex].findIndex(e-this.layer.chunkPos[this.chunkIndex],t,!0)
;(!n||this.rangeIndex<r)&&this.setRangeIndex(r)}this.next()}forward(e,t){
(this.to-e||this.endSide-t)<0&&this.gotoInner(e,t,!0)}next(){for(;;){
if(this.chunkIndex==this.layer.chunk.length){
this.from=this.to=1e9,this.value=null;break}{
let e=this.layer.chunkPos[this.chunkIndex],t=this.layer.chunk[this.chunkIndex],n=e+t.from[this.rangeIndex]
;if(this.from=n,
this.to=e+t.to[this.rangeIndex],this.value=t.value[this.rangeIndex],
this.setRangeIndex(this.rangeIndex+1),
this.minPoint<0||this.value.point&&this.to-this.from>=this.minPoint)break}}}
setRangeIndex(e){if(e==this.layer.chunk[this.chunkIndex].value.length){
if(this.chunkIndex++,
this.skip)for(;this.chunkIndex<this.layer.chunk.length&&this.skip.has(this.layer.chunk[this.chunkIndex]);)this.chunkIndex++
;this.rangeIndex=0}else this.rangeIndex=e}nextChunk(){
this.chunkIndex++,this.rangeIndex=0,this.next()}compare(e){
return this.from-e.from||this.startSide-e.startSide||this.rank-e.rank||this.to-e.to||this.endSide-e.endSide
}}class qie{constructor(e){this.heap=e}static from(e,t=null,n=-1){let r=[]
;for(let o=0;o<e.length;o++)for(let a=e[o];!a.isEmpty;a=a.nextLayer)a.maxPoint>=n&&r.push(new Vie(a,t,n,o))
;return 1==r.length?r[0]:new qie(r)}get startSide(){
return this.value?this.value.startSide:0}goto(e,t=-1e9){
for(let n of this.heap)n.goto(e,t)
;for(let n=this.heap.length>>1;n>=0;n--)Wie(this.heap,n);return this.next(),this
}forward(e,t){for(let n of this.heap)n.forward(e,t)
;for(let n=this.heap.length>>1;n>=0;n--)Wie(this.heap,n)
;(this.to-e||this.value.endSide-t)<0&&this.next()}next(){
if(0==this.heap.length)this.from=this.to=1e9,this.value=null,this.rank=-1;else{
let e=this.heap[0]
;this.from=e.from,this.to=e.to,this.value=e.value,this.rank=e.rank,
e.value&&e.next(),Wie(this.heap,0)}}}function Wie(e,t){for(let n=e[t];;){
let r=1+(t<<1);if(r>=e.length)break;let o=e[r]
;if(r+1<e.length&&o.compare(e[r+1])>=0&&(o=e[r+1],r++),n.compare(o)<0)break
;e[r]=n,e[t]=o,t=r}}class Xie{constructor(e,t,n){this.minPoint=n,this.active=[],
this.activeTo=[],
this.activeRank=[],this.minActive=-1,this.point=null,this.pointFrom=0,
this.pointRank=0,
this.to=-1e9,this.endSide=0,this.openStart=-1,this.cursor=qie.from(e,t,n)}
goto(e,t=-1e9){
return this.cursor.goto(e,t),this.active.length=this.activeTo.length=this.activeRank.length=0,
this.minActive=-1,this.to=e,this.endSide=t,this.openStart=-1,this.next(),this}
forward(e,t){
for(;this.minActive>-1&&(this.activeTo[this.minActive]-e||this.active[this.minActive].endSide-t)<0;)this.removeActive(this.minActive)
;this.cursor.forward(e,t)}removeActive(e){
Kie(this.active,e),Kie(this.activeTo,e),
Kie(this.activeRank,e),this.minActive=ese(this.active,this.activeTo)}
addActive(e){let t=0,{value:n,to:r,rank:o}=this.cursor
;for(;t<this.activeRank.length&&(o-this.activeRank[t]||r-this.activeTo[t])>0;)t++
;Jie(this.active,t,n),
Jie(this.activeTo,t,r),Jie(this.activeRank,t,o),e&&Jie(e,t,this.cursor.from),
this.minActive=ese(this.active,this.activeTo)}next(){let e=this.to,t=this.point
;this.point=null;let n=this.openStart<0?[]:null;for(;;){let r=this.minActive
;if(r>-1&&(this.activeTo[r]-this.cursor.from||this.active[r].endSide-this.cursor.startSide)<0){
if(this.activeTo[r]>e){
this.to=this.activeTo[r],this.endSide=this.active[r].endSide;break}
this.removeActive(r),n&&Kie(n,r)}else{if(!this.cursor.value){
this.to=this.endSide=1e9;break}if(this.cursor.from>e){
this.to=this.cursor.from,this.endSide=this.cursor.startSide;break}{
let e=this.cursor.value;if(e.point){
if(!(t&&this.cursor.to==this.to&&this.cursor.from<this.cursor.to)){this.point=e,
this.pointFrom=this.cursor.from,
this.pointRank=this.cursor.rank,this.to=this.cursor.to,
this.endSide=e.endSide,this.cursor.next(),this.forward(this.to,this.endSide)
;break}this.cursor.next()}else this.addActive(n),this.cursor.next()}}}if(n){
this.openStart=0;for(let t=n.length-1;t>=0&&n[t]<e;t--)this.openStart++}}
activeForPoint(e){if(!this.active.length)return this.active;let t=[]
;for(let n=this.active.length-1;n>=0&&!(this.activeRank[n]<this.pointRank);n--)(this.activeTo[n]>e||this.activeTo[n]==e&&this.active[n].endSide>=this.point.endSide)&&t.push(this.active[n])
;return t.reverse()}openEnd(e){let t=0
;for(let n=this.activeTo.length-1;n>=0&&this.activeTo[n]>e;n--)t++;return t}}
function Gie(e,t,n,r,o,a){e.goto(t),n.goto(r);let i=r+o,s=r,l=r-t;for(;;){
let t=e.to+l-n.to,r=t||e.endSide-n.endSide,o=r<0?e.to+l:n.to,c=Math.min(o,i)
;if(e.point||n.point?e.point&&n.point&&(e.point==n.point||e.point.eq(n.point))&&Yie(e.activeForPoint(e.to),n.activeForPoint(n.to))||a.comparePoint(s,c,e.point,n.point):c>s&&!Yie(e.active,n.active)&&a.compareRange(s,c,e.active,n.active),
o>i)break
;(t||e.openEnd!=n.openEnd)&&a.boundChange&&a.boundChange(o),s=o,r<=0&&e.next(),
r>=0&&n.next()}}function Yie(e,t){if(e.length!=t.length)return!1
;for(let n=0;n<e.length;n++)if(e[n]!=t[n]&&!e[n].eq(t[n]))return!1;return!0}
function Kie(e,t){for(let n=t,r=e.length-1;n<r;n++)e[n]=e[n+1];e.pop()}
function Jie(e,t,n){for(let r=e.length-1;r>=t;r--)e[r+1]=e[r];e[t]=n}
function ese(e,t){let n=-1,r=1e9
;for(let o=0;o<t.length;o++)(t[o]-r||e[o].endSide-e[n].endSide)<0&&(n=o,r=t[o])
;return n}function tse(e,t,n=e.length){let r=0
;for(let o=0;o<n;)9==e.charCodeAt(o)?(r+=t-r%t,o++):(r++,o=Pae(e,o));return r}
const nse="undefined"==typeof Symbol?"__ͼ":Symbol.for("ͼ"),rse="undefined"==typeof Symbol?"__styleSet"+Math.floor(1e8*Math.random()):Symbol("styleSet"),ose="undefined"!=typeof globalThis?globalThis:"undefined"!=typeof window?window:{}
;class ase{constructor(e,t){this.rules=[];let{finish:n}=t||{};function r(e){
return/^@/.test(e)?[e]:e.split(/,\s*/)}function o(e,t,a,i){
let s=[],l=/^@(\w+)\b/.exec(e[0]),c=l&&"keyframes"==l[1]
;if(l&&null==t)return a.push(e[0]+";");for(let n in t){let i=t[n]
;if(/&/.test(n))o(n.split(/,\s*/).map((t=>e.map((e=>t.replace(/&/,e))))).reduce(((e,t)=>e.concat(t))),i,a);else if(i&&"object"==typeof i){
if(!l)throw new RangeError("The value of a property ("+n+") should be a primitive value.")
;o(r(n),i,s,c)
}else null!=i&&s.push(n.replace(/_.*/,"").replace(/[A-Z]/g,(e=>"-"+e.toLowerCase()))+": "+i+";")
}(s.length||c)&&a.push((!n||l||i?e:e.map(n)).join(", ")+" {"+s.join(" ")+"}")}
for(let a in e)o(r(a),e[a],this.rules)}getRules(){return this.rules.join("\n")}
static newName(){let e=ose[nse]||1;return ose[nse]=e+1,"ͼ"+e.toString(36)}
static mount(e,t,n){let r=e[rse],o=n&&n.nonce;r?o&&r.setNonce(o):r=new sse(e,o),
r.mount(Array.isArray(t)?t:[t],e)}}let ise=new Map;class sse{constructor(e,t){
let n=e.ownerDocument||e,r=n.defaultView
;if(!e.head&&e.adoptedStyleSheets&&r.CSSStyleSheet){let t=ise.get(n)
;if(t)return e[rse]=t;this.sheet=new r.CSSStyleSheet,ise.set(n,this)
}else this.styleTag=n.createElement("style"),
t&&this.styleTag.setAttribute("nonce",t);this.modules=[],e[rse]=this}mount(e,t){
let n=this.sheet,r=0,o=0;for(let a=0;a<e.length;a++){
let t=e[a],i=this.modules.indexOf(t)
;if(i<o&&i>-1&&(this.modules.splice(i,1),o--,i=-1),-1==i){
if(this.modules.splice(o++,0,t),
n)for(let e=0;e<t.rules.length;e++)n.insertRule(t.rules[e],r++)}else{
for(;o<i;)r+=this.modules[o++].rules.length;r+=t.rules.length,o++}}
if(n)t.adoptedStyleSheets.indexOf(this.sheet)<0&&(t.adoptedStyleSheets=[this.sheet,...t.adoptedStyleSheets]);else{
let e=""
;for(let t=0;t<this.modules.length;t++)e+=this.modules[t].getRules()+"\n"
;this.styleTag.textContent=e;let n=t.head||t
;this.styleTag.parentNode!=n&&n.insertBefore(this.styleTag,n.firstChild)}}
setNonce(e){
this.styleTag&&this.styleTag.getAttribute("nonce")!=e&&this.styleTag.setAttribute("nonce",e)
}}for(var lse={8:"Backspace",9:"Tab",10:"Enter",12:"NumLock",13:"Enter",
16:"Shift",17:"Control",18:"Alt",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",
34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",
40:"ArrowDown",44:"PrintScreen",45:"Insert",46:"Delete",59:";",61:"=",91:"Meta",
92:"Meta",106:"*",107:"+",108:",",109:"-",110:".",111:"/",144:"NumLock",
145:"ScrollLock",160:"Shift",161:"Shift",162:"Control",163:"Control",164:"Alt",
165:"Alt",173:"-",186:";",187:"=",188:",",189:"-",190:".",191:"/",192:"`",
219:"[",220:"\\",221:"]",222:"'"},cse={48:")",49:"!",50:"@",51:"#",52:"$",
53:"%",54:"^",55:"&",56:"*",57:"(",59:":",61:"+",173:"_",186:":",187:"+",
188:"<",189:"_",190:">",191:"?",192:"~",219:"{",220:"|",221:"}",222:'"'
},use="undefined"!=typeof navigator&&/Mac/.test(navigator.platform),dse="undefined"!=typeof navigator&&/MSIE \d|Trident\/(?:[7-9]|\d{2,})\..*rv:(\d+)/.exec(navigator.userAgent),pse=0;pse<10;pse++)lse[48+pse]=lse[96+pse]=String(pse)
;for(pse=1;pse<=24;pse++)lse[pse+111]="F"+pse
;for(pse=65;pse<=90;pse++)lse[pse]=String.fromCharCode(pse+32),
cse[pse]=String.fromCharCode(pse)
;for(var hse in lse)cse.hasOwnProperty(hse)||(cse[hse]=lse[hse])
;function fse(e){let t
;return t=11==e.nodeType?e.getSelection?e:e.ownerDocument:e,t.getSelection()}
function mse(e,t){return!!t&&(e==t||e.contains(1!=t.nodeType?t.parentNode:t))}
function gse(e,t){if(!t.anchorNode)return!1;try{return mse(e,t.anchorNode)
}catch(g5e){return!1}}function vse(e){
return 3==e.nodeType?$se(e,0,e.nodeValue.length).getClientRects():1==e.nodeType?e.getClientRects():[]
}function bse(e,t,n,r){return!!n&&(wse(e,t,n,r,-1)||wse(e,t,n,r,1))}
function yse(e){for(var t=0;;t++)if(!(e=e.previousSibling))return t}
function Ose(e){
return 1==e.nodeType&&/^(DIV|P|LI|UL|OL|BLOCKQUOTE|DD|DT|H\d|SECTION|PRE)$/.test(e.nodeName)
}function wse(e,t,n,r,o){for(;;){if(e==n&&t==r)return!0;if(t==(o<0?0:xse(e))){
if("DIV"==e.nodeName)return!1;let n=e.parentNode;if(!n||1!=n.nodeType)return!1
;t=yse(e)+(o<0?0:1),e=n}else{if(1!=e.nodeType)return!1
;if(1==(e=e.childNodes[t+(o<0?-1:0)]).nodeType&&"false"==e.contentEditable)return!1
;t=o<0?xse(e):0}}}function xse(e){
return 3==e.nodeType?e.nodeValue.length:e.childNodes.length}function kse(e,t){
let n=t?e.left:e.right;return{left:n,right:n,top:e.top,bottom:e.bottom}}
function Sse(e){let t=e.visualViewport;return t?{left:0,right:t.width,top:0,
bottom:t.height}:{left:0,right:e.innerWidth,top:0,bottom:e.innerHeight}}
function _se(e,t){let n=t.width/e.offsetWidth,r=t.height/e.offsetHeight
;return(n>.995&&n<1.005||!isFinite(n)||Math.abs(t.width-e.offsetWidth)<1)&&(n=1),
(r>.995&&r<1.005||!isFinite(r)||Math.abs(t.height-e.offsetHeight)<1)&&(r=1),{
scaleX:n,scaleY:r}}class Tse{constructor(){
this.anchorNode=null,this.anchorOffset=0,this.focusNode=null,this.focusOffset=0}
eq(e){
return this.anchorNode==e.anchorNode&&this.anchorOffset==e.anchorOffset&&this.focusNode==e.focusNode&&this.focusOffset==e.focusOffset
}setRange(e){let{anchorNode:t,focusNode:n}=e
;this.set(t,Math.min(e.anchorOffset,t?xse(t):0),n,Math.min(e.focusOffset,n?xse(n):0))
}set(e,t,n,r){
this.anchorNode=e,this.anchorOffset=t,this.focusNode=n,this.focusOffset=r}}
let Ese,Ase=null;function Cse(e){if(e.setActive)return e.setActive()
;if(Ase)return e.focus(Ase);let t=[]
;for(let n=e;n&&(t.push(n,n.scrollTop,n.scrollLeft),
n!=n.ownerDocument);n=n.parentNode);if(e.focus(null==Ase?{get preventScroll(){
return Ase={preventScroll:!0},!0}}:void 0),!Ase){Ase=!1
;for(let e=0;e<t.length;){let n=t[e++],r=t[e++],o=t[e++]
;n.scrollTop!=r&&(n.scrollTop=r),n.scrollLeft!=o&&(n.scrollLeft=o)}}}
function $se(e,t,n=t){let r=Ese||(Ese=document.createRange())
;return r.setEnd(e,n),r.setStart(e,t),r}function Pse(e,t,n,r){let o={key:t,
code:t,keyCode:n,which:n,cancelable:!0}
;r&&({altKey:o.altKey,ctrlKey:o.ctrlKey,shiftKey:o.shiftKey,metaKey:o.metaKey}=r)
;let a=new KeyboardEvent("keydown",o);a.synthetic=!0,e.dispatchEvent(a)
;let i=new KeyboardEvent("keyup",o)
;return i.synthetic=!0,e.dispatchEvent(i),a.defaultPrevented||i.defaultPrevented
}function Dse(e){
for(;e.attributes.length;)e.removeAttributeNode(e.attributes[0])}
function Ise(e){return e.scrollTop>Math.max(1,e.scrollHeight-e.clientHeight-4)}
function Mse(e,t){for(let n=e,r=t;;){if(3==n.nodeType&&r>0)return{node:n,
offset:r};if(1==n.nodeType&&r>0){if("false"==n.contentEditable)return null
;n=n.childNodes[r-1],r=xse(n)}else{if(!n.parentNode||Ose(n))return null
;r=yse(n),n=n.parentNode}}}function Nse(e,t){for(let n=e,r=t;;){
if(3==n.nodeType&&r<n.nodeValue.length)return{node:n,offset:r}
;if(1==n.nodeType&&r<n.childNodes.length){
if("false"==n.contentEditable)return null;n=n.childNodes[r],r=0}else{
if(!n.parentNode||Ose(n))return null;r=yse(n)+1,n=n.parentNode}}}class Rse{
constructor(e,t,n=!0){this.node=e,this.offset=t,this.precise=n}
static before(e,t){return new Rse(e.parentNode,yse(e),t)}static after(e,t){
return new Rse(e.parentNode,yse(e)+1,t)}}const Lse=[];class Bse{constructor(){
this.parent=null,this.dom=null,this.flags=2}get overrideDOMText(){return null}
get posAtStart(){return this.parent?this.parent.posBefore(this):0}
get posAtEnd(){return this.posAtStart+this.length}posBefore(e){
let t=this.posAtStart;for(let n of this.children){if(n==e)return t
;t+=n.length+n.breakAfter}throw new RangeError("Invalid child in posBefore")}
posAfter(e){return this.posBefore(e)+e.length}sync(e,t){if(2&this.flags){
let n,r=this.dom,o=null;for(let a of this.children){if(7&a.flags){
if(!a.dom&&(n=o?o.nextSibling:r.firstChild)){let e=Bse.get(n)
;(!e||!e.parent&&e.canReuseDOM(a))&&a.reuseDOM(n)}a.sync(e,t),a.flags&=-8}
if(n=o?o.nextSibling:r.firstChild,
t&&!t.written&&t.node==r&&n!=a.dom&&(t.written=!0),
a.dom.parentNode==r)for(;n&&n!=a.dom;)n=jse(n);else r.insertBefore(a.dom,n)
;o=a.dom}
for(n=o?o.nextSibling:r.firstChild,n&&t&&t.node==r&&(t.written=!0);n;)n=jse(n)
}else if(1&this.flags)for(let n of this.children)7&n.flags&&(n.sync(e,t),
n.flags&=-8)}reuseDOM(e){}localPosFromDOM(e,t){let n
;if(e==this.dom)n=this.dom.childNodes[t];else{let r=0==xse(e)?0:0==t?-1:1
;for(;;){let t=e.parentNode;if(t==this.dom)break
;0==r&&t.firstChild!=t.lastChild&&(r=e==t.firstChild?-1:1),e=t}
n=r<0?e:e.nextSibling}if(n==this.dom.firstChild)return 0
;for(;n&&!Bse.get(n);)n=n.nextSibling;if(!n)return this.length
;for(let r=0,o=0;;r++){let e=this.children[r];if(e.dom==n)return o
;o+=e.length+e.breakAfter}}domBoundsAround(e,t,n=0){let r=-1,o=-1,a=-1,i=-1
;for(let s=0,l=n,c=n;s<this.children.length;s++){
let n=this.children[s],u=l+n.length;if(l<e&&u>t)return n.domBoundsAround(e,t,l)
;if(u>=e&&-1==r&&(r=s,o=l),l>t&&n.dom.parentNode==this.dom){a=s,i=c;break}
c=u,l=u+n.breakAfter}return{from:o,to:i<0?n+this.length:i,
startDOM:(r?this.children[r-1].dom.nextSibling:null)||this.dom.firstChild,
endDOM:a<this.children.length&&a>=0?this.children[a].dom:null}}markDirty(e=!1){
this.flags|=2,this.markParentsDirty(e)}markParentsDirty(e){
for(let t=this.parent;t;t=t.parent){if(e&&(t.flags|=2),1&t.flags)return
;t.flags|=1,e=!1}}setParent(e){
this.parent!=e&&(this.parent=e,7&this.flags&&this.markParentsDirty(!0))}
setDOM(e){
this.dom!=e&&(this.dom&&(this.dom.cmView=null),this.dom=e,e.cmView=this)}
get rootView(){for(let e=this;;){let t=e.parent;if(!t)return e;e=t}}
replaceChildren(e,t,n=Lse){this.markDirty();for(let r=e;r<t;r++){
let e=this.children[r];e.parent==this&&n.indexOf(e)<0&&e.destroy()}
n.length<250?this.children.splice(e,t-e,...n):this.children=[].concat(this.children.slice(0,e),n,this.children.slice(t))
;for(let r=0;r<n.length;r++)n[r].setParent(this)}ignoreMutation(e){return!1}
ignoreEvent(e){return!1}childCursor(e=this.length){
return new Use(this.children,e,this.children.length)}childPos(e,t=1){
return this.childCursor().findPos(e,t)}toString(){
let e=this.constructor.name.replace("View","")
;return e+(this.children.length?"("+this.children.join()+")":this.length?"["+("Text"==e?this.text:this.length)+"]":"")+(this.breakAfter?"#":"")
}static get(e){return e.cmView}get isEditable(){return!0}get isWidget(){return!1
}get isHidden(){return!1}merge(e,t,n,r,o,a){return!1}become(e){return!1}
canReuseDOM(e){return e.constructor==this.constructor&&!(8&(this.flags|e.flags))
}getSide(){return 0}destroy(){
for(let e of this.children)e.parent==this&&e.destroy();this.parent=null}}
function jse(e){let t=e.nextSibling;return e.parentNode.removeChild(e),t}
Bse.prototype.breakAfter=0;class Use{constructor(e,t,n){
this.children=e,this.pos=t,this.i=n,this.off=0}findPos(e,t=1){for(;;){
if(e>this.pos||e==this.pos&&(t>0||0==this.i||this.children[this.i-1].breakAfter))return this.off=e-this.pos,
this;let n=this.children[--this.i];this.pos-=n.length+n.breakAfter}}}
function zse(e,t,n,r,o,a,i,s,l){
let{children:c}=e,u=c.length?c[t]:null,d=a.length?a[a.length-1]:null,p=d?d.breakAfter:i
;if(!(t==r&&u&&!i&&!p&&a.length<2&&u.merge(n,o,a.length?d:null,0==n,s,l))){
if(r<c.length){let e=c[r]
;e&&(o<e.length||e.breakAfter&&(null==d?void 0:d.breakAfter))?(t==r&&(e=e.split(o),
o=0),
!p&&d&&e.merge(0,o,d,!0,0,l)?a[a.length-1]=e:((o||e.children.length&&!e.children[0].length)&&e.merge(0,o,null,!1,0,l),
a.push(e))):(null==e?void 0:e.breakAfter)&&(d?d.breakAfter=1:i=1),r++}
for(u&&(u.breakAfter=i,
n>0&&(!i&&a.length&&u.merge(n,u.length,a[0],!1,s,0)?u.breakAfter=a.shift().breakAfter:(n<u.length||u.children.length&&0==u.children[u.children.length-1].length)&&u.merge(n,u.length,null,!1,s,0),
t++));t<r&&a.length;)if(c[r-1].become(a[a.length-1]))r--,
a.pop(),l=a.length?0:s;else{if(!c[t].become(a[0]))break
;t++,a.shift(),s=a.length?0:l}
!a.length&&t&&r<c.length&&!c[t-1].breakAfter&&c[r].merge(0,0,c[t-1],!1,s,l)&&t--,
(t<r||a.length)&&e.replaceChildren(t,r,a)}}function Fse(e,t,n,r,o,a){
let i=e.childCursor(),{i:s,off:l}=i.findPos(n,1),{i:c,off:u}=i.findPos(t,-1),d=t-n
;for(let p of r)d+=p.length;e.length+=d,zse(e,c,u,s,l,r,0,o,a)}
let Zse="undefined"!=typeof navigator?navigator:{userAgent:"",vendor:"",
platform:""},Qse="undefined"!=typeof document?document:{documentElement:{
style:{}}}
;const Hse=/Edge\/(\d+)/.exec(Zse.userAgent),Vse=/MSIE \d/.test(Zse.userAgent),qse=/Trident\/(?:[7-9]|\d{2,})\..*rv:(\d+)/.exec(Zse.userAgent),Wse=!!(Vse||qse||Hse),Xse=!Wse&&/gecko\/(\d+)/i.test(Zse.userAgent),Gse=!Wse&&/Chrome\/(\d+)/.exec(Zse.userAgent),Yse="webkitFontSmoothing"in Qse.documentElement.style,Kse=!Wse&&/Apple Computer/.test(Zse.vendor),Jse=Kse&&(/Mobile\/\w+/.test(Zse.userAgent)||Zse.maxTouchPoints>2)
;var ele={mac:Jse||/Mac/.test(Zse.platform),windows:/Win/.test(Zse.platform),
linux:/Linux|X11/.test(Zse.platform),ie:Wse,
ie_version:Vse?Qse.documentMode||6:qse?+qse[1]:Hse?+Hse[1]:0,gecko:Xse,
gecko_version:Xse?+(/Firefox\/(\d+)/.exec(Zse.userAgent)||[0,0])[1]:0,
chrome:!!Gse,chrome_version:Gse?+Gse[1]:0,ios:Jse,
android:/Android\b/.test(Zse.userAgent),webkit:Yse,safari:Kse,
webkit_version:Yse?+(/\bAppleWebKit\/(\d+)/.exec(Zse.userAgent)||[0,0])[1]:0,
tabSize:null!=Qse.documentElement.style.tabSize?"tab-size":"-moz-tab-size"}
;class tle extends Bse{constructor(e){super(),this.text=e}get length(){
return this.text.length}createDOM(e){
this.setDOM(e||document.createTextNode(this.text))}sync(e,t){
this.dom||this.createDOM(),
this.dom.nodeValue!=this.text&&(t&&t.node==this.dom&&(t.written=!0),
this.dom.nodeValue=this.text)}reuseDOM(e){3==e.nodeType&&this.createDOM(e)}
merge(e,t,n){
return!(8&this.flags||n&&(!(n instanceof tle)||this.length-(t-e)+n.length>256||8&n.flags))&&(this.text=this.text.slice(0,e)+(n?n.text:"")+this.text.slice(t),
this.markDirty(),!0)}split(e){let t=new tle(this.text.slice(e))
;return this.text=this.text.slice(0,e),this.markDirty(),t.flags|=8&this.flags,t}
localPosFromDOM(e,t){return e==this.dom?t:t?this.text.length:0}domAtPos(e){
return new Rse(this.dom,e)}domBoundsAround(e,t,n){return{from:n,
to:n+this.length,startDOM:this.dom,endDOM:this.dom.nextSibling}}coordsAt(e,t){
return function(e,t,n){let r=e.nodeValue.length;t>r&&(t=r);let o=t,a=t,i=0
;0==t&&n<0||t==r&&n>=0?ele.chrome||ele.gecko||(t?(o--,
i=1):a<r&&(a++,i=-1)):n<0?o--:a<r&&a++;let s=$se(e,o,a).getClientRects()
;if(!s.length)return null;let l=s[(i?i<0:n>=0)?0:s.length-1]
;ele.safari&&!i&&0==l.width&&(l=Array.prototype.find.call(s,(e=>e.width))||l)
;return i?kse(l,i<0):l||null}(this.dom,e,t)}}class nle extends Bse{
constructor(e,t=[],n=0){super(),this.mark=e,this.children=t,this.length=n
;for(let r of t)r.setParent(this)}setAttrs(e){
if(Dse(e),this.mark.class&&(e.className=this.mark.class),
this.mark.attrs)for(let t in this.mark.attrs)e.setAttribute(t,this.mark.attrs[t])
;return e}canReuseDOM(e){return super.canReuseDOM(e)&&!(8&(this.flags|e.flags))}
reuseDOM(e){
e.nodeName==this.mark.tagName.toUpperCase()&&(this.setDOM(e),this.flags|=6)}
sync(e,t){
this.dom?4&this.flags&&this.setAttrs(this.dom):this.setDOM(this.setAttrs(document.createElement(this.mark.tagName))),
super.sync(e,t)}merge(e,t,n,r,o,a){
return(!n||!(!(n instanceof nle&&n.mark.eq(this.mark))||e&&o<=0||t<this.length&&a<=0))&&(Fse(this,e,t,n?n.children.slice():[],o-1,a-1),
this.markDirty(),!0)}split(e){let t=[],n=0,r=-1,o=0;for(let i of this.children){
let a=n+i.length;a>e&&t.push(n<e?i.split(e-n):i),r<0&&n>=e&&(r=o),n=a,o++}
let a=this.length-e
;return this.length=e,r>-1&&(this.children.length=r,this.markDirty()),
new nle(this.mark,t,a)}domAtPos(e){return ale(this,e)}coordsAt(e,t){
return sle(this,e,t)}}class rle extends Bse{static create(e,t,n){
return new rle(e,t,n)}constructor(e,t,n){
super(),this.widget=e,this.length=t,this.side=n,this.prevWidget=null}split(e){
let t=rle.create(this.widget,this.length-e,this.side);return this.length-=e,t}
sync(e){
this.dom&&this.widget.updateDOM(this.dom,e)||(this.dom&&this.prevWidget&&this.prevWidget.destroy(this.dom),
this.prevWidget=null,
this.setDOM(this.widget.toDOM(e)),this.widget.editable||(this.dom.contentEditable="false"))
}getSide(){return this.side}merge(e,t,n,r,o,a){
return!(n&&(!(n instanceof rle&&this.widget.compare(n.widget))||e>0&&o<=0||t<this.length&&a<=0))&&(this.length=e+(n?n.length:0)+(this.length-t),
!0)}become(e){
return e instanceof rle&&e.side==this.side&&this.widget.constructor==e.widget.constructor&&(this.widget.compare(e.widget)||this.markDirty(!0),
this.dom&&!this.prevWidget&&(this.prevWidget=this.widget),
this.widget=e.widget,this.length=e.length,!0)}ignoreMutation(){return!0}
ignoreEvent(e){return this.widget.ignoreEvent(e)}get overrideDOMText(){
if(0==this.length)return wae.empty;let e=this;for(;e.parent;)e=e.parent
;let{view:t}=e,n=t&&t.state.doc,r=this.posAtStart
;return n?n.slice(r,r+this.length):wae.empty}domAtPos(e){
return(this.length?0==e:this.side>0)?Rse.before(this.dom):Rse.after(this.dom,e==this.length)
}domBoundsAround(){return null}coordsAt(e,t){
let n=this.widget.coordsAt(this.dom,e,t);if(n)return n
;let r=this.dom.getClientRects(),o=null;if(!r.length)return null
;let a=this.side?this.side<0:e>0
;for(let i=a?r.length-1:0;o=r[i],!(e>0?0==i:i==r.length-1||o.top<o.bottom);i+=a?-1:1);
return kse(o,!a)}get isEditable(){return!1}get isWidget(){return!0}
get isHidden(){return this.widget.isHidden}destroy(){
super.destroy(),this.dom&&this.widget.destroy(this.dom)}}class ole extends Bse{
constructor(e){super(),this.side=e}get length(){return 0}merge(){return!1}
become(e){return e instanceof ole&&e.side==this.side}split(){
return new ole(this.side)}sync(){if(!this.dom){
let e=document.createElement("img")
;e.className="cm-widgetBuffer",e.setAttribute("aria-hidden","true"),
this.setDOM(e)}}getSide(){return this.side}domAtPos(e){
return this.side>0?Rse.before(this.dom):Rse.after(this.dom)}localPosFromDOM(){
return 0}domBoundsAround(){return null}coordsAt(e){
return this.dom.getBoundingClientRect()}get overrideDOMText(){return wae.empty}
get isHidden(){return!0}}function ale(e,t){let n=e.dom,{children:r}=e,o=0
;for(let a=0;o<r.length;o++){let e=r[o],i=a+e.length
;if(!(i==a&&e.getSide()<=0)){
if(t>a&&t<i&&e.dom.parentNode==n)return e.domAtPos(t-a);if(t<=a)break;a=i}}
for(let a=o;a>0;a--){let e=r[a-1]
;if(e.dom.parentNode==n)return e.domAtPos(e.length)}for(let a=o;a<r.length;a++){
let e=r[a];if(e.dom.parentNode==n)return e.domAtPos(0)}return new Rse(n,0)}
function ile(e,t,n){let r,{children:o}=e
;n>0&&t instanceof nle&&o.length&&(r=o[o.length-1])instanceof nle&&r.mark.eq(t.mark)?ile(r,t.children[0],n-1):(o.push(t),
t.setParent(e)),e.length+=t.length}function sle(e,t,n){
let r=null,o=-1,a=null,i=-1;!function e(t,s){
for(let l=0,c=0;l<t.children.length&&c<=s;l++){let u=t.children[l],d=c+u.length
;d>=s&&(u.children.length?e(u,s-c):(!a||a.isHidden&&n>0)&&(d>s||c==d&&u.getSide()>0)?(a=u,
i=s-c):(c<s||c==d&&u.getSide()<0&&!u.isHidden)&&(r=u,o=s-c)),c=d}}(e,t)
;let s=(n<0?r:a)||r||a;return s?s.coordsAt(Math.max(0,s==r?o:i),n):function(e){
let t=e.dom.lastChild;if(!t)return e.dom.getBoundingClientRect();let n=vse(t)
;return n[n.length-1]||null}(e)}function lle(e,t){
for(let n in e)"class"==n&&t.class?t.class+=" "+e.class:"style"==n&&t.style?t.style+=";"+e.style:t[n]=e[n]
;return t}
tle.prototype.children=rle.prototype.children=ole.prototype.children=Lse
;const cle=Object.create(null);function ule(e,t,n){if(e==t)return!0
;e||(e=cle),t||(t=cle);let r=Object.keys(e),o=Object.keys(t)
;if(r.length-(n&&r.indexOf(n)>-1?1:0)!=o.length-(n&&o.indexOf(n)>-1?1:0))return!1
;for(let a of r)if(a!=n&&(-1==o.indexOf(a)||e[a]!==t[a]))return!1;return!0}
function dle(e,t,n){let r=!1
;if(t)for(let o in t)n&&o in n||(r=!0,"style"==o?e.style.cssText="":e.removeAttribute(o))
;if(n)for(let o in n)t&&t[o]==n[o]||(r=!0,
"style"==o?e.style.cssText=n[o]:e.setAttribute(o,n[o]));return r}
function ple(e){let t=Object.create(null)
;for(let n=0;n<e.attributes.length;n++){let r=e.attributes[n];t[r.name]=r.value}
return t}class hle{eq(e){return!1}updateDOM(e,t){return!1}compare(e){
return this==e||this.constructor==e.constructor&&this.eq(e)}
get estimatedHeight(){return-1}get lineBreaks(){return 0}ignoreEvent(e){return!0
}coordsAt(e,t,n){return null}get isHidden(){return!1}get editable(){return!1}
destroy(e){}}var fle=function(e){
return e[e.Text=0]="Text",e[e.WidgetBefore=1]="WidgetBefore",
e[e.WidgetAfter=2]="WidgetAfter",e[e.WidgetRange=3]="WidgetRange",e
}(fle||(fle={}));class mle extends jie{constructor(e,t,n,r){
super(),this.startSide=e,this.endSide=t,this.widget=n,this.spec=r}
get heightRelevant(){return!1}static mark(e){return new gle(e)}static widget(e){
let t=Math.max(-1e4,Math.min(1e4,e.side||0)),n=!!e.block
;return t+=n&&!e.inlineOrder?t>0?3e8:-4e8:t>0?1e8:-1e8,
new ble(e,t,t,n,e.widget||null,!1)}static replace(e){let t,n,r=!!e.block
;if(e.isBlockGap)t=-5e8,n=4e8;else{let{start:o,end:a}=yle(e,r)
;t=(o?r?-3e8:-1:5e8)-1,n=1+(a?r?2e8:1:-6e8)}
return new ble(e,t,n,r,e.widget||null,!0)}static line(e){return new vle(e)}
static set(e,t=!1){return Zie.of(e,t)}hasHeight(){
return!!this.widget&&this.widget.estimatedHeight>-1}}mle.none=Zie.empty
;class gle extends mle{constructor(e){let{start:t,end:n}=yle(e)
;super(t?-1:5e8,n?1:-6e8,null,e),
this.tagName=e.tagName||"span",this.class=e.class||"",
this.attrs=e.attributes||null}eq(e){var t,n
;return this==e||e instanceof gle&&this.tagName==e.tagName&&(this.class||(null===(t=this.attrs)||void 0===t?void 0:t.class))==(e.class||(null===(n=e.attrs)||void 0===n?void 0:n.class))&&ule(this.attrs,e.attrs,"class")
}range(e,t=e){if(e>=t)throw new RangeError("Mark decorations may not be empty")
;return super.range(e,t)}}gle.prototype.point=!1;class vle extends mle{
constructor(e){super(-2e8,-2e8,null,e)}eq(e){
return e instanceof vle&&this.spec.class==e.spec.class&&ule(this.spec.attributes,e.spec.attributes)
}range(e,t=e){
if(t!=e)throw new RangeError("Line decoration ranges must be zero-length")
;return super.range(e,t)}}
vle.prototype.mapMode=Rae.TrackBefore,vle.prototype.point=!0
;class ble extends mle{constructor(e,t,n,r,o,a){
super(t,n,o,e),this.block=r,this.isReplace=a,
this.mapMode=r?t<=0?Rae.TrackBefore:Rae.TrackAfter:Rae.TrackDel}get type(){
return this.startSide!=this.endSide?fle.WidgetRange:this.startSide<=0?fle.WidgetBefore:fle.WidgetAfter
}get heightRelevant(){
return this.block||!!this.widget&&(this.widget.estimatedHeight>=5||this.widget.lineBreaks>0)
}eq(e){
return e instanceof ble&&(t=this.widget,n=e.widget,t==n||!!(t&&n&&t.compare(n)))&&this.block==e.block&&this.startSide==e.startSide&&this.endSide==e.endSide
;var t,n}range(e,t=e){
if(this.isReplace&&(e>t||e==t&&this.startSide>0&&this.endSide<=0))throw new RangeError("Invalid range for replacement decoration")
;if(!this.isReplace&&t!=e)throw new RangeError("Widget decorations can only have zero-length ranges")
;return super.range(e,t)}}function yle(e,t=!1){
let{inclusiveStart:n,inclusiveEnd:r}=e
;return null==n&&(n=e.inclusive),null==r&&(r=e.inclusive),{start:null!=n?n:t,
end:null!=r?r:t}}function Ole(e,t,n,r=0){let o=n.length-1
;o>=0&&n[o]+r>=e?n[o]=Math.max(n[o],t):n.push(e,t)}ble.prototype.point=!0
;class wle extends Bse{constructor(){
super(...arguments),this.children=[],this.length=0,
this.prevAttrs=void 0,this.attrs=null,this.breakAfter=0}merge(e,t,n,r,o,a){
if(n){if(!(n instanceof wle))return!1;this.dom||n.transferDOM(this)}
return r&&this.setDeco(n?n.attrs:null),
Fse(this,e,t,n?n.children.slice():[],o,a),!0}split(e){let t=new wle
;if(t.breakAfter=this.breakAfter,0==this.length)return t
;let{i:n,off:r}=this.childPos(e)
;r&&(t.append(this.children[n].split(r),0),this.children[n].merge(r,this.children[n].length,null,!1,0,0),
n++);for(let o=n;o<this.children.length;o++)t.append(this.children[o],0)
;for(;n>0&&0==this.children[n-1].length;)this.children[--n].destroy()
;return this.children.length=n,this.markDirty(),this.length=e,t}transferDOM(e){
this.dom&&(this.markDirty(),
e.setDOM(this.dom),e.prevAttrs=void 0===this.prevAttrs?this.attrs:this.prevAttrs,
this.prevAttrs=void 0,this.dom=null)}setDeco(e){
ule(this.attrs,e)||(this.dom&&(this.prevAttrs=this.attrs,
this.markDirty()),this.attrs=e)}append(e,t){ile(this,e,t)}addLineDeco(e){
let t=e.spec.attributes,n=e.spec.class
;t&&(this.attrs=lle(t,this.attrs||{})),n&&(this.attrs=lle({class:n
},this.attrs||{}))}domAtPos(e){return ale(this,e)}reuseDOM(e){
"DIV"==e.nodeName&&(this.setDOM(e),this.flags|=6)}sync(e,t){var n
;this.dom?4&this.flags&&(Dse(this.dom),
this.dom.className="cm-line",this.prevAttrs=this.attrs?null:void 0):(this.setDOM(document.createElement("div")),
this.dom.className="cm-line",
this.prevAttrs=this.attrs?null:void 0),void 0!==this.prevAttrs&&(dle(this.dom,this.prevAttrs,this.attrs),
this.dom.classList.add("cm-line"),this.prevAttrs=void 0),super.sync(e,t)
;let r=this.dom.lastChild;for(;r&&Bse.get(r)instanceof nle;)r=r.lastChild
;if(!(r&&this.length&&("BR"==r.nodeName||0!=(null===(n=Bse.get(r))||void 0===n?void 0:n.isEditable)||ele.ios&&this.children.some((e=>e instanceof tle))))){
let e=document.createElement("BR");e.cmIgnore=!0,this.dom.appendChild(e)}}
measureTextSize(){if(0==this.children.length||this.length>20)return null
;let e,t=0;for(let n of this.children){
if(!(n instanceof tle)||/[^ -~]/.test(n.text))return null;let r=vse(n.dom)
;if(1!=r.length)return null;t+=r[0].width,e=r[0].height}return t?{
lineHeight:this.dom.getBoundingClientRect().height,charWidth:t/this.length,
textHeight:e}:null}coordsAt(e,t){let n=sle(this,e,t)
;if(!this.children.length&&n&&this.parent){
let{heightOracle:e}=this.parent.view.viewState,t=n.bottom-n.top
;if(Math.abs(t-e.lineHeight)<2&&e.textHeight<t){let r=(t-e.textHeight)/2;return{
top:n.top+r,bottom:n.bottom-r,left:n.left,right:n.left}}}return n}become(e){
return e instanceof wle&&0==this.children.length&&0==e.children.length&&ule(this.attrs,e.attrs)&&this.breakAfter==e.breakAfter
}covers(){return!0}static find(e,t){for(let n=0,r=0;n<e.children.length;n++){
let o=e.children[n],a=r+o.length;if(a>=t){if(o instanceof wle)return o
;if(a>t)break}r=a+o.breakAfter}return null}}class xle extends Bse{
constructor(e,t,n){
super(),this.widget=e,this.length=t,this.deco=n,this.breakAfter=0,
this.prevWidget=null}merge(e,t,n,r,o,a){
return!(n&&(!(n instanceof xle&&this.widget.compare(n.widget))||e>0&&o<=0||t<this.length&&a<=0))&&(this.length=e+(n?n.length:0)+(this.length-t),
!0)}domAtPos(e){
return 0==e?Rse.before(this.dom):Rse.after(this.dom,e==this.length)}split(e){
let t=this.length-e;this.length=e;let n=new xle(this.widget,t,this.deco)
;return n.breakAfter=this.breakAfter,n}get children(){return Lse}sync(e){
this.dom&&this.widget.updateDOM(this.dom,e)||(this.dom&&this.prevWidget&&this.prevWidget.destroy(this.dom),
this.prevWidget=null,
this.setDOM(this.widget.toDOM(e)),this.widget.editable||(this.dom.contentEditable="false"))
}get overrideDOMText(){
return this.parent?this.parent.view.state.doc.slice(this.posAtStart,this.posAtEnd):wae.empty
}domBoundsAround(){return null}become(e){
return e instanceof xle&&e.widget.constructor==this.widget.constructor&&(e.widget.compare(this.widget)||this.markDirty(!0),
this.dom&&!this.prevWidget&&(this.prevWidget=this.widget),
this.widget=e.widget,this.length=e.length,
this.deco=e.deco,this.breakAfter=e.breakAfter,!0)}ignoreMutation(){return!0}
ignoreEvent(e){return this.widget.ignoreEvent(e)}get isEditable(){return!1}
get isWidget(){return!0}coordsAt(e,t){let n=this.widget.coordsAt(this.dom,e,t)
;return n||(this.widget instanceof kle?null:kse(this.dom.getBoundingClientRect(),this.length?0==e:t<=0))
}destroy(){super.destroy(),this.dom&&this.widget.destroy(this.dom)}covers(e){
let{startSide:t,endSide:n}=this.deco;return t!=n&&(e<0?t<0:n>0)}}
class kle extends hle{constructor(e){super(),this.height=e}toDOM(){
let e=document.createElement("div")
;return e.className="cm-gap",this.updateDOM(e),e}eq(e){
return e.height==this.height}updateDOM(e){
return e.style.height=this.height+"px",!0}get editable(){return!0}
get estimatedHeight(){return this.height}ignoreEvent(){return!1}}class Sle{
constructor(e,t,n,r){
this.doc=e,this.pos=t,this.end=n,this.disallowBlockEffectsFor=r,this.content=[],
this.curLine=null,
this.breakAtStart=0,this.pendingBuffer=0,this.bufferMarks=[],this.atCursorPos=!0,
this.openStart=-1,
this.openEnd=-1,this.text="",this.textOff=0,this.cursor=e.iter(),this.skip=t}
posCovered(){
if(0==this.content.length)return!this.breakAtStart&&this.doc.lineAt(this.pos).from!=this.pos
;let e=this.content[this.content.length-1]
;return!(e.breakAfter||e instanceof xle&&e.deco.endSide<0)}getLine(){
return this.curLine||(this.content.push(this.curLine=new wle),
this.atCursorPos=!0),this.curLine}flushBuffer(e=this.bufferMarks){
this.pendingBuffer&&(this.curLine.append(_le(new ole(-1),e),e.length),
this.pendingBuffer=0)}addBlockWidget(e){
this.flushBuffer(),this.curLine=null,this.content.push(e)}finish(e){
this.pendingBuffer&&e<=this.bufferMarks.length?this.flushBuffer():this.pendingBuffer=0,
this.posCovered()||e&&this.content.length&&this.content[this.content.length-1]instanceof xle||this.getLine()
}buildText(e,t,n){for(;e>0;){if(this.textOff==this.text.length){
let{value:t,lineBreak:n,done:r}=this.cursor.next(this.skip)
;if(this.skip=0,r)throw new Error("Ran out of text content when drawing inline views")
;if(n){
this.posCovered()||this.getLine(),this.content.length?this.content[this.content.length-1].breakAfter=1:this.breakAtStart=1,
this.flushBuffer(),this.curLine=null,this.atCursorPos=!0,e--;continue}
this.text=t,this.textOff=0}let r=Math.min(this.text.length-this.textOff,e,512)
;this.flushBuffer(t.slice(t.length-n)),
this.getLine().append(_le(new tle(this.text.slice(this.textOff,this.textOff+r)),t),n),
this.atCursorPos=!0,this.textOff+=r,e-=r,n=0}}span(e,t,n,r){
this.buildText(t-e,n,r),this.pos=t,this.openStart<0&&(this.openStart=r)}
point(e,t,n,r,o,a){if(this.disallowBlockEffectsFor[a]&&n instanceof ble){
if(n.block)throw new RangeError("Block decorations may not be specified via plugins")
;if(t>this.doc.lineAt(this.pos).to)throw new RangeError("Decorations that replace line breaks may not be specified via plugins")
}let i=t-e
;if(n instanceof ble)if(n.block)n.startSide>0&&!this.posCovered()&&this.getLine(),
this.addBlockWidget(new xle(n.widget||Tle.block,i,n));else{
let a=rle.create(n.widget||Tle.inline,i,i?0:n.startSide),s=this.atCursorPos&&!a.isEditable&&o<=r.length&&(e<t||n.startSide>0),l=!a.isEditable&&(e<t||o>r.length||n.startSide<=0),c=this.getLine()
;2!=this.pendingBuffer||s||a.isEditable||(this.pendingBuffer=0),
this.flushBuffer(r),
s&&(c.append(_le(new ole(1),r),o),o=r.length+Math.max(0,o-r.length)),
c.append(_le(a,r),o),
this.atCursorPos=l,this.pendingBuffer=l?e<t||o>r.length?1:2:0,
this.pendingBuffer&&(this.bufferMarks=r.slice())
}else this.doc.lineAt(this.pos).from==this.pos&&this.getLine().addLineDeco(n)
;i&&(this.textOff+i<=this.text.length?this.textOff+=i:(this.skip+=i-(this.text.length-this.textOff),
this.text="",this.textOff=0),this.pos=t),this.openStart<0&&(this.openStart=o)}
static build(e,t,n,r,o){let a=new Sle(e,t,n,o)
;return a.openEnd=Zie.spans(r,t,n,a),
a.openStart<0&&(a.openStart=a.openEnd),a.finish(a.openEnd),a}}function _le(e,t){
for(let n of t)e=new nle(n,[e],e.length);return e}class Tle extends hle{
constructor(e){super(),this.tag=e}eq(e){return e.tag==this.tag}toDOM(){
return document.createElement(this.tag)}updateDOM(e){
return e.nodeName.toLowerCase()==this.tag}get isHidden(){return!0}}
Tle.inline=new Tle("span"),Tle.block=new Tle("div");var Ele=function(e){
return e[e.LTR=0]="LTR",e[e.RTL=1]="RTL",e}(Ele||(Ele={}))
;const Ale=Ele.LTR,Cle=Ele.RTL;function $le(e){let t=[]
;for(let n=0;n<e.length;n++)t.push(1<<+e[n]);return t}
const Ple=$le("88888888888888888888888888888888888666888888787833333333337888888000000000000000000000000008888880000000000000000000000000088888888888888888888888888888888888887866668888088888663380888308888800000000000000000000000800000000000000000000000000000008"),Dle=$le("4444448826627288999999999992222222222222222222222222222222222222222222222229999999999999999999994444444444644222822222222222222222222222222222222222222222222222222222222222222222222222222222222222222222222222222222999999949999999229989999223333333333"),Ile=Object.create(null),Mle=[]
;for(let v5e of["()","[]","{}"]){let e=v5e.charCodeAt(0),t=v5e.charCodeAt(1)
;Ile[e]=t,Ile[t]=-e}function Nle(e){
return e<=247?Ple[e]:1424<=e&&e<=1524?2:1536<=e&&e<=1785?Dle[e-1536]:1774<=e&&e<=2220?4:8192<=e&&e<=8204?256:64336<=e&&e<=65023?4:1
}const Rle=/[\u0590-\u05f4\u0600-\u06ff\u0700-\u08ac\ufb50-\ufdff]/;class Lle{
get dir(){return this.level%2?Cle:Ale}constructor(e,t,n){
this.from=e,this.to=t,this.level=n}side(e,t){
return this.dir==t==e?this.to:this.from}forward(e,t){return e==(this.dir==t)}
static find(e,t,n,r){let o=-1;for(let a=0;a<e.length;a++){let i=e[a]
;if(i.from<=t&&i.to>=t){if(i.level==n)return a
;(o<0||(0!=r?r<0?i.from<t:i.to>t:e[o].level>i.level))&&(o=a)}}
if(o<0)throw new RangeError("Index out of range");return o}}function Ble(e,t){
if(e.length!=t.length)return!1;for(let n=0;n<e.length;n++){let r=e[n],o=t[n]
;if(r.from!=o.from||r.to!=o.to||r.direction!=o.direction||!Ble(r.inner,o.inner))return!1
}return!0}const jle=[];function Ule(e,t,n,r,o,a,i){let s=r%2?2:1
;if(r%2==o%2)for(let l=t,c=0;l<n;){let t=!0,u=!1;if(c==a.length||l<a[c].from){
let e=jle[l];e!=s&&(t=!1,u=16==e)}let d=t||1!=s?null:[],p=t?r:r+1,h=l
;e:for(;;)if(c<a.length&&h==a[c].from){if(u)break e;let f=a[c]
;if(!t)for(let e=f.to,t=c+1;;){if(e==n)break e;if(!(t<a.length&&a[t].from==e)){
if(jle[e]==s)break e;break}e=a[t++].to}if(c++,d)d.push(f);else{
f.from>l&&i.push(new Lle(l,f.from,p)),
zle(e,f.direction==Ale!=!(p%2)?r+1:r,o,f.inner,f.from,f.to,i),l=f.to}h=f.to
}else{if(h==n||(t?jle[h]!=s:jle[h]==s))break;h++}
d?Ule(e,l,h,r+1,o,d,i):l<h&&i.push(new Lle(l,h,p)),l=h
}else for(let l=n,c=a.length;l>t;){let n=!0,u=!1;if(!c||l>a[c-1].to){
let e=jle[l-1];e!=s&&(n=!1,u=16==e)}let d=n||1!=s?null:[],p=n?r:r+1,h=l
;e:for(;;)if(c&&h==a[c-1].to){if(u)break e;let f=a[--c]
;if(!n)for(let e=f.from,n=c;;){if(e==t)break e;if(!n||a[n-1].to!=e){
if(jle[e-1]==s)break e;break}e=a[--n].from}if(d)d.push(f);else{
f.to<l&&i.push(new Lle(f.to,l,p)),
zle(e,f.direction==Ale!=!(p%2)?r+1:r,o,f.inner,f.from,f.to,i),l=f.from}h=f.from
}else{if(h==t||(n?jle[h-1]!=s:jle[h-1]==s))break;h--}
d?Ule(e,h,l,r+1,o,d,i):h<l&&i.push(new Lle(h,l,p)),l=h}}
function zle(e,t,n,r,o,a,i){let s=t%2?2:1;!function(e,t,n,r,o){
for(let a=0;a<=r.length;a++){
let i=a?r[a-1].to:t,s=a<r.length?r[a].from:n,l=a?256:o
;for(let t=i,n=l,r=l;t<s;t++){let o=Nle(e.charCodeAt(t))
;512==o?o=n:8==o&&4==r&&(o=16),jle[t]=4==o?2:o,7&o&&(r=o),n=o}
for(let e=i,t=l,r=l;e<s;e++){let o=jle[e]
;if(128==o)e<s-1&&t==jle[e+1]&&24&t?o=jle[e]=t:jle[e]=256;else if(64==o){
let o=e+1;for(;o<s&&64==jle[o];)o++;let a=e&&8==t||o<n&&8==jle[o]?1==r?1:8:256
;for(let t=e;t<o;t++)jle[t]=a;e=o-1}else 8==o&&1==r&&(jle[e]=1);t=o,7&o&&(r=o)}}
}(e,o,a,r,s),function(e,t,n,r,o){let a=1==o?2:1
;for(let i=0,s=0,l=0;i<=r.length;i++){
let c=i?r[i-1].to:t,u=i<r.length?r[i].from:n
;for(let t,n,r,i=c;i<u;i++)if(n=Ile[t=e.charCodeAt(i)])if(n<0){
for(let e=s-3;e>=0;e-=3)if(Mle[e+1]==-n){let t=Mle[e+2],n=2&t?o:4&t?1&t?a:o:0
;n&&(jle[i]=jle[Mle[e]]=n),s=e;break}}else{if(189==Mle.length)break
;Mle[s++]=i,Mle[s++]=t,Mle[s++]=l}else if(2==(r=jle[i])||1==r){let e=r==o
;l=e?0:1;for(let t=s-3;t>=0;t-=3){let n=Mle[t+2];if(2&n)break
;if(e)Mle[t+2]|=2;else{if(4&n)break;Mle[t+2]|=4}}}}
}(e,o,a,r,s),function(e,t,n,r){for(let o=0,a=r;o<=n.length;o++){
let i=o?n[o-1].to:e,s=o<n.length?n[o].from:t;for(let l=i;l<s;){let i=jle[l]
;if(256==i){let i=l+1;for(;;)if(i==s){if(o==n.length)break
;i=n[o++].to,s=o<n.length?n[o].from:t}else{if(256!=jle[i])break;i++}
let c=1==a,u=c==(1==(i<t?jle[i]:r))?c?1:2:r
;for(let t=i,r=o,a=r?n[r-1].to:e;t>l;)t==a&&(t=n[--r].from,
a=r?n[r-1].to:e),jle[--t]=u;l=i}else a=i,l++}}}(o,a,r,s),Ule(e,o,a,t,n,r,i)}
function Fle(e){return[new Lle(0,e,0)]}let Zle="";function Qle(e,t,n,r,o){var a
;let i=r.head-e.from,s=Lle.find(t,i,null!==(a=r.bidiLevel)&&void 0!==a?a:-1,r.assoc),l=t[s],c=l.side(o,n)
;if(i==c){let e=s+=o?1:-1;if(e<0||e>=t.length)return null
;l=t[s=e],i=l.side(!o,n),c=l.side(o,n)}let u=Pae(e.text,i,l.forward(o,n))
;(u<l.from||u>l.to)&&(u=c),Zle=e.text.slice(Math.min(i,u),Math.max(i,u))
;let d=s==(o?t.length-1:0)?null:t[s+(o?1:-1)]
;return d&&u==c&&d.level+(o?0:1)<l.level?Vae.cursor(d.side(!o,n)+e.from,d.forward(o,n)?1:-1,d.level):Vae.cursor(u+e.from,l.forward(o,n)?-1:1,l.level)
}function Hle(e,t,n){for(let r=t;r<n;r++){let t=Nle(e.charCodeAt(r))
;if(1==t)return Ale;if(2==t||4==t)return Cle}return Ale}
const Vle=Xae.define(),qle=Xae.define(),Wle=Xae.define(),Xle=Xae.define(),Gle=Xae.define(),Yle=Xae.define(),Kle=Xae.define(),Jle=Xae.define(),ece=Xae.define(),tce=Xae.define({
combine:e=>e.some((e=>e))}),nce=Xae.define({combine:e=>e.some((e=>e))
}),rce=Xae.define();class oce{
constructor(e,t="nearest",n="nearest",r=5,o=5,a=!1){
this.range=e,this.y=t,this.x=n,this.yMargin=r,this.xMargin=o,this.isSnapshot=a}
map(e){
return e.empty?this:new oce(this.range.map(e),this.y,this.x,this.yMargin,this.xMargin,this.isSnapshot)
}clip(e){
return this.range.to<=e.doc.length?this:new oce(Vae.cursor(e.doc.length),this.y,this.x,this.yMargin,this.xMargin,this.isSnapshot)
}}const ace=_ie.define({map:(e,t)=>e.map(t)}),ice=_ie.define()
;function sce(e,t,n){let r=e.facet(Xle)
;r.length?r[0](t):window.onerror?window.onerror(String(t),n,void 0,void 0,t):n?console.error(n+":",t):console.error(t)
}const lce=Xae.define({combine:e=>!e.length||e[0]});let cce=0
;const uce=Xae.define();class dce{constructor(e,t,n,r,o){
this.id=e,this.create=t,
this.domEventHandlers=n,this.domEventObservers=r,this.extension=o(this)}
static define(e,t){
const{eventHandlers:n,eventObservers:r,provide:o,decorations:a}=t||{}
;return new dce(cce++,e,n,r,(e=>{let t=[uce.of(e)];return a&&t.push(mce.of((t=>{
let n=t.plugin(e);return n?a(n):mle.none}))),o&&t.push(o(e)),t}))}
static fromClass(e,t){return dce.define((t=>new e(t)),t)}}class pce{
constructor(e){this.spec=e,this.mustUpdate=null,this.value=null}update(e){
if(this.value){if(this.mustUpdate){let e=this.mustUpdate
;if(this.mustUpdate=null,this.value.update)try{this.value.update(e)}catch(Bw){
if(sce(e.state,Bw,"CodeMirror plugin crashed"),this.value.destroy)try{
this.value.destroy()}catch(g5e){}this.deactivate()}}}else if(this.spec)try{
this.value=this.spec.create(e)}catch(Bw){
sce(e.state,Bw,"CodeMirror plugin crashed"),this.deactivate()}return this}
destroy(e){var t;if(null===(t=this.value)||void 0===t?void 0:t.destroy)try{
this.value.destroy()}catch(Bw){sce(e.state,Bw,"CodeMirror plugin crashed")}}
deactivate(){this.spec=this.value=null}}
const hce=Xae.define(),fce=Xae.define(),mce=Xae.define(),gce=Xae.define(),vce=Xae.define(),bce=Xae.define()
;function yce(e,t){let n=e.state.facet(bce);if(!n.length)return n
;let r=n.map((t=>t instanceof Function?t(e):t)),o=[]
;return Zie.spans(r,t.from,t.to,{point(){},span(e,n,r,a){
let i=e-t.from,s=n-t.from,l=o;for(let o=r.length-1;o>=0;o--,a--){
let e,n=r[o].spec.bidiIsolate
;if(null==n&&(n=Hle(t.text,i,s)),a>0&&l.length&&(e=l[l.length-1]).to==i&&e.direction==n)e.to=s,
l=e.inner;else{let e={from:i,to:s,direction:n,inner:[]};l.push(e),l=e.inner}}}
}),o}const Oce=Xae.define();function wce(e){let t=0,n=0,r=0,o=0
;for(let a of e.state.facet(Oce)){let i=a(e)
;i&&(null!=i.left&&(t=Math.max(t,i.left)),
null!=i.right&&(n=Math.max(n,i.right)),
null!=i.top&&(r=Math.max(r,i.top)),null!=i.bottom&&(o=Math.max(o,i.bottom)))}
return{left:t,right:n,top:r,bottom:o}}const xce=Xae.define();class kce{
constructor(e,t,n,r){this.fromA=e,this.toA=t,this.fromB=n,this.toB=r}join(e){
return new kce(Math.min(this.fromA,e.fromA),Math.max(this.toA,e.toA),Math.min(this.fromB,e.fromB),Math.max(this.toB,e.toB))
}addToSet(e){let t=e.length,n=this;for(;t>0;t--){let r=e[t-1]
;if(!(r.fromA>n.toA)){if(r.toA<n.fromA)break;n=n.join(r),e.splice(t-1,1)}}
return e.splice(t,0,n),e}static extendWithRanges(e,t){if(0==t.length)return e
;let n=[];for(let r=0,o=0,a=0,i=0;;r++){
let s=r==e.length?null:e[r],l=a-i,c=s?s.fromB:1e9;for(;o<t.length&&t[o]<c;){
let e=t[o],r=t[o+1],a=Math.max(i,e),s=Math.min(c,r)
;if(a<=s&&new kce(a+l,s+l,a,s).addToSet(n),r>c)break;o+=2}if(!s)return n
;new kce(s.fromA,s.toA,s.fromB,s.toB).addToSet(n),a=s.toA,i=s.toB}}}class Sce{
constructor(e,t,n){
this.view=e,this.state=t,this.transactions=n,this.flags=0,this.startState=e.state,
this.changes=Bae.empty(this.startState.doc.length)
;for(let o of n)this.changes=this.changes.compose(o.changes);let r=[]
;this.changes.iterChangedRanges(((e,t,n,o)=>r.push(new kce(e,t,n,o)))),
this.changedRanges=r}static create(e,t,n){return new Sce(e,t,n)}
get viewportChanged(){return(4&this.flags)>0}get heightChanged(){
return(2&this.flags)>0}get geometryChanged(){
return this.docChanged||(10&this.flags)>0}get focusChanged(){
return(1&this.flags)>0}get docChanged(){return!this.changes.empty}
get selectionSet(){return this.transactions.some((e=>e.selection))}get empty(){
return 0==this.flags&&0==this.transactions.length}}class _ce extends Bse{
get length(){return this.view.state.doc.length}constructor(e){
super(),this.view=e,
this.decorations=[],this.dynamicDecorationMap=[!1],this.domChanged=null,
this.hasComposition=null,
this.markedForComposition=new Set,this.editContextFormatting=mle.none,
this.lastCompositionAfterCursor=!1,
this.minWidth=0,this.minWidthFrom=0,this.minWidthTo=0,this.impreciseAnchor=null,
this.impreciseHead=null,
this.forceSelection=!1,this.lastUpdate=Date.now(),this.setDOM(e.contentDOM),
this.children=[new wle],
this.children[0].setParent(this),this.updateDeco(),this.updateInner([new kce(0,0,0,e.state.doc.length)],0,null)
}update(e){var t;let n=e.changedRanges
;this.minWidth>0&&n.length&&(n.every((({fromA:e,toA:t})=>t<this.minWidthFrom||e>this.minWidthTo))?(this.minWidthFrom=e.changes.mapPos(this.minWidthFrom,1),
this.minWidthTo=e.changes.mapPos(this.minWidthTo,1)):this.minWidth=this.minWidthFrom=this.minWidthTo=0),
this.updateEditContextFormatting(e);let r=-1
;this.view.inputState.composing>=0&&!this.view.observer.editContext&&((null===(t=this.domChanged)||void 0===t?void 0:t.newSel)?r=this.domChanged.newSel.head:function(e,t){
let n=!1;t&&e.iterChangedRanges(((e,r)=>{e<t.to&&r>t.from&&(n=!0)}));return n
}(e.changes,this.hasComposition)||e.selectionSet||(r=e.state.selection.main.head))
;let o=r>-1?function(e,t,n){let r=Tce(e,n);if(!r)return null
;let{node:o,from:a,to:i}=r,s=o.nodeValue;if(/[\n\r]/.test(s))return null
;if(e.state.doc.sliceString(r.from,r.to)!=s)return null
;let l=t.invertedDesc,c=new kce(l.mapPos(a),l.mapPos(i),a,i),u=[]
;for(let d=o.parentNode;;d=d.parentNode){let t=Bse.get(d)
;if(t instanceof nle)u.push({node:d,deco:t.mark});else{
if(t instanceof wle||"DIV"==d.nodeName&&d.parentNode==e.contentDOM)return{
range:c,text:o,marks:u,line:d};if(d==e.contentDOM)return null;u.push({node:d,
deco:new gle({inclusive:!0,attributes:ple(d),tagName:d.tagName.toLowerCase()})})
}}}(this.view,e.changes,r):null;if(this.domChanged=null,this.hasComposition){
this.markedForComposition.clear();let{from:t,to:r}=this.hasComposition
;n=new kce(t,r,e.changes.mapPos(t,-1),e.changes.mapPos(r,1)).addToSet(n.slice())
}this.hasComposition=o?{from:o.range.fromB,to:o.range.toB
}:null,(ele.ie||ele.chrome)&&!o&&e&&e.state.doc.lines!=e.startState.doc.lines&&(this.forceSelection=!0)
;let a=function(e,t,n){let r=new Ece;return Zie.compare(e,t,n,r),r.changes
}(this.decorations,this.updateDeco(),e.changes)
;return n=kce.extendWithRanges(n,a),
!!(7&this.flags||0!=n.length)&&(this.updateInner(n,e.startState.doc.length,o),
e.transactions.length&&(this.lastUpdate=Date.now()),!0)}updateInner(e,t,n){
this.view.viewState.mustMeasureContent=!0,this.updateChildren(e,t,n)
;let{observer:r}=this.view;r.ignore((()=>{
this.dom.style.height=this.view.viewState.contentHeight/this.view.scaleY+"px",
this.dom.style.flexBasis=this.minWidth?this.minWidth+"px":""
;let e=ele.chrome||ele.ios?{node:r.selectionRange.focusNode,written:!1}:void 0
;this.sync(this.view,e),
this.flags&=-8,e&&(e.written||r.selectionRange.focusNode!=e.node)&&(this.forceSelection=!0),
this.dom.style.height=""})),this.markedForComposition.forEach((e=>e.flags&=-9))
;let o=[]
;if(this.view.viewport.from||this.view.viewport.to<this.view.state.doc.length)for(let a of this.children)a instanceof xle&&a.widget instanceof kle&&o.push(a.dom)
;r.updateGaps(o)}updateChildren(e,t,n){
let r=n?n.range.addToSet(e.slice()):e,o=this.childCursor(t)
;for(let a=r.length-1;;a--){let e=a>=0?r[a]:null;if(!e)break
;let t,i,s,l,{fromA:c,toA:u,fromB:d,toB:p}=e
;if(n&&n.range.fromB<p&&n.range.toB>d){
let e=Sle.build(this.view.state.doc,d,n.range.fromB,this.decorations,this.dynamicDecorationMap),r=Sle.build(this.view.state.doc,n.range.toB,p,this.decorations,this.dynamicDecorationMap)
;i=e.breakAtStart,s=e.openStart,l=r.openEnd;let o=this.compositionView(n)
;r.breakAtStart?o.breakAfter=1:r.content.length&&o.merge(o.length,o.length,r.content[0],!1,r.openStart,0)&&(o.breakAfter=r.content[0].breakAfter,
r.content.shift()),
e.content.length&&o.merge(0,0,e.content[e.content.length-1],!0,0,e.openEnd)&&e.content.pop(),
t=e.content.concat(o).concat(r.content)
}else({content:t,breakAtStart:i,openStart:s,openEnd:l}=Sle.build(this.view.state.doc,d,p,this.decorations,this.dynamicDecorationMap))
;let{i:h,off:f}=o.findPos(u,1),{i:m,off:g}=o.findPos(c,-1)
;zse(this,m,g,h,f,t,i,s,l)}n&&this.fixCompositionDOM(n)}
updateEditContextFormatting(e){
this.editContextFormatting=this.editContextFormatting.map(e.changes)
;for(let t of e.transactions)for(let e of t.effects)e.is(ice)&&(this.editContextFormatting=e.value)
}compositionView(e){let t=new tle(e.text.nodeValue);t.flags|=8
;for(let{deco:r}of e.marks)t=new nle(r,[t],t.length);let n=new wle
;return n.append(t,0),n}fixCompositionDOM(e){let t=(e,t)=>{
t.flags|=8|(t.children.some((e=>7&e.flags))?1:0),
this.markedForComposition.add(t);let n=Bse.get(e)
;n&&n!=t&&(n.dom=null),t.setDOM(e)
},n=this.childPos(e.range.fromB,1),r=this.children[n.i];t(e.line,r)
;for(let o=e.marks.length-1;o>=-1;o--)n=r.childPos(n.off,1),
r=r.children[n.i],t(o>=0?e.marks[o].node:e.text,r)}updateSelection(e=!1,t=!1){
!e&&this.view.observer.selectionRange.focusNode||this.view.observer.readSelectionRange()
;let n=this.view.root.activeElement,r=n==this.dom,o=!r&&!(this.view.state.facet(lce)||this.dom.tabIndex>-1)&&gse(this.dom,this.view.observer.selectionRange)&&!(n&&this.dom.contains(n))
;if(!(r||t||o))return;let a=this.forceSelection;this.forceSelection=!1
;let i=this.view.state.selection.main,s=this.moveToLine(this.domAtPos(i.anchor)),l=i.empty?s:this.moveToLine(this.domAtPos(i.head))
;if(ele.gecko&&i.empty&&!this.hasComposition&&(1==(c=s).node.nodeType&&c.node.firstChild&&(0==c.offset||"false"==c.node.childNodes[c.offset-1].contentEditable)&&(c.offset==c.node.childNodes.length||"false"==c.node.childNodes[c.offset].contentEditable))){
let e=document.createTextNode("")
;this.view.observer.ignore((()=>s.node.insertBefore(e,s.node.childNodes[s.offset]||null))),
s=l=new Rse(e,0),a=!0}var c;let u=this.view.observer.selectionRange
;!a&&u.focusNode&&(bse(s.node,s.offset,u.anchorNode,u.anchorOffset)&&bse(l.node,l.offset,u.focusNode,u.focusOffset)||this.suppressWidgetCursorChange(u,i))||(this.view.observer.ignore((()=>{
ele.android&&ele.chrome&&this.dom.contains(u.focusNode)&&function(e,t){
for(let n=e;n&&n!=t;n=n.assignedSlot||n.parentNode)if(1==n.nodeType&&"false"==n.contentEditable)return!0
;return!1}(u.focusNode,this.dom)&&(this.dom.blur(),this.dom.focus({
preventScroll:!0}));let e=fse(this.view.root);if(e)if(i.empty){if(ele.gecko){
let e=(t=s.node,
r=s.offset,1!=t.nodeType?0:(r&&"false"==t.childNodes[r-1].contentEditable?1:0)|(r<t.childNodes.length&&"false"==t.childNodes[r].contentEditable?2:0))
;if(e&&3!=e){let t=(1==e?Mse:Nse)(s.node,s.offset)
;t&&(s=new Rse(t.node,t.offset))}}
e.collapse(s.node,s.offset),null!=i.bidiLevel&&void 0!==e.caretBidiLevel&&(e.caretBidiLevel=i.bidiLevel)
}else if(e.extend){e.collapse(s.node,s.offset);try{e.extend(l.node,l.offset)
}catch(g5e){}}else{let t=document.createRange()
;i.anchor>i.head&&([s,l]=[l,s]),t.setEnd(l.node,l.offset),
t.setStart(s.node,s.offset),e.removeAllRanges(),e.addRange(t)}else;var t,r
;o&&this.view.root.activeElement==this.dom&&(this.dom.blur(),n&&n.focus())
})),this.view.observer.setSelectionRange(s,l)),
this.impreciseAnchor=s.precise?null:new Rse(u.anchorNode,u.anchorOffset),
this.impreciseHead=l.precise?null:new Rse(u.focusNode,u.focusOffset)}
suppressWidgetCursorChange(e,t){
return this.hasComposition&&t.empty&&bse(e.focusNode,e.focusOffset,e.anchorNode,e.anchorOffset)&&this.posFromDOM(e.focusNode,e.focusOffset)==t.head
}enforceCursorAssoc(){if(this.hasComposition)return
;let{view:e}=this,t=e.state.selection.main,n=fse(e.root),{anchorNode:r,anchorOffset:o}=e.observer.selectionRange
;if(!(n&&t.empty&&t.assoc&&n.modify))return;let a=wle.find(this,t.head)
;if(!a)return;let i=a.posAtStart;if(t.head==i||t.head==i+a.length)return
;let s=this.coordsAt(t.head,-1),l=this.coordsAt(t.head,1)
;if(!s||!l||s.bottom>l.top)return;let c=this.domAtPos(t.head+t.assoc)
;n.collapse(c.node,c.offset),
n.modify("move",t.assoc<0?"forward":"backward","lineboundary"),
e.observer.readSelectionRange();let u=e.observer.selectionRange
;e.docView.posFromDOM(u.anchorNode,u.anchorOffset)!=t.from&&n.collapse(r,o)}
moveToLine(e){let t,n=this.dom;if(e.node!=n)return e
;for(let r=e.offset;!t&&r<n.childNodes.length;r++){
let e=Bse.get(n.childNodes[r]);e instanceof wle&&(t=e.domAtPos(0))}
for(let r=e.offset-1;!t&&r>=0;r--){let e=Bse.get(n.childNodes[r])
;e instanceof wle&&(t=e.domAtPos(e.length))}
return t?new Rse(t.node,t.offset,!0):e}nearest(e){for(let t=e;t;){
let e=Bse.get(t);if(e&&e.rootView==this)return e;t=t.parentNode}return null}
posFromDOM(e,t){let n=this.nearest(e)
;if(!n)throw new RangeError("Trying to find position for a DOM position outside of the document")
;return n.localPosFromDOM(e,t)+n.posAtStart}domAtPos(e){
let{i:t,off:n}=this.childCursor().findPos(e,-1);for(;t<this.children.length-1;){
let e=this.children[t];if(n<e.length||e instanceof wle)break;t++,n=0}
return this.children[t].domAtPos(n)}coordsAt(e,t){let n=null,r=0
;for(let o=this.length,a=this.children.length-1;a>=0;a--){
let i=this.children[a],s=o-i.breakAfter,l=s-i.length;if(s<e)break
;if(l<=e&&(l<e||i.covers(-1))&&(s>e||i.covers(1))&&(!n||i instanceof wle&&!(n instanceof wle&&t>=0)))n=i,
r=l;else if(n&&l==e&&s==e&&i instanceof xle&&Math.abs(t)<2){
if(i.deco.startSide<0)break;a&&(n=null)}o=l}return n?n.coordsAt(e-r,t):null}
coordsForChar(e){let{i:t,off:n}=this.childPos(e,1),r=this.children[t]
;if(!(r instanceof wle))return null;for(;r.children.length;){
let{i:e,off:t}=r.childPos(n,1);for(;;e++){if(e==r.children.length)return null
;if((r=r.children[e]).length)break}n=t}if(!(r instanceof tle))return null
;let o=Pae(r.text,n);if(o==n)return null;let a=$se(r.dom,n,o).getClientRects()
;for(let i=0;i<a.length;i++){let e=a[i]
;if(i==a.length-1||e.top<e.bottom&&e.left<e.right)return e}return null}
measureVisibleLineHeights(e){
let t=[],{from:n,to:r}=e,o=this.view.contentDOM.clientWidth,a=o>Math.max(this.view.scrollDOM.clientWidth,this.minWidth)+1,i=-1,s=this.view.textDirection==Ele.LTR
;for(let l=0,c=0;c<this.children.length;c++){let e=this.children[c],u=l+e.length
;if(u>r)break;if(l>=n){let n=e.dom.getBoundingClientRect()
;if(t.push(n.height),a){let t=e.dom.lastChild,r=t?vse(t):[];if(r.length){
let e=r[r.length-1],t=s?e.right-n.left:n.right-e.left;t>i&&(i=t,this.minWidth=o,
this.minWidthFrom=l,this.minWidthTo=u)}}}l=u+e.breakAfter}return t}
textDirectionAt(e){let{i:t}=this.childPos(e,1)
;return"rtl"==getComputedStyle(this.children[t].dom).direction?Ele.RTL:Ele.LTR}
measureTextSize(){for(let o of this.children)if(o instanceof wle){
let e=o.measureTextSize();if(e)return e}
let e,t,n,r=document.createElement("div")
;return r.className="cm-line",r.style.width="99999px",
r.style.position="absolute",
r.textContent="abc def ghi jkl mno pqr stu",this.view.observer.ignore((()=>{
this.dom.appendChild(r);let o=vse(r.firstChild)[0]
;e=r.getBoundingClientRect().height,t=o?o.width/27:7,n=o?o.height:e,r.remove()
})),{lineHeight:e,charWidth:t,textHeight:n}}childCursor(e=this.length){
let t=this.children.length
;return t&&(e-=this.children[--t].length),new Use(this.children,e,t)}
computeBlockGapDeco(){let e=[],t=this.view.viewState;for(let n=0,r=0;;r++){
let o=r==t.viewports.length?null:t.viewports[r],a=o?o.from-1:this.length
;if(a>n){let r=(t.lineBlockAt(a).bottom-t.lineBlockAt(n).top)/this.view.scaleY
;e.push(mle.replace({widget:new kle(r),block:!0,inclusive:!0,isBlockGap:!0
}).range(n,a))}if(!o)break;n=o.to+1}return mle.set(e)}updateDeco(){
let e=1,t=this.view.state.facet(mce).map((t=>(this.dynamicDecorationMap[e++]="function"==typeof t)?t(this.view):t)),n=!1,r=this.view.state.facet(gce).map(((e,t)=>{
let r="function"==typeof e;return r&&(n=!0),r?e(this.view):e}))
;for(r.length&&(this.dynamicDecorationMap[e++]=n,
t.push(Zie.join(r))),this.decorations=[this.editContextFormatting,...t,this.computeBlockGapDeco(),this.view.viewState.lineGapDeco];e<this.decorations.length;)this.dynamicDecorationMap[e++]=!1
;return this.decorations}scrollIntoView(e){if(e.isSnapshot){
let t=this.view.viewState.lineBlockAt(e.range.head)
;return this.view.scrollDOM.scrollTop=t.top-e.yMargin,
void(this.view.scrollDOM.scrollLeft=e.xMargin)}
for(let l of this.view.state.facet(rce))try{if(l(this.view,e.range,e))return!0
}catch(Bw){sce(this.view.state,Bw,"scroll handler")}
let t,{range:n}=e,r=this.coordsAt(n.head,n.empty?n.assoc:n.head>n.anchor?-1:1)
;if(!r)return;!n.empty&&(t=this.coordsAt(n.anchor,n.anchor>n.head?-1:1))&&(r={
left:Math.min(r.left,t.left),top:Math.min(r.top,t.top),
right:Math.max(r.right,t.right),bottom:Math.max(r.bottom,t.bottom)})
;let o=wce(this.view),a={left:r.left-o.left,top:r.top-o.top,
right:r.right+o.right,bottom:r.bottom+o.bottom
},{offsetWidth:i,offsetHeight:s}=this.view.scrollDOM;!function(e,t,n,r,o,a,i,s){
let l=e.ownerDocument,c=l.defaultView||window
;for(let u=e,d=!1;u&&!d;)if(1==u.nodeType){let e,p=u==l.body,h=1,f=1
;if(p)e=Sse(c);else{
if(/^(fixed|sticky)$/.test(getComputedStyle(u).position)&&(d=!0),
u.scrollHeight<=u.clientHeight&&u.scrollWidth<=u.clientWidth){
u=u.assignedSlot||u.parentNode;continue}let t=u.getBoundingClientRect()
;({scaleX:h,scaleY:f}=_se(u,t)),e={left:t.left,right:t.left+u.clientWidth*h,
top:t.top,bottom:t.top+u.clientHeight*f}}let m=0,g=0
;if("nearest"==o)t.top<e.top?(g=-(e.top-t.top+i),
n>0&&t.bottom>e.bottom+g&&(g=t.bottom-e.bottom+g+i)):t.bottom>e.bottom&&(g=t.bottom-e.bottom+i,
n<0&&t.top-g<e.top&&(g=-(e.top+g-t.top+i)));else{
let r=t.bottom-t.top,a=e.bottom-e.top
;g=("center"==o&&r<=a?t.top+r/2-a/2:"start"==o||"center"==o&&n<0?t.top-i:t.bottom-a+i)-e.top
}
if("nearest"==r?t.left<e.left?(m=-(e.left-t.left+a),n>0&&t.right>e.right+m&&(m=t.right-e.right+m+a)):t.right>e.right&&(m=t.right-e.right+a,
n<0&&t.left<e.left+m&&(m=-(e.left+m-t.left+a))):m=("center"==r?t.left+(t.right-t.left)/2-(e.right-e.left)/2:"start"==r==s?t.left-a:t.right-(e.right-e.left)+a)-e.left,
m||g)if(p)c.scrollBy(m,g);else{let e=0,n=0;if(g){let e=u.scrollTop
;u.scrollTop+=g/f,n=(u.scrollTop-e)*f}if(m){let t=u.scrollLeft
;u.scrollLeft+=m/h,e=(u.scrollLeft-t)*h}t={left:t.left-e,top:t.top-n,
right:t.right-e,bottom:t.bottom-n
},e&&Math.abs(e-m)<1&&(r="nearest"),n&&Math.abs(n-g)<1&&(o="nearest")}if(p)break
;u=u.assignedSlot||u.parentNode}else{if(11!=u.nodeType)break;u=u.host}
}(this.view.scrollDOM,a,n.head<n.anchor?-1:1,e.x,e.y,Math.max(Math.min(e.xMargin,i),-i),Math.max(Math.min(e.yMargin,s),-s),this.view.textDirection==Ele.LTR)
}}function Tce(e,t){let n=e.observer.selectionRange;if(!n.focusNode)return null
;let r=Mse(n.focusNode,n.focusOffset),o=Nse(n.focusNode,n.focusOffset),a=r||o
;if(o&&r&&o.node!=r.node){let t=Bse.get(o.node)
;if(!t||t instanceof tle&&t.text!=o.node.nodeValue)a=o;else if(e.docView.lastCompositionAfterCursor){
let e=Bse.get(r.node);!e||e instanceof tle&&e.text!=r.node.nodeValue||(a=o)}}
if(e.docView.lastCompositionAfterCursor=a!=r,!a)return null;let i=t-a.offset
;return{from:i,to:i+a.node.nodeValue.length,node:a.node}}let Ece=class{
constructor(){this.changes=[]}compareRange(e,t){Ole(e,t,this.changes)}
comparePoint(e,t){Ole(e,t,this.changes)}boundChange(e){Ole(e,e,this.changes)}}
;function Ace(e,t){return t.left>e?t.left-e:Math.max(0,e-t.right)}
function Cce(e,t){return t.top>e?t.top-e:Math.max(0,e-t.bottom)}
function $ce(e,t){return e.top<t.bottom-1&&e.bottom>t.top+1}function Pce(e,t){
return t<e.top?{top:t,left:e.left,right:e.right,bottom:e.bottom}:e}
function Dce(e,t){return t>e.bottom?{top:e.top,left:e.left,right:e.right,
bottom:t}:e}function Ice(e,t,n){let r,o,a,i,s,l,c,u,d=!1
;for(let h=e.firstChild;h;h=h.nextSibling){let e=vse(h)
;for(let p=0;p<e.length;p++){let f=e[p]
;o&&$ce(o,f)&&(f=Pce(Dce(f,o.bottom),o.top));let m=Ace(t,f),g=Cce(n,f)
;if(0==m&&0==g)return 3==h.nodeType?Mce(h,t,n):Ice(h,t,n)
;if(!r||i>g||i==g&&a>m){r=h,o=f,a=m,i=g;let s=g?n<f.top?-1:1:m?t<f.left?-1:1:0
;d=!s||(s>0?p<e.length-1:p>0)}
0==m?n>f.bottom&&(!c||c.bottom<f.bottom)?(s=h,c=f):n<f.top&&(!u||u.top>f.top)&&(l=h,
u=f):c&&$ce(c,f)?c=Dce(c,f.bottom):u&&$ce(u,f)&&(u=Pce(u,f.top))}}
if(c&&c.bottom>=n?(r=s,o=c):u&&u.top<=n&&(r=l,o=u),!r)return{node:e,offset:0}
;let p=Math.max(o.left,Math.min(o.right,t))
;return 3==r.nodeType?Mce(r,p,n):d&&"false"!=r.contentEditable?Ice(r,p,n):{
node:e,
offset:Array.prototype.indexOf.call(e.childNodes,r)+(t>=(o.left+o.right)/2?1:0)}
}function Mce(e,t,n){let r=e.nodeValue.length,o=-1,a=1e9,i=0
;for(let s=0;s<r;s++){let r=$se(e,s,s+1).getClientRects()
;for(let l=0;l<r.length;l++){let c=r[l];if(c.top==c.bottom)continue
;i||(i=t-c.left);let u=(c.top>n?c.top-n:n-c.bottom)-1
;if(c.left-1<=t&&c.right+1>=t&&u<a){let n=t>=(c.left+c.right)/2,r=n
;if(ele.chrome||ele.gecko){
$se(e,s).getBoundingClientRect().left==c.right&&(r=!n)}if(u<=0)return{node:e,
offset:s+(r?1:0)};o=s+(r?1:0),a=u}}}return{node:e,
offset:o>-1?o:i>0?e.nodeValue.length:0}}function Nce(e,t,n,r=-1){var o,a
;let i,s=e.contentDOM.getBoundingClientRect(),l=s.top+e.viewState.paddingTop,{docHeight:c}=e.viewState,{x:u,y:d}=t,p=d-l
;if(p<0)return 0;if(p>c)return e.state.doc.length
;for(let O=e.viewState.heightOracle.textHeight/2,w=!1;i=e.elementAtHeight(p),
i.type!=fle.Text;)for(;p=r>0?i.bottom+O:i.top-O,!(p>=0&&p<=c);){
if(w)return n?null:0;w=!0,r=-r}d=l+p;let h=i.from
;if(h<e.viewport.from)return 0==e.viewport.from?0:n?null:Rce(e,s,i,u,d)
;if(h>e.viewport.to)return e.viewport.to==e.state.doc.length?e.state.doc.length:n?null:Rce(e,s,i,u,d)
;let f=e.dom.ownerDocument,m=e.root.elementFromPoint?e.root:f,g=m.elementFromPoint(u,d)
;g&&!e.contentDOM.contains(g)&&(g=null),
g||(u=Math.max(s.left+1,Math.min(s.right-1,u)),
g=m.elementFromPoint(u,d),g&&!e.contentDOM.contains(g)&&(g=null));let v,b=-1
;if(g&&0!=(null===(o=e.docView.nearest(g))||void 0===o?void 0:o.isEditable)){
if(f.caretPositionFromPoint){let e=f.caretPositionFromPoint(u,d)
;e&&({offsetNode:v,offset:b}=e)}else if(f.caretRangeFromPoint){
let t=f.caretRangeFromPoint(u,d)
;t&&(({startContainer:v,startOffset:b}=t),(!e.contentDOM.contains(v)||ele.safari&&function(e,t,n){
let r;if(3!=e.nodeType||t!=(r=e.nodeValue.length))return!1
;for(let o=e.nextSibling;o;o=o.nextSibling)if(1!=o.nodeType||"BR"!=o.nodeName)return!1
;return $se(e,r-1,r).getBoundingClientRect().left>n
}(v,b,u)||ele.chrome&&function(e,t,n){if(0!=t)return!1;for(let o=e;;){
let e=o.parentNode;if(!e||1!=e.nodeType||e.firstChild!=o)return!1
;if(e.classList.contains("cm-line"))break;o=e}
let r=1==e.nodeType?e.getBoundingClientRect():$se(e,0,Math.max(e.nodeValue.length,1)).getBoundingClientRect()
;return n-r.left>5}(v,b,u))&&(v=void 0))}v&&(b=Math.min(xse(v),b))}
if(!v||!e.docView.dom.contains(v)){let t=wle.find(e.docView,h)
;if(!t)return p>i.top+i.height/2?i.to:i.from;({node:v,offset:b}=Ice(t.dom,u,d))}
let y=e.docView.nearest(v);if(!y)return null
;if(y.isWidget&&1==(null===(a=y.dom)||void 0===a?void 0:a.nodeType)){
let e=y.dom.getBoundingClientRect()
;return t.y<e.top||t.y<=e.bottom&&t.x<=(e.left+e.right)/2?y.posAtStart:y.posAtEnd
}return y.localPosFromDOM(v,b)+y.posAtStart}function Rce(e,t,n,r,o){
let a=Math.round((r-t.left)*e.defaultCharacterWidth)
;if(e.lineWrapping&&n.height>1.5*e.defaultLineHeight){
let t=e.viewState.heightOracle.textHeight
;a+=Math.floor((o-n.top-.5*(e.defaultLineHeight-t))/t)*e.viewState.heightOracle.lineLength
}let i=e.state.sliceDoc(n.from,n.to);return n.from+function(e,t,n,r){
for(let o=0,a=0;;){if(a>=t)return o;if(o==e.length)break
;a+=9==e.charCodeAt(o)?n-a%n:1,o=Pae(e,o)}return e.length}(i,a,e.state.tabSize)}
function Lce(e,t,n,r){let o=function(e,t){let n=e.lineBlockAt(t)
;if(Array.isArray(n.type))for(let r of n.type)if(r.to>t||r.to==t&&(r.to==n.to||r.type==fle.Text))return r
;return n
}(e,t.head),a=r&&o.type==fle.Text&&(e.lineWrapping||o.widgetLineBreaks)?e.coordsAtPos(t.assoc<0&&t.head>o.from?t.head-1:t.head):null
;if(a){
let t=e.dom.getBoundingClientRect(),r=e.textDirectionAt(o.from),i=e.posAtCoords({
x:n==(r==Ele.LTR)?t.right-1:t.left+1,y:(a.top+a.bottom)/2})
;if(null!=i)return Vae.cursor(i,n?-1:1)}return Vae.cursor(n?o.to:o.from,n?-1:1)}
function Bce(e,t,n,r){
let o=e.state.doc.lineAt(t.head),a=e.bidiSpans(o),i=e.textDirectionAt(o.from)
;for(let s=t,l=null;;){let t=Qle(o,a,i,s,n),c=Zle;if(!t){
if(o.number==(n?e.state.doc.lines:1))return s
;c="\n",o=e.state.doc.line(o.number+(n?1:-1)),
a=e.bidiSpans(o),t=e.visualLineSide(o,!n)}if(l){if(!l(c))return s}else{
if(!r)return t;l=r(c)}s=t}}function jce(e,t,n){for(;;){let r=0
;for(let o of e)o.between(t-1,t+1,((e,o,a)=>{if(t>e&&t<o){
let a=r||n||(t-e<o-t?-1:1);t=a<0?e:o,r=a}}));if(!r)return t}}
function Uce(e,t,n){
let r=jce(e.state.facet(vce).map((t=>t(e))),n.from,t.head>n.from?-1:1)
;return r==n.from?n:Vae.cursor(r,r<n.from?1:-1)}const zce="";class Fce{
constructor(e,t){
this.points=e,this.text="",this.lineSeparator=t.facet(Lie.lineSeparator)}
append(e){this.text+=e}lineBreak(){this.text+=zce}readRange(e,t){
if(!e)return this;let n=e.parentNode;for(let r=e;;){this.findPointBefore(n,r)
;let e=this.text.length;this.readNode(r);let o=r.nextSibling;if(o==t)break
;let a=Bse.get(r),i=Bse.get(o)
;(a&&i?a.breakAfter:(a?a.breakAfter:Ose(r))||Ose(o)&&("BR"!=r.nodeName||r.cmIgnore)&&this.text.length>e)&&this.lineBreak(),
r=o}return this.findPointBefore(n,t),this}readTextNode(e){let t=e.nodeValue
;for(let n of this.points)n.node==e&&(n.pos=this.text.length+Math.min(n.offset,t.length))
;for(let n=0,r=this.lineSeparator?null:/\r\n?|\n/g;;){let o,a=-1,i=1
;if(this.lineSeparator?(a=t.indexOf(this.lineSeparator,n),
i=this.lineSeparator.length):(o=r.exec(t))&&(a=o.index,
i=o[0].length),this.append(t.slice(n,a<0?t.length:a)),a<0)break
;if(this.lineBreak(),
i>1)for(let t of this.points)t.node==e&&t.pos>this.text.length&&(t.pos-=i-1)
;n=a+i}}readNode(e){if(e.cmIgnore)return;let t=Bse.get(e),n=t&&t.overrideDOMText
;if(null!=n){this.findPointInside(e,n.length)
;for(let e=n.iter();!e.next().done;)e.lineBreak?this.lineBreak():this.append(e.value)
}else 3==e.nodeType?this.readTextNode(e):"BR"==e.nodeName?e.nextSibling&&this.lineBreak():1==e.nodeType&&this.readRange(e.firstChild,null)
}findPointBefore(e,t){
for(let n of this.points)n.node==e&&e.childNodes[n.offset]==t&&(n.pos=this.text.length)
}findPointInside(e,t){
for(let n of this.points)(3==e.nodeType?n.node==e:e.contains(n.node))&&(n.pos=this.text.length+(Zce(e,n.node,n.offset)?t:0))
}}function Zce(e,t,n){for(;;){if(!t||n<xse(t))return!1;if(t==e)return!0
;n=yse(t)+1,t=t.parentNode}}class Qce{constructor(e,t){
this.node=e,this.offset=t,this.pos=-1}}class Hce{constructor(e,t,n,r){
this.typeOver=r,this.bounds=null,this.text="",this.domChanged=t>-1
;let{impreciseHead:o,impreciseAnchor:a}=e.docView
;if(e.state.readOnly&&t>-1)this.newSel=null;else if(t>-1&&(this.bounds=e.docView.domBoundsAround(t,n,0))){
let t=o||a?[]:function(e){let t=[]
;if(e.root.activeElement!=e.contentDOM)return t
;let{anchorNode:n,anchorOffset:r,focusNode:o,focusOffset:a}=e.observer.selectionRange
;n&&(t.push(new Qce(n,r)),o==n&&a==r||t.push(new Qce(o,a)));return t
}(e),n=new Fce(t,e.state)
;n.readRange(this.bounds.startDOM,this.bounds.endDOM),this.text=n.text,
this.newSel=function(e,t){if(0==e.length)return null
;let n=e[0].pos,r=2==e.length?e[1].pos:n
;return n>-1&&r>-1?Vae.single(n+t,r+t):null}(t,this.bounds.from)}else{
let t=e.observer.selectionRange,n=o&&o.node==t.focusNode&&o.offset==t.focusOffset||!mse(e.contentDOM,t.focusNode)?e.state.selection.main.head:e.docView.posFromDOM(t.focusNode,t.focusOffset),r=a&&a.node==t.anchorNode&&a.offset==t.anchorOffset||!mse(e.contentDOM,t.anchorNode)?e.state.selection.main.anchor:e.docView.posFromDOM(t.anchorNode,t.anchorOffset),i=e.viewport
;if((ele.ios||ele.chrome)&&e.state.selection.main.empty&&n!=r&&(i.from>0||i.to<e.state.doc.length)){
let t=Math.min(n,r),o=Math.max(n,r),a=i.from-t,s=i.to-o
;0!=a&&1!=a&&0!=t||0!=s&&-1!=s&&o!=e.state.doc.length||(n=0,
r=e.state.doc.length)}this.newSel=Vae.single(r,n)}}}function Vce(e,t){
let n,{newSel:r}=t,o=e.state.selection.main,a=e.inputState.lastKeyTime>Date.now()-100?e.inputState.lastKeyCode:-1
;if(t.bounds){let{from:r,to:i}=t.bounds,s=o.from,l=null
;(8===a||ele.android&&t.text.length<i-r)&&(s=o.to,l="end")
;let c=function(e,t,n,r){let o=Math.min(e.length,t.length),a=0
;for(;a<o&&e.charCodeAt(a)==t.charCodeAt(a);)a++
;if(a==o&&e.length==t.length)return null;let i=e.length,s=t.length
;for(;i>0&&s>0&&e.charCodeAt(i-1)==t.charCodeAt(s-1);)i--,s--;if("end"==r){
n-=i+Math.max(0,a-Math.min(i,s))-a}if(i<a&&e.length<t.length){
a-=n<=a&&n>=i?a-n:0,s=a+(s-i),i=a}else if(s<a){a-=n<=a&&n>=s?a-n:0,i=a+(i-s),s=a
}return{from:a,toA:i,toB:s}}(e.state.doc.sliceString(r,i,zce),t.text,s-r,l)
;c&&(ele.chrome&&13==a&&c.toB==c.from+2&&t.text.slice(c.from,c.toB)==zce+zce&&c.toB--,
n={from:r+c.from,to:r+c.toA,insert:wae.of(t.text.slice(c.from,c.toB).split(zce))
})}else r&&(!e.hasFocus&&e.state.facet(lce)||r.main.eq(o))&&(r=null)
;if(!n&&!r)return!1;if(!n&&t.typeOver&&!o.empty&&r&&r.main.empty?n={from:o.from,
to:o.to,insert:e.state.doc.slice(o.from,o.to)
}:n&&n.from>=o.from&&n.to<=o.to&&(n.from!=o.from||n.to!=o.to)&&o.to-o.from-(n.to-n.from)<=4?n={
from:o.from,to:o.to,
insert:e.state.doc.slice(o.from,n.from).append(n.insert).append(e.state.doc.slice(n.to,o.to))
}:(ele.mac||ele.android)&&n&&n.from==n.to&&n.from==o.head-1&&/^\. ?$/.test(n.insert.toString())&&"off"==e.contentDOM.getAttribute("autocorrect")?(r&&2==n.insert.length&&(r=Vae.single(r.main.anchor-1,r.main.head-1)),
n={from:o.from,to:o.to,insert:wae.of([" "])
}):ele.chrome&&n&&n.from==n.to&&n.from==o.head&&"\n "==n.insert.toString()&&e.lineWrapping&&(r&&(r=Vae.single(r.main.anchor-1,r.main.head-1)),
n={from:o.from,to:o.to,insert:wae.of([" "])}),n)return qce(e,n,r,a)
;if(r&&!r.main.eq(o)){let t=!1,n="select"
;return e.inputState.lastSelectionTime>Date.now()-50&&("select"==e.inputState.lastSelectionOrigin&&(t=!0),
n=e.inputState.lastSelectionOrigin),e.dispatch({selection:r,scrollIntoView:t,
userEvent:n}),!0}return!1}function qce(e,t,n,r=-1){
if(ele.ios&&e.inputState.flushIOSKey(t))return!0;let o=e.state.selection.main
;if(ele.android&&(t.to==o.to&&(t.from==o.from||t.from==o.from-1&&" "==e.state.sliceDoc(t.from,o.from))&&1==t.insert.length&&2==t.insert.lines&&Pse(e.contentDOM,"Enter",13)||(t.from==o.from-1&&t.to==o.to&&0==t.insert.length||8==r&&t.insert.length<t.to-t.from&&t.to>o.head)&&Pse(e.contentDOM,"Backspace",8)||t.from==o.from&&t.to==o.to+1&&0==t.insert.length&&Pse(e.contentDOM,"Delete",46)))return!0
;let a,i=t.insert.toString();e.inputState.composing>=0&&e.inputState.composing++
;let s=()=>a||(a=function(e,t,n){let r,o=e.state,a=o.selection.main
;if(t.from>=a.from&&t.to<=a.to&&t.to-t.from>=(a.to-a.from)/3&&(!n||n.main.empty&&n.main.from==t.from+t.insert.length)&&e.inputState.composing<0){
let n=a.from<t.from?o.sliceDoc(a.from,t.from):"",i=a.to>t.to?o.sliceDoc(t.to,a.to):""
;r=o.replaceSelection(e.state.toText(n+t.insert.sliceString(0,void 0,e.state.lineBreak)+i))
}else{let i=o.changes(t),s=n&&n.main.to<=i.newLength?n.main:void 0
;if(o.selection.ranges.length>1&&e.inputState.composing>=0&&t.to<=a.to&&t.to>=a.to-10){
let l,c=e.state.sliceDoc(t.from,t.to),u=n&&Tce(e,n.main.head);if(u){
let e=t.insert.length-(t.to-t.from);l={from:u.from,to:u.to-e}
}else l=e.state.doc.lineAt(a.head);let d=a.to-t.to,p=a.to-a.from
;r=o.changeByRange((n=>{if(n.from==a.from&&n.to==a.to)return{changes:i,
range:s||n.map(i)};let r=n.to-d,u=r-c.length
;if(n.to-n.from!=p||e.state.sliceDoc(u,r)!=c||n.to>=l.from&&n.from<=l.to)return{
range:n};let h=o.changes({from:u,to:r,insert:t.insert}),f=n.to-a.to;return{
changes:h,
range:s?Vae.range(Math.max(0,s.anchor+f),Math.max(0,s.head+f)):n.map(h)}}))
}else r={changes:i,selection:s&&o.selection.replaceRange(s)}}let i="input.type"
;(e.composing||e.inputState.compositionPendingChange&&e.inputState.compositionEndedAt>Date.now()-50)&&(e.inputState.compositionPendingChange=!1,
i+=".compose",
e.inputState.compositionFirstChange&&(i+=".start",e.inputState.compositionFirstChange=!1))
;return o.update(r,{userEvent:i,scrollIntoView:!0})}(e,t,n))
;return e.state.facet(Yle).some((n=>n(e,t.from,t.to,i,s)))||e.dispatch(s()),!0}
class Wce{setSelectionOrigin(e){
this.lastSelectionOrigin=e,this.lastSelectionTime=Date.now()}constructor(e){
var t
;this.view=e,this.lastKeyCode=0,this.lastKeyTime=0,this.lastTouchTime=0,this.lastFocusTime=0,
this.lastScrollTop=0,
this.lastScrollLeft=0,this.pendingIOSKey=void 0,this.tabFocusMode=-1,
this.lastSelectionOrigin=null,
this.lastSelectionTime=0,this.lastContextMenu=0,this.scrollHandlers=[],
this.handlers=Object.create(null),
this.composing=-1,this.compositionFirstChange=null,
this.compositionEndedAt=0,this.compositionPendingKey=!1,
this.compositionPendingChange=!1,
this.mouseSelection=null,this.draggedContent=null,
this.handleEvent=this.handleEvent.bind(this),
this.notifiedFocused=e.hasFocus,ele.safari&&e.contentDOM.addEventListener("input",(()=>null)),
ele.gecko&&(t=e.contentDOM.ownerDocument,
Oue.has(t)||(Oue.add(t),t.addEventListener("copy",(()=>{})),
t.addEventListener("cut",(()=>{}))))}handleEvent(e){(function(e,t){
if(!t.bubbles)return!0;if(t.defaultPrevented)return!1
;for(let n,r=t.target;r!=e.contentDOM;r=r.parentNode)if(!r||11==r.nodeType||(n=Bse.get(r))&&n.ignoreEvent(t))return!1
;return!0
})(this.view,e)&&!this.ignoreDuringComposition(e)&&("keydown"==e.type&&this.keydown(e)||this.runHandlers(e.type,e))
}runHandlers(e,t){let n=this.handlers[e];if(n){
for(let e of n.observers)e(this.view,t);for(let e of n.handlers){
if(t.defaultPrevented)break;if(e(this.view,t)){t.preventDefault();break}}}}
ensureHandlers(e){let t=function(e){let t=Object.create(null);function n(e){
return t[e]||(t[e]={observers:[],handlers:[]})}for(let r of e){let e=r.spec
;if(e&&e.domEventHandlers)for(let t in e.domEventHandlers){
let o=e.domEventHandlers[t];o&&n(t).handlers.push(Xce(r.value,o))}
if(e&&e.domEventObservers)for(let t in e.domEventObservers){
let o=e.domEventObservers[t];o&&n(t).observers.push(Xce(r.value,o))}}
for(let r in tue)n(r).handlers.push(tue[r])
;for(let r in nue)n(r).observers.push(nue[r]);return t
}(e),n=this.handlers,r=this.view.contentDOM;for(let o in t)if("scroll"!=o){
let e=!t[o].handlers.length,a=n[o]
;a&&e!=!a.handlers.length&&(r.removeEventListener(o,this.handleEvent),
a=null),a||r.addEventListener(o,this.handleEvent,{passive:e})}
for(let o in n)"scroll"==o||t[o]||r.removeEventListener(o,this.handleEvent)
;this.handlers=t}keydown(e){
if(this.lastKeyCode=e.keyCode,this.lastKeyTime=Date.now(),
9==e.keyCode&&this.tabFocusMode>-1&&(!this.tabFocusMode||Date.now()<=this.tabFocusMode))return!0
;if(this.tabFocusMode>0&&27!=e.keyCode&&Kce.indexOf(e.keyCode)<0&&(this.tabFocusMode=-1),
ele.android&&ele.chrome&&!e.synthetic&&(13==e.keyCode||8==e.keyCode))return this.view.observer.delayAndroidKey(e.key,e.keyCode),
!0;let t
;return!ele.ios||e.synthetic||e.altKey||e.metaKey||!((t=Gce.find((t=>t.keyCode==e.keyCode)))&&!e.ctrlKey||Yce.indexOf(e.key)>-1&&e.ctrlKey&&!e.shiftKey)?(229!=e.keyCode&&this.view.observer.forceFlush(),
!1):(this.pendingIOSKey=t||e,setTimeout((()=>this.flushIOSKey()),250),!0)}
flushIOSKey(e){let t=this.pendingIOSKey
;return!!t&&(!("Enter"==t.key&&e&&e.from<e.to&&/^\S+$/.test(e.insert.toString()))&&(this.pendingIOSKey=void 0,
Pse(this.view.contentDOM,t.key,t.keyCode,t instanceof KeyboardEvent?t:void 0)))}
ignoreDuringComposition(e){
return!!/^key/.test(e.type)&&(this.composing>0||!!(ele.safari&&!ele.ios&&this.compositionPendingKey&&Date.now()-this.compositionEndedAt<100)&&(this.compositionPendingKey=!1,
!0))}startMouseSelection(e){
this.mouseSelection&&this.mouseSelection.destroy(),this.mouseSelection=e}
update(e){
this.view.observer.update(e),this.mouseSelection&&this.mouseSelection.update(e),
this.draggedContent&&e.docChanged&&(this.draggedContent=this.draggedContent.map(e.changes)),
e.transactions.length&&(this.lastKeyCode=this.lastSelectionTime=0)}destroy(){
this.mouseSelection&&this.mouseSelection.destroy()}}function Xce(e,t){
return(n,r)=>{try{return t.call(e,r,n)}catch(Bw){sce(n.state,Bw)}}}const Gce=[{
key:"Backspace",keyCode:8,inputType:"deleteContentBackward"},{key:"Enter",
keyCode:13,inputType:"insertParagraph"},{key:"Enter",keyCode:13,
inputType:"insertLineBreak"},{key:"Delete",keyCode:46,
inputType:"deleteContentForward"}],Yce="dthko",Kce=[16,17,18,20,91,92,224,225]
;function Jce(e){return.7*Math.max(0,e)+8}class eue{constructor(e,t,n,r){
this.view=e,this.startEvent=t,this.style=n,this.mustSelect=r,this.scrollSpeed={
x:0,y:0},this.scrolling=-1,this.lastEvent=t,this.scrollParents=function(e){
let t,n,r=e.ownerDocument
;for(let o=e.parentNode;o&&!(o==r.body||t&&n);)if(1==o.nodeType)!n&&o.scrollHeight>o.clientHeight&&(n=o),
!t&&o.scrollWidth>o.clientWidth&&(t=o),o=o.assignedSlot||o.parentNode;else{
if(11!=o.nodeType)break;o=o.host}return{x:t,y:n}
}(e.contentDOM),this.atoms=e.state.facet(vce).map((t=>t(e)))
;let o=e.contentDOM.ownerDocument
;o.addEventListener("mousemove",this.move=this.move.bind(this)),
o.addEventListener("mouseup",this.up=this.up.bind(this)),this.extend=t.shiftKey,
this.multiple=e.state.facet(Lie.allowMultipleSelections)&&function(e,t){
let n=e.state.facet(Vle);return n.length?n[0](t):ele.mac?t.metaKey:t.ctrlKey
}(e,t),this.dragging=!(!function(e,t){let{main:n}=e.state.selection
;if(n.empty)return!1;let r=fse(e.root);if(!r||0==r.rangeCount)return!0
;let o=r.getRangeAt(0).getClientRects();for(let a=0;a<o.length;a++){let e=o[a]
;if(e.left<=t.clientX&&e.right>=t.clientX&&e.top<=t.clientY&&e.bottom>=t.clientY)return!0
}return!1}(e,t)||1!=fue(t))&&null}start(e){!1===this.dragging&&this.select(e)}
move(e){if(0==e.buttons)return this.destroy()
;if(this.dragging||null==this.dragging&&(t=this.startEvent,
n=e,Math.max(Math.abs(t.clientX-n.clientX),Math.abs(t.clientY-n.clientY))<10))return
;var t,n;this.select(this.lastEvent=e)
;let r=0,o=0,a=0,i=0,s=this.view.win.innerWidth,l=this.view.win.innerHeight
;this.scrollParents.x&&({left:a,right:s}=this.scrollParents.x.getBoundingClientRect()),
this.scrollParents.y&&({top:i,bottom:l}=this.scrollParents.y.getBoundingClientRect())
;let c=wce(this.view)
;e.clientX-c.left<=a+6?r=-Jce(a-e.clientX):e.clientX+c.right>=s-6&&(r=Jce(e.clientX-s)),
e.clientY-c.top<=i+6?o=-Jce(i-e.clientY):e.clientY+c.bottom>=l-6&&(o=Jce(e.clientY-l)),
this.setScrollSpeed(r,o)}up(e){null==this.dragging&&this.select(this.lastEvent),
this.dragging||e.preventDefault(),this.destroy()}destroy(){
this.setScrollSpeed(0,0);let e=this.view.contentDOM.ownerDocument
;e.removeEventListener("mousemove",this.move),
e.removeEventListener("mouseup",this.up),
this.view.inputState.mouseSelection=this.view.inputState.draggedContent=null}
setScrollSpeed(e,t){this.scrollSpeed={x:e,y:t
},e||t?this.scrolling<0&&(this.scrolling=setInterval((()=>this.scroll()),50)):this.scrolling>-1&&(clearInterval(this.scrolling),
this.scrolling=-1)}scroll(){let{x:e,y:t}=this.scrollSpeed
;e&&this.scrollParents.x&&(this.scrollParents.x.scrollLeft+=e,
e=0),t&&this.scrollParents.y&&(this.scrollParents.y.scrollTop+=t,
t=0),(e||t)&&this.view.win.scrollBy(e,t),
!1===this.dragging&&this.select(this.lastEvent)}skipAtoms(e){let t=null
;for(let n=0;n<e.ranges.length;n++){let r=e.ranges[n],o=null;if(r.empty){
let e=jce(this.atoms,r.from,0);e!=r.from&&(o=Vae.cursor(e,-1))}else{
let e=jce(this.atoms,r.from,-1),t=jce(this.atoms,r.to,1)
;e==r.from&&t==r.to||(o=Vae.range(r.from==r.anchor?e:t,r.from==r.head?e:t))}
o&&(t||(t=e.ranges.slice()),t[n]=o)}return t?Vae.create(t,e.mainIndex):e}
select(e){
let{view:t}=this,n=this.skipAtoms(this.style.get(e,this.extend,this.multiple))
;!this.mustSelect&&n.eq(t.state.selection,!1===this.dragging)||this.view.dispatch({
selection:n,userEvent:"select.pointer"}),this.mustSelect=!1}update(e){
e.transactions.some((e=>e.isUserEvent("input.type")))?this.destroy():this.style.update(e)&&setTimeout((()=>this.select(this.lastEvent)),20)
}}
const tue=Object.create(null),nue=Object.create(null),rue=ele.ie&&ele.ie_version<15||ele.ios&&ele.webkit_version<604
;function oue(e,t,n){for(let r of e.facet(t))n=r(n,e);return n}
function aue(e,t){t=oue(e.state,Jle,t)
;let n,{state:r}=e,o=1,a=r.toText(t),i=a.lines==r.selection.ranges.length,s=null!=gue&&r.selection.ranges.every((e=>e.empty))&&gue==a.toString()
;if(s){let e=-1;n=r.changeByRange((n=>{let s=r.doc.lineAt(n.from)
;if(s.from==e)return{range:n};e=s.from
;let l=r.toText((i?a.line(o++).text:t)+r.lineBreak);return{changes:{from:s.from,
insert:l},range:Vae.cursor(n.from+l.length)}}))}else n=i?r.changeByRange((e=>{
let t=a.line(o++);return{changes:{from:e.from,to:e.to,insert:t.text},
range:Vae.cursor(e.from+t.length)}})):r.replaceSelection(a);e.dispatch(n,{
userEvent:"input.paste",scrollIntoView:!0})}function iue(e,t,n,r){
if(1==r)return Vae.cursor(t,n);if(2==r)return function(e,t,n=1){
let r=e.charCategorizer(t),o=e.doc.lineAt(t),a=t-o.from
;if(0==o.length)return Vae.cursor(t);0==a?n=1:a==o.length&&(n=-1);let i=a,s=a
;n<0?i=Pae(o.text,a,!1):s=Pae(o.text,a);let l=r(o.text.slice(i,s));for(;i>0;){
let e=Pae(o.text,i,!1);if(r(o.text.slice(e,i))!=l)break;i=e}for(;s<o.length;){
let e=Pae(o.text,s);if(r(o.text.slice(s,e))!=l)break;s=e}
return Vae.range(i+o.from,s+o.from)}(e.state,t,n);{
let n=wle.find(e.docView,t),r=e.state.doc.lineAt(n?n.posAtEnd:t),o=n?n.posAtStart:r.from,a=n?n.posAtEnd:r.to
;return a<e.state.doc.length&&a==r.to&&a++,Vae.range(o,a)}}nue.scroll=e=>{
e.inputState.lastScrollTop=e.scrollDOM.scrollTop,
e.inputState.lastScrollLeft=e.scrollDOM.scrollLeft
},tue.keydown=(e,t)=>(e.inputState.setSelectionOrigin("select"),
27==t.keyCode&&0!=e.inputState.tabFocusMode&&(e.inputState.tabFocusMode=Date.now()+2e3),
!1),nue.touchstart=(e,t)=>{
e.inputState.lastTouchTime=Date.now(),e.inputState.setSelectionOrigin("select.pointer")
},nue.touchmove=e=>{e.inputState.setSelectionOrigin("select.pointer")
},tue.mousedown=(e,t)=>{
if(e.observer.flush(),e.inputState.lastTouchTime>Date.now()-2e3)return!1
;let n=null;for(let r of e.state.facet(Wle))if(n=r(e,t),n)break
;if(n||0!=t.button||(n=function(e,t){let n=cue(e,t),r=fue(t),o=e.state.selection
;return{update(e){
e.docChanged&&(n.pos=e.changes.mapPos(n.pos),o=o.map(e.changes))},get(t,a,i){
let s,l=cue(e,t),c=iue(e,l.pos,l.bias,r);if(n.pos!=l.pos&&!a){
let t=iue(e,n.pos,n.bias,r),o=Math.min(t.from,c.from),a=Math.max(t.to,c.to)
;c=o<c.from?Vae.range(o,a):Vae.range(a,o)}
return a?o.replaceRange(o.main.extend(c.from,c.to)):i&&1==r&&o.ranges.length>1&&(s=function(e,t){
for(let n=0;n<e.ranges.length;n++){let{from:r,to:o}=e.ranges[n]
;if(r<=t&&o>=t)return Vae.create(e.ranges.slice(0,n).concat(e.ranges.slice(n+1)),e.mainIndex==n?0:e.mainIndex-(e.mainIndex>n?1:0))
}return null}(o,l.pos))?s:i?o.addRange(c):Vae.create([c])}}}(e,t)),n){
let r=!e.hasFocus
;e.inputState.startMouseSelection(new eue(e,t,n,r)),r&&e.observer.ignore((()=>{
Cse(e.contentDOM);let t=e.root.activeElement
;t&&!t.contains(e.contentDOM)&&t.blur()}));let o=e.inputState.mouseSelection
;if(o)return o.start(t),!1===o.dragging}return!1}
;let sue=(e,t,n)=>t>=n.top&&t<=n.bottom&&e>=n.left&&e<=n.right
;function lue(e,t,n,r){let o=wle.find(e.docView,t);if(!o)return 1
;let a=t-o.posAtStart;if(0==a)return 1;if(a==o.length)return-1
;let i=o.coordsAt(a,-1);if(i&&sue(n,r,i))return-1;let s=o.coordsAt(a,1)
;return s&&sue(n,r,s)?1:i&&i.bottom>=r?-1:1}function cue(e,t){
let n=e.posAtCoords({x:t.clientX,y:t.clientY},!1);return{pos:n,
bias:lue(e,n,t.clientX,t.clientY)}}const uue=ele.ie&&ele.ie_version<=11
;let due=null,pue=0,hue=0;function fue(e){if(!uue)return e.detail
;let t=due,n=hue
;return due=e,hue=Date.now(),pue=!t||n>Date.now()-400&&Math.abs(t.clientX-e.clientX)<2&&Math.abs(t.clientY-e.clientY)<2?(pue+1)%3:1
}function mue(e,t,n,r){if(!(n=oue(e.state,Jle,n)))return;let o=e.posAtCoords({
x:t.clientX,y:t.clientY
},!1),{draggedContent:a}=e.inputState,i=r&&a&&function(e,t){
let n=e.state.facet(qle);return n.length?n[0](t):ele.mac?!t.altKey:!t.ctrlKey
}(e,t)?{from:a.from,to:a.to}:null,s={from:o,insert:n
},l=e.state.changes(i?[i,s]:s);e.focus(),e.dispatch({changes:l,selection:{
anchor:l.mapPos(o,-1),head:l.mapPos(o,1)},userEvent:i?"move.drop":"input.drop"
}),e.inputState.draggedContent=null}tue.dragstart=(e,t)=>{
let{selection:{main:n}}=e.state;if(t.target.draggable){
let r=e.docView.nearest(t.target);if(r&&r.isWidget){
let e=r.posAtStart,t=e+r.length;(e>=n.to||t<=n.from)&&(n=Vae.range(e,t))}}
let{inputState:r}=e
;return r.mouseSelection&&(r.mouseSelection.dragging=!0),r.draggedContent=n,
t.dataTransfer&&(t.dataTransfer.setData("Text",oue(e.state,ece,e.state.sliceDoc(n.from,n.to))),
t.dataTransfer.effectAllowed="copyMove"),!1
},tue.dragend=e=>(e.inputState.draggedContent=null,!1),tue.drop=(e,t)=>{
if(!t.dataTransfer)return!1;if(e.state.readOnly)return!0
;let n=t.dataTransfer.files;if(n&&n.length){let r=Array(n.length),o=0,a=()=>{
++o==n.length&&mue(e,t,r.filter((e=>null!=e)).join(e.state.lineBreak),!1)}
;for(let e=0;e<n.length;e++){let t=new FileReader;t.onerror=a,t.onload=()=>{
/[\x00-\x08\x0e-\x1f]{2}/.test(t.result)||(r[e]=t.result),a()
},t.readAsText(n[e])}return!0}{let n=t.dataTransfer.getData("Text")
;if(n)return mue(e,t,n,!0),!0}return!1},tue.paste=(e,t)=>{
if(e.state.readOnly)return!0;e.observer.flush();let n=rue?null:t.clipboardData
;return n?(aue(e,n.getData("text/plain")||n.getData("text/uri-list")),
!0):(function(e){let t=e.dom.parentNode;if(!t)return
;let n=t.appendChild(document.createElement("textarea"))
;n.style.cssText="position: fixed; left: -10000px; top: 10px",
n.focus(),setTimeout((()=>{e.focus(),n.remove(),aue(e,n.value)}),50)}(e),!1)}
;let gue=null;tue.copy=tue.cut=(e,t)=>{
let{text:n,ranges:r,linewise:o}=function(e){let t=[],n=[],r=!1
;for(let o of e.selection.ranges)o.empty||(t.push(e.sliceDoc(o.from,o.to)),
n.push(o));if(!t.length){let o=-1;for(let{from:r}of e.selection.ranges){
let a=e.doc.lineAt(r);a.number>o&&(t.push(a.text),n.push({from:a.from,
to:Math.min(e.doc.length,a.to+1)})),o=a.number}r=!0}return{
text:oue(e,ece,t.join(e.lineBreak)),ranges:n,linewise:r}}(e.state)
;if(!n&&!o)return!1;gue=o?n:null,"cut"!=t.type||e.state.readOnly||e.dispatch({
changes:r,scrollIntoView:!0,userEvent:"delete.cut"})
;let a=rue?null:t.clipboardData
;return a?(a.clearData(),a.setData("text/plain",n),!0):(function(e,t){
let n=e.dom.parentNode;if(!n)return
;let r=n.appendChild(document.createElement("textarea"))
;r.style.cssText="position: fixed; left: -10000px; top: 10px",
r.value=t,r.focus(),r.selectionEnd=t.length,r.selectionStart=0,setTimeout((()=>{
r.remove(),e.focus()}),50)}(e,n),!1)};const vue=xie.define();function bue(e,t){
let n=[];for(let r of e.facet(Kle)){let o=r(e,t);o&&n.push(o)}
return n?e.update({effects:n,annotations:vue.of(!0)}):null}function yue(e){
setTimeout((()=>{let t=e.hasFocus;if(t!=e.inputState.notifiedFocused){
let n=bue(e.state,t);n?e.dispatch(n):e.update([])}}),10)}nue.focus=e=>{
e.inputState.lastFocusTime=Date.now(),
e.scrollDOM.scrollTop||!e.inputState.lastScrollTop&&!e.inputState.lastScrollLeft||(e.scrollDOM.scrollTop=e.inputState.lastScrollTop,
e.scrollDOM.scrollLeft=e.inputState.lastScrollLeft),yue(e)},nue.blur=e=>{
e.observer.clearSelectionRange(),yue(e)
},nue.compositionstart=nue.compositionupdate=e=>{
e.observer.editContext||(null==e.inputState.compositionFirstChange&&(e.inputState.compositionFirstChange=!0),
e.inputState.composing<0&&(e.inputState.composing=0))},nue.compositionend=e=>{
e.observer.editContext||(e.inputState.composing=-1,
e.inputState.compositionEndedAt=Date.now(),
e.inputState.compositionPendingKey=!0,
e.inputState.compositionPendingChange=e.observer.pendingRecords().length>0,
e.inputState.compositionFirstChange=null,
ele.chrome&&ele.android?e.observer.flushSoon():e.inputState.compositionPendingChange?Promise.resolve().then((()=>e.observer.flush())):setTimeout((()=>{
e.inputState.composing<0&&e.docView.hasComposition&&e.update([])}),50))
},nue.contextmenu=e=>{e.inputState.lastContextMenu=Date.now()
},tue.beforeinput=(e,t)=>{var n,r
;if("insertReplacementText"==t.inputType&&e.observer.editContext){
let r=null===(n=t.dataTransfer)||void 0===n?void 0:n.getData("text/plain"),o=t.getTargetRanges()
;if(r&&o.length){
let t=o[0],n=e.posAtDOM(t.startContainer,t.startOffset),a=e.posAtDOM(t.endContainer,t.endOffset)
;return qce(e,{from:n,to:a,insert:e.state.toText(r)},null),!0}}let o
;if(ele.chrome&&ele.android&&(o=Gce.find((e=>e.inputType==t.inputType)))&&(e.observer.delayAndroidKey(o.key,o.keyCode),
"Backspace"==o.key||"Delete"==o.key)){
let t=(null===(r=window.visualViewport)||void 0===r?void 0:r.height)||0
;setTimeout((()=>{var n
;((null===(n=window.visualViewport)||void 0===n?void 0:n.height)||0)>t+10&&e.hasFocus&&(e.contentDOM.blur(),
e.focus())}),100)}
return ele.ios&&"deleteContentForward"==t.inputType&&e.observer.flushSoon(),
ele.safari&&"insertText"==t.inputType&&e.inputState.composing>=0&&setTimeout((()=>nue.compositionend(e,t)),20),
!1};const Oue=new Set;const wue=["pre-wrap","normal","pre-line","break-spaces"]
;let xue=!1;function kue(){xue=!1}class Sue{constructor(e){
this.lineWrapping=e,this.doc=wae.empty,this.heightSamples={},this.lineHeight=14,
this.charWidth=7,this.textHeight=14,this.lineLength=30}heightForGap(e,t){
let n=this.doc.lineAt(t).number-this.doc.lineAt(e).number+1
;return this.lineWrapping&&(n+=Math.max(0,Math.ceil((t-e-n*this.lineLength*.5)/this.lineLength))),
this.lineHeight*n}heightForLine(e){if(!this.lineWrapping)return this.lineHeight
;return(1+Math.max(0,Math.ceil((e-this.lineLength)/(this.lineLength-5))))*this.lineHeight
}setDoc(e){return this.doc=e,this}mustRefreshForWrapping(e){
return wue.indexOf(e)>-1!=this.lineWrapping}mustRefreshForHeights(e){let t=!1
;for(let n=0;n<e.length;n++){let r=e[n]
;r<0?n++:this.heightSamples[Math.floor(10*r)]||(t=!0,
this.heightSamples[Math.floor(10*r)]=!0)}return t}refresh(e,t,n,r,o,a){
let i=wue.indexOf(e)>-1,s=Math.round(t)!=Math.round(this.lineHeight)||this.lineWrapping!=i
;if(this.lineWrapping=i,
this.lineHeight=t,this.charWidth=n,this.textHeight=r,this.lineLength=o,s){
this.heightSamples={};for(let e=0;e<a.length;e++){let t=a[e]
;t<0?e++:this.heightSamples[Math.floor(10*t)]=!0}}return s}}class _ue{
constructor(e,t){this.from=e,this.heights=t,this.index=0}get more(){
return this.index<this.heights.length}}class Tue{constructor(e,t,n,r,o){
this.from=e,this.length=t,this.top=n,this.height=r,this._content=o}get type(){
return"number"==typeof this._content?fle.Text:Array.isArray(this._content)?this._content:this._content.type
}get to(){return this.from+this.length}get bottom(){return this.top+this.height}
get widget(){return this._content instanceof ble?this._content.widget:null}
get widgetLineBreaks(){return"number"==typeof this._content?this._content:0}
join(e){
let t=(Array.isArray(this._content)?this._content:[this]).concat(Array.isArray(e._content)?e._content:[e])
;return new Tue(this.from,this.length+e.length,this.top,this.height+e.height,t)}
}var Eue=function(e){
return e[e.ByPos=0]="ByPos",e[e.ByHeight=1]="ByHeight",e[e.ByPosNoHeight=2]="ByPosNoHeight",
e}(Eue||(Eue={}));const Aue=.001;class Cue{constructor(e,t,n=2){
this.length=e,this.height=t,this.flags=n}get outdated(){return(2&this.flags)>0}
set outdated(e){this.flags=(e?2:0)|-3&this.flags}setHeight(e){
this.height!=e&&(Math.abs(this.height-e)>Aue&&(xue=!0),this.height=e)}
replace(e,t,n){return Cue.of(n)}decomposeLeft(e,t){t.push(this)}
decomposeRight(e,t){t.push(this)}applyChanges(e,t,n,r){let o=this,a=n.doc
;for(let i=r.length-1;i>=0;i--){
let{fromA:s,toA:l,fromB:c,toB:u}=r[i],d=o.lineAt(s,Eue.ByPosNoHeight,n.setDoc(t),0,0),p=d.to>=l?d:o.lineAt(l,Eue.ByPosNoHeight,n,0,0)
;for(u+=p.to-l,
l=p.to;i>0&&d.from<=r[i-1].toA;)s=r[i-1].fromA,c=r[i-1].fromB,i--,
s<d.from&&(d=o.lineAt(s,Eue.ByPosNoHeight,n,0,0));c+=d.from-s,s=d.from
;let h=Rue.build(n.setDoc(a),e,c,u);o=$ue(o,o.replace(s,l,h))}
return o.updateHeight(n,0)}static empty(){return new Due(0,0)}static of(e){
if(1==e.length)return e[0];let t=0,n=e.length,r=0,o=0;for(;;)if(t==n)if(r>2*o){
let o=e[t-1]
;o.break?e.splice(--t,1,o.left,null,o.right):e.splice(--t,1,o.left,o.right),
n+=1+o.break,r-=o.size}else{if(!(o>2*r))break;{let t=e[n]
;t.break?e.splice(n,1,t.left,null,t.right):e.splice(n,1,t.left,t.right),
n+=2+t.break,o-=t.size}}else if(r<o){let n=e[t++];n&&(r+=n.size)}else{
let t=e[--n];t&&(o+=t.size)}let a=0
;return null==e[t-1]?(a=1,t--):null==e[t]&&(a=1,
n++),new Mue(Cue.of(e.slice(0,t)),a,Cue.of(e.slice(n)))}}function $ue(e,t){
return e==t?e:(e.constructor!=t.constructor&&(xue=!0),t)}Cue.prototype.size=1
;class Pue extends Cue{constructor(e,t,n){super(e,t),this.deco=n}
blockAt(e,t,n,r){return new Tue(r,this.length,n,this.height,this.deco||0)}
lineAt(e,t,n,r,o){return this.blockAt(0,n,r,o)}forEachLine(e,t,n,r,o,a){
e<=o+this.length&&t>=o&&a(this.blockAt(0,n,r,o))}updateHeight(e,t=0,n=!1,r){
return r&&r.from<=t&&r.more&&this.setHeight(r.heights[r.index++]),
this.outdated=!1,this}toString(){return`block(${this.length})`}}
class Due extends Pue{constructor(e,t){
super(e,t,null),this.collapsed=0,this.widgetHeight=0,this.breaks=0}
blockAt(e,t,n,r){return new Tue(r,this.length,n,this.height,this.breaks)}
replace(e,t,n){let r=n[0]
;return 1==n.length&&(r instanceof Due||r instanceof Iue&&4&r.flags)&&Math.abs(this.length-r.length)<10?(r instanceof Iue?r=new Due(r.length,this.height):r.height=this.height,
this.outdated||(r.outdated=!1),r):Cue.of(n)}updateHeight(e,t=0,n=!1,r){
return r&&r.from<=t&&r.more?this.setHeight(r.heights[r.index++]):(n||this.outdated)&&this.setHeight(Math.max(this.widgetHeight,e.heightForLine(this.length-this.collapsed))+this.breaks*e.lineHeight),
this.outdated=!1,this}toString(){
return`line(${this.length}${this.collapsed?-this.collapsed:""}${this.widgetHeight?":"+this.widgetHeight:""})`
}}class Iue extends Cue{constructor(e){super(e,0)}heightMetrics(e,t){
let n,r=e.doc.lineAt(t).number,o=e.doc.lineAt(t+this.length).number,a=o-r+1,i=0
;if(e.lineWrapping){let t=Math.min(this.height,e.lineHeight*a)
;n=t/a,this.length>a+1&&(i=(this.height-t)/(this.length-a-1))
}else n=this.height/a;return{firstLine:r,lastLine:o,perLine:n,perChar:i}}
blockAt(e,t,n,r){
let{firstLine:o,lastLine:a,perLine:i,perChar:s}=this.heightMetrics(t,r)
;if(t.lineWrapping){
let o=r+(e<t.lineHeight?0:Math.round(Math.max(0,Math.min(1,(e-n)/this.height))*this.length)),a=t.doc.lineAt(o),l=i+a.length*s,c=Math.max(n,e-l/2)
;return new Tue(a.from,a.length,c,l,0)}{
let r=Math.max(0,Math.min(a-o,Math.floor((e-n)/i))),{from:s,length:l}=t.doc.line(o+r)
;return new Tue(s,l,n+i*r,i,0)}}lineAt(e,t,n,r,o){
if(t==Eue.ByHeight)return this.blockAt(e,n,r,o);if(t==Eue.ByPosNoHeight){
let{from:t,to:r}=n.doc.lineAt(e);return new Tue(t,r-t,0,0,0)}
let{firstLine:a,perLine:i,perChar:s}=this.heightMetrics(n,o),l=n.doc.lineAt(e),c=i+l.length*s,u=l.number-a,d=r+i*u+s*(l.from-o-u)
;return new Tue(l.from,l.length,Math.max(r,Math.min(d,r+this.height-c)),c,0)}
forEachLine(e,t,n,r,o,a){e=Math.max(e,o),t=Math.min(t,o+this.length)
;let{firstLine:i,perLine:s,perChar:l}=this.heightMetrics(n,o)
;for(let c=e,u=r;c<=t;){let t=n.doc.lineAt(c);if(c==e){let n=t.number-i
;u+=s*n+l*(e-o-n)}let r=s+l*t.length
;a(new Tue(t.from,t.length,u,r,0)),u+=r,c=t.to+1}}replace(e,t,n){
let r=this.length-t;if(r>0){let e=n[n.length-1]
;e instanceof Iue?n[n.length-1]=new Iue(e.length+r):n.push(null,new Iue(r-1))}
if(e>0){let t=n[0]
;t instanceof Iue?n[0]=new Iue(e+t.length):n.unshift(new Iue(e-1),null)}
return Cue.of(n)}decomposeLeft(e,t){t.push(new Iue(e-1),null)}
decomposeRight(e,t){t.push(null,new Iue(this.length-e-1))}
updateHeight(e,t=0,n=!1,r){let o=t+this.length
;if(r&&r.from<=t+this.length&&r.more){let n=[],a=Math.max(t,r.from),i=-1
;for(r.from>t&&n.push(new Iue(r.from-t-1).updateHeight(e,t));a<=o&&r.more;){
let t=e.doc.lineAt(a).length;n.length&&n.push(null);let o=r.heights[r.index++]
;-1==i?i=o:Math.abs(o-i)>=Aue&&(i=-2);let s=new Due(t,o)
;s.outdated=!1,n.push(s),a+=t+1}
a<=o&&n.push(null,new Iue(o-a).updateHeight(e,a));let s=Cue.of(n)
;return(i<0||Math.abs(s.height-this.height)>=Aue||Math.abs(i-this.heightMetrics(e,t).perLine)>=Aue)&&(xue=!0),
$ue(this,s)}
return(n||this.outdated)&&(this.setHeight(e.heightForGap(t,t+this.length)),
this.outdated=!1),this}toString(){return`gap(${this.length})`}}
class Mue extends Cue{constructor(e,t,n){
super(e.length+t+n.length,e.height+n.height,t|(e.outdated||n.outdated?2:0)),
this.left=e,this.right=n,this.size=e.size+n.size}get break(){return 1&this.flags
}blockAt(e,t,n,r){let o=n+this.left.height
;return e<o?this.left.blockAt(e,t,n,r):this.right.blockAt(e,t,o,r+this.left.length+this.break)
}lineAt(e,t,n,r,o){
let a=r+this.left.height,i=o+this.left.length+this.break,s=t==Eue.ByHeight?e<a:e<i,l=s?this.left.lineAt(e,t,n,r,o):this.right.lineAt(e,t,n,a,i)
;if(this.break||(s?l.to<i:l.from>i))return l
;let c=t==Eue.ByPosNoHeight?Eue.ByPosNoHeight:Eue.ByPos
;return s?l.join(this.right.lineAt(i,c,n,a,i)):this.left.lineAt(i,c,n,r,o).join(l)
}forEachLine(e,t,n,r,o,a){
let i=r+this.left.height,s=o+this.left.length+this.break
;if(this.break)e<s&&this.left.forEachLine(e,t,n,r,o,a),
t>=s&&this.right.forEachLine(e,t,n,i,s,a);else{
let l=this.lineAt(s,Eue.ByPos,n,r,o)
;e<l.from&&this.left.forEachLine(e,l.from-1,n,r,o,a),
l.to>=e&&l.from<=t&&a(l),t>l.to&&this.right.forEachLine(l.to+1,t,n,i,s,a)}}
replace(e,t,n){let r=this.left.length+this.break
;if(t<r)return this.balanced(this.left.replace(e,t,n),this.right)
;if(e>this.left.length)return this.balanced(this.left,this.right.replace(e-r,t-r,n))
;let o=[];e>0&&this.decomposeLeft(e,o);let a=o.length;for(let i of n)o.push(i)
;if(e>0&&Nue(o,a-1),t<this.length){let e=o.length
;this.decomposeRight(t,o),Nue(o,e)}return Cue.of(o)}decomposeLeft(e,t){
let n=this.left.length;if(e<=n)return this.left.decomposeLeft(e,t)
;t.push(this.left),
this.break&&(n++,e>=n&&t.push(null)),e>n&&this.right.decomposeLeft(e-n,t)}
decomposeRight(e,t){let n=this.left.length,r=n+this.break
;if(e>=r)return this.right.decomposeRight(e-r,t)
;e<n&&this.left.decomposeRight(e,t),
this.break&&e<r&&t.push(null),t.push(this.right)}balanced(e,t){
return e.size>2*t.size||t.size>2*e.size?Cue.of(this.break?[e,null,t]:[e,t]):(this.left=$ue(this.left,e),
this.right=$ue(this.right,t),
this.setHeight(e.height+t.height),this.outdated=e.outdated||t.outdated,
this.size=e.size+t.size,this.length=e.length+this.break+t.length,this)}
updateHeight(e,t=0,n=!1,r){
let{left:o,right:a}=this,i=t+o.length+this.break,s=null
;return r&&r.from<=t+o.length&&r.more?s=o=o.updateHeight(e,t,n,r):o.updateHeight(e,t,n),
r&&r.from<=i+a.length&&r.more?s=a=a.updateHeight(e,i,n,r):a.updateHeight(e,i,n),
s?this.balanced(o,a):(this.height=this.left.height+this.right.height,
this.outdated=!1,this)}toString(){
return this.left+(this.break?" ":"-")+this.right}}function Nue(e,t){let n,r
;null==e[t]&&(n=e[t-1])instanceof Iue&&(r=e[t+1])instanceof Iue&&e.splice(t-1,3,new Iue(n.length+1+r.length))
}class Rue{constructor(e,t){
this.pos=e,this.oracle=t,this.nodes=[],this.lineStart=-1,
this.lineEnd=-1,this.covering=null,this.writtenTo=e}get isCovered(){
return this.covering&&this.nodes[this.nodes.length-1]==this.covering}span(e,t){
if(this.lineStart>-1){
let e=Math.min(t,this.lineEnd),n=this.nodes[this.nodes.length-1]
;n instanceof Due?n.length+=e-this.pos:(e>this.pos||!this.isCovered)&&this.nodes.push(new Due(e-this.pos,-1)),
this.writtenTo=e,t>e&&(this.nodes.push(null),this.writtenTo++,this.lineStart=-1)
}this.pos=t}point(e,t,n){if(e<t||n.heightRelevant){
let r=n.widget?n.widget.estimatedHeight:0,o=n.widget?n.widget.lineBreaks:0
;r<0&&(r=this.oracle.lineHeight);let a=t-e
;n.block?this.addBlock(new Pue(a,r,n)):(a||o||r>=5)&&this.addLineDeco(r,o,a)
}else t>e&&this.span(e,t)
;this.lineEnd>-1&&this.lineEnd<this.pos&&(this.lineEnd=this.oracle.doc.lineAt(this.pos).to)
}enterLine(){if(this.lineStart>-1)return
;let{from:e,to:t}=this.oracle.doc.lineAt(this.pos)
;this.lineStart=e,this.lineEnd=t,
this.writtenTo<e&&((this.writtenTo<e-1||null==this.nodes[this.nodes.length-1])&&this.nodes.push(this.blankContent(this.writtenTo,e-1)),
this.nodes.push(null)),
this.pos>e&&this.nodes.push(new Due(this.pos-e,-1)),this.writtenTo=this.pos}
blankContent(e,t){let n=new Iue(t-e)
;return this.oracle.doc.lineAt(e).to==t&&(n.flags|=4),n}ensureLine(){
this.enterLine();let e=this.nodes.length?this.nodes[this.nodes.length-1]:null
;if(e instanceof Due)return e;let t=new Due(0,-1);return this.nodes.push(t),t}
addBlock(e){this.enterLine();let t=e.deco
;t&&t.startSide>0&&!this.isCovered&&this.ensureLine(),
this.nodes.push(e),this.writtenTo=this.pos=this.pos+e.length,
t&&t.endSide>0&&(this.covering=e)}addLineDeco(e,t,n){let r=this.ensureLine()
;r.length+=n,
r.collapsed+=n,r.widgetHeight=Math.max(r.widgetHeight,e),r.breaks+=t,
this.writtenTo=this.pos=this.pos+n}finish(e){
let t=0==this.nodes.length?null:this.nodes[this.nodes.length-1]
;!(this.lineStart>-1)||t instanceof Due||this.isCovered?(this.writtenTo<this.pos||null==t)&&this.nodes.push(this.blankContent(this.writtenTo,this.pos)):this.nodes.push(new Due(0,-1))
;let n=e
;for(let r of this.nodes)r instanceof Due&&r.updateHeight(this.oracle,n),
n+=r?r.length:1;return this.nodes}static build(e,t,n,r){let o=new Rue(n,e)
;return Zie.spans(t,n,r,o,0),o.finish(n)}}class Lue{constructor(){
this.changes=[]}compareRange(){}comparePoint(e,t,n,r){
(e<t||n&&n.heightRelevant||r&&r.heightRelevant)&&Ole(e,t,this.changes,5)}}
function Bue(e,t){
let n=e.getBoundingClientRect(),r=e.ownerDocument,o=r.defaultView||window,a=Math.max(0,n.left),i=Math.min(o.innerWidth,n.right),s=Math.max(0,n.top),l=Math.min(o.innerHeight,n.bottom)
;for(let c=e.parentNode;c&&c!=r.body;)if(1==c.nodeType){
let t=c,n=window.getComputedStyle(t)
;if((t.scrollHeight>t.clientHeight||t.scrollWidth>t.clientWidth)&&"visible"!=n.overflow){
let n=t.getBoundingClientRect()
;a=Math.max(a,n.left),i=Math.min(i,n.right),s=Math.max(s,n.top),
l=Math.min(c==e.parentNode?o.innerHeight:l,n.bottom)}
c="absolute"==n.position||"fixed"==n.position?t.offsetParent:t.parentNode}else{
if(11!=c.nodeType)break;c=c.host}return{left:a-n.left,
right:Math.max(a,i)-n.left,top:s-(n.top+t),bottom:Math.max(s,l)-(n.top+t)}}
function jue(e,t){let n=e.getBoundingClientRect();return{left:0,
right:n.right-n.left,top:t,bottom:n.bottom-(n.top+t)}}class Uue{
constructor(e,t,n,r){this.from=e,this.to=t,this.size=n,this.displaySize=r}
static same(e,t){if(e.length!=t.length)return!1;for(let n=0;n<e.length;n++){
let r=e[n],o=t[n];if(r.from!=o.from||r.to!=o.to||r.size!=o.size)return!1}
return!0}draw(e,t){return mle.replace({
widget:new zue(this.displaySize*(t?e.scaleY:e.scaleX),t)
}).range(this.from,this.to)}}class zue extends hle{constructor(e,t){
super(),this.size=e,this.vertical=t}eq(e){
return e.size==this.size&&e.vertical==this.vertical}toDOM(){
let e=document.createElement("div")
;return this.vertical?e.style.height=this.size+"px":(e.style.width=this.size+"px",
e.style.height="2px",e.style.display="inline-block"),e}get estimatedHeight(){
return this.vertical?this.size:-1}}class Fue{constructor(e){
this.state=e,this.pixelViewport={left:0,right:window.innerWidth,top:0,bottom:0},
this.inView=!0,
this.paddingTop=0,this.paddingBottom=0,this.contentDOMWidth=0,this.contentDOMHeight=0,
this.editorHeight=0,
this.editorWidth=0,this.scrollTop=0,this.scrolledToBottom=!1,
this.scaleX=1,this.scaleY=1,
this.scrollAnchorPos=0,this.scrollAnchorHeight=-1,this.scaler=Vue,
this.scrollTarget=null,
this.printing=!1,this.mustMeasureContent=!0,this.defaultTextDirection=Ele.LTR,
this.visibleRanges=[],this.mustEnforceCursorAssoc=!1
;let t=e.facet(fce).some((e=>"function"!=typeof e&&"cm-lineWrapping"==e.class))
;this.heightOracle=new Sue(t),
this.stateDeco=e.facet(mce).filter((e=>"function"!=typeof e)),
this.heightMap=Cue.empty().applyChanges(this.stateDeco,wae.empty,this.heightOracle.setDoc(e.doc),[new kce(0,0,0,e.doc.length)])
;for(let n=0;n<2&&(this.viewport=this.getViewport(0,null),
this.updateForViewport());n++);
this.updateViewportLines(),this.lineGaps=this.ensureLineGaps([]),
this.lineGapDeco=mle.set(this.lineGaps.map((e=>e.draw(this,!1)))),
this.computeVisibleRanges()}updateForViewport(){
let e=[this.viewport],{main:t}=this.state.selection;for(let n=0;n<=1;n++){
let r=n?t.head:t.anchor;if(!e.some((({from:e,to:t})=>r>=e&&r<=t))){
let{from:t,to:n}=this.lineBlockAt(r);e.push(new Zue(t,n))}}
return this.viewports=e.sort(((e,t)=>e.from-t.from)),this.updateScaler()}
updateScaler(){let e=this.scaler
;return this.scaler=this.heightMap.height<=7e6?Vue:new que(this.heightOracle,this.heightMap,this.viewports),
e.eq(this.scaler)?0:2}updateViewportLines(){
this.viewportLines=[],this.heightMap.forEachLine(this.viewport.from,this.viewport.to,this.heightOracle.setDoc(this.state.doc),0,0,(e=>{
this.viewportLines.push(Wue(e,this.scaler))}))}update(e,t=null){
this.state=e.state;let n=this.stateDeco
;this.stateDeco=this.state.facet(mce).filter((e=>"function"!=typeof e))
;let r=e.changedRanges,o=kce.extendWithRanges(r,function(e,t,n){let r=new Lue
;return Zie.compare(e,t,n,r,0),r.changes
}(n,this.stateDeco,e?e.changes:Bae.empty(this.state.doc.length))),a=this.heightMap.height,i=this.scrolledToBottom?null:this.scrollAnchorAt(this.scrollTop)
;kue(),
this.heightMap=this.heightMap.applyChanges(this.stateDeco,e.startState.doc,this.heightOracle.setDoc(this.state.doc),o),
(this.heightMap.height!=a||xue)&&(e.flags|=2),
i?(this.scrollAnchorPos=e.changes.mapPos(i.from,-1),
this.scrollAnchorHeight=i.top):(this.scrollAnchorPos=-1,
this.scrollAnchorHeight=this.heightMap.height)
;let s=o.length?this.mapViewport(this.viewport,e.changes):this.viewport
;(t&&(t.range.head<s.from||t.range.head>s.to)||!this.viewportIsAppropriate(s))&&(s=this.getViewport(0,t))
;let l=s.from!=this.viewport.from||s.to!=this.viewport.to
;this.viewport=s,e.flags|=this.updateForViewport(),
(l||!e.changes.empty||2&e.flags)&&this.updateViewportLines(),
(this.lineGaps.length||this.viewport.to-this.viewport.from>4e3)&&this.updateLineGaps(this.ensureLineGaps(this.mapLineGaps(this.lineGaps,e.changes))),
e.flags|=this.computeVisibleRanges(),
t&&(this.scrollTarget=t),!this.mustEnforceCursorAssoc&&e.selectionSet&&e.view.lineWrapping&&e.state.selection.main.empty&&e.state.selection.main.assoc&&!e.state.facet(nce)&&(this.mustEnforceCursorAssoc=!0)
}measure(e){
let t=e.contentDOM,n=window.getComputedStyle(t),r=this.heightOracle,o=n.whiteSpace
;this.defaultTextDirection="rtl"==n.direction?Ele.RTL:Ele.LTR
;let a=this.heightOracle.mustRefreshForWrapping(o),i=t.getBoundingClientRect(),s=a||this.mustMeasureContent||this.contentDOMHeight!=i.height
;this.contentDOMHeight=i.height,this.mustMeasureContent=!1;let l=0,c=0
;if(i.width&&i.height){let{scaleX:e,scaleY:n}=_se(t,i)
;(e>.005&&Math.abs(this.scaleX-e)>.005||n>.005&&Math.abs(this.scaleY-n)>.005)&&(this.scaleX=e,
this.scaleY=n,l|=8,a=s=!0)}
let u=(parseInt(n.paddingTop)||0)*this.scaleY,d=(parseInt(n.paddingBottom)||0)*this.scaleY
;this.paddingTop==u&&this.paddingBottom==d||(this.paddingTop=u,
this.paddingBottom=d,
l|=10),this.editorWidth!=e.scrollDOM.clientWidth&&(r.lineWrapping&&(s=!0),
this.editorWidth=e.scrollDOM.clientWidth,l|=8)
;let p=e.scrollDOM.scrollTop*this.scaleY
;this.scrollTop!=p&&(this.scrollAnchorHeight=-1,
this.scrollTop=p),this.scrolledToBottom=Ise(e.scrollDOM)
;let h=(this.printing?jue:Bue)(t,this.paddingTop),f=h.top-this.pixelViewport.top,m=h.bottom-this.pixelViewport.bottom
;this.pixelViewport=h
;let g=this.pixelViewport.bottom>this.pixelViewport.top&&this.pixelViewport.right>this.pixelViewport.left
;if(g!=this.inView&&(this.inView=g,
g&&(s=!0)),!this.inView&&!this.scrollTarget)return 0;let v=i.width
;if(this.contentDOMWidth==v&&this.editorHeight==e.scrollDOM.clientHeight||(this.contentDOMWidth=i.width,
this.editorHeight=e.scrollDOM.clientHeight,l|=8),s){
let t=e.docView.measureVisibleLineHeights(this.viewport)
;if(r.mustRefreshForHeights(t)&&(a=!0),
a||r.lineWrapping&&Math.abs(v-this.contentDOMWidth)>r.charWidth){
let{lineHeight:n,charWidth:i,textHeight:s}=e.docView.measureTextSize()
;a=n>0&&r.refresh(o,n,i,s,v/i,t),a&&(e.docView.minWidth=0,l|=8)}
f>0&&m>0?c=Math.max(f,m):f<0&&m<0&&(c=Math.min(f,m)),kue()
;for(let n of this.viewports){
let o=n.from==this.viewport.from?t:e.docView.measureVisibleLineHeights(n)
;this.heightMap=(a?Cue.empty().applyChanges(this.stateDeco,wae.empty,this.heightOracle,[new kce(0,0,0,e.state.doc.length)]):this.heightMap).updateHeight(r,0,a,new _ue(n.from,o))
}xue&&(l|=2)}
let b=!this.viewportIsAppropriate(this.viewport,c)||this.scrollTarget&&(this.scrollTarget.range.head<this.viewport.from||this.scrollTarget.range.head>this.viewport.to)
;return b&&(2&l&&(l|=this.updateScaler()),
this.viewport=this.getViewport(c,this.scrollTarget),
l|=this.updateForViewport()),
(2&l||b)&&this.updateViewportLines(),(this.lineGaps.length||this.viewport.to-this.viewport.from>4e3)&&this.updateLineGaps(this.ensureLineGaps(a?[]:this.lineGaps,e)),
l|=this.computeVisibleRanges(),
this.mustEnforceCursorAssoc&&(this.mustEnforceCursorAssoc=!1,
e.docView.enforceCursorAssoc()),l}get visibleTop(){
return this.scaler.fromDOM(this.pixelViewport.top)}get visibleBottom(){
return this.scaler.fromDOM(this.pixelViewport.bottom)}getViewport(e,t){
let n=.5-Math.max(-.5,Math.min(.5,e/1e3/2)),r=this.heightMap,o=this.heightOracle,{visibleTop:a,visibleBottom:i}=this,s=new Zue(r.lineAt(a-1e3*n,Eue.ByHeight,o,0,0).from,r.lineAt(i+1e3*(1-n),Eue.ByHeight,o,0,0).to)
;if(t){let{head:e}=t.range;if(e<s.from||e>s.to){
let n,a=Math.min(this.editorHeight,this.pixelViewport.bottom-this.pixelViewport.top),i=r.lineAt(e,Eue.ByPos,o,0,0)
;n="center"==t.y?(i.top+i.bottom)/2-a/2:"start"==t.y||"nearest"==t.y&&e<s.from?i.top:i.bottom-a,
s=new Zue(r.lineAt(n-500,Eue.ByHeight,o,0,0).from,r.lineAt(n+a+500,Eue.ByHeight,o,0,0).to)
}}return s}mapViewport(e,t){let n=t.mapPos(e.from,-1),r=t.mapPos(e.to,1)
;return new Zue(this.heightMap.lineAt(n,Eue.ByPos,this.heightOracle,0,0).from,this.heightMap.lineAt(r,Eue.ByPos,this.heightOracle,0,0).to)
}viewportIsAppropriate({from:e,to:t},n=0){if(!this.inView)return!0
;let{top:r}=this.heightMap.lineAt(e,Eue.ByPos,this.heightOracle,0,0),{bottom:o}=this.heightMap.lineAt(t,Eue.ByPos,this.heightOracle,0,0),{visibleTop:a,visibleBottom:i}=this
;return(0==e||r<=a-Math.max(10,Math.min(-n,250)))&&(t==this.state.doc.length||o>=i+Math.max(10,Math.min(n,250)))&&r>a-2e3&&o<i+2e3
}mapLineGaps(e,t){if(!e.length||t.empty)return e;let n=[]
;for(let r of e)t.touchesRange(r.from,r.to)||n.push(new Uue(t.mapPos(r.from),t.mapPos(r.to),r.size,r.displaySize))
;return n}ensureLineGaps(e,t){
let n=this.heightOracle.lineWrapping,r=n?1e4:2e3,o=r>>1,a=r<<1
;if(this.defaultTextDirection!=Ele.LTR&&!n)return[];let i=[],s=(r,a,l,c)=>{
if(a-r<o)return;let u=this.state.selection.main,d=[u.from];u.empty||d.push(u.to)
;for(let e of d)if(e>r&&e<a)return s(r,e-10,l,c),void s(e+10,a,l,c)
;let p=function(e,t){for(let n of e)if(t(n))return n;return
}(e,(e=>e.from>=l.from&&e.to<=l.to&&Math.abs(e.from-r)<o&&Math.abs(e.to-a)<o&&!d.some((t=>e.from<t&&e.to>t))))
;if(!p){if(a<l.to&&t&&n&&t.visibleRanges.some((e=>e.from<=a&&e.to>=a))){
let e=t.moveToLineBoundary(Vae.cursor(a),!1,!0).head;e>r&&(a=e)}
let e=this.gapSize(l,r,a,c);p=new Uue(r,a,e,n||e<2e6?e:2e6)}i.push(p)},l=t=>{
if(t.length<a||t.type!=fle.Text)return;let o=function(e,t,n){let r=[],o=e,a=0
;Zie.spans(n,e,t,{span(){},point(e,t){e>o&&(r.push({from:o,to:e}),a+=e-o),o=t}
},20),o<t&&(r.push({from:o,to:t}),a+=t-o);return{total:a,ranges:r}
}(t.from,t.to,this.stateDeco);if(o.total<a)return
;let i,l,c=this.scrollTarget?this.scrollTarget.range.head:null;if(n){
let e,n,a=r/this.heightOracle.lineLength*this.heightOracle.lineHeight
;if(null!=c){
let r=Hue(o,c),i=((this.visibleBottom-this.visibleTop)/2+a)/t.height;e=r-i,n=r+i
}else e=(this.visibleTop-t.top-a)/t.height,
n=(this.visibleBottom-t.top+a)/t.height;i=Que(o,e),l=Que(o,n)}else{
let n=o.total*this.heightOracle.charWidth,a=r*this.heightOracle.charWidth,s=0
;if(n>2e6)for(let r of e)r.from>=t.from&&r.from<t.to&&r.size!=r.displaySize&&r.from*this.heightOracle.charWidth+s<this.pixelViewport.left&&(s=r.size-r.displaySize)
;let u,d,p=this.pixelViewport.left+s,h=this.pixelViewport.right+s;if(null!=c){
let e=Hue(o,c),t=((h-p)/2+a)/n;u=e-t,d=e+t}else u=(p-a)/n,d=(h+a)/n
;i=Que(o,u),l=Que(o,d)}i>t.from&&s(t.from,i,t,o),l<t.to&&s(l,t.to,t,o)}
;for(let c of this.viewportLines)Array.isArray(c.type)?c.type.forEach(l):l(c)
;return i}gapSize(e,t,n,r){let o=Hue(r,n)-Hue(r,t)
;return this.heightOracle.lineWrapping?e.height*o:r.total*this.heightOracle.charWidth*o
}updateLineGaps(e){
Uue.same(e,this.lineGaps)||(this.lineGaps=e,this.lineGapDeco=mle.set(e.map((e=>e.draw(this,this.heightOracle.lineWrapping)))))
}computeVisibleRanges(){let e=this.stateDeco
;this.lineGaps.length&&(e=e.concat(this.lineGapDeco));let t=[]
;Zie.spans(e,this.viewport.from,this.viewport.to,{span(e,n){t.push({from:e,to:n
})},point(){}},20)
;let n=t.length!=this.visibleRanges.length||this.visibleRanges.some(((e,n)=>e.from!=t[n].from||e.to!=t[n].to))
;return this.visibleRanges=t,n?4:0}lineBlockAt(e){
return e>=this.viewport.from&&e<=this.viewport.to&&this.viewportLines.find((t=>t.from<=e&&t.to>=e))||Wue(this.heightMap.lineAt(e,Eue.ByPos,this.heightOracle,0,0),this.scaler)
}lineBlockAtHeight(e){
return e>=this.viewportLines[0].top&&e<=this.viewportLines[this.viewportLines.length-1].bottom&&this.viewportLines.find((t=>t.top<=e&&t.bottom>=e))||Wue(this.heightMap.lineAt(this.scaler.fromDOM(e),Eue.ByHeight,this.heightOracle,0,0),this.scaler)
}scrollAnchorAt(e){let t=this.lineBlockAtHeight(e+8)
;return t.from>=this.viewport.from||this.viewportLines[0].top-e>200?t:this.viewportLines[0]
}elementAtHeight(e){
return Wue(this.heightMap.blockAt(this.scaler.fromDOM(e),this.heightOracle,0,0),this.scaler)
}get docHeight(){return this.scaler.toDOM(this.heightMap.height)}
get contentHeight(){return this.docHeight+this.paddingTop+this.paddingBottom}}
class Zue{constructor(e,t){this.from=e,this.to=t}}
function Que({total:e,ranges:t},n){if(n<=0)return t[0].from
;if(n>=1)return t[t.length-1].to;let r=Math.floor(e*n);for(let o=0;;o++){
let{from:e,to:n}=t[o],a=n-e;if(r<=a)return e+r;r-=a}}function Hue(e,t){let n=0
;for(let{from:r,to:o}of e.ranges){if(t<=o){n+=t-r;break}n+=o-r}return n/e.total}
const Vue={toDOM:e=>e,fromDOM:e=>e,scale:1,eq(e){return e==this}};class que{
constructor(e,t,n){let r=0,o=0,a=0;this.viewports=n.map((({from:n,to:o})=>{
let a=t.lineAt(n,Eue.ByPos,e,0,0).top,i=t.lineAt(o,Eue.ByPos,e,0,0).bottom
;return r+=i-a,{from:n,to:o,top:a,bottom:i,domTop:0,domBottom:0}
})),this.scale=(7e6-r)/(t.height-r)
;for(let i of this.viewports)i.domTop=a+(i.top-o)*this.scale,
a=i.domBottom=i.domTop+(i.bottom-i.top),o=i.bottom}toDOM(e){
for(let t=0,n=0,r=0;;t++){let o=t<this.viewports.length?this.viewports[t]:null
;if(!o||e<o.top)return r+(e-n)*this.scale
;if(e<=o.bottom)return o.domTop+(e-o.top);n=o.bottom,r=o.domBottom}}fromDOM(e){
for(let t=0,n=0,r=0;;t++){let o=t<this.viewports.length?this.viewports[t]:null
;if(!o||e<o.domTop)return n+(e-r)/this.scale
;if(e<=o.domBottom)return o.top+(e-o.domTop);n=o.bottom,r=o.domBottom}}eq(e){
return e instanceof que&&(this.scale==e.scale&&this.viewports.length==e.viewports.length&&this.viewports.every(((t,n)=>t.from==e.viewports[n].from&&t.to==e.viewports[n].to)))
}}function Wue(e,t){if(1==t.scale)return e
;let n=t.toDOM(e.top),r=t.toDOM(e.bottom)
;return new Tue(e.from,e.length,n,r-n,Array.isArray(e._content)?e._content.map((e=>Wue(e,t))):e._content)
}const Xue=Xae.define({combine:e=>e.join(" ")}),Gue=Xae.define({
combine:e=>e.indexOf(!0)>-1
}),Yue=ase.newName(),Kue=ase.newName(),Jue=ase.newName(),ede={"&light":"."+Kue,
"&dark":"."+Jue};function tde(e,t,n){return new ase(t,{
finish:t=>/&/.test(t)?t.replace(/&\w*/,(t=>{if("&"==t)return e
;if(!n||!n[t])throw new RangeError(`Unsupported selector: ${t}`);return n[t]
})):e+" "+t})}const nde=tde("."+Yue,{"&":{position:"relative !important",
boxSizing:"border-box","&.cm-focused":{outline:"1px dotted #212121"},
display:"flex !important",flexDirection:"column"},".cm-scroller":{
display:"flex !important",alignItems:"flex-start !important",
fontFamily:"monospace",lineHeight:1.4,height:"100%",overflowX:"auto",
position:"relative",zIndex:0,overflowAnchor:"none"},".cm-content":{margin:0,
flexGrow:2,flexShrink:0,display:"block",whiteSpace:"pre",wordWrap:"normal",
boxSizing:"border-box",minHeight:"100%",padding:"4px 0",outline:"none",
"&[contenteditable=true]":{WebkitUserModify:"read-write-plaintext-only"}},
".cm-lineWrapping":{whiteSpace_fallback:"pre-wrap",whiteSpace:"break-spaces",
wordBreak:"break-word",overflowWrap:"anywhere",flexShrink:1},
"&light .cm-content":{caretColor:"black"},"&dark .cm-content":{
caretColor:"white"},".cm-line":{display:"block",padding:"0 2px 0 6px"},
".cm-layer":{position:"absolute",left:0,top:0,contain:"size style","& > *":{
position:"absolute"}},"&light .cm-selectionBackground":{background:"#d9d9d9"},
"&dark .cm-selectionBackground":{background:"#222"},
"&light.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground":{
background:"#d7d4f0"},
"&dark.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground":{
background:"#233"},".cm-cursorLayer":{pointerEvents:"none"},
"&.cm-focused > .cm-scroller > .cm-cursorLayer":{
animation:"steps(1) cm-blink 1.2s infinite"},"@keyframes cm-blink":{"0%":{},
"50%":{opacity:0},"100%":{}},"@keyframes cm-blink2":{"0%":{},"50%":{opacity:0},
"100%":{}},".cm-cursor, .cm-dropCursor":{borderLeft:"1.2px solid black",
marginLeft:"-0.6px",pointerEvents:"none"},".cm-cursor":{display:"none"},
"&dark .cm-cursor":{borderLeftColor:"#ddd"},".cm-dropCursor":{
position:"absolute"},
"&.cm-focused > .cm-scroller > .cm-cursorLayer .cm-cursor":{display:"block"},
".cm-iso":{unicodeBidi:"isolate"},".cm-announced":{position:"fixed",
top:"-10000px"},"@media print":{".cm-announced":{display:"none"}},
"&light .cm-activeLine":{backgroundColor:"#cceeff44"},"&dark .cm-activeLine":{
backgroundColor:"#99eeff33"},"&light .cm-specialChar":{color:"red"},
"&dark .cm-specialChar":{color:"#f78"},".cm-gutters":{flexShrink:0,
display:"flex",height:"100%",boxSizing:"border-box",insetInlineStart:0,
zIndex:200},"&light .cm-gutters":{backgroundColor:"#f5f5f5",color:"#6c6c6c",
borderRight:"1px solid #ddd"},"&dark .cm-gutters":{backgroundColor:"#333338",
color:"#ccc"},".cm-gutter":{display:"flex !important",flexDirection:"column",
flexShrink:0,boxSizing:"border-box",minHeight:"100%",overflow:"hidden"},
".cm-gutterElement":{boxSizing:"border-box"},
".cm-lineNumbers .cm-gutterElement":{padding:"0 3px 0 5px",minWidth:"20px",
textAlign:"right",whiteSpace:"nowrap"},"&light .cm-activeLineGutter":{
backgroundColor:"#e2f2ff"},"&dark .cm-activeLineGutter":{
backgroundColor:"#222227"},".cm-panels":{boxSizing:"border-box",
position:"sticky",left:0,right:0,zIndex:300},"&light .cm-panels":{
backgroundColor:"#f5f5f5",color:"black"},"&light .cm-panels-top":{
borderBottom:"1px solid #ddd"},"&light .cm-panels-bottom":{
borderTop:"1px solid #ddd"},"&dark .cm-panels":{backgroundColor:"#333338",
color:"white"},".cm-tab":{display:"inline-block",overflow:"hidden",
verticalAlign:"bottom"},".cm-widgetBuffer":{verticalAlign:"text-top",
height:"1em",width:0,display:"inline"},".cm-placeholder":{color:"#888",
display:"inline-block",verticalAlign:"top"},".cm-highlightSpace":{
backgroundImage:"radial-gradient(circle at 50% 55%, #aaa 20%, transparent 5%)",
backgroundPosition:"center"},".cm-highlightTab":{
backgroundImage:'url(\'data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" width="200" height="20"><path stroke="%23888" stroke-width="1" fill="none" d="M1 10H196L190 5M190 15L196 10M197 4L197 16"/></svg>\')',
backgroundSize:"auto 100%",backgroundPosition:"right 90%",
backgroundRepeat:"no-repeat"},".cm-trailingSpace":{backgroundColor:"#ff332255"},
".cm-button":{verticalAlign:"middle",color:"inherit",fontSize:"70%",
padding:".2em 1em",borderRadius:"1px"},"&light .cm-button":{
backgroundImage:"linear-gradient(#eff1f5, #d9d9df)",border:"1px solid #888",
"&:active":{backgroundImage:"linear-gradient(#b4b4b4, #d0d3d6)"}},
"&dark .cm-button":{backgroundImage:"linear-gradient(#393939, #111)",
border:"1px solid #888","&:active":{
backgroundImage:"linear-gradient(#111, #333)"}},".cm-textfield":{
verticalAlign:"middle",color:"inherit",fontSize:"70%",border:"1px solid silver",
padding:".2em .5em"},"&light .cm-textfield":{backgroundColor:"white"},
"&dark .cm-textfield":{border:"1px solid #555",backgroundColor:"inherit"}
},ede),rde={childList:!0,characterData:!0,subtree:!0,attributes:!0,
characterDataOldValue:!0},ode=ele.ie&&ele.ie_version<=11;class ade{
constructor(e){
this.view=e,this.active=!1,this.editContext=null,this.selectionRange=new Tse,
this.selectionChanged=!1,
this.delayedFlush=-1,this.resizeTimeout=-1,this.queue=[],
this.delayedAndroidKey=null,
this.flushingAndroidKey=-1,this.lastChange=0,this.scrollTargets=[],
this.intersection=null,
this.resizeScroll=null,this.intersecting=!1,this.gapIntersection=null,
this.gaps=[],
this.printQuery=null,this.parentCheck=-1,this.dom=e.contentDOM,this.observer=new MutationObserver((t=>{
for(let e of t)this.queue.push(e)
;(ele.ie&&ele.ie_version<=11||ele.ios&&e.composing)&&t.some((e=>"childList"==e.type&&e.removedNodes.length||"characterData"==e.type&&e.oldValue.length>e.target.nodeValue.length))?this.flushSoon():this.flush()
})),
!window.EditContext||!1===e.constructor.EDIT_CONTEXT||ele.chrome&&ele.chrome_version<126||(this.editContext=new lde(e),
e.state.facet(lce)&&(e.contentDOM.editContext=this.editContext.editContext)),
ode&&(this.onCharData=e=>{this.queue.push({target:e.target,type:"characterData",
oldValue:e.prevValue}),this.flushSoon()
}),this.onSelectionChange=this.onSelectionChange.bind(this),
this.onResize=this.onResize.bind(this),
this.onPrint=this.onPrint.bind(this),this.onScroll=this.onScroll.bind(this),
window.matchMedia&&(this.printQuery=window.matchMedia("print")),
"function"==typeof ResizeObserver&&(this.resizeScroll=new ResizeObserver((()=>{
var e
;(null===(e=this.view.docView)||void 0===e?void 0:e.lastUpdate)<Date.now()-75&&this.onResize()
})),
this.resizeScroll.observe(e.scrollDOM)),this.addWindowListeners(this.win=e.win),
this.start(),
"function"==typeof IntersectionObserver&&(this.intersection=new IntersectionObserver((e=>{
this.parentCheck<0&&(this.parentCheck=setTimeout(this.listenForScroll.bind(this),1e3)),
e.length>0&&e[e.length-1].intersectionRatio>0!=this.intersecting&&(this.intersecting=!this.intersecting,
this.intersecting!=this.view.inView&&this.onScrollChanged(document.createEvent("Event")))
}),{threshold:[0,.001]
}),this.intersection.observe(this.dom),this.gapIntersection=new IntersectionObserver((e=>{
e.length>0&&e[e.length-1].intersectionRatio>0&&this.onScrollChanged(document.createEvent("Event"))
}),{})),this.listenForScroll(),this.readSelectionRange()}onScrollChanged(e){
this.view.inputState.runHandlers("scroll",e),
this.intersecting&&this.view.measure()}onScroll(e){
this.intersecting&&this.flush(!1),
this.editContext&&this.view.requestMeasure(this.editContext.measureReq),
this.onScrollChanged(e)}onResize(){
this.resizeTimeout<0&&(this.resizeTimeout=setTimeout((()=>{
this.resizeTimeout=-1,this.view.requestMeasure()}),50))}onPrint(e){
("change"!=e.type&&e.type||e.matches)&&(this.view.viewState.printing=!0,
this.view.measure(),setTimeout((()=>{
this.view.viewState.printing=!1,this.view.requestMeasure()}),500))}
updateGaps(e){
if(this.gapIntersection&&(e.length!=this.gaps.length||this.gaps.some(((t,n)=>t!=e[n])))){
this.gapIntersection.disconnect();for(let t of e)this.gapIntersection.observe(t)
;this.gaps=e}}onSelectionChange(e){let t=this.selectionChanged
;if(!this.readSelectionRange()||this.delayedAndroidKey)return
;let{view:n}=this,r=this.selectionRange
;if(n.state.facet(lce)?n.root.activeElement!=this.dom:!gse(this.dom,r))return
;let o=r.anchorNode&&n.docView.nearest(r.anchorNode)
;o&&o.ignoreEvent(e)?t||(this.selectionChanged=!1):(ele.ie&&ele.ie_version<=11||ele.android&&ele.chrome)&&!n.state.selection.main.empty&&r.focusNode&&bse(r.focusNode,r.focusOffset,r.anchorNode,r.anchorOffset)?this.flushSoon():this.flush(!1)
}readSelectionRange(){let{view:e}=this,t=fse(e.root);if(!t)return!1
;let n=ele.safari&&11==e.root.nodeType&&e.root.activeElement==this.dom&&function(e,t){
if(t.getComposedRanges){let n=t.getComposedRanges(e.root)[0]
;if(n)return sde(e,n)}let n=null;function r(e){
e.preventDefault(),e.stopImmediatePropagation(),n=e.getTargetRanges()[0]}
return e.contentDOM.addEventListener("beforeinput",r,!0),
e.dom.ownerDocument.execCommand("indent"),
e.contentDOM.removeEventListener("beforeinput",r,!0),n?sde(e,n):null
}(this.view,t)||t;if(!n||this.selectionRange.eq(n))return!1
;let r=gse(this.dom,n)
;return r&&!this.selectionChanged&&e.inputState.lastFocusTime>Date.now()-200&&e.inputState.lastTouchTime<Date.now()-300&&function(e,t){
let n=t.focusNode,r=t.focusOffset
;if(!n||t.anchorNode!=n||t.anchorOffset!=r)return!1
;for(r=Math.min(r,xse(n));;)if(r){if(1!=n.nodeType)return!1
;let e=n.childNodes[r-1];"false"==e.contentEditable?r--:(n=e,r=xse(n))}else{
if(n==e)return!0;r=yse(n),n=n.parentNode}
}(this.dom,n)?(this.view.inputState.lastFocusTime=0,e.docView.updateSelection(),
!1):(this.selectionRange.setRange(n),r&&(this.selectionChanged=!0),!0)}
setSelectionRange(e,t){this.selectionRange.set(e.node,e.offset,t.node,t.offset),
this.selectionChanged=!1}clearSelectionRange(){
this.selectionRange.set(null,0,null,0)}listenForScroll(){this.parentCheck=-1
;let e=0,t=null
;for(let n=this.dom;n;)if(1==n.nodeType)!t&&e<this.scrollTargets.length&&this.scrollTargets[e]==n?e++:t||(t=this.scrollTargets.slice(0,e)),
t&&t.push(n),n=n.assignedSlot||n.parentNode;else{if(11!=n.nodeType)break
;n=n.host}if(e<this.scrollTargets.length&&!t&&(t=this.scrollTargets.slice(0,e)),
t){for(let e of this.scrollTargets)e.removeEventListener("scroll",this.onScroll)
;for(let e of this.scrollTargets=t)e.addEventListener("scroll",this.onScroll)}}
ignore(e){if(!this.active)return e();try{return this.stop(),e()}finally{
this.start(),this.clear()}}start(){
this.active||(this.observer.observe(this.dom,rde),
ode&&this.dom.addEventListener("DOMCharacterDataModified",this.onCharData),
this.active=!0)}stop(){
this.active&&(this.active=!1,this.observer.disconnect(),ode&&this.dom.removeEventListener("DOMCharacterDataModified",this.onCharData))
}clear(){this.processRecords(),this.queue.length=0,this.selectionChanged=!1}
delayAndroidKey(e,t){var n;if(!this.delayedAndroidKey){let e=()=>{
let e=this.delayedAndroidKey;if(e){
this.clearDelayedAndroidKey(),this.view.inputState.lastKeyCode=e.keyCode,
this.view.inputState.lastKeyTime=Date.now(),
!this.flush()&&e.force&&Pse(this.dom,e.key,e.keyCode)}}
;this.flushingAndroidKey=this.view.win.requestAnimationFrame(e)}
this.delayedAndroidKey&&"Enter"!=e||(this.delayedAndroidKey={key:e,keyCode:t,
force:this.lastChange<Date.now()-50||!!(null===(n=this.delayedAndroidKey)||void 0===n?void 0:n.force)
})}clearDelayedAndroidKey(){
this.win.cancelAnimationFrame(this.flushingAndroidKey),
this.delayedAndroidKey=null,this.flushingAndroidKey=-1}flushSoon(){
this.delayedFlush<0&&(this.delayedFlush=this.view.win.requestAnimationFrame((()=>{
this.delayedFlush=-1,this.flush()})))}forceFlush(){
this.delayedFlush>=0&&(this.view.win.cancelAnimationFrame(this.delayedFlush),
this.delayedFlush=-1),this.flush()}pendingRecords(){
for(let e of this.observer.takeRecords())this.queue.push(e);return this.queue}
processRecords(){let e=this.pendingRecords();e.length&&(this.queue=[])
;let t=-1,n=-1,r=!1;for(let o of e){let e=this.readMutation(o)
;e&&(e.typeOver&&(r=!0),
-1==t?({from:t,to:n}=e):(t=Math.min(e.from,t),n=Math.max(e.to,n)))}return{
from:t,to:n,typeOver:r}}readChange(){
let{from:e,to:t,typeOver:n}=this.processRecords(),r=this.selectionChanged&&gse(this.dom,this.selectionRange)
;if(e<0&&!r)return null
;e>-1&&(this.lastChange=Date.now()),this.view.inputState.lastFocusTime=0,
this.selectionChanged=!1;let o=new Hce(this.view,e,t,n)
;return this.view.docView.domChanged={newSel:o.newSel?o.newSel.main:null},o}
flush(e=!0){if(this.delayedFlush>=0||this.delayedAndroidKey)return!1
;e&&this.readSelectionRange();let t=this.readChange()
;if(!t)return this.view.requestMeasure(),!1
;let n=this.view.state,r=Vce(this.view,t)
;return this.view.state==n&&(t.domChanged||t.newSel&&!t.newSel.main.eq(this.view.state.selection.main))&&this.view.update([]),
r}readMutation(e){let t=this.view.docView.nearest(e.target)
;if(!t||t.ignoreMutation(e))return null
;if(t.markDirty("attributes"==e.type),"attributes"==e.type&&(t.flags|=4),
"childList"==e.type){
let n=ide(t,e.previousSibling||e.target.previousSibling,-1),r=ide(t,e.nextSibling||e.target.nextSibling,1)
;return{from:n?t.posAfter(n):t.posAtStart,to:r?t.posBefore(r):t.posAtEnd,
typeOver:!1}}return"characterData"==e.type?{from:t.posAtStart,to:t.posAtEnd,
typeOver:e.target.nodeValue==e.oldValue}:null}setWindow(e){
e!=this.win&&(this.removeWindowListeners(this.win),
this.win=e,this.addWindowListeners(this.win))}addWindowListeners(e){
e.addEventListener("resize",this.onResize),
this.printQuery?this.printQuery.addEventListener?this.printQuery.addEventListener("change",this.onPrint):this.printQuery.addListener(this.onPrint):e.addEventListener("beforeprint",this.onPrint),
e.addEventListener("scroll",this.onScroll),
e.document.addEventListener("selectionchange",this.onSelectionChange)}
removeWindowListeners(e){
e.removeEventListener("scroll",this.onScroll),e.removeEventListener("resize",this.onResize),
this.printQuery?this.printQuery.removeEventListener?this.printQuery.removeEventListener("change",this.onPrint):this.printQuery.removeListener(this.onPrint):e.removeEventListener("beforeprint",this.onPrint),
e.document.removeEventListener("selectionchange",this.onSelectionChange)}
update(e){
this.editContext&&(this.editContext.update(e),e.startState.facet(lce)!=e.state.facet(lce)&&(e.view.contentDOM.editContext=e.state.facet(lce)?this.editContext.editContext:null))
}destroy(){var e,t,n
;this.stop(),null===(e=this.intersection)||void 0===e||e.disconnect(),
null===(t=this.gapIntersection)||void 0===t||t.disconnect(),
null===(n=this.resizeScroll)||void 0===n||n.disconnect()
;for(let r of this.scrollTargets)r.removeEventListener("scroll",this.onScroll)
;this.removeWindowListeners(this.win),
clearTimeout(this.parentCheck),clearTimeout(this.resizeTimeout),
this.win.cancelAnimationFrame(this.delayedFlush),
this.win.cancelAnimationFrame(this.flushingAndroidKey),
this.editContext&&(this.view.contentDOM.editContext=null,
this.editContext.destroy())}}function ide(e,t,n){for(;t;){let r=Bse.get(t)
;if(r&&r.parent==e)return r;let o=t.parentNode
;t=o!=e.dom?o:n>0?t.nextSibling:t.previousSibling}return null}function sde(e,t){
let n=t.startContainer,r=t.startOffset,o=t.endContainer,a=t.endOffset,i=e.docView.domAtPos(e.state.selection.main.anchor)
;return bse(i.node,i.offset,o,a)&&([n,r,o,a]=[o,a,n,r]),{anchorNode:n,
anchorOffset:r,focusNode:o,focusOffset:a}}class lde{constructor(e){
this.from=0,this.to=0,
this.pendingContextChange=null,this.handlers=Object.create(null),
this.composing=null,this.resetRange(e.state)
;let t=this.editContext=new window.EditContext({
text:e.state.doc.sliceString(this.from,this.to),
selectionStart:this.toContextPos(Math.max(this.from,Math.min(this.to,e.state.selection.main.anchor))),
selectionEnd:this.toContextPos(e.state.selection.main.head)})
;this.handlers.textupdate=t=>{
let{anchor:n}=e.state.selection.main,r=this.toEditorPos(t.updateRangeStart),o=this.toEditorPos(t.updateRangeEnd)
;e.inputState.composing>=0&&!this.composing&&(this.composing={
contextBase:t.updateRangeStart,editorBase:r,drifted:!1});let a={from:r,to:o,
insert:wae.of(t.text.split("\n"))}
;if(a.from==this.from&&n<this.from?a.from=n:a.to==this.to&&n>this.to&&(a.to=n),
a.from!=a.to||a.insert.length){
if(this.pendingContextChange=a,!e.state.readOnly){
let n=this.to-this.from+(a.to-a.from+a.insert.length)
;qce(e,a,Vae.single(this.toEditorPos(t.selectionStart,n),this.toEditorPos(t.selectionEnd,n)))
}
this.pendingContextChange&&(this.revertPending(e.state),this.setSelection(e.state))
}},this.handlers.characterboundsupdate=n=>{let r=[],o=null
;for(let t=this.toEditorPos(n.rangeStart),a=this.toEditorPos(n.rangeEnd);t<a;t++){
let n=e.coordsForChar(t)
;o=n&&new DOMRect(n.left,n.top,n.right-n.left,n.bottom-n.top)||o||new DOMRect,
r.push(o)}t.updateCharacterBounds(n.rangeStart,r)
},this.handlers.textformatupdate=t=>{let n=[];for(let e of t.getTextFormats()){
let t=e.underlineStyle,r=e.underlineThickness;if("None"!=t&&"None"!=r){
let o=this.toEditorPos(e.rangeStart),a=this.toEditorPos(e.rangeEnd);if(o<a){
let e=`text-decoration: underline ${"Dashed"==t?"dashed ":"Squiggle"==t?"wavy ":""}${"Thin"==r?1:2}px`
;n.push(mle.mark({attributes:{style:e}}).range(o,a))}}}e.dispatch({
effects:ice.of(mle.set(n))})},this.handlers.compositionstart=()=>{
e.inputState.composing<0&&(e.inputState.composing=0,
e.inputState.compositionFirstChange=!0)},this.handlers.compositionend=()=>{
if(e.inputState.composing=-1,
e.inputState.compositionFirstChange=null,this.composing){
let{drifted:t}=this.composing;this.composing=null,t&&this.reset(e.state)}}
;for(let n in this.handlers)t.addEventListener(n,this.handlers[n])
;this.measureReq={read:e=>{
this.editContext.updateControlBounds(e.contentDOM.getBoundingClientRect())
;let t=fse(e.root)
;t&&t.rangeCount&&this.editContext.updateSelectionBounds(t.getRangeAt(0).getBoundingClientRect())
}}}applyEdits(e){let t=0,n=!1,r=this.pendingContextChange
;return e.changes.iterChanges(((o,a,i,s,l)=>{if(n)return;let c=l.length-(a-o)
;if(r&&a>=r.to){
if(r.from==o&&r.to==a&&r.insert.eq(l))return r=this.pendingContextChange=null,
t+=c,void(this.to+=c);r=null,this.revertPending(e.state)}
if(o+=t,(a+=t)<=this.from)this.from+=c,this.to+=c;else if(o<this.to){
if(o<this.from||a>this.to||this.to-this.from+l.length>3e4)return void(n=!0)
;this.editContext.updateText(this.toContextPos(o),this.toContextPos(a),l.toString()),
this.to+=c}t+=c})),r&&!n&&this.revertPending(e.state),!n}update(e){
let t=this.pendingContextChange
;this.composing&&(this.composing.drifted||e.transactions.some((e=>!e.isUserEvent("input.type")&&e.changes.touchesRange(this.from,this.to))))?(this.composing.drifted=!0,
this.composing.editorBase=e.changes.mapPos(this.composing.editorBase)):this.applyEdits(e)&&this.rangeIsValid(e.state)?(e.docChanged||e.selectionSet||t)&&this.setSelection(e.state):(this.pendingContextChange=null,
this.reset(e.state)),
(e.geometryChanged||e.docChanged||e.selectionSet)&&e.view.requestMeasure(this.measureReq)
}resetRange(e){let{head:t}=e.selection.main
;this.from=Math.max(0,t-1e4),this.to=Math.min(e.doc.length,t+1e4)}reset(e){
this.resetRange(e),
this.editContext.updateText(0,this.editContext.text.length,e.doc.sliceString(this.from,this.to)),
this.setSelection(e)}revertPending(e){let t=this.pendingContextChange
;this.pendingContextChange=null,
this.editContext.updateText(this.toContextPos(t.from),this.toContextPos(t.from+t.insert.length),e.doc.sliceString(t.from,t.to))
}setSelection(e){
let{main:t}=e.selection,n=this.toContextPos(Math.max(this.from,Math.min(this.to,t.anchor))),r=this.toContextPos(t.head)
;this.editContext.selectionStart==n&&this.editContext.selectionEnd==r||this.editContext.updateSelection(n,r)
}rangeIsValid(e){let{head:t}=e.selection.main
;return!(this.from>0&&t-this.from<500||this.to<e.doc.length&&this.to-t<500||this.to-this.from>3e4)
}toEditorPos(e,t=this.to-this.from){e=Math.min(e,t);let n=this.composing
;return n&&n.drifted?n.editorBase+(e-n.contextBase):e+this.from}toContextPos(e){
let t=this.composing
;return t&&t.drifted?t.contextBase+(e-t.editorBase):e-this.from}destroy(){
for(let e in this.handlers)this.editContext.removeEventListener(e,this.handlers[e])
}}class cde{get state(){return this.viewState.state}get viewport(){
return this.viewState.viewport}get visibleRanges(){
return this.viewState.visibleRanges}get inView(){return this.viewState.inView}
get composing(){return this.inputState.composing>0}get compositionStarted(){
return this.inputState.composing>=0}get root(){return this._root}get win(){
return this.dom.ownerDocument.defaultView||window}constructor(e={}){var t
;this.plugins=[],
this.pluginMap=new Map,this.editorAttrs={},this.contentAttrs={},
this.bidiCache=[],this.destroyed=!1,this.updateState=2,this.measureScheduled=-1,
this.measureRequests=[],
this.contentDOM=document.createElement("div"),this.scrollDOM=document.createElement("div"),
this.scrollDOM.tabIndex=-1,
this.scrollDOM.className="cm-scroller",this.scrollDOM.appendChild(this.contentDOM),
this.announceDOM=document.createElement("div"),
this.announceDOM.className="cm-announced",
this.announceDOM.setAttribute("aria-live","polite"),
this.dom=document.createElement("div"),
this.dom.appendChild(this.announceDOM),this.dom.appendChild(this.scrollDOM),
e.parent&&e.parent.appendChild(this.dom);let{dispatch:n}=e
;this.dispatchTransactions=e.dispatchTransactions||n&&(e=>e.forEach((e=>n(e,this))))||(e=>this.update(e)),
this.dispatch=this.dispatch.bind(this),this._root=e.root||function(e){for(;e;){
if(e&&(9==e.nodeType||11==e.nodeType&&e.host))return e
;e=e.assignedSlot||e.parentNode}return null
}(e.parent)||document,this.viewState=new Fue(e.state||Lie.create(e)),
e.scrollTo&&e.scrollTo.is(ace)&&(this.viewState.scrollTarget=e.scrollTo.value.clip(this.viewState.state)),
this.plugins=this.state.facet(uce).map((e=>new pce(e)))
;for(let r of this.plugins)r.update(this)
;this.observer=new ade(this),this.inputState=new Wce(this),
this.inputState.ensureHandlers(this.plugins),
this.docView=new _ce(this),this.mountStyles(),
this.updateAttrs(),this.updateState=0,
this.requestMeasure(),(null===(t=document.fonts)||void 0===t?void 0:t.ready)&&document.fonts.ready.then((()=>this.requestMeasure()))
}dispatch(...e){
let t=1==e.length&&e[0]instanceof Tie?e:1==e.length&&Array.isArray(e[0])?e[0]:[this.state.update(...e)]
;this.dispatchTransactions(t,this)}update(e){
if(0!=this.updateState)throw new Error("Calls to EditorView.update are not allowed while an update is in progress")
;let t,n=!1,r=!1,o=this.state;for(let d of e){
if(d.startState!=o)throw new RangeError("Trying to update state with a transaction that doesn't start from the previous state.")
;o=d.state}if(this.destroyed)return void(this.viewState.state=o)
;let a=this.hasFocus,i=0,s=null
;e.some((e=>e.annotation(vue)))?(this.inputState.notifiedFocused=a,
i=1):a!=this.inputState.notifiedFocused&&(this.inputState.notifiedFocused=a,
s=bue(o,a),s||(i=1));let l=this.observer.delayedAndroidKey,c=null
;if(l?(this.observer.clearDelayedAndroidKey(),
c=this.observer.readChange(),(c&&!this.state.doc.eq(o.doc)||!this.state.selection.eq(o.selection))&&(c=null)):this.observer.clear(),
o.facet(Lie.phrases)!=this.state.facet(Lie.phrases))return this.setState(o)
;t=Sce.create(this,o,e),t.flags|=i;let u=this.viewState.scrollTarget;try{
this.updateState=2;for(let t of e){if(u&&(u=u.map(t.changes)),t.scrollIntoView){
let{main:e}=t.state.selection
;u=new oce(e.empty?e:Vae.cursor(e.head,e.head>e.anchor?-1:1))}
for(let e of t.effects)e.is(ace)&&(u=e.value.clip(this.state))}
this.viewState.update(t,u),
this.bidiCache=pde.update(this.bidiCache,t.changes),t.empty||(this.updatePlugins(t),
this.inputState.update(t)),
n=this.docView.update(t),this.state.facet(xce)!=this.styleModules&&this.mountStyles(),
r=this.updateAttrs(),
this.showAnnouncements(e),this.docView.updateSelection(n,e.some((e=>e.isUserEvent("select.pointer"))))
}finally{this.updateState=0}
if(t.startState.facet(Xue)!=t.state.facet(Xue)&&(this.viewState.mustMeasureContent=!0),
(n||r||u||this.viewState.mustEnforceCursorAssoc||this.viewState.mustMeasureContent)&&this.requestMeasure(),
n&&this.docViewUpdate(),!t.empty)for(let d of this.state.facet(Gle))try{d(t)
}catch(Bw){sce(this.state,Bw,"update listener")}
(s||c)&&Promise.resolve().then((()=>{
s&&this.state==s.startState&&this.dispatch(s),
c&&!Vce(this,c)&&l.force&&Pse(this.contentDOM,l.key,l.keyCode)}))}setState(e){
if(0!=this.updateState)throw new Error("Calls to EditorView.setState are not allowed while an update is in progress")
;if(this.destroyed)return void(this.viewState.state=e);this.updateState=2
;let t=this.hasFocus;try{for(let e of this.plugins)e.destroy(this)
;this.viewState=new Fue(e),
this.plugins=e.facet(uce).map((e=>new pce(e))),this.pluginMap.clear()
;for(let e of this.plugins)e.update(this)
;this.docView.destroy(),this.docView=new _ce(this),
this.inputState.ensureHandlers(this.plugins),
this.mountStyles(),this.updateAttrs(),this.bidiCache=[]}finally{
this.updateState=0}t&&this.focus(),this.requestMeasure()}updatePlugins(e){
let t=e.startState.facet(uce),n=e.state.facet(uce);if(t!=n){let r=[]
;for(let o of n){let n=t.indexOf(o);if(n<0)r.push(new pce(o));else{
let t=this.plugins[n];t.mustUpdate=e,r.push(t)}}
for(let t of this.plugins)t.mustUpdate!=e&&t.destroy(this)
;this.plugins=r,this.pluginMap.clear()
}else for(let r of this.plugins)r.mustUpdate=e
;for(let r=0;r<this.plugins.length;r++)this.plugins[r].update(this)
;t!=n&&this.inputState.ensureHandlers(this.plugins)}docViewUpdate(){
for(let e of this.plugins){let t=e.value;if(t&&t.docViewUpdate)try{
t.docViewUpdate(this)}catch(Bw){sce(this.state,Bw,"doc view update listener")}}}
measure(e=!0){if(this.destroyed)return
;if(this.measureScheduled>-1&&this.win.cancelAnimationFrame(this.measureScheduled),
this.observer.delayedAndroidKey)return this.measureScheduled=-1,
void this.requestMeasure();this.measureScheduled=0,e&&this.observer.forceFlush()
;let t=null,n=this.scrollDOM,r=n.scrollTop*this.scaleY,{scrollAnchorPos:o,scrollAnchorHeight:a}=this.viewState
;Math.abs(r-this.viewState.scrollTop)>1&&(a=-1),
this.viewState.scrollAnchorHeight=-1;try{for(let e=0;;e++){
if(a<0)if(Ise(n))o=-1,a=this.viewState.heightMap.height;else{
let e=this.viewState.scrollAnchorAt(r);o=e.from,a=e.top}this.updateState=1
;let i=this.viewState.measure(this)
;if(!i&&!this.measureRequests.length&&null==this.viewState.scrollTarget)break
;if(e>5){
console.warn(this.measureRequests.length?"Measure loop restarted more than 5 times":"Viewport failed to stabilize")
;break}let s=[];4&i||([this.measureRequests,s]=[s,this.measureRequests])
;let l=s.map((e=>{try{return e.read(this)}catch(Bw){
return sce(this.state,Bw),dde}})),c=Sce.create(this,this.state,[]),u=!1
;c.flags|=i,t?t.flags|=i:t=c,this.updateState=2,c.empty||(this.updatePlugins(c),
this.inputState.update(c),
this.updateAttrs(),u=this.docView.update(c),u&&this.docViewUpdate())
;for(let e=0;e<s.length;e++)if(l[e]!=dde)try{let t=s[e]
;t.write&&t.write(l[e],this)}catch(Bw){sce(this.state,Bw)}
if(u&&this.docView.updateSelection(!0),
!c.viewportChanged&&0==this.measureRequests.length){
if(this.viewState.editorHeight){if(this.viewState.scrollTarget){
this.docView.scrollIntoView(this.viewState.scrollTarget),
this.viewState.scrollTarget=null,a=-1;continue}{
let e=(o<0?this.viewState.heightMap.height:this.viewState.lineBlockAt(o).top)-a
;if(e>1||e<-1){r+=e,n.scrollTop=r/this.scaleY,a=-1;continue}}}break}}}finally{
this.updateState=0,this.measureScheduled=-1}
if(t&&!t.empty)for(let i of this.state.facet(Gle))i(t)}get themeClasses(){
return Yue+" "+(this.state.facet(Gue)?Jue:Kue)+" "+this.state.facet(Xue)}
updateAttrs(){let e=hde(this,hce,{
class:"cm-editor"+(this.hasFocus?" cm-focused ":" ")+this.themeClasses}),t={
spellcheck:"false",autocorrect:"off",autocapitalize:"off",
writingsuggestions:"false",translate:"no",
contenteditable:this.state.facet(lce)?"true":"false",class:"cm-content",
style:`${ele.tabSize}: ${this.state.tabSize}`,role:"textbox",
"aria-multiline":"true"}
;this.state.readOnly&&(t["aria-readonly"]="true"),hde(this,fce,t)
;let n=this.observer.ignore((()=>{
let n=dle(this.contentDOM,this.contentAttrs,t),r=dle(this.dom,this.editorAttrs,e)
;return n||r}));return this.editorAttrs=e,this.contentAttrs=t,n}
showAnnouncements(e){let t=!0
;for(let n of e)for(let e of n.effects)if(e.is(cde.announce)){
t&&(this.announceDOM.textContent=""),
t=!1,this.announceDOM.appendChild(document.createElement("div")).textContent=e.value
}}mountStyles(){this.styleModules=this.state.facet(xce)
;let e=this.state.facet(cde.cspNonce)
;ase.mount(this.root,this.styleModules.concat(nde).reverse(),e?{nonce:e}:void 0)
}readMeasured(){
if(2==this.updateState)throw new Error("Reading the editor layout isn't allowed during an update")
;0==this.updateState&&this.measureScheduled>-1&&this.measure(!1)}
requestMeasure(e){
if(this.measureScheduled<0&&(this.measureScheduled=this.win.requestAnimationFrame((()=>this.measure()))),
e){if(this.measureRequests.indexOf(e)>-1)return
;if(null!=e.key)for(let t=0;t<this.measureRequests.length;t++)if(this.measureRequests[t].key===e.key)return void(this.measureRequests[t]=e)
;this.measureRequests.push(e)}}plugin(e){let t=this.pluginMap.get(e)
;return(void 0===t||t&&t.spec!=e)&&this.pluginMap.set(e,t=this.plugins.find((t=>t.spec==e))||null),
t&&t.update(this).value}get documentTop(){
return this.contentDOM.getBoundingClientRect().top+this.viewState.paddingTop}
get documentPadding(){return{top:this.viewState.paddingTop,
bottom:this.viewState.paddingBottom}}get scaleX(){return this.viewState.scaleX}
get scaleY(){return this.viewState.scaleY}elementAtHeight(e){
return this.readMeasured(),this.viewState.elementAtHeight(e)}
lineBlockAtHeight(e){
return this.readMeasured(),this.viewState.lineBlockAtHeight(e)}
get viewportLineBlocks(){return this.viewState.viewportLines}lineBlockAt(e){
return this.viewState.lineBlockAt(e)}get contentHeight(){
return this.viewState.contentHeight}moveByChar(e,t,n){
return Uce(this,e,Bce(this,e,t,n))}moveByGroup(e,t){
return Uce(this,e,Bce(this,e,t,(t=>function(e,t,n){
let r=e.state.charCategorizer(t),o=r(n);return e=>{let t=r(e)
;return o==Iie.Space&&(o=t),o==t}}(this,e.head,t))))}visualLineSide(e,t){
let n=this.bidiSpans(e),r=this.textDirectionAt(e.from),o=n[t?n.length-1:0]
;return Vae.cursor(o.side(t,r)+e.from,o.forward(!t,r)?1:-1)}
moveToLineBoundary(e,t,n=!0){return Lce(this,e,t,n)}moveVertically(e,t,n){
return Uce(this,e,function(e,t,n,r){let o=t.head,a=n?1:-1
;if(o==(n?e.state.doc.length:0))return Vae.cursor(o,t.assoc)
;let i,s=t.goalColumn,l=e.contentDOM.getBoundingClientRect(),c=e.coordsAtPos(o,t.assoc||-1),u=e.documentTop
;if(c)null==s&&(s=c.left-l.left),i=a<0?c.top:c.bottom;else{
let t=e.viewState.lineBlockAt(o)
;null==s&&(s=Math.min(l.right-l.left,e.defaultCharacterWidth*(o-t.from))),
i=(a<0?t.top:t.bottom)+u}
let d=l.left+s,p=null!=r?r:e.viewState.heightOracle.textHeight>>1
;for(let h=0;;h+=10){let t=i+(p+h)*a,n=Nce(e,{x:d,y:t},!1,a)
;if(t<l.top||t>l.bottom||(a<0?n<o:n>o)){
let r=e.docView.coordsForChar(n),o=!r||t<r.top?-1:1
;return Vae.cursor(n,o,void 0,s)}}}(this,e,t,n))}domAtPos(e){
return this.docView.domAtPos(e)}posAtDOM(e,t=0){
return this.docView.posFromDOM(e,t)}posAtCoords(e,t=!0){
return this.readMeasured(),Nce(this,e,t)}coordsAtPos(e,t=1){this.readMeasured()
;let n=this.docView.coordsAt(e,t);if(!n||n.left==n.right)return n
;let r=this.state.doc.lineAt(e),o=this.bidiSpans(r)
;return kse(n,o[Lle.find(o,e-r.from,-1,t)].dir==Ele.LTR==t>0)}coordsForChar(e){
return this.readMeasured(),this.docView.coordsForChar(e)}
get defaultCharacterWidth(){return this.viewState.heightOracle.charWidth}
get defaultLineHeight(){return this.viewState.heightOracle.lineHeight}
get textDirection(){return this.viewState.defaultTextDirection}
textDirectionAt(e){
return!this.state.facet(tce)||e<this.viewport.from||e>this.viewport.to?this.textDirection:(this.readMeasured(),
this.docView.textDirectionAt(e))}get lineWrapping(){
return this.viewState.heightOracle.lineWrapping}bidiSpans(e){
if(e.length>ude)return Fle(e.length);let t,n=this.textDirectionAt(e.from)
;for(let o of this.bidiCache)if(o.from==e.from&&o.dir==n&&(o.fresh||Ble(o.isolates,t=yce(this,e))))return o.order
;t||(t=yce(this,e));let r=function(e,t,n){if(!e)return[new Lle(0,0,t==Cle?1:0)]
;if(t==Ale&&!n.length&&!Rle.test(e))return Fle(e.length)
;if(n.length)for(;e.length>jle.length;)jle[jle.length]=256;let r=[],o=t==Ale?0:1
;return zle(e,o,o,n,0,e.length,r),r}(e.text,n,t)
;return this.bidiCache.push(new pde(e.from,e.to,n,t,!0,r)),r}get hasFocus(){
var e
;return(this.dom.ownerDocument.hasFocus()||ele.safari&&(null===(e=this.inputState)||void 0===e?void 0:e.lastContextMenu)>Date.now()-3e4)&&this.root.activeElement==this.contentDOM
}focus(){this.observer.ignore((()=>{
Cse(this.contentDOM),this.docView.updateSelection()}))}setRoot(e){
this._root!=e&&(this._root=e,
this.observer.setWindow((9==e.nodeType?e:e.ownerDocument).defaultView||window),
this.mountStyles())}destroy(){
this.root.activeElement==this.contentDOM&&this.contentDOM.blur()
;for(let e of this.plugins)e.destroy(this)
;this.plugins=[],this.inputState.destroy(),
this.docView.destroy(),this.dom.remove(),
this.observer.destroy(),this.measureScheduled>-1&&this.win.cancelAnimationFrame(this.measureScheduled),
this.destroyed=!0}static scrollIntoView(e,t={}){
return ace.of(new oce("number"==typeof e?Vae.cursor(e):e,t.y,t.x,t.yMargin,t.xMargin))
}scrollSnapshot(){
let{scrollTop:e,scrollLeft:t}=this.scrollDOM,n=this.viewState.scrollAnchorAt(e)
;return ace.of(new oce(Vae.cursor(n.from),"start","start",n.top-e,t,!0))}
setTabFocusMode(e){
null==e?this.inputState.tabFocusMode=this.inputState.tabFocusMode<0?0:-1:"boolean"==typeof e?this.inputState.tabFocusMode=e?0:-1:0!=this.inputState.tabFocusMode&&(this.inputState.tabFocusMode=Date.now()+e)
}static domEventHandlers(e){return dce.define((()=>({})),{eventHandlers:e})}
static domEventObservers(e){return dce.define((()=>({})),{eventObservers:e})}
static theme(e,t){let n=ase.newName(),r=[Xue.of(n),xce.of(tde(`.${n}`,e))]
;return t&&t.dark&&r.push(Gue.of(!0)),r}static baseTheme(e){
return lie.lowest(xce.of(tde("."+Yue,e,ede)))}static findFromDOM(e){var t
;let n=e.querySelector(".cm-content"),r=n&&Bse.get(n)||Bse.get(e)
;return(null===(t=null==r?void 0:r.rootView)||void 0===t?void 0:t.view)||null}}
cde.styleModule=xce,
cde.inputHandler=Yle,cde.clipboardInputFilter=Jle,cde.clipboardOutputFilter=ece,
cde.scrollHandler=rce,
cde.focusChangeEffect=Kle,cde.perLineTextDirection=tce,cde.exceptionSink=Xle,
cde.updateListener=Gle,
cde.editable=lce,cde.mouseSelectionStyle=Wle,cde.dragMovesSelection=qle,
cde.clickAddsSelectionRange=Vle,
cde.decorations=mce,cde.outerDecorations=gce,cde.atomicRanges=vce,
cde.bidiIsolatedRanges=bce,
cde.scrollMargins=Oce,cde.darkTheme=Gue,cde.cspNonce=Xae.define({
combine:e=>e.length?e[0]:""
}),cde.contentAttributes=fce,cde.editorAttributes=hce,
cde.lineWrapping=cde.contentAttributes.of({class:"cm-lineWrapping"
}),cde.announce=_ie.define();const ude=4096,dde={};class pde{
constructor(e,t,n,r,o,a){
this.from=e,this.to=t,this.dir=n,this.isolates=r,this.fresh=o,this.order=a}
static update(e,t){if(t.empty&&!e.some((e=>e.fresh)))return e
;let n=[],r=e.length?e[e.length-1].dir:Ele.LTR
;for(let o=Math.max(0,e.length-10);o<e.length;o++){let a=e[o]
;a.dir!=r||t.touchesRange(a.from,a.to)||n.push(new pde(t.mapPos(a.from,1),t.mapPos(a.to,-1),a.dir,a.isolates,!1,a.order))
}return n}}function hde(e,t,n){
for(let r=e.state.facet(t),o=r.length-1;o>=0;o--){
let t=r[o],a="function"==typeof t?t(e):t;a&&lle(a,n)}return n}
const fde=ele.mac?"mac":ele.windows?"win":ele.linux?"linux":"key"
;function mde(e,t,n){
return t.altKey&&(e="Alt-"+e),t.ctrlKey&&(e="Ctrl-"+e),t.metaKey&&(e="Meta-"+e),
!1!==n&&t.shiftKey&&(e="Shift-"+e),e}
const gde=lie.default(cde.domEventHandlers({keydown:(e,t)=>function(e,t,n,r){
wde=t;let o=function(e){
var t=!(use&&e.metaKey&&e.shiftKey&&!e.ctrlKey&&!e.altKey||dse&&e.shiftKey&&e.key&&1==e.key.length||"Unidentified"==e.key)&&e.key||(e.shiftKey?cse:lse)[e.keyCode]||e.key||"Unidentified"
;return"Esc"==t&&(t="Escape"),"Del"==t&&(t="Delete"),"Left"==t&&(t="ArrowLeft"),
"Up"==t&&(t="ArrowUp"),"Right"==t&&(t="ArrowRight"),"Down"==t&&(t="ArrowDown"),t
}(t),a=Mae(Dae(o,0))==o.length&&" "!=o,i="",s=!1,l=!1,c=!1
;yde&&yde.view==n&&yde.scope==r&&(i=yde.prefix+" ",
Kce.indexOf(t.keyCode)<0&&(l=!0,yde=null));let u,d,p=new Set,h=e=>{if(e){
for(let t of e.run)if(!p.has(t)&&(p.add(t),
t(n)))return e.stopPropagation&&(c=!0),!0
;e.preventDefault&&(e.stopPropagation&&(c=!0),l=!0)}return!1},f=e[r]
;f&&(h(f[i+mde(o,t,!a)])?s=!0:a&&(t.altKey||t.metaKey||t.ctrlKey)&&!(ele.windows&&t.ctrlKey&&t.altKey)&&(u=lse[t.keyCode])&&u!=o?(h(f[i+mde(u,t,!0)])||t.shiftKey&&(d=cse[t.keyCode])!=o&&d!=u&&h(f[i+mde(d,t,!1)]))&&(s=!0):a&&t.shiftKey&&h(f[i+mde(o,t,!0)])&&(s=!0),
!s&&h(f._any)&&(s=!0));l&&(s=!0);s&&c&&t.stopPropagation();return wde=null,s
}(function(e){let t=e.facet(vde),n=bde.get(t);n||bde.set(t,n=function(e,t=fde){
let n=Object.create(null),r=Object.create(null),o=(e,t)=>{let n=r[e]
;if(null==n)r[e]=t;else if(n!=t)throw new Error("Key binding "+e+" is used both as a regular binding and as a multi-stroke prefix")
},a=(e,r,a,i,s)=>{var l,c
;let u=n[e]||(n[e]=Object.create(null)),d=r.split(/ (?!$)/).map((e=>function(e,t){
const n=e.split(/-(?!$)/);let r,o,a,i,s=n[n.length-1];"Space"==s&&(s=" ")
;for(let l=0;l<n.length-1;++l){const e=n[l]
;if(/^(cmd|meta|m)$/i.test(e))i=!0;else if(/^a(lt)?$/i.test(e))r=!0;else if(/^(c|ctrl|control)$/i.test(e))o=!0;else if(/^s(hift)?$/i.test(e))a=!0;else{
if(!/^mod$/i.test(e))throw new Error("Unrecognized modifier name: "+e)
;"mac"==t?i=!0:o=!0}}
return r&&(s="Alt-"+s),o&&(s="Ctrl-"+s),i&&(s="Meta-"+s),a&&(s="Shift-"+s),s
}(e,t)));for(let t=1;t<d.length;t++){let n=d.slice(0,t).join(" ")
;o(n,!0),u[n]||(u[n]={preventDefault:!0,stopPropagation:!1,run:[t=>{let r=yde={
view:t,prefix:n,scope:e};return setTimeout((()=>{yde==r&&(yde=null)}),Ode),!0}]
})}let p=d.join(" ");o(p,!1);let h=u[p]||(u[p]={preventDefault:!1,
stopPropagation:!1,
run:(null===(c=null===(l=u._any)||void 0===l?void 0:l.run)||void 0===c?void 0:c.slice())||[]
});a&&h.run.push(a),i&&(h.preventDefault=!0),s&&(h.stopPropagation=!0)}
;for(let i of e){let e=i.scope?i.scope.split(" "):["editor"]
;if(i.any)for(let t of e){let e=n[t]||(n[t]=Object.create(null))
;e._any||(e._any={preventDefault:!1,stopPropagation:!1,run:[]});let{any:r}=i
;for(let t in e)e[t].run.push((e=>r(e,wde)))}let r=i[t]||i.key
;if(r)for(let t of e)a(t,r,i.run,i.preventDefault,i.stopPropagation),
i.shift&&a(t,"Shift-"+r,i.shift,i.preventDefault,i.stopPropagation)}return n
}(t.reduce(((e,t)=>e.concat(t)),[])));return n}(t.state),e,t,"editor")
})),vde=Xae.define({enables:gde}),bde=new WeakMap;let yde=null;const Ode=4e3
;let wde=null;const xde={".cm-line":{},".cm-content":{}}
;function kde(e,t,n,r,o){t.lastIndex=0
;for(let a,i=e.iterRange(n,r),s=n;!i.next().done;s+=i.value.length)if(!i.lineBreak)for(;a=t.exec(i.value);)o(s+a.index,a)
}
!(ele.ios&&ele.webkit&&ele.webkit_version<534)&&(xde[".cm-line"].caretColor=xde[".cm-content"].caretColor="transparent !important")
;class Sde{constructor(e){
const{regexp:t,decoration:n,decorate:r,boundary:o,maxLength:a=1e3}=e
;if(!t.global)throw new RangeError("The regular expression given to MatchDecorator should have its 'g' flag set")
;if(this.regexp=t,
r)this.addMatch=(e,t,n,o)=>r(o,n,n+e[0].length,e,t);else if("function"==typeof n)this.addMatch=(e,t,r,o)=>{
let a=n(e,t,r);a&&o(r,r+e[0].length,a)};else{
if(!n)throw new RangeError("Either 'decorate' or 'decoration' should be provided to MatchDecorator")
;this.addMatch=(e,t,r,o)=>o(r,r+e[0].length,n)}this.boundary=o,this.maxLength=a}
createDeco(e){let t=new Qie,n=t.add.bind(t)
;for(let{from:r,to:o}of function(e,t){let n=e.visibleRanges
;if(1==n.length&&n[0].from==e.viewport.from&&n[0].to==e.viewport.to)return n
;let r=[]
;for(let{from:o,to:a}of n)o=Math.max(e.state.doc.lineAt(o).from,o-t),a=Math.min(e.state.doc.lineAt(a).to,a+t),
r.length&&r[r.length-1].to>=o?r[r.length-1].to=a:r.push({from:o,to:a});return r
}(e,this.maxLength))kde(e.state.doc,this.regexp,r,o,((t,r)=>this.addMatch(r,e,t,n)))
;return t.finish()}updateDeco(e,t){let n=1e9,r=-1
;return e.docChanged&&e.changes.iterChanges(((t,o,a,i)=>{
i>e.view.viewport.from&&a<e.view.viewport.to&&(n=Math.min(a,n),r=Math.max(i,r))
})),
e.viewportChanged||r-n>1e3?this.createDeco(e.view):r>-1?this.updateRange(e.view,t.map(e.changes),n,r):t
}updateRange(e,t,n,r){for(let o of e.visibleRanges){
let a=Math.max(o.from,n),i=Math.min(o.to,r);if(i>a){
let n=e.state.doc.lineAt(a),r=n.to<i?e.state.doc.lineAt(i):n,s=Math.max(o.from,n.from),l=Math.min(o.to,r.to)
;if(this.boundary){for(;a>n.from;a--)if(this.boundary.test(n.text[a-1-n.from])){
s=a;break}for(;i<r.to;i++)if(this.boundary.test(r.text[i-r.from])){l=i;break}}
let c,u=[],d=(e,t,n)=>u.push(n.range(e,t))
;if(n==r)for(this.regexp.lastIndex=s-n.from;(c=this.regexp.exec(n.text))&&c.index<l-n.from;)this.addMatch(c,e,c.index+n.from,d);else kde(e.state.doc,this.regexp,s,l,((t,n)=>this.addMatch(n,e,t,d)))
;t=t.update({filterFrom:s,filterTo:l,filter:(e,t)=>e<s||t>l,add:u})}}return t}}
const _de=null!=/x/.unicode?"gu":"g",Tde=new RegExp("[\0-\b\n--­؜​‎‏\u2028\u2029‭‮⁦⁧⁩\ufeff￹-￼]",_de),Ede={
0:"null",7:"bell",8:"backspace",10:"newline",11:"vertical tab",
13:"carriage return",27:"escape",8203:"zero width space",
8204:"zero width non-joiner",8205:"zero width joiner",8206:"left-to-right mark",
8207:"right-to-left mark",8232:"line separator",8237:"left-to-right override",
8238:"right-to-left override",8294:"left-to-right isolate",
8295:"right-to-left isolate",8297:"pop directional isolate",
8233:"paragraph separator",65279:"zero width no-break space",
65532:"object replacement"};let Ade=null;const Cde=Xae.define({combine(e){
let t=Bie(e,{render:null,specialChars:Tde,addSpecialChars:null})
;return(t.replaceTabs=!function(){var e
;if(null==Ade&&"undefined"!=typeof document&&document.body){
let t=document.body.style
;Ade=null!=(null!==(e=t.tabSize)&&void 0!==e?e:t.MozTabSize)}return Ade||!1
}())&&(t.specialChars=new RegExp("\t|"+t.specialChars.source,_de)),
t.addSpecialChars&&(t.specialChars=new RegExp(t.specialChars.source+"|"+t.addSpecialChars.source,_de)),
t}});function $de(e={}){return[Cde.of(e),Pde||(Pde=dce.fromClass(class{
constructor(e){
this.view=e,this.decorations=mle.none,this.decorationCache=Object.create(null),
this.decorator=this.makeDecorator(e.state.facet(Cde)),
this.decorations=this.decorator.createDeco(e)}makeDecorator(e){return new Sde({
regexp:e.specialChars,decoration:(t,n,r)=>{let{doc:o}=n.state,a=Dae(t[0],0)
;if(9==a){let e=o.lineAt(r),t=n.state.tabSize,a=tse(e.text,t,r-e.from)
;return mle.replace({
widget:new Ide((t-a%t)*this.view.defaultCharacterWidth/this.view.scaleX)})}
return this.decorationCache[a]||(this.decorationCache[a]=mle.replace({
widget:new Dde(e,a)}))},boundary:e.replaceTabs?void 0:/[^]/})}update(e){
let t=e.state.facet(Cde)
;e.startState.facet(Cde)!=t?(this.decorator=this.makeDecorator(t),
this.decorations=this.decorator.createDeco(e.view)):this.decorations=this.decorator.updateDeco(e,this.decorations)
}},{decorations:e=>e.decorations}))]}let Pde=null;class Dde extends hle{
constructor(e,t){super(),this.options=e,this.code=t}eq(e){
return e.code==this.code}toDOM(e){
let t=(n=this.code)>=32?"•":10==n?"␤":String.fromCharCode(9216+n);var n
;let r=e.state.phrase("Control character")+" "+(Ede[this.code]||"0x"+this.code.toString(16)),o=this.options.render&&this.options.render(this.code,r,t)
;if(o)return o;let a=document.createElement("span")
;return a.textContent=t,a.title=r,
a.setAttribute("aria-label",r),a.className="cm-specialChar",a}ignoreEvent(){
return!1}}class Ide extends hle{constructor(e){super(),this.width=e}eq(e){
return e.width==this.width}toDOM(){let e=document.createElement("span")
;return e.textContent="\t",e.className="cm-tab",e.style.width=this.width+"px",e}
ignoreEvent(){return!1}}class Mde extends hle{constructor(e){
super(),this.content=e}toDOM(e){let t=document.createElement("span")
;return t.className="cm-placeholder",
t.style.pointerEvents="none",t.appendChild("string"==typeof this.content?document.createTextNode(this.content):"function"==typeof this.content?this.content(e):this.content.cloneNode(!0)),
"string"==typeof this.content?t.setAttribute("aria-label","placeholder "+this.content):t.setAttribute("aria-hidden","true"),
t}coordsAt(e){let t=e.firstChild?vse(e.firstChild):[];if(!t.length)return null
;let n=window.getComputedStyle(e.parentNode),r=kse(t[0],"rtl"!=n.direction),o=parseInt(n.lineHeight)
;return r.bottom-r.top>1.5*o?{left:r.left,right:r.right,top:r.top,bottom:r.top+o
}:r}ignoreEvent(){return!1}}const Nde="-10000px";class Rde{constructor(e,t,n,r){
this.facet=t,
this.createTooltipView=n,this.removeTooltipView=r,this.input=e.state.facet(t),
this.tooltips=this.input.filter((e=>e));let o=null
;this.tooltipViews=this.tooltips.map((e=>o=n(e,o)))}update(e,t){var n
;let r=e.state.facet(this.facet),o=r.filter((e=>e));if(r===this.input){
for(let t of this.tooltipViews)t.update&&t.update(e);return!1}
let a=[],i=t?[]:null;for(let s=0;s<o.length;s++){let n=o[s],r=-1;if(n){
for(let e=0;e<this.tooltips.length;e++){let t=this.tooltips[e]
;t&&t.create==n.create&&(r=e)}
if(r<0)a[s]=this.createTooltipView(n,s?a[s-1]:null),i&&(i[s]=!!n.above);else{
let n=a[s]=this.tooltipViews[r];i&&(i[s]=t[r]),n.update&&n.update(e)}}}
for(let s of this.tooltipViews)a.indexOf(s)<0&&(this.removeTooltipView(s),
null===(n=s.destroy)||void 0===n||n.call(s))
;return t&&(i.forEach(((e,n)=>t[n]=e)),
t.length=i.length),this.input=r,this.tooltips=o,this.tooltipViews=a,!0}}
function Lde(e){let{win:t}=e;return{top:0,left:0,bottom:t.innerHeight,
right:t.innerWidth}}const Bde=Xae.define({combine:e=>{var t,n,r;return{
position:ele.ios?"absolute":(null===(t=e.find((e=>e.position)))||void 0===t?void 0:t.position)||"fixed",
parent:(null===(n=e.find((e=>e.parent)))||void 0===n?void 0:n.parent)||null,
tooltipSpace:(null===(r=e.find((e=>e.tooltipSpace)))||void 0===r?void 0:r.tooltipSpace)||Lde
}}}),jde=new WeakMap,Ude=dce.fromClass(class{constructor(e){
this.view=e,this.above=[],
this.inView=!0,this.madeAbsolute=!1,this.lastTransaction=0,
this.measureTimeout=-1;let t=e.state.facet(Bde)
;this.position=t.position,this.parent=t.parent,
this.classes=e.themeClasses,this.createContainer(),this.measureReq={
read:this.readMeasure.bind(this),write:this.writeMeasure.bind(this),key:this
},this.resizeObserver="function"==typeof ResizeObserver?new ResizeObserver((()=>this.measureSoon())):null,
this.manager=new Rde(e,Qde,((e,t)=>this.createTooltip(e,t)),(e=>{
this.resizeObserver&&this.resizeObserver.unobserve(e.dom),e.dom.remove()
})),this.above=this.manager.tooltips.map((e=>!!e.above)),
this.intersectionObserver="function"==typeof IntersectionObserver?new IntersectionObserver((e=>{
Date.now()>this.lastTransaction-50&&e.length>0&&e[e.length-1].intersectionRatio<1&&this.measureSoon()
}),{threshold:[1]
}):null,this.observeIntersection(),e.win.addEventListener("resize",this.measureSoon=this.measureSoon.bind(this)),
this.maybeMeasure()}createContainer(){
this.parent?(this.container=document.createElement("div"),
this.container.style.position="relative",
this.container.className=this.view.themeClasses,
this.parent.appendChild(this.container)):this.container=this.view.dom}
observeIntersection(){if(this.intersectionObserver){
this.intersectionObserver.disconnect()
;for(let e of this.manager.tooltipViews)this.intersectionObserver.observe(e.dom)
}}measureSoon(){this.measureTimeout<0&&(this.measureTimeout=setTimeout((()=>{
this.measureTimeout=-1,this.maybeMeasure()}),50))}update(e){
e.transactions.length&&(this.lastTransaction=Date.now())
;let t=this.manager.update(e,this.above);t&&this.observeIntersection()
;let n=t||e.geometryChanged,r=e.state.facet(Bde)
;if(r.position!=this.position&&!this.madeAbsolute){this.position=r.position
;for(let e of this.manager.tooltipViews)e.dom.style.position=this.position;n=!0}
if(r.parent!=this.parent){
this.parent&&this.container.remove(),this.parent=r.parent,this.createContainer()
;for(let e of this.manager.tooltipViews)this.container.appendChild(e.dom);n=!0
}else this.parent&&this.view.themeClasses!=this.classes&&(this.classes=this.container.className=this.view.themeClasses)
;n&&this.maybeMeasure()}createTooltip(e,t){
let n=e.create(this.view),r=t?t.dom:null
;if(n.dom.classList.add("cm-tooltip"),e.arrow&&!n.dom.querySelector(".cm-tooltip > .cm-tooltip-arrow")){
let e=document.createElement("div")
;e.className="cm-tooltip-arrow",n.dom.appendChild(e)}
return n.dom.style.position=this.position,
n.dom.style.top=Nde,n.dom.style.left="0px",this.container.insertBefore(n.dom,r),
n.mount&&n.mount(this.view),
this.resizeObserver&&this.resizeObserver.observe(n.dom),n}destroy(){var e,t,n
;this.view.win.removeEventListener("resize",this.measureSoon)
;for(let r of this.manager.tooltipViews)r.dom.remove(),
null===(e=r.destroy)||void 0===e||e.call(r)
;this.parent&&this.container.remove(),
null===(t=this.resizeObserver)||void 0===t||t.disconnect(),
null===(n=this.intersectionObserver)||void 0===n||n.disconnect(),
clearTimeout(this.measureTimeout)}readMeasure(){let e=1,t=1,n=!1
;if("fixed"==this.position&&this.manager.tooltipViews.length){
let{dom:e}=this.manager.tooltipViews[0]
;if(ele.gecko)n=e.offsetParent!=this.container.ownerDocument.body;else if(e.style.top==Nde&&"0px"==e.style.left){
let t=e.getBoundingClientRect();n=Math.abs(t.top+1e4)>1||Math.abs(t.left)>1}}
if(n||"absolute"==this.position)if(this.parent){
let n=this.parent.getBoundingClientRect()
;n.width&&n.height&&(e=n.width/this.parent.offsetWidth,
t=n.height/this.parent.offsetHeight)
}else({scaleX:e,scaleY:t}=this.view.viewState)
;let r=this.view.scrollDOM.getBoundingClientRect(),o=wce(this.view);return{
visible:{left:r.left+o.left,top:r.top+o.top,right:r.right-o.right,
bottom:r.bottom-o.bottom},
parent:this.parent?this.container.getBoundingClientRect():this.view.dom.getBoundingClientRect(),
pos:this.manager.tooltips.map(((e,t)=>{let n=this.manager.tooltipViews[t]
;return n.getCoords?n.getCoords(e.pos):this.view.coordsAtPos(e.pos)})),
size:this.manager.tooltipViews.map((({dom:e})=>e.getBoundingClientRect())),
space:this.view.state.facet(Bde).tooltipSpace(this.view),scaleX:e,scaleY:t,
makeAbsolute:n}}writeMeasure(e){var t;if(e.makeAbsolute){
this.madeAbsolute=!0,this.position="absolute"
;for(let e of this.manager.tooltipViews)e.dom.style.position="absolute"}
let{visible:n,space:r,scaleX:o,scaleY:a}=e,i=[]
;for(let s=0;s<this.manager.tooltips.length;s++){
let l=this.manager.tooltips[s],c=this.manager.tooltipViews[s],{dom:u}=c,d=e.pos[s],p=e.size[s]
;if(!d||!1!==l.clip&&(d.bottom<=Math.max(n.top,r.top)||d.top>=Math.min(n.bottom,r.bottom)||d.right<Math.max(n.left,r.left)-.1||d.left>Math.min(n.right,r.right)+.1)){
u.style.top=Nde;continue}
let h=l.arrow?c.dom.querySelector(".cm-tooltip-arrow"):null,f=h?7:0,m=p.right-p.left,g=null!==(t=jde.get(c))&&void 0!==t?t:p.bottom-p.top,v=c.offset||Zde,b=this.view.textDirection==Ele.LTR,y=p.width>r.right-r.left?b?r.left:r.right-p.width:b?Math.max(r.left,Math.min(d.left-(h?14:0)+v.x,r.right-m)):Math.min(Math.max(r.left,d.left-m+(h?14:0)-v.x),r.right-m),O=this.above[s]
;!l.strictSide&&(O?d.top-g-f-v.y<r.top:d.bottom+g+f+v.y>r.bottom)&&O==r.bottom-d.bottom>d.top-r.top&&(O=this.above[s]=!O)
;let w=(O?d.top-r.top:r.bottom-d.bottom)-f;if(w<g&&!1!==c.resize){
if(w<this.view.defaultLineHeight){u.style.top=Nde;continue}
jde.set(c,g),u.style.height=(g=w)/a+"px"
}else u.style.height&&(u.style.height="")
;let x=O?d.top-g-f-v.y:d.bottom+f+v.y,k=y+m
;if(!0!==c.overlap)for(let e of i)e.left<k&&e.right>y&&e.top<x+g&&e.bottom>x&&(x=O?e.top-g-2-f:e.bottom+f+2)
;if("absolute"==this.position?(u.style.top=(x-e.parent.top)/a+"px",
zde(u,(y-e.parent.left)/o)):(u.style.top=x/a+"px",zde(u,y/o)),h){
let e=d.left+(b?v.x:-v.x)-(y+14-7);h.style.left=e/o+"px"}
!0!==c.overlap&&i.push({left:y,top:x,right:k,bottom:x+g
}),u.classList.toggle("cm-tooltip-above",O),
u.classList.toggle("cm-tooltip-below",!O),c.positioned&&c.positioned(e.space)}}
maybeMeasure(){
if(this.manager.tooltips.length&&(this.view.inView&&this.view.requestMeasure(this.measureReq),
this.inView!=this.view.inView&&(this.inView=this.view.inView,
!this.inView)))for(let e of this.manager.tooltipViews)e.dom.style.top=Nde}},{
eventObservers:{scroll(){this.maybeMeasure()}}});function zde(e,t){
let n=parseInt(e.style.left,10)
;(isNaN(n)||Math.abs(t-n)>1)&&(e.style.left=t+"px")}const Fde=cde.baseTheme({
".cm-tooltip":{zIndex:500,boxSizing:"border-box"},"&light .cm-tooltip":{
border:"1px solid #bbb",backgroundColor:"#f5f5f5"},
"&light .cm-tooltip-section:not(:first-child)":{borderTop:"1px solid #bbb"},
"&dark .cm-tooltip":{backgroundColor:"#333338",color:"white"},
".cm-tooltip-arrow":{height:"7px",width:"14px",position:"absolute",zIndex:-1,
overflow:"hidden","&:before, &:after":{content:"''",position:"absolute",width:0,
height:0,borderLeft:"7px solid transparent",borderRight:"7px solid transparent"
},".cm-tooltip-above &":{bottom:"-7px","&:before":{borderTop:"7px solid #bbb"},
"&:after":{borderTop:"7px solid #f5f5f5",bottom:"1px"}},".cm-tooltip-below &":{
top:"-7px","&:before":{borderBottom:"7px solid #bbb"},"&:after":{
borderBottom:"7px solid #f5f5f5",top:"1px"}}},
"&dark .cm-tooltip .cm-tooltip-arrow":{"&:before":{borderTopColor:"#333338",
borderBottomColor:"#333338"},"&:after":{borderTopColor:"transparent",
borderBottomColor:"transparent"}}}),Zde={x:0,y:0},Qde=Xae.define({
enables:[Ude,Fde]}),Hde=Xae.define({combine:e=>e.reduce(((e,t)=>e.concat(t)),[])
});class Vde{static create(e){return new Vde(e)}constructor(e){
this.view=e,this.mounted=!1,
this.dom=document.createElement("div"),this.dom.classList.add("cm-tooltip-hover"),
this.manager=new Rde(e,Hde,((e,t)=>this.createHostedView(e,t)),(e=>e.dom.remove()))
}createHostedView(e,t){let n=e.create(this.view)
;return n.dom.classList.add("cm-tooltip-section"),
this.dom.insertBefore(n.dom,t?t.dom.nextSibling:this.dom.firstChild),
this.mounted&&n.mount&&n.mount(this.view),n}mount(e){
for(let t of this.manager.tooltipViews)t.mount&&t.mount(e);this.mounted=!0}
positioned(e){
for(let t of this.manager.tooltipViews)t.positioned&&t.positioned(e)}update(e){
this.manager.update(e)}destroy(){var e
;for(let t of this.manager.tooltipViews)null===(e=t.destroy)||void 0===e||e.call(t)
}passProp(e){let t;for(let n of this.manager.tooltipViews){let r=n[e]
;if(void 0!==r)if(void 0===t)t=r;else if(t!==r)return}return t}get offset(){
return this.passProp("offset")}get getCoords(){return this.passProp("getCoords")
}get overlap(){return this.passProp("overlap")}get resize(){
return this.passProp("resize")}}const qde=Qde.compute([Hde],(e=>{
let t=e.facet(Hde);return 0===t.length?null:{pos:Math.min(...t.map((e=>e.pos))),
end:Math.max(...t.map((e=>{var t;return null!==(t=e.end)&&void 0!==t?t:e.pos
}))),create:Vde.create,above:t[0].above,arrow:t.some((e=>e.arrow))}}))
;class Wde{constructor(e,t,n,r,o){
this.view=e,this.source=t,this.field=n,this.setHover=r,
this.hoverTime=o,this.hoverTimeout=-1,
this.restartTimeout=-1,this.pending=null,this.lastMove={x:0,y:0,target:e.dom,
time:0
},this.checkHover=this.checkHover.bind(this),e.dom.addEventListener("mouseleave",this.mouseleave=this.mouseleave.bind(this)),
e.dom.addEventListener("mousemove",this.mousemove=this.mousemove.bind(this))}
update(){
this.pending&&(this.pending=null,clearTimeout(this.restartTimeout),this.restartTimeout=setTimeout((()=>this.startHover()),20))
}get active(){return this.view.state.field(this.field)}checkHover(){
if(this.hoverTimeout=-1,this.active.length)return
;let e=Date.now()-this.lastMove.time
;e<this.hoverTime?this.hoverTimeout=setTimeout(this.checkHover,this.hoverTime-e):this.startHover()
}startHover(){clearTimeout(this.restartTimeout)
;let{view:e,lastMove:t}=this,n=e.docView.nearest(t.target);if(!n)return
;let r,o=1;if(n instanceof rle)r=n.posAtStart;else{
if(r=e.posAtCoords(t),null==r)return;let n=e.coordsAtPos(r)
;if(!n||t.y<n.top||t.y>n.bottom||t.x<n.left-e.defaultCharacterWidth||t.x>n.right+e.defaultCharacterWidth)return
;let a=e.bidiSpans(e.state.doc.lineAt(r)).find((e=>e.from<=r&&e.to>=r)),i=a&&a.dir==Ele.RTL?-1:1
;o=t.x<n.left?-i:i}let a=this.source(e,r,o);if(null==a?void 0:a.then){
let t=this.pending={pos:r};a.then((n=>{
this.pending==t&&(this.pending=null,!n||Array.isArray(n)&&!n.length||e.dispatch({
effects:this.setHover.of(Array.isArray(n)?n:[n])}))
}),(t=>sce(e.state,t,"hover tooltip")))
}else!a||Array.isArray(a)&&!a.length||e.dispatch({
effects:this.setHover.of(Array.isArray(a)?a:[a])})}get tooltip(){
let e=this.view.plugin(Ude),t=e?e.manager.tooltips.findIndex((e=>e.create==Vde.create)):-1
;return t>-1?e.manager.tooltipViews[t]:null}mousemove(e){var t,n;this.lastMove={
x:e.clientX,y:e.clientY,target:e.target,time:Date.now()
},this.hoverTimeout<0&&(this.hoverTimeout=setTimeout(this.checkHover,this.hoverTime))
;let{active:r,tooltip:o}=this;if(r.length&&o&&!function(e,t){
let n,{left:r,right:o,top:a,bottom:i}=e.getBoundingClientRect()
;if(n=e.querySelector(".cm-tooltip-arrow")){let e=n.getBoundingClientRect()
;a=Math.min(e.top,a),i=Math.max(e.bottom,i)}
return t.clientX>=r-Xde&&t.clientX<=o+Xde&&t.clientY>=a-Xde&&t.clientY<=i+Xde
}(o.dom,e)||this.pending){
let{pos:o}=r[0]||this.pending,a=null!==(n=null===(t=r[0])||void 0===t?void 0:t.end)&&void 0!==n?n:o
;(o==a?this.view.posAtCoords(this.lastMove)==o:function(e,t,n,r,o,a){
let i=e.scrollDOM.getBoundingClientRect(),s=e.documentTop+e.documentPadding.top+e.contentHeight
;if(i.left>r||i.right<r||i.top>o||Math.min(i.bottom,s)<o)return!1
;let l=e.posAtCoords({x:r,y:o},!1);return l>=t&&l<=n
}(this.view,o,a,e.clientX,e.clientY))||(this.view.dispatch({
effects:this.setHover.of([])}),this.pending=null)}}mouseleave(e){
clearTimeout(this.hoverTimeout),this.hoverTimeout=-1;let{active:t}=this
;if(t.length){let{tooltip:t}=this
;t&&t.dom.contains(e.relatedTarget)?this.watchTooltipLeave(t.dom):this.view.dispatch({
effects:this.setHover.of([])})}}watchTooltipLeave(e){let t=n=>{
e.removeEventListener("mouseleave",t),
this.active.length&&!this.view.dom.contains(n.relatedTarget)&&this.view.dispatch({
effects:this.setHover.of([])})};e.addEventListener("mouseleave",t)}destroy(){
clearTimeout(this.hoverTimeout),
this.view.dom.removeEventListener("mouseleave",this.mouseleave),
this.view.dom.removeEventListener("mousemove",this.mousemove)}}const Xde=4
;function Gde(e,t={}){let n=_ie.define(),r=nie.define({create:()=>[],
update(e,r){
if(e.length&&(t.hideOnChange&&(r.docChanged||r.selection)?e=[]:t.hideOn&&(e=e.filter((e=>!t.hideOn(r,e)))),
r.docChanged)){let t=[];for(let n of e){
let e=r.changes.mapPos(n.pos,-1,Rae.TrackDel);if(null!=e){
let o=Object.assign(Object.create(null),n)
;o.pos=e,null!=o.end&&(o.end=r.changes.mapPos(o.end)),t.push(o)}}e=t}
for(let t of r.effects)t.is(n)&&(e=t.value),t.is(Kde)&&(e=[]);return e},
provide:e=>Hde.from(e)});return{active:r,
extension:[r,dce.define((o=>new Wde(o,e,r,n,t.hoverTime||300))),qde]}}
function Yde(e,t){let n=e.plugin(Ude);if(!n)return null
;let r=n.manager.tooltips.indexOf(t);return r<0?null:n.manager.tooltipViews[r]}
const Kde=_ie.define(),Jde=Xae.define({combine(e){let t,n
;for(let r of e)t=t||r.topContainer,n=n||r.bottomContainer;return{
topContainer:t,bottomContainer:n}}}),epe=dce.fromClass(class{constructor(e){
this.input=e.state.facet(rpe),
this.specs=this.input.filter((e=>e)),this.panels=this.specs.map((t=>t(e)))
;let t=e.state.facet(Jde)
;this.top=new tpe(e,!0,t.topContainer),this.bottom=new tpe(e,!1,t.bottomContainer),
this.top.sync(this.panels.filter((e=>e.top))),
this.bottom.sync(this.panels.filter((e=>!e.top)))
;for(let n of this.panels)n.dom.classList.add("cm-panel"),n.mount&&n.mount()}
update(e){let t=e.state.facet(Jde)
;this.top.container!=t.topContainer&&(this.top.sync([]),
this.top=new tpe(e.view,!0,t.topContainer)),
this.bottom.container!=t.bottomContainer&&(this.bottom.sync([]),
this.bottom=new tpe(e.view,!1,t.bottomContainer)),
this.top.syncClasses(),this.bottom.syncClasses();let n=e.state.facet(rpe)
;if(n!=this.input){let t=n.filter((e=>e)),r=[],o=[],a=[],i=[];for(let n of t){
let t,s=this.specs.indexOf(n)
;s<0?(t=n(e.view),i.push(t)):(t=this.panels[s],t.update&&t.update(e)),r.push(t),
(t.top?o:a).push(t)}
this.specs=t,this.panels=r,this.top.sync(o),this.bottom.sync(a)
;for(let e of i)e.dom.classList.add("cm-panel"),e.mount&&e.mount()
}else for(let r of this.panels)r.update&&r.update(e)}destroy(){
this.top.sync([]),this.bottom.sync([])}},{provide:e=>cde.scrollMargins.of((t=>{
let n=t.plugin(e);return n&&{top:n.top.scrollMargin(),
bottom:n.bottom.scrollMargin()}}))});class tpe{constructor(e,t,n){
this.view=e,this.top=t,
this.container=n,this.dom=void 0,this.classes="",this.panels=[],
this.syncClasses()}sync(e){
for(let t of this.panels)t.destroy&&e.indexOf(t)<0&&t.destroy()
;this.panels=e,this.syncDOM()}syncDOM(){
if(0==this.panels.length)return void(this.dom&&(this.dom.remove(),
this.dom=void 0));if(!this.dom){
this.dom=document.createElement("div"),this.dom.className=this.top?"cm-panels cm-panels-top":"cm-panels cm-panels-bottom",
this.dom.style[this.top?"top":"bottom"]="0";let e=this.container||this.view.dom
;e.insertBefore(this.dom,this.top?e.firstChild:null)}let e=this.dom.firstChild
;for(let t of this.panels)if(t.dom.parentNode==this.dom){for(;e!=t.dom;)e=npe(e)
;e=e.nextSibling}else this.dom.insertBefore(t.dom,e);for(;e;)e=npe(e)}
scrollMargin(){
return!this.dom||this.container?0:Math.max(0,this.top?this.dom.getBoundingClientRect().bottom-Math.max(0,this.view.scrollDOM.getBoundingClientRect().top):Math.min(innerHeight,this.view.scrollDOM.getBoundingClientRect().bottom)-this.dom.getBoundingClientRect().top)
}syncClasses(){if(this.container&&this.classes!=this.view.themeClasses){
for(let e of this.classes.split(" "))e&&this.container.classList.remove(e)
;for(let e of(this.classes=this.view.themeClasses).split(" "))e&&this.container.classList.add(e)
}}}function npe(e){let t=e.nextSibling;return e.remove(),t}
const rpe=Xae.define({enables:epe});class ope extends jie{compare(e){
return this==e||this.constructor==e.constructor&&this.eq(e)}eq(e){return!1}
destroy(e){}}
ope.prototype.elementClass="",ope.prototype.toDOM=void 0,ope.prototype.mapMode=Rae.TrackBefore,
ope.prototype.startSide=ope.prototype.endSide=-1,ope.prototype.point=!0
;const ape=Xae.define(),ipe=Xae.define(),spe={class:"",renderEmptyElements:!1,
elementStyle:"",markers:()=>Zie.empty,lineMarker:()=>null,widgetMarker:()=>null,
lineMarkerChange:null,initialSpacer:null,updateSpacer:null,domEventHandlers:{}
},lpe=Xae.define();function cpe(e){
return[dpe(),lpe.of(Object.assign(Object.assign({},spe),e))]}
const upe=Xae.define({combine:e=>e.some((e=>e))});function dpe(e){return[ppe]}
const ppe=dce.fromClass(class{constructor(e){
this.view=e,this.prevViewport=e.viewport,this.dom=document.createElement("div"),
this.dom.className="cm-gutters",
this.dom.setAttribute("aria-hidden","true"),this.dom.style.minHeight=this.view.contentHeight/this.view.scaleY+"px",
this.gutters=e.state.facet(lpe).map((t=>new gpe(e,t)))
;for(let t of this.gutters)this.dom.appendChild(t.dom)
;this.fixed=!e.state.facet(upe),
this.fixed&&(this.dom.style.position="sticky"),this.syncGutters(!1),
e.scrollDOM.insertBefore(this.dom,e.contentDOM)}update(e){
if(this.updateGutters(e)){
let t=this.prevViewport,n=e.view.viewport,r=Math.min(t.to,n.to)-Math.max(t.from,n.from)
;this.syncGutters(r<.8*(n.to-n.from))}
e.geometryChanged&&(this.dom.style.minHeight=this.view.contentHeight/this.view.scaleY+"px"),
this.view.state.facet(upe)!=!this.fixed&&(this.fixed=!this.fixed,
this.dom.style.position=this.fixed?"sticky":""),
this.prevViewport=e.view.viewport}syncGutters(e){let t=this.dom.nextSibling
;e&&this.dom.remove()
;let n=Zie.iter(this.view.state.facet(ape),this.view.viewport.from),r=[],o=this.gutters.map((e=>new mpe(e,this.view.viewport,-this.view.documentPadding.top)))
;for(let a of this.view.viewportLineBlocks)if(r.length&&(r=[]),
Array.isArray(a.type)){let e=!0;for(let t of a.type)if(t.type==fle.Text&&e){
fpe(n,r,t.from);for(let e of o)e.line(this.view,t,r);e=!1
}else if(t.widget)for(let e of o)e.widget(this.view,t)
}else if(a.type==fle.Text){fpe(n,r,a.from);for(let e of o)e.line(this.view,a,r)
}else if(a.widget)for(let e of o)e.widget(this.view,a);for(let a of o)a.finish()
;e&&this.view.scrollDOM.insertBefore(this.dom,t)}updateGutters(e){
let t=e.startState.facet(lpe),n=e.state.facet(lpe),r=e.docChanged||e.heightChanged||e.viewportChanged||!Zie.eq(e.startState.facet(ape),e.state.facet(ape),e.view.viewport.from,e.view.viewport.to)
;if(t==n)for(let o of this.gutters)o.update(e)&&(r=!0);else{r=!0;let o=[]
;for(let r of n){let n=t.indexOf(r)
;n<0?o.push(new gpe(this.view,r)):(this.gutters[n].update(e),
o.push(this.gutters[n]))}
for(let e of this.gutters)e.dom.remove(),o.indexOf(e)<0&&e.destroy()
;for(let e of o)this.dom.appendChild(e.dom);this.gutters=o}return r}destroy(){
for(let e of this.gutters)e.destroy();this.dom.remove()}},{
provide:e=>cde.scrollMargins.of((t=>{let n=t.plugin(e)
;return n&&0!=n.gutters.length&&n.fixed?t.textDirection==Ele.LTR?{
left:n.dom.offsetWidth*t.scaleX}:{right:n.dom.offsetWidth*t.scaleX}:null}))})
;function hpe(e){return Array.isArray(e)?e:[e]}function fpe(e,t,n){
for(;e.value&&e.from<=n;)e.from==n&&t.push(e.value),e.next()}class mpe{
constructor(e,t,n){
this.gutter=e,this.height=n,this.i=0,this.cursor=Zie.iter(e.markers,t.from)}
addElement(e,t,n){
let{gutter:r}=this,o=(t.top-this.height)/e.scaleY,a=t.height/e.scaleY
;if(this.i==r.elements.length){let t=new vpe(e,a,o,n)
;r.elements.push(t),r.dom.appendChild(t.dom)
}else r.elements[this.i].update(e,a,o,n);this.height=t.bottom,this.i++}
line(e,t,n){let r=[];fpe(this.cursor,r,t.from),n.length&&(r=r.concat(n))
;let o=this.gutter.config.lineMarker(e,t,r);o&&r.unshift(o);let a=this.gutter
;(0!=r.length||a.config.renderEmptyElements)&&this.addElement(e,t,r)}
widget(e,t){let n=this.gutter.config.widgetMarker(e,t.widget,t),r=n?[n]:null
;for(let o of e.state.facet(ipe)){let n=o(e,t.widget,t);n&&(r||(r=[])).push(n)}
r&&this.addElement(e,t,r)}finish(){let e=this.gutter
;for(;e.elements.length>this.i;){let t=e.elements.pop()
;e.dom.removeChild(t.dom),t.destroy()}}}class gpe{constructor(e,t){
this.view=e,this.config=t,
this.elements=[],this.spacer=null,this.dom=document.createElement("div"),
this.dom.className="cm-gutter"+(this.config.class?" "+this.config.class:"")
;for(let n in t.domEventHandlers)this.dom.addEventListener(n,(r=>{
let o,a=r.target;if(a!=this.dom&&this.dom.contains(a)){
for(;a.parentNode!=this.dom;)a=a.parentNode;let e=a.getBoundingClientRect()
;o=(e.top+e.bottom)/2}else o=r.clientY
;let i=e.lineBlockAtHeight(o-e.documentTop)
;t.domEventHandlers[n](e,i,r)&&r.preventDefault()}))
;this.markers=hpe(t.markers(e)),
t.initialSpacer&&(this.spacer=new vpe(e,0,0,[t.initialSpacer(e)]),
this.dom.appendChild(this.spacer.dom),
this.spacer.dom.style.cssText+="visibility: hidden; pointer-events: none")}
update(e){let t=this.markers
;if(this.markers=hpe(this.config.markers(e.view)),this.spacer&&this.config.updateSpacer){
let t=this.config.updateSpacer(this.spacer.markers[0],e)
;t!=this.spacer.markers[0]&&this.spacer.update(e.view,0,0,[t])}
let n=e.view.viewport
;return!Zie.eq(this.markers,t,n.from,n.to)||!!this.config.lineMarkerChange&&this.config.lineMarkerChange(e)
}destroy(){for(let e of this.elements)e.destroy()}}class vpe{
constructor(e,t,n,r){
this.height=-1,this.above=0,this.markers=[],this.dom=document.createElement("div"),
this.dom.className="cm-gutterElement",this.update(e,t,n,r)}update(e,t,n,r){
this.height!=t&&(this.height=t,
this.dom.style.height=t+"px"),this.above!=n&&(this.dom.style.marginTop=(this.above=n)?n+"px":""),
function(e,t){if(e.length!=t.length)return!1
;for(let n=0;n<e.length;n++)if(!e[n].compare(t[n]))return!1;return!0
}(this.markers,r)||this.setMarkers(e,r)}setMarkers(e,t){
let n="cm-gutterElement",r=this.dom.firstChild;for(let o=0,a=0;;){
let i=a,s=o<t.length?t[o++]:null,l=!1;if(s){let e=s.elementClass;e&&(n+=" "+e)
;for(let t=a;t<this.markers.length;t++)if(this.markers[t].compare(s)){i=t,l=!0
;break}}else i=this.markers.length;for(;a<i;){let e=this.markers[a++]
;if(e.toDOM){e.destroy(r);let t=r.nextSibling;r.remove(),r=t}}if(!s)break
;s.toDOM&&(l?r=r.nextSibling:this.dom.insertBefore(s.toDOM(e),r)),l&&a++}
this.dom.className=n,this.markers=t}destroy(){this.setMarkers(null,[])}}
const bpe=Xae.define(),ype=Xae.define(),Ope=Xae.define({combine:e=>Bie(e,{
formatNumber:String,domEventHandlers:{}},{domEventHandlers(e,t){
let n=Object.assign({},e);for(let r in t){let e=n[r],o=t[r]
;n[r]=e?(t,n,r)=>e(t,n,r)||o(t,n,r):o}return n}})});class wpe extends ope{
constructor(e){super(),this.number=e}eq(e){return this.number==e.number}toDOM(){
return document.createTextNode(this.number)}}function xpe(e,t){
return e.state.facet(Ope).formatNumber(t,e.state)}
const kpe=lpe.compute([Ope],(e=>({class:"cm-lineNumbers",renderEmptyElements:!1,
markers:e=>e.state.facet(bpe),
lineMarker:(e,t,n)=>n.some((e=>e.toDOM))?null:new wpe(xpe(e,e.state.doc.lineAt(t.from).number)),
widgetMarker:(e,t,n)=>{for(let r of e.state.facet(ype)){let o=r(e,t,n)
;if(o)return o}return null},
lineMarkerChange:e=>e.startState.facet(Ope)!=e.state.facet(Ope),
initialSpacer:e=>new wpe(xpe(e,Spe(e.state.doc.lines))),updateSpacer(e,t){
let n=xpe(t.view,Spe(t.view.state.doc.lines));return n==e.number?e:new wpe(n)},
domEventHandlers:e.facet(Ope).domEventHandlers})));function Spe(e){let t=9
;for(;t<e;)t=10*t+9;return t}const _pe=1024;let Tpe=0;class Epe{
constructor(e,t){this.from=e,this.to=t}}class Ape{constructor(e={}){
this.id=Tpe++,this.perNode=!!e.perNode,this.deserialize=e.deserialize||(()=>{
throw new Error("This node type doesn't define a deserialize function")})}
add(e){
if(this.perNode)throw new RangeError("Can't add per-node props to node types")
;return"function"!=typeof e&&(e=Ppe.match(e)),t=>{let n=e(t)
;return void 0===n?null:[this,n]}}}Ape.closedBy=new Ape({
deserialize:e=>e.split(" ")}),Ape.openedBy=new Ape({deserialize:e=>e.split(" ")
}),Ape.group=new Ape({deserialize:e=>e.split(" ")}),Ape.isolate=new Ape({
deserialize:e=>{
if(e&&"rtl"!=e&&"ltr"!=e&&"auto"!=e)throw new RangeError("Invalid value for isolate: "+e)
;return e||"auto"}}),Ape.contextHash=new Ape({perNode:!0
}),Ape.lookAhead=new Ape({perNode:!0}),Ape.mounted=new Ape({perNode:!0})
;class Cpe{constructor(e,t,n){this.tree=e,this.overlay=t,this.parser=n}
static get(e){return e&&e.props&&e.props[Ape.mounted.id]}}
const $pe=Object.create(null);class Ppe{constructor(e,t,n,r=0){
this.name=e,this.props=t,this.id=n,this.flags=r}static define(e){
let t=e.props&&e.props.length?Object.create(null):$pe,n=(e.top?1:0)|(e.skipped?2:0)|(e.error?4:0)|(null==e.name?8:0),r=new Ppe(e.name||"",t,e.id,n)
;if(e.props)for(let o of e.props)if(Array.isArray(o)||(o=o(r)),o){
if(o[0].perNode)throw new RangeError("Can't store a per-node prop on a node type")
;t[o[0].id]=o[1]}return r}prop(e){return this.props[e.id]}get isTop(){
return(1&this.flags)>0}get isSkipped(){return(2&this.flags)>0}get isError(){
return(4&this.flags)>0}get isAnonymous(){return(8&this.flags)>0}is(e){
if("string"==typeof e){if(this.name==e)return!0;let t=this.prop(Ape.group)
;return!!t&&t.indexOf(e)>-1}return this.id==e}static match(e){
let t=Object.create(null);for(let n in e)for(let r of n.split(" "))t[r]=e[n]
;return e=>{for(let n=e.prop(Ape.group),r=-1;r<(n?n.length:0);r++){
let o=t[r<0?e.name:n[r]];if(o)return o}}}}
Ppe.none=new Ppe("",Object.create(null),0,8);class Dpe{constructor(e){
this.types=e
;for(let t=0;t<e.length;t++)if(e[t].id!=t)throw new RangeError("Node type ids should correspond to array positions when creating a node set")
}extend(...e){let t=[];for(let n of this.types){let r=null;for(let t of e){
let e=t(n);e&&(r||(r=Object.assign({},n.props)),r[e[0].id]=e[1])}
t.push(r?new Ppe(n.name,r,n.id,n.flags):n)}return new Dpe(t)}}
const Ipe=new WeakMap,Mpe=new WeakMap;var Npe,Rpe
;(Rpe=Npe||(Npe={}))[Rpe.ExcludeBuffers=1]="ExcludeBuffers",
Rpe[Rpe.IncludeAnonymous=2]="IncludeAnonymous",
Rpe[Rpe.IgnoreMounts=4]="IgnoreMounts",
Rpe[Rpe.IgnoreOverlays=8]="IgnoreOverlays";class Lpe{constructor(e,t,n,r,o){
if(this.type=e,
this.children=t,this.positions=n,this.length=r,this.props=null,o&&o.length){
this.props=Object.create(null)
;for(let[e,t]of o)this.props["number"==typeof e?e:e.id]=t}}toString(){
let e=Cpe.get(this);if(e&&!e.overlay)return e.tree.toString();let t=""
;for(let n of this.children){let e=n.toString();e&&(t&&(t+=","),t+=e)}
return this.type.name?(/\W/.test(this.type.name)&&!this.type.isError?JSON.stringify(this.type.name):this.type.name)+(t.length?"("+t+")":""):t
}cursor(e=0){return new Gpe(this.topNode,e)}cursorAt(e,t=0,n=0){
let r=Ipe.get(this)||this.topNode,o=new Gpe(r)
;return o.moveTo(e,t),Ipe.set(this,o._tree),o}get topNode(){
return new Zpe(this,0,0,null)}resolve(e,t=0){
let n=zpe(Ipe.get(this)||this.topNode,e,t,!1);return Ipe.set(this,n),n}
resolveInner(e,t=0){let n=zpe(Mpe.get(this)||this.topNode,e,t,!0)
;return Mpe.set(this,n),n}resolveStack(e,t=0){return function(e,t,n){
let r=e.resolveInner(t,n),o=null
;for(let a=r instanceof Zpe?r:r.context.parent;a;a=a.parent)if(a.index<0){
let e=a.parent;(o||(o=[r])).push(e.resolve(t,n)),a=e}else{let e=Cpe.get(a.tree)
;if(e&&e.overlay&&e.overlay[0].from<=t&&e.overlay[e.overlay.length-1].to>=t){
let i=new Zpe(e.tree,e.overlay[0].from+a.from,-1,a)
;(o||(o=[r])).push(zpe(i,t,n,!1))}}return o?Wpe(o):r}(this,e,t)}iterate(e){
let{enter:t,leave:n,from:r=0,to:o=this.length}=e,a=e.mode||0,i=(a&Npe.IncludeAnonymous)>0
;for(let s=this.cursor(a|Npe.IncludeAnonymous);;){let e=!1
;if(s.from<=o&&s.to>=r&&(!i&&s.type.isAnonymous||!1!==t(s))){
if(s.firstChild())continue;e=!0}
for(;e&&n&&(i||!s.type.isAnonymous)&&n(s),!s.nextSibling();){
if(!s.parent())return;e=!0}}}prop(e){
return e.perNode?this.props?this.props[e.id]:void 0:this.type.prop(e)}
get propValues(){let e=[]
;if(this.props)for(let t in this.props)e.push([+t,this.props[t]]);return e}
balance(e={}){
return this.children.length<=8?this:ehe(Ppe.none,this.children,this.positions,0,this.children.length,0,this.length,((e,t,n)=>new Lpe(this.type,e,t,n,this.propValues)),e.makeTree||((e,t,n)=>new Lpe(Ppe.none,e,t,n)))
}static build(e){return function(e){var t
;let{buffer:n,nodeSet:r,maxBufferLength:o=_pe,reused:a=[],minRepeatType:i=r.types.length}=e,s=Array.isArray(n)?new Bpe(n,n.length):n,l=r.types,c=0,u=0
;function d(e,t,n,b,y,O){let{id:w,start:x,end:k,size:S}=s,_=u,T=c;for(;S<0;){
if(s.next(),-1==S){let t=a[w];return n.push(t),void b.push(x-e)}
if(-3==S)return void(c=w);if(-4==S)return void(u=w)
;throw new RangeError(`Unrecognized record size: ${S}`)}let E,A,C=l[w],$=x-e
;if(k-x<=o&&(A=g(s.pos-t,y))){
let t=new Uint16Array(A.size-A.skip),n=s.pos-A.size,o=t.length
;for(;s.pos>n;)o=v(A.start,t,o);E=new jpe(t,k-A.start,r),$=A.start-e}else{
let e=s.pos-S;s.next();let t=[],n=[],r=w>=i?w:-1,a=0,l=k
;for(;s.pos>e;)r>=0&&s.id==r&&s.size>=0?(s.end<=l-o&&(f(t,n,x,a,s.end,l,r,_,T),
a=t.length,l=s.end),s.next()):O>2500?p(x,e,t,n):d(x,e,t,n,r,O+1)
;if(r>=0&&a>0&&a<t.length&&f(t,n,x,a,x,l,r,_,T),
t.reverse(),n.reverse(),r>-1&&a>0){let e=h(C,T)
;E=ehe(C,t,n,0,t.length,0,k-x,e,e)}else E=m(C,t,n,k-x,_-k,T)}n.push(E),b.push($)
}function p(e,t,n,a){let i=[],l=0,c=-1;for(;s.pos>t;){
let{id:e,start:t,end:n,size:r}=s;if(r>4)s.next();else{if(c>-1&&t<c)break
;c<0&&(c=n-o),i.push(e,t,n),l++,s.next()}}if(l){
let t=new Uint16Array(4*l),o=i[i.length-2]
;for(let e=i.length-3,n=0;e>=0;e-=3)t[n++]=i[e],t[n++]=i[e+1]-o,t[n++]=i[e+2]-o,
t[n++]=n;n.push(new jpe(t,i[2]-o,r)),a.push(o-e)}}function h(e,t){
return(n,r,o)=>{let a,i,s=0,l=n.length-1;if(l>=0&&(a=n[l])instanceof Lpe){
if(!l&&a.type==e&&a.length==o)return a
;(i=a.prop(Ape.lookAhead))&&(s=r[l]+a.length+i)}return m(e,n,r,o,s,t)}}
function f(e,t,n,o,a,i,s,l,c){let u=[],d=[]
;for(;e.length>o;)u.push(e.pop()),d.push(t.pop()+n-a)
;e.push(m(r.types[s],u,d,i-a,l-i,c)),t.push(a-n)}function m(e,t,n,r,o,a,i){
if(a){let e=[Ape.contextHash,a];i=i?[e].concat(i):[e]}if(o>25){
let e=[Ape.lookAhead,o];i=i?[e].concat(i):[e]}return new Lpe(e,t,n,r,i)}
function g(e,t){let n=s.fork(),r=0,a=0,l=0,c=n.end-o,u={size:0,start:0,skip:0}
;e:for(let o=n.pos-e;n.pos>o;){let e=n.size;if(n.id==t&&e>=0){
u.size=r,u.start=a,u.skip=l,l+=4,r+=4,n.next();continue}let s=n.pos-e
;if(e<0||s<o||n.start<c)break;let d=n.id>=i?4:0,p=n.start
;for(n.next();n.pos>s;){if(n.size<0){if(-3!=n.size)break e;d+=4
}else n.id>=i&&(d+=4);n.next()}a=p,r+=e,l+=d}
return(t<0||r==e)&&(u.size=r,u.start=a,u.skip=l),u.size>4?u:void 0}
function v(e,t,n){let{id:r,start:o,end:a,size:l}=s;if(s.next(),l>=0&&r<i){
let i=n;if(l>4){let r=s.pos-(l-4);for(;s.pos>r;)n=v(e,t,n)}
t[--n]=i,t[--n]=a-e,t[--n]=o-e,t[--n]=r}else-3==l?c=r:-4==l&&(u=r);return n}
let b=[],y=[];for(;s.pos>0;)d(e.start||0,e.bufferStart||0,b,y,-1,0)
;let O=null!==(t=e.length)&&void 0!==t?t:b.length?y[0]+b[0].length:0
;return new Lpe(l[e.topID],b.reverse(),y.reverse(),O)}(e)}}
Lpe.empty=new Lpe(Ppe.none,[],[],0);class Bpe{constructor(e,t){
this.buffer=e,this.index=t}get id(){return this.buffer[this.index-4]}
get start(){return this.buffer[this.index-3]}get end(){
return this.buffer[this.index-2]}get size(){return this.buffer[this.index-1]}
get pos(){return this.index}next(){this.index-=4}fork(){
return new Bpe(this.buffer,this.index)}}class jpe{constructor(e,t,n){
this.buffer=e,this.length=t,this.set=n}get type(){return Ppe.none}toString(){
let e=[]
;for(let t=0;t<this.buffer.length;)e.push(this.childString(t)),t=this.buffer[t+3]
;return e.join(",")}childString(e){
let t=this.buffer[e],n=this.buffer[e+3],r=this.set.types[t],o=r.name
;if(/\W/.test(o)&&!r.isError&&(o=JSON.stringify(o)),n==(e+=4))return o;let a=[]
;for(;e<n;)a.push(this.childString(e)),e=this.buffer[e+3]
;return o+"("+a.join(",")+")"}findChild(e,t,n,r,o){let{buffer:a}=this,i=-1
;for(let s=e;s!=t&&!(Upe(o,r,a[s+1],a[s+2])&&(i=s,n>0));s=a[s+3]);return i}
slice(e,t,n){let r=this.buffer,o=new Uint16Array(t-e),a=0;for(let i=e,s=0;i<t;){
o[s++]=r[i++],o[s++]=r[i++]-n;let t=o[s++]=r[i++]-n
;o[s++]=r[i++]-e,a=Math.max(a,t)}return new jpe(o,a,this.set)}}
function Upe(e,t,n,r){switch(e){case-2:return n<t;case-1:return r>=t&&n<t
;case 0:return n<t&&r>t;case 1:return n<=t&&r>t;case 2:return r>t;case 4:
return!0}}function zpe(e,t,n,r){
for(var o;e.from==e.to||(n<1?e.from>=t:e.from>t)||(n>-1?e.to<=t:e.to<t);){
let t=!r&&e instanceof Zpe&&e.index<0?null:e.parent;if(!t)return e;e=t}
let a=r?0:Npe.IgnoreOverlays
;if(r)for(let i=e,s=i.parent;s;i=s,s=i.parent)i instanceof Zpe&&i.index<0&&(null===(o=s.enter(t,n,a))||void 0===o?void 0:o.from)!=i.from&&(e=s)
;for(;;){let r=e.enter(t,n,a);if(!r)return e;e=r}}class Fpe{cursor(e=0){
return new Gpe(this,e)}getChild(e,t=null,n=null){let r=Qpe(this,e,t,n)
;return r.length?r[0]:null}getChildren(e,t=null,n=null){return Qpe(this,e,t,n)}
resolve(e,t=0){return zpe(this,e,t,!1)}resolveInner(e,t=0){
return zpe(this,e,t,!0)}matchContext(e){return Hpe(this.parent,e)}
enterUnfinishedNodesBefore(e){let t=this.childBefore(e),n=this;for(;t;){
let e=t.lastChild;if(!e||e.to!=t.to)break
;e.type.isError&&e.from==e.to?(n=t,t=e.prevSibling):t=e}return n}get node(){
return this}get next(){return this.parent}}class Zpe extends Fpe{
constructor(e,t,n,r){
super(),this._tree=e,this.from=t,this.index=n,this._parent=r}get type(){
return this._tree.type}get name(){return this._tree.type.name}get to(){
return this.from+this._tree.length}nextChild(e,t,n,r,o=0){for(let a=this;;){
for(let{children:i,positions:s}=a._tree,l=t>0?i.length:-1;e!=l;e+=t){
let l=i[e],c=s[e]+a.from;if(Upe(r,n,c,c+l.length))if(l instanceof jpe){
if(o&Npe.ExcludeBuffers)continue;let i=l.findChild(0,l.buffer.length,t,n-c,r)
;if(i>-1)return new qpe(new Vpe(a,l,e,c),null,i)
}else if(o&Npe.IncludeAnonymous||!l.type.isAnonymous||Ype(l)){let i
;if(!(o&Npe.IgnoreMounts)&&(i=Cpe.get(l))&&!i.overlay)return new Zpe(i.tree,c,e,a)
;let s=new Zpe(l,c,e,a)
;return o&Npe.IncludeAnonymous||!s.type.isAnonymous?s:s.nextChild(t<0?l.children.length-1:0,t,n,r)
}}if(o&Npe.IncludeAnonymous||!a.type.isAnonymous)return null
;if(e=a.index>=0?a.index+t:t<0?-1:a._parent._tree.children.length,
a=a._parent,!a)return null}}get firstChild(){return this.nextChild(0,1,0,4)}
get lastChild(){return this.nextChild(this._tree.children.length-1,-1,0,4)}
childAfter(e){return this.nextChild(0,1,e,2)}childBefore(e){
return this.nextChild(this._tree.children.length-1,-1,e,-2)}enter(e,t,n=0){let r
;if(!(n&Npe.IgnoreOverlays)&&(r=Cpe.get(this._tree))&&r.overlay){
let n=e-this.from
;for(let{from:e,to:o}of r.overlay)if((t>0?e<=n:e<n)&&(t<0?o>=n:o>n))return new Zpe(r.tree,r.overlay[0].from+this.from,-1,this)
}return this.nextChild(0,1,e,t,n)}nextSignificantParent(){let e=this
;for(;e.type.isAnonymous&&e._parent;)e=e._parent;return e}get parent(){
return this._parent?this._parent.nextSignificantParent():null}get nextSibling(){
return this._parent&&this.index>=0?this._parent.nextChild(this.index+1,1,0,4):null
}get prevSibling(){
return this._parent&&this.index>=0?this._parent.nextChild(this.index-1,-1,0,4):null
}get tree(){return this._tree}toTree(){return this._tree}toString(){
return this._tree.toString()}}function Qpe(e,t,n,r){let o=e.cursor(),a=[]
;if(!o.firstChild())return a
;if(null!=n)for(let i=!1;!i;)if(i=o.type.is(n),!o.nextSibling())return a
;for(;;){if(null!=r&&o.type.is(r))return a
;if(o.type.is(t)&&a.push(o.node),!o.nextSibling())return null==r?a:[]}}
function Hpe(e,t,n=t.length-1){for(let r=e;n>=0;r=r.parent){if(!r)return!1
;if(!r.type.isAnonymous){if(t[n]&&t[n]!=r.name)return!1;n--}}return!0}class Vpe{
constructor(e,t,n,r){this.parent=e,this.buffer=t,this.index=n,this.start=r}}
class qpe extends Fpe{get name(){return this.type.name}get from(){
return this.context.start+this.context.buffer.buffer[this.index+1]}get to(){
return this.context.start+this.context.buffer.buffer[this.index+2]}
constructor(e,t,n){
super(),this.context=e,this._parent=t,this.index=n,this.type=e.buffer.set.types[e.buffer.buffer[n]]
}child(e,t,n){
let{buffer:r}=this.context,o=r.findChild(this.index+4,r.buffer[this.index+3],e,t-this.context.start,n)
;return o<0?null:new qpe(this.context,this,o)}get firstChild(){
return this.child(1,0,4)}get lastChild(){return this.child(-1,0,4)}
childAfter(e){return this.child(1,e,2)}childBefore(e){return this.child(-1,e,-2)
}enter(e,t,n=0){if(n&Npe.ExcludeBuffers)return null
;let{buffer:r}=this.context,o=r.findChild(this.index+4,r.buffer[this.index+3],t>0?1:-1,e-this.context.start,t)
;return o<0?null:new qpe(this.context,this,o)}get parent(){
return this._parent||this.context.parent.nextSignificantParent()}
externalSibling(e){
return this._parent?null:this.context.parent.nextChild(this.context.index+e,e,0,4)
}get nextSibling(){let{buffer:e}=this.context,t=e.buffer[this.index+3]
;return t<(this._parent?e.buffer[this._parent.index+3]:e.buffer.length)?new qpe(this.context,this._parent,t):this.externalSibling(1)
}get prevSibling(){
let{buffer:e}=this.context,t=this._parent?this._parent.index+4:0
;return this.index==t?this.externalSibling(-1):new qpe(this.context,this._parent,e.findChild(t,this.index,-1,0,4))
}get tree(){return null}toTree(){
let e=[],t=[],{buffer:n}=this.context,r=this.index+4,o=n.buffer[this.index+3]
;if(o>r){let a=n.buffer[this.index+1];e.push(n.slice(r,o,a)),t.push(0)}
return new Lpe(this.type,e,t,this.to-this.from)}toString(){
return this.context.buffer.childString(this.index)}}function Wpe(e){
if(!e.length)return null;let t=0,n=e[0];for(let a=1;a<e.length;a++){let r=e[a]
;(r.from>n.from||r.to<n.to)&&(n=r,t=a)}
let r=n instanceof Zpe&&n.index<0?null:n.parent,o=e.slice()
;return r?o[t]=r:o.splice(t,1),new Xpe(o,n)}class Xpe{constructor(e,t){
this.heads=e,this.node=t}get next(){return Wpe(this.heads)}}class Gpe{
get name(){return this.type.name}constructor(e,t=0){
if(this.mode=t,this.buffer=null,this.stack=[],this.index=0,this.bufferNode=null,
e instanceof Zpe)this.yieldNode(e);else{
this._tree=e.context.parent,this.buffer=e.context
;for(let t=e._parent;t;t=t._parent)this.stack.unshift(t.index)
;this.bufferNode=e,this.yieldBuf(e.index)}}yieldNode(e){
return!!e&&(this._tree=e,this.type=e.type,this.from=e.from,this.to=e.to,!0)}
yieldBuf(e,t){this.index=e;let{start:n,buffer:r}=this.buffer
;return this.type=t||r.set.types[r.buffer[e]],
this.from=n+r.buffer[e+1],this.to=n+r.buffer[e+2],!0}yield(e){
return!!e&&(e instanceof Zpe?(this.buffer=null,
this.yieldNode(e)):(this.buffer=e.context,this.yieldBuf(e.index,e.type)))}
toString(){
return this.buffer?this.buffer.buffer.childString(this.index):this._tree.toString()
}enterChild(e,t,n){
if(!this.buffer)return this.yield(this._tree.nextChild(e<0?this._tree._tree.children.length-1:0,e,t,n,this.mode))
;let{buffer:r}=this.buffer,o=r.findChild(this.index+4,r.buffer[this.index+3],e,t-this.buffer.start,n)
;return!(o<0)&&(this.stack.push(this.index),this.yieldBuf(o))}firstChild(){
return this.enterChild(1,0,4)}lastChild(){return this.enterChild(-1,0,4)}
childAfter(e){return this.enterChild(1,e,2)}childBefore(e){
return this.enterChild(-1,e,-2)}enter(e,t,n=this.mode){
return this.buffer?!(n&Npe.ExcludeBuffers)&&this.enterChild(1,e,t):this.yield(this._tree.enter(e,t,n))
}parent(){
if(!this.buffer)return this.yieldNode(this.mode&Npe.IncludeAnonymous?this._tree._parent:this._tree.parent)
;if(this.stack.length)return this.yieldBuf(this.stack.pop())
;let e=this.mode&Npe.IncludeAnonymous?this.buffer.parent:this.buffer.parent.nextSignificantParent()
;return this.buffer=null,this.yieldNode(e)}sibling(e){
if(!this.buffer)return!!this._tree._parent&&this.yield(this._tree.index<0?null:this._tree._parent.nextChild(this._tree.index+e,e,0,4,this.mode))
;let{buffer:t}=this.buffer,n=this.stack.length-1;if(e<0){
let e=n<0?0:this.stack[n]+4
;if(this.index!=e)return this.yieldBuf(t.findChild(e,this.index,-1,0,4))}else{
let e=t.buffer[this.index+3]
;if(e<(n<0?t.buffer.length:t.buffer[this.stack[n]+3]))return this.yieldBuf(e)}
return n<0&&this.yield(this.buffer.parent.nextChild(this.buffer.index+e,e,0,4,this.mode))
}nextSibling(){return this.sibling(1)}prevSibling(){return this.sibling(-1)}
atLastNode(e){let t,n,{buffer:r}=this;if(r){if(e>0){
if(this.index<r.buffer.buffer.length)return!1
}else for(let e=0;e<this.index;e++)if(r.buffer.buffer[e+3]<this.index)return!1
;({index:t,parent:n}=r)}else({index:t,_parent:n}=this._tree)
;for(;n;({index:t,_parent:n}=n))if(t>-1)for(let r=t+e,o=e<0?-1:n._tree.children.length;r!=o;r+=e){
let e=n._tree.children[r]
;if(this.mode&Npe.IncludeAnonymous||e instanceof jpe||!e.type.isAnonymous||Ype(e))return!1
}return!0}move(e,t){if(t&&this.enterChild(e,0,4))return!0;for(;;){
if(this.sibling(e))return!0;if(this.atLastNode(e)||!this.parent())return!1}}
next(e=!0){return this.move(1,e)}prev(e=!0){return this.move(-1,e)}
moveTo(e,t=0){
for(;(this.from==this.to||(t<1?this.from>=e:this.from>e)||(t>-1?this.to<=e:this.to<e))&&this.parent(););
for(;this.enterChild(1,e,t););return this}get node(){
if(!this.buffer)return this._tree;let e=this.bufferNode,t=null,n=0
;if(e&&e.context==this.buffer)e:for(let r=this.index,o=this.stack.length;o>=0;){
for(let a=e;a;a=a._parent)if(a.index==r){if(r==this.index)return a;t=a,n=o+1
;break e}r=this.stack[--o]}
for(let r=n;r<this.stack.length;r++)t=new qpe(this.buffer,t,this.stack[r])
;return this.bufferNode=new qpe(this.buffer,t,this.index)}get tree(){
return this.buffer?null:this._tree._tree}iterate(e,t){for(let n=0;;){let r=!1
;if(this.type.isAnonymous||!1!==e(this)){if(this.firstChild()){n++;continue}
this.type.isAnonymous||(r=!0)}for(;;){
if(r&&t&&t(this),r=this.type.isAnonymous,!n)return;if(this.nextSibling())break
;this.parent(),n--,r=!0}}}matchContext(e){
if(!this.buffer)return Hpe(this.node.parent,e)
;let{buffer:t}=this.buffer,{types:n}=t.set
;for(let r=e.length-1,o=this.stack.length-1;r>=0;o--){
if(o<0)return Hpe(this._tree,e,r);let a=n[t.buffer[this.stack[o]]]
;if(!a.isAnonymous){if(e[r]&&e[r]!=a.name)return!1;r--}}return!0}}
function Ype(e){
return e.children.some((e=>e instanceof jpe||!e.type.isAnonymous||Ype(e)))}
const Kpe=new WeakMap;function Jpe(e,t){
if(!e.isAnonymous||t instanceof jpe||t.type!=e)return 1;let n=Kpe.get(t)
;if(null==n){n=1;for(let r of t.children){if(r.type!=e||!(r instanceof Lpe)){n=1
;break}n+=Jpe(e,r)}Kpe.set(t,n)}return n}function ehe(e,t,n,r,o,a,i,s,l){let c=0
;for(let h=r;h<o;h++)c+=Jpe(e,t[h]);let u=Math.ceil(1.5*c/8),d=[],p=[]
;return function t(n,r,o,i,s){for(let c=o;c<i;){let o=c,h=r[c],f=Jpe(e,n[c])
;for(c++;c<i;c++){let t=Jpe(e,n[c]);if(f+t>=u)break;f+=t}if(c==o+1){if(f>u){
let e=n[o];t(e.children,e.positions,0,e.children.length,r[o]+s);continue}
d.push(n[o])}else{let t=r[c-1]+n[c-1].length-h;d.push(ehe(e,n,r,o,c,h,t,null,l))
}p.push(h+s-a)}}(t,n,r,o,0),(s||l)(d,p,i)}class the{constructor(){
this.map=new WeakMap}setBuffer(e,t,n){let r=this.map.get(e)
;r||this.map.set(e,r=new Map),r.set(t,n)}getBuffer(e,t){let n=this.map.get(e)
;return n&&n.get(t)}set(e,t){
e instanceof qpe?this.setBuffer(e.context.buffer,e.index,t):e instanceof Zpe&&this.map.set(e.tree,t)
}get(e){
return e instanceof qpe?this.getBuffer(e.context.buffer,e.index):e instanceof Zpe?this.map.get(e.tree):void 0
}cursorSet(e,t){
e.buffer?this.setBuffer(e.buffer.buffer,e.index,t):this.map.set(e.tree,t)}
cursorGet(e){
return e.buffer?this.getBuffer(e.buffer.buffer,e.index):this.map.get(e.tree)}}
class nhe{constructor(e,t,n,r,o=!1,a=!1){
this.from=e,this.to=t,this.tree=n,this.offset=r,this.open=(o?1:0)|(a?2:0)}
get openStart(){return(1&this.open)>0}get openEnd(){return(2&this.open)>0}
static addTree(e,t=[],n=!1){let r=[new nhe(0,e.length,e,0,!1,n)]
;for(let o of t)o.to>e.length&&r.push(o);return r}
static applyChanges(e,t,n=128){if(!t.length)return e
;let r=[],o=1,a=e.length?e[0]:null;for(let i=0,s=0,l=0;;i++){
let c=i<t.length?t[i]:null,u=c?c.fromA:1e9;if(u-s>=n)for(;a&&a.from<u;){let t=a
;if(s>=t.from||u<=t.to||l){let e=Math.max(t.from,s)-l,n=Math.min(t.to,u)-l
;t=e>=n?null:new nhe(e,n,t.tree,t.offset+l,i>0,!!c)}if(t&&r.push(t),a.to>u)break
;a=o<e.length?e[o++]:null}if(!c)break;s=c.toA,l=c.toA-c.toB}return r}}class rhe{
startParse(e,t,n){
return"string"==typeof e&&(e=new ohe(e)),n=n?n.length?n.map((e=>new Epe(e.from,e.to))):[new Epe(0,0)]:[new Epe(0,e.length)],
this.createParse(e,t||[],n)}parse(e,t,n){let r=this.startParse(e,t,n);for(;;){
let e=r.advance();if(e)return e}}}class ohe{constructor(e){this.string=e}
get length(){return this.string.length}chunk(e){return this.string.slice(e)}
get lineChunks(){return!1}read(e,t){return this.string.slice(e,t)}}class ahe{
constructor(e,t,n,r,o){
this.parser=e,this.parse=t,this.overlay=n,this.target=r,this.from=o}}
function ihe(e){
if(!e.length||e.some((e=>e.from>=e.to)))throw new RangeError("Invalid inner parse ranges given: "+JSON.stringify(e))
}class she{constructor(e,t,n,r,o,a,i){
this.parser=e,this.predicate=t,this.mounts=n,
this.index=r,this.start=o,this.target=a,this.prev=i,this.depth=0,this.ranges=[]}
}const lhe=new Ape({perNode:!0});class che{constructor(e,t,n,r,o){
this.nest=t,this.input=n,
this.fragments=r,this.ranges=o,this.inner=[],this.innerDone=0,
this.baseTree=null,this.stoppedAt=null,this.baseParse=e}advance(){
if(this.baseParse){let e=this.baseParse.advance();if(!e)return null
;if(this.baseParse=null,
this.baseTree=e,this.startInner(),null!=this.stoppedAt)for(let t of this.inner)t.parse.stopAt(this.stoppedAt)
}if(this.innerDone==this.inner.length){let e=this.baseTree
;return null!=this.stoppedAt&&(e=new Lpe(e.type,e.children,e.positions,e.length,e.propValues.concat([[lhe,this.stoppedAt]]))),
e}let e=this.inner[this.innerDone],t=e.parse.advance();if(t){this.innerDone++
;let n=Object.assign(Object.create(null),e.target.props)
;n[Ape.mounted.id]=new Cpe(t,e.overlay,e.parser),e.target.props=n}return null}
get parsedPos(){if(this.baseParse)return 0;let e=this.input.length
;for(let t=this.innerDone;t<this.inner.length;t++)this.inner[t].from<e&&(e=Math.min(e,this.inner[t].parse.parsedPos))
;return e}stopAt(e){
if(this.stoppedAt=e,this.baseParse)this.baseParse.stopAt(e);else for(let t=this.innerDone;t<this.inner.length;t++)this.inner[t].parse.stopAt(e)
}startInner(){
let e=new fhe(this.fragments),t=null,n=null,r=new Gpe(new Zpe(this.baseTree,this.ranges[0].from,0,null),Npe.IncludeAnonymous|Npe.IgnoreMounts)
;e:for(let o,a;;){let i,s=!0
;if(null!=this.stoppedAt&&r.from>=this.stoppedAt)s=!1;else if(e.hasNode(r)){
if(t){
let e=t.mounts.find((e=>e.frag.from<=r.from&&e.frag.to>=r.to&&e.mount.overlay))
;if(e)for(let n of e.mount.overlay){let o=n.from+e.pos,a=n.to+e.pos
;o>=r.from&&a<=r.to&&!t.ranges.some((e=>e.from<a&&e.to>o))&&t.ranges.push({
from:o,to:a})}}s=!1
}else if(n&&(a=uhe(n.ranges,r.from,r.to)))s=2!=a;else if(!r.type.isAnonymous&&(o=this.nest(r,this.input))&&(r.from<r.to||!o.overlay)){
r.tree||phe(r);let a=e.findMounts(r.from,o.parser)
;if("function"==typeof o.overlay)t=new she(o.parser,o.overlay,a,this.inner.length,r.from,r.tree,t);else{
let e=mhe(this.ranges,o.overlay||(r.from<r.to?[new Epe(r.from,r.to)]:[]))
;e.length&&ihe(e),
!e.length&&o.overlay||this.inner.push(new ahe(o.parser,e.length?o.parser.startParse(this.input,vhe(a,e),e):o.parser.startParse(""),o.overlay?o.overlay.map((e=>new Epe(e.from-r.from,e.to-r.from))):null,r.tree,e.length?e[0].from:r.from)),
o.overlay?e.length&&(n={ranges:e,depth:0,prev:n}):s=!1}
}else if(t&&(i=t.predicate(r))&&(!0===i&&(i=new Epe(r.from,r.to)),i.from<i.to)){
let e=t.ranges.length-1;e>=0&&t.ranges[e].to==i.from?t.ranges[e]={
from:t.ranges[e].from,to:i.to}:t.ranges.push(i)}
if(s&&r.firstChild())t&&t.depth++,n&&n.depth++;else for(;!r.nextSibling();){
if(!r.parent())break e;if(t&&! --t.depth){let e=mhe(this.ranges,t.ranges)
;e.length&&(ihe(e),
this.inner.splice(t.index,0,new ahe(t.parser,t.parser.startParse(this.input,vhe(t.mounts,e),e),t.ranges.map((e=>new Epe(e.from-t.start,e.to-t.start))),t.target,e[0].from))),
t=t.prev}n&&! --n.depth&&(n=n.prev)}}}}function uhe(e,t,n){for(let r of e){
if(r.from>=n)break;if(r.to>t)return r.from<=t&&r.to>=n?2:1}return 0}
function dhe(e,t,n,r,o,a){if(t<n){let i=e.buffer[t+1]
;r.push(e.slice(t,n,i)),o.push(i-a)}}function phe(e){
let{node:t}=e,n=[],r=t.context.buffer;do{n.push(e.index),e.parent()
}while(!e.tree)
;let o=e.tree,a=o.children.indexOf(r),i=o.children[a],s=i.buffer,l=[a]
;o.children[a]=function e(r,o,a,c,u,d){let p=n[d],h=[],f=[];dhe(i,r,p,h,f,c)
;let m=s[p+1],g=s[p+2];l.push(h.length)
;let v=d?e(p+4,s[p+3],i.set.types[s[p]],m,g-m,d-1):t.toTree()
;return h.push(v),f.push(m-c),dhe(i,s[p+3],o,h,f,c),new Lpe(a,h,f,u)
}(0,s.length,Ppe.none,0,i.length,n.length-1);for(let c of l){
let t=e.tree.children[c],n=e.tree.positions[c]
;e.yield(new Zpe(t,n+e.from,c,e._tree))}}class hhe{constructor(e,t){
this.offset=t,
this.done=!1,this.cursor=e.cursor(Npe.IncludeAnonymous|Npe.IgnoreMounts)}
moveTo(e){let{cursor:t}=this,n=e-this.offset
;for(;!this.done&&t.from<n;)t.to>=e&&t.enter(n,1,Npe.IgnoreOverlays|Npe.ExcludeBuffers)||t.next(!1)||(this.done=!0)
}hasNode(e){
if(this.moveTo(e.from),!this.done&&this.cursor.from+this.offset==e.from&&this.cursor.tree)for(let t=this.cursor.tree;;){
if(t==e.tree)return!0
;if(!(t.children.length&&0==t.positions[0]&&t.children[0]instanceof Lpe))break
;t=t.children[0]}return!1}}let fhe=class{constructor(e){var t
;if(this.fragments=e,this.curTo=0,this.fragI=0,e.length){let n=this.curFrag=e[0]
;this.curTo=null!==(t=n.tree.prop(lhe))&&void 0!==t?t:n.to,
this.inner=new hhe(n.tree,-n.offset)}else this.curFrag=this.inner=null}
hasNode(e){for(;this.curFrag&&e.from>=this.curTo;)this.nextFrag()
;return this.curFrag&&this.curFrag.from<=e.from&&this.curTo>=e.to&&this.inner.hasNode(e)
}nextFrag(){var e
;if(this.fragI++,this.fragI==this.fragments.length)this.curFrag=this.inner=null;else{
let t=this.curFrag=this.fragments[this.fragI]
;this.curTo=null!==(e=t.tree.prop(lhe))&&void 0!==e?e:t.to,
this.inner=new hhe(t.tree,-t.offset)}}findMounts(e,t){var n;let r=[]
;if(this.inner){this.inner.cursor.moveTo(e,1)
;for(let e=this.inner.cursor.node;e;e=e.parent){
let o=null===(n=e.tree)||void 0===n?void 0:n.prop(Ape.mounted)
;if(o&&o.parser==t)for(let t=this.fragI;t<this.fragments.length;t++){
let n=this.fragments[t];if(n.from>=e.to)break
;n.tree==this.curFrag.tree&&r.push({frag:n,pos:e.from-n.offset,mount:o})}}}
return r}};function mhe(e,t){let n=null,r=t;for(let o=1,a=0;o<e.length;o++){
let i=e[o-1].to,s=e[o].from;for(;a<r.length;a++){let e=r[a];if(e.from>=s)break
;e.to<=i||(n||(r=n=t.slice()),
e.from<i?(n[a]=new Epe(e.from,i),e.to>s&&n.splice(a+1,0,new Epe(s,e.to))):e.to>s?n[a--]=new Epe(s,e.to):n.splice(a--,1))
}}return r}function ghe(e,t,n,r){let o=0,a=0,i=!1,s=!1,l=-1e9,c=[];for(;;){
let u=o==e.length?1e9:i?e[o].to:e[o].from,d=a==t.length?1e9:s?t[a].to:t[a].from
;if(i!=s){let e=Math.max(l,n),t=Math.min(u,d,r);e<t&&c.push(new Epe(e,t))}
if(l=Math.min(u,d),1e9==l)break
;u==l&&(i?(i=!1,o++):i=!0),d==l&&(s?(s=!1,a++):s=!0)}return c}function vhe(e,t){
let n=[];for(let{pos:r,mount:o,frag:a}of e){
let e=r+(o.overlay?o.overlay[0].from:0),i=e+o.tree.length,s=Math.max(a.from,e),l=Math.min(a.to,i)
;if(o.overlay){let i=o.overlay.map((e=>new Epe(e.from+r,e.to+r))),c=ghe(t,i,s,l)
;for(let t=0,r=s;;t++){let i=t==c.length,s=i?l:c[t].from
;if(s>r&&n.push(new nhe(r,s,o.tree,-e,a.from>=r||a.openStart,a.to<=s||a.openEnd)),
i)break;r=c[t].to}
}else n.push(new nhe(s,l,o.tree,-e,a.from>=e||a.openStart,a.to<=i||a.openEnd))}
return n}let bhe=0,yhe=class e{constructor(e,t,n,r){
this.name=e,this.set=t,this.base=n,this.modified=r,this.id=bhe++}toString(){
let{name:e}=this;for(let t of this.modified)t.name&&(e=`${t.name}(${e})`)
;return e}static define(t,n){let r="string"==typeof t?t:"?"
;if(t instanceof e&&(n=t),
null==n?void 0:n.base)throw new Error("Can not derive from a modified tag")
;let o=new e(r,[],null,[]);if(o.set.push(o),n)for(let e of n.set)o.set.push(e)
;return o}static defineModifier(e){let t=new whe(e)
;return e=>e.modified.indexOf(t)>-1?e:whe.get(e.base||e,e.modified.concat(t).sort(((e,t)=>e.id-t.id)))
}},Ohe=0;class whe{constructor(e){this.name=e,this.instances=[],this.id=Ohe++}
static get(e,t){if(!t.length)return e;let n=t[0].instances.find((n=>{
return n.base==e&&(r=t,
o=n.modified,r.length==o.length&&r.every(((e,t)=>e==o[t])));var r,o}))
;if(n)return n;let r=[],o=new yhe(e.name,r,e,t)
;for(let i of t)i.instances.push(o);let a=function(e){let t=[[]]
;for(let n=0;n<e.length;n++)for(let r=0,o=t.length;r<o;r++)t.push(t[r].concat(e[n]))
;return t.sort(((e,t)=>t.length-e.length))}(t)
;for(let i of e.set)if(!i.modified.length)for(let e of a)r.push(whe.get(i,e))
;return o}}function xhe(e){let t=Object.create(null);for(let n in e){let r=e[n]
;Array.isArray(r)||(r=[r]);for(let e of n.split(" "))if(e){let n=[],o=2,a=e
;for(let t=0;;){if("..."==a&&t>0&&t+3==e.length){o=1;break}
let r=/^"(?:[^"\\]|\\.)*?"|[^\/!]+/.exec(a)
;if(!r)throw new RangeError("Invalid path: "+e)
;if(n.push("*"==r[0]?"":'"'==r[0][0]?JSON.parse(r[0]):r[0]),
t+=r[0].length,t==e.length)break;let i=e[t++];if(t==e.length&&"!"==i){o=0;break}
if("/"!=i)throw new RangeError("Invalid path: "+e);a=e.slice(t)}
let i=n.length-1,s=n[i];if(!s)throw new RangeError("Invalid path: "+e)
;let l=new She(r,o,i>0?n.slice(0,i):null);t[s]=l.sort(t[s])}}return khe.add(t)}
const khe=new Ape;class She{constructor(e,t,n,r){
this.tags=e,this.mode=t,this.context=n,this.next=r}get opaque(){
return 0==this.mode}get inherit(){return 1==this.mode}sort(e){
return!e||e.depth<this.depth?(this.next=e,this):(e.next=this.sort(e.next),e)}
get depth(){return this.context?this.context.length:0}}function _he(e,t){
let n=Object.create(null)
;for(let a of e)if(Array.isArray(a.tag))for(let e of a.tag)n[e.id]=a.class;else n[a.tag.id]=a.class
;let{scope:r,all:o=null}=t||{};return{style:e=>{let t=o
;for(let r of e)for(let e of r.set){let r=n[e.id];if(r){t=t?t+" "+r:r;break}}
return t},scope:r}}function The(e,t,n,r=0,o=e.length){
let a=new Ehe(r,Array.isArray(t)?t:[t],n)
;a.highlightRange(e.cursor(),r,o,"",a.highlighters),a.flush(o)}
She.empty=new She([],2,null);class Ehe{constructor(e,t,n){
this.at=e,this.highlighters=t,this.span=n,this.class=""}startSpan(e,t){
t!=this.class&&(this.flush(e),e>this.at&&(this.at=e),this.class=t)}flush(e){
e>this.at&&this.class&&this.span(this.at,e,this.class)}
highlightRange(e,t,n,r,o){let{type:a,from:i,to:s}=e;if(i>=n||s<=t)return
;a.isTop&&(o=this.highlighters.filter((e=>!e.scope||e.scope(a))))
;let l=r,c=function(e){let t=e.type.prop(khe)
;for(;t&&t.context&&!e.matchContext(t.context);)t=t.next;return t||null
}(e)||She.empty,u=function(e,t){let n=null;for(let r of e){let e=r.style(t)
;e&&(n=n?n+" "+e:e)}return n}(o,c.tags)
;if(u&&(l&&(l+=" "),l+=u,1==c.mode&&(r+=(r?" ":"")+u)),
this.startSpan(Math.max(t,i),l),c.opaque)return
;let d=e.tree&&e.tree.prop(Ape.mounted);if(d&&d.overlay){
let a=e.node.enter(d.overlay[0].from+i,1),c=this.highlighters.filter((e=>!e.scope||e.scope(d.tree.type))),u=e.firstChild()
;for(let p=0,h=i;;p++){
let f=p<d.overlay.length?d.overlay[p]:null,m=f?f.from+i:s,g=Math.max(t,h),v=Math.min(n,m)
;if(g<v&&u)for(;e.from<v&&(this.highlightRange(e,g,v,r,o),
this.startSpan(Math.min(v,e.to),l),!(e.to>=m)&&e.nextSibling()););
if(!f||m>n)break
;h=f.to+i,h>t&&(this.highlightRange(a.cursor(),Math.max(t,f.from+i),Math.min(n,h),"",c),
this.startSpan(Math.min(n,h),l))}u&&e.parent()}else if(e.firstChild()){d&&(r="")
;do{if(!(e.to<=t)){if(e.from>=n)break
;this.highlightRange(e,t,n,r,o),this.startSpan(Math.min(n,e.to),l)}
}while(e.nextSibling());e.parent()}}}
const Ahe=yhe.define,Che=Ahe(),$he=Ahe(),Phe=Ahe($he),Dhe=Ahe($he),Ihe=Ahe(),Mhe=Ahe(Ihe),Nhe=Ahe(Ihe),Rhe=Ahe(),Lhe=Ahe(Rhe),Bhe=Ahe(),jhe=Ahe(),Uhe=Ahe(),zhe=Ahe(Uhe),Fhe=Ahe(),Zhe={
comment:Che,lineComment:Ahe(Che),blockComment:Ahe(Che),docComment:Ahe(Che),
name:$he,variableName:Ahe($he),typeName:Phe,tagName:Ahe(Phe),propertyName:Dhe,
attributeName:Ahe(Dhe),className:Ahe($he),labelName:Ahe($he),namespace:Ahe($he),
macroName:Ahe($he),literal:Ihe,string:Mhe,docString:Ahe(Mhe),character:Ahe(Mhe),
attributeValue:Ahe(Mhe),number:Nhe,integer:Ahe(Nhe),float:Ahe(Nhe),
bool:Ahe(Ihe),regexp:Ahe(Ihe),escape:Ahe(Ihe),color:Ahe(Ihe),url:Ahe(Ihe),
keyword:Bhe,self:Ahe(Bhe),null:Ahe(Bhe),atom:Ahe(Bhe),unit:Ahe(Bhe),
modifier:Ahe(Bhe),operatorKeyword:Ahe(Bhe),controlKeyword:Ahe(Bhe),
definitionKeyword:Ahe(Bhe),moduleKeyword:Ahe(Bhe),operator:jhe,
derefOperator:Ahe(jhe),arithmeticOperator:Ahe(jhe),logicOperator:Ahe(jhe),
bitwiseOperator:Ahe(jhe),compareOperator:Ahe(jhe),updateOperator:Ahe(jhe),
definitionOperator:Ahe(jhe),typeOperator:Ahe(jhe),controlOperator:Ahe(jhe),
punctuation:Uhe,separator:Ahe(Uhe),bracket:zhe,angleBracket:Ahe(zhe),
squareBracket:Ahe(zhe),paren:Ahe(zhe),brace:Ahe(zhe),content:Rhe,heading:Lhe,
heading1:Ahe(Lhe),heading2:Ahe(Lhe),heading3:Ahe(Lhe),heading4:Ahe(Lhe),
heading5:Ahe(Lhe),heading6:Ahe(Lhe),contentSeparator:Ahe(Rhe),list:Ahe(Rhe),
quote:Ahe(Rhe),emphasis:Ahe(Rhe),strong:Ahe(Rhe),link:Ahe(Rhe),
monospace:Ahe(Rhe),strikethrough:Ahe(Rhe),inserted:Ahe(),deleted:Ahe(),
changed:Ahe(),invalid:Ahe(),meta:Fhe,documentMeta:Ahe(Fhe),annotation:Ahe(Fhe),
processingInstruction:Ahe(Fhe),definition:yhe.defineModifier("definition"),
constant:yhe.defineModifier("constant"),function:yhe.defineModifier("function"),
standard:yhe.defineModifier("standard"),local:yhe.defineModifier("local"),
special:yhe.defineModifier("special")};for(let v5e in Zhe){let e=Zhe[v5e]
;e instanceof yhe&&(e.name=v5e)}var Qhe;_he([{tag:Zhe.link,class:"tok-link"},{
tag:Zhe.heading,class:"tok-heading"},{tag:Zhe.emphasis,class:"tok-emphasis"},{
tag:Zhe.strong,class:"tok-strong"},{tag:Zhe.keyword,class:"tok-keyword"},{
tag:Zhe.atom,class:"tok-atom"},{tag:Zhe.bool,class:"tok-bool"},{tag:Zhe.url,
class:"tok-url"},{tag:Zhe.labelName,class:"tok-labelName"},{tag:Zhe.inserted,
class:"tok-inserted"},{tag:Zhe.deleted,class:"tok-deleted"},{tag:Zhe.literal,
class:"tok-literal"},{tag:Zhe.string,class:"tok-string"},{tag:Zhe.number,
class:"tok-number"},{tag:[Zhe.regexp,Zhe.escape,Zhe.special(Zhe.string)],
class:"tok-string2"},{tag:Zhe.variableName,class:"tok-variableName"},{
tag:Zhe.local(Zhe.variableName),class:"tok-variableName tok-local"},{
tag:Zhe.definition(Zhe.variableName),class:"tok-variableName tok-definition"},{
tag:Zhe.special(Zhe.variableName),class:"tok-variableName2"},{
tag:Zhe.definition(Zhe.propertyName),class:"tok-propertyName tok-definition"},{
tag:Zhe.typeName,class:"tok-typeName"},{tag:Zhe.namespace,class:"tok-namespace"
},{tag:Zhe.className,class:"tok-className"},{tag:Zhe.macroName,
class:"tok-macroName"},{tag:Zhe.propertyName,class:"tok-propertyName"},{
tag:Zhe.operator,class:"tok-operator"},{tag:Zhe.comment,class:"tok-comment"},{
tag:Zhe.meta,class:"tok-meta"},{tag:Zhe.invalid,class:"tok-invalid"},{
tag:Zhe.punctuation,class:"tok-punctuation"}]);const Hhe=new Ape
;function Vhe(e){return Xae.define({combine:e?t=>t.concat(e):void 0})}
const qhe=new Ape;class Whe{constructor(e,t,n=[],r=""){
this.data=e,this.name=r,Lie.prototype.hasOwnProperty("tree")||Object.defineProperty(Lie.prototype,"tree",{
get(){return Yhe(this)}
}),this.parser=t,this.extension=[ife.of(this),Lie.languageData.of(((e,t,n)=>{
let r=Xhe(e,t,n),o=r.type.prop(Hhe);if(!o)return[]
;let a=e.facet(o),i=r.type.prop(qhe);if(i){let o=r.resolve(t-r.from,n)
;for(let t of i)if(t.test(o,e)){let n=e.facet(t.facet)
;return"replace"==t.type?n:n.concat(a)}}return a}))].concat(n)}
isActiveAt(e,t,n=-1){return Xhe(e,t,n).type.prop(Hhe)==this.data}findRegions(e){
let t=e.facet(ife);if((null==t?void 0:t.data)==this.data)return[{from:0,
to:e.doc.length}];if(!t||!t.allowsNesting)return[];let n=[],r=(e,t)=>{
if(e.prop(Hhe)==this.data)return void n.push({from:t,to:t+e.length})
;let o=e.prop(Ape.mounted);if(o){if(o.tree.prop(Hhe)==this.data){
if(o.overlay)for(let e of o.overlay)n.push({from:e.from+t,to:e.to+t
});else n.push({from:t,to:t+e.length});return}if(o.overlay){let e=n.length
;if(r(o.tree,o.overlay[0].from+t),n.length>e)return}}
for(let n=0;n<e.children.length;n++){let o=e.children[n]
;o instanceof Lpe&&r(o,e.positions[n]+t)}};return r(Yhe(e),0),n}
get allowsNesting(){return!0}}function Xhe(e,t,n){
let r=e.facet(ife),o=Yhe(e).topNode
;if(!r||r.allowsNesting)for(let a=o;a;a=a.enter(t,n,Npe.ExcludeBuffers))a.type.isTop&&(o=a)
;return o}Whe.setState=_ie.define();class Ghe extends Whe{constructor(e,t,n){
super(e,t,[],n),this.parser=t}static define(e){let t=Vhe(e.languageData)
;return new Ghe(t,e.parser.configure({props:[Hhe.add((e=>e.isTop?t:void 0))]
}),e.name)}configure(e,t){
return new Ghe(this.data,this.parser.configure(e),t||this.name)}
get allowsNesting(){return this.parser.hasWrappers()}}function Yhe(e){
let t=e.field(Whe.state,!1);return t?t.tree:Lpe.empty}class Khe{constructor(e){
this.doc=e,this.cursorPos=0,this.string="",this.cursor=e.iter()}get length(){
return this.doc.length}syncTo(e){
return this.string=this.cursor.next(e-this.cursorPos).value,
this.cursorPos=e+this.string.length,this.cursorPos-this.string.length}chunk(e){
return this.syncTo(e),this.string}get lineChunks(){return!0}read(e,t){
let n=this.cursorPos-this.string.length
;return e<n||t>=this.cursorPos?this.doc.sliceString(e,t):this.string.slice(e-n,t-n)
}}let Jhe=null;class efe{constructor(e,t,n=[],r,o,a,i,s){
this.parser=e,this.state=t,
this.fragments=n,this.tree=r,this.treeLen=o,this.viewport=a,
this.skipped=i,this.scheduleOn=s,this.parse=null,this.tempSkipped=[]}
static create(e,t,n){return new efe(e,t,[],Lpe.empty,0,n,[],null)}startParse(){
return this.parser.startParse(new Khe(this.state.doc),this.fragments)}work(e,t){
return null!=t&&t>=this.state.doc.length&&(t=void 0),
this.tree!=Lpe.empty&&this.isDone(null!=t?t:this.state.doc.length)?(this.takeTree(),
!0):this.withContext((()=>{var n;if("number"==typeof e){let t=Date.now()+e
;e=()=>Date.now()>t}
for(this.parse||(this.parse=this.startParse()),null!=t&&(null==this.parse.stoppedAt||this.parse.stoppedAt>t)&&t<this.state.doc.length&&this.parse.stopAt(t);;){
let r=this.parse.advance();if(r){
if(this.fragments=this.withoutTempSkipped(nhe.addTree(r,this.fragments,null!=this.parse.stoppedAt)),
this.treeLen=null!==(n=this.parse.stoppedAt)&&void 0!==n?n:this.state.doc.length,
this.tree=r,
this.parse=null,!(this.treeLen<(null!=t?t:this.state.doc.length)))return!0
;this.parse=this.startParse()}if(e())return!1}}))}takeTree(){let e,t
;this.parse&&(e=this.parse.parsedPos)>=this.treeLen&&((null==this.parse.stoppedAt||this.parse.stoppedAt>e)&&this.parse.stopAt(e),
this.withContext((()=>{for(;!(t=this.parse.advance()););
})),this.treeLen=e,this.tree=t,
this.fragments=this.withoutTempSkipped(nhe.addTree(this.tree,this.fragments,!0)),
this.parse=null)}withContext(e){let t=Jhe;Jhe=this;try{return e()}finally{Jhe=t}
}withoutTempSkipped(e){for(let t;t=this.tempSkipped.pop();)e=tfe(e,t.from,t.to)
;return e}changes(e,t){
let{fragments:n,tree:r,treeLen:o,viewport:a,skipped:i}=this
;if(this.takeTree(),!e.empty){let t=[]
;if(e.iterChangedRanges(((e,n,r,o)=>t.push({fromA:e,toA:n,fromB:r,toB:o
}))),n=nhe.applyChanges(n,t),r=Lpe.empty,o=0,a={from:e.mapPos(a.from,-1),
to:e.mapPos(a.to,1)},this.skipped.length){i=[];for(let t of this.skipped){
let n=e.mapPos(t.from,1),r=e.mapPos(t.to,-1);n<r&&i.push({from:n,to:r})}}}
return new efe(this.parser,t,n,r,o,a,i,this.scheduleOn)}updateViewport(e){
if(this.viewport.from==e.from&&this.viewport.to==e.to)return!1;this.viewport=e
;let t=this.skipped.length;for(let n=0;n<this.skipped.length;n++){
let{from:t,to:r}=this.skipped[n]
;t<e.to&&r>e.from&&(this.fragments=tfe(this.fragments,t,r),
this.skipped.splice(n--,1))}return!(this.skipped.length>=t)&&(this.reset(),!0)}
reset(){this.parse&&(this.takeTree(),this.parse=null)}skipUntilInView(e,t){
this.skipped.push({from:e,to:t})}static getSkippingParser(e){
return new class extends rhe{createParse(t,n,r){
let o=r[0].from,a=r[r.length-1].to,i={parsedPos:o,advance(){let t=Jhe;if(t){
for(let e of r)t.tempSkipped.push(e)
;e&&(t.scheduleOn=t.scheduleOn?Promise.all([t.scheduleOn,e]):e)}
return this.parsedPos=a,new Lpe(Ppe.none,[],[],a-o)},stoppedAt:null,stopAt(){}}
;return i}}}isDone(e){e=Math.min(e,this.state.doc.length);let t=this.fragments
;return this.treeLen>=e&&t.length&&0==t[0].from&&t[0].to>=e}static get(){
return Jhe}}function tfe(e,t,n){return nhe.applyChanges(e,[{fromA:t,toA:n,
fromB:t,toB:n}])}class nfe{constructor(e){this.context=e,this.tree=e.tree}
apply(e){if(!e.docChanged&&this.tree==this.context.tree)return this
;let t=this.context.changes(e.changes,e.state),n=this.context.treeLen==e.startState.doc.length?void 0:Math.max(e.changes.mapPos(this.context.treeLen),t.viewport.to)
;return t.work(20,n)||t.takeTree(),new nfe(t)}static init(e){
let t=Math.min(3e3,e.doc.length),n=efe.create(e.facet(ife).parser,e,{from:0,to:t
});return n.work(20,t)||n.takeTree(),new nfe(n)}}Whe.state=nie.define({
create:nfe.init,update(e,t){
for(let n of t.effects)if(n.is(Whe.setState))return n.value
;return t.startState.facet(ife)!=t.state.facet(ife)?nfe.init(t.state):e.apply(t)
}});let rfe=e=>{let t=setTimeout((()=>e()),500);return()=>clearTimeout(t)}
;"undefined"!=typeof requestIdleCallback&&(rfe=e=>{let t=-1,n=setTimeout((()=>{
t=requestIdleCallback(e,{timeout:400})}),100)
;return()=>t<0?clearTimeout(n):cancelIdleCallback(t)})
;const ofe="undefined"!=typeof navigator&&(null===(Qhe=navigator.scheduling)||void 0===Qhe?void 0:Qhe.isInputPending)?()=>navigator.scheduling.isInputPending():null,afe=dce.fromClass(class{
constructor(e){
this.view=e,this.working=null,this.workScheduled=0,this.chunkEnd=-1,
this.chunkBudget=-1,this.work=this.work.bind(this),this.scheduleWork()}
update(e){let t=this.view.state.field(Whe.state).context
;(t.updateViewport(e.view.viewport)||this.view.viewport.to>t.treeLen)&&this.scheduleWork(),
(e.docChanged||e.selectionSet)&&(this.view.hasFocus&&(this.chunkBudget+=50),
this.scheduleWork()),this.checkAsyncSchedule(t)}scheduleWork(){
if(this.working)return;let{state:e}=this.view,t=e.field(Whe.state)
;t.tree==t.context.tree&&t.context.isDone(e.doc.length)||(this.working=rfe(this.work))
}work(e){this.working=null;let t=Date.now()
;if(this.chunkEnd<t&&(this.chunkEnd<0||this.view.hasFocus)&&(this.chunkEnd=t+3e4,
this.chunkBudget=3e3),this.chunkBudget<=0)return
;let{state:n,viewport:{to:r}}=this.view,o=n.field(Whe.state)
;if(o.tree==o.context.tree&&o.context.isDone(r+1e5))return
;let a=Date.now()+Math.min(this.chunkBudget,100,e&&!ofe?Math.max(25,e.timeRemaining()-5):1e9),i=o.context.treeLen<r&&n.doc.length>r+1e3,s=o.context.work((()=>ofe&&ofe()||Date.now()>a),r+(i?0:1e5))
;this.chunkBudget-=Date.now()-t,(s||this.chunkBudget<=0)&&(o.context.takeTree(),
this.view.dispatch({effects:Whe.setState.of(new nfe(o.context))
})),this.chunkBudget>0&&(!s||i)&&this.scheduleWork(),
this.checkAsyncSchedule(o.context)}checkAsyncSchedule(e){
e.scheduleOn&&(this.workScheduled++,
e.scheduleOn.then((()=>this.scheduleWork())).catch((e=>sce(this.view.state,e))).then((()=>this.workScheduled--)),
e.scheduleOn=null)}destroy(){this.working&&this.working()}isWorking(){
return!!(this.working||this.workScheduled>0)}},{eventHandlers:{focus(){
this.scheduleWork()}}}),ife=Xae.define({combine:e=>e.length?e[0]:null,
enables:e=>[Whe.state,afe,cde.contentAttributes.compute([e],(t=>{
let n=t.facet(e);return n&&n.name?{"data-language":n.name}:{}}))]});class sfe{
constructor(e,t=[]){this.language=e,this.support=t,this.extension=[e,t]}}
const lfe=Xae.define(),cfe=Xae.define({combine:e=>{if(!e.length)return"  "
;let t=e[0]
;if(!t||/\S/.test(t)||Array.from(t).some((e=>e!=t[0])))throw new Error("Invalid indent unit: "+JSON.stringify(e[0]))
;return t}});function ufe(e){let t=e.facet(cfe)
;return 9==t.charCodeAt(0)?e.tabSize*t.length:t.length}function dfe(e,t){
let n="",r=e.tabSize,o=e.facet(cfe)[0];if("\t"==o){for(;t>=r;)n+="\t",t-=r;o=" "
}for(let a=0;a<t;a++)n+=o;return n}function pfe(e,t){
e instanceof Lie&&(e=new hfe(e));for(let r of e.state.facet(lfe)){let n=r(e,t)
;if(void 0!==n)return n}let n=Yhe(e.state);return n.length>=t?function(e,t,n){
let r=t.resolveStack(n),o=t.resolveInner(n,-1).resolve(n,0).enterUnfinishedNodesBefore(n)
;if(o!=r.node){let e=[];for(let t=o;t!=r.node;t=t.parent)e.push(t)
;for(let t=e.length-1;t>=0;t--)r={node:e[t],next:r}}return mfe(r,e,n)
}(e,n,t):null}class hfe{constructor(e,t={}){
this.state=e,this.options=t,this.unit=ufe(e)}lineAt(e,t=1){
let n=this.state.doc.lineAt(e),{simulateBreak:r,simulateDoubleBreak:o}=this.options
;return null!=r&&r>=n.from&&r<=n.to?o&&r==e?{text:"",from:e}:(t<0?r<e:r<=e)?{
text:n.text.slice(r-n.from),from:r}:{text:n.text.slice(0,r-n.from),from:n.from
}:n}textAfterPos(e,t=1){
if(this.options.simulateDoubleBreak&&e==this.options.simulateBreak)return""
;let{text:n,from:r}=this.lineAt(e,t)
;return n.slice(e-r,Math.min(n.length,e+100-r))}column(e,t=1){
let{text:n,from:r}=this.lineAt(e,t),o=this.countColumn(n,e-r),a=this.options.overrideIndentation?this.options.overrideIndentation(r):-1
;return a>-1&&(o+=a-this.countColumn(n,n.search(/\S|$/))),o}
countColumn(e,t=e.length){return tse(e,this.state.tabSize,t)}lineIndent(e,t=1){
let{text:n,from:r}=this.lineAt(e,t),o=this.options.overrideIndentation;if(o){
let e=o(r);if(e>-1)return e}return this.countColumn(n,n.search(/\S|$/))}
get simulatedBreak(){return this.options.simulateBreak||null}}const ffe=new Ape
;function mfe(e,t,n){for(let r=e;r;r=r.next){let e=gfe(r.node)
;if(e)return e(bfe.create(t,n,r))}return 0}function gfe(e){
let t=e.type.prop(ffe);if(t)return t;let n,r=e.firstChild
;if(r&&(n=r.type.prop(Ape.closedBy))){
let t=e.lastChild,r=t&&n.indexOf(t.name)>-1
;return e=>wfe(e,!0,1,void 0,r&&!function(e){
return e.pos==e.options.simulateBreak&&e.options.simulateDoubleBreak
}(e)?t.from:void 0)}return null==e.parent?vfe:null}function vfe(){return 0}
class bfe extends hfe{constructor(e,t,n){
super(e.state,e.options),this.base=e,this.pos=t,this.context=n}get node(){
return this.context.node}static create(e,t,n){return new bfe(e,t,n)}
get textAfter(){return this.textAfterPos(this.pos)}get baseIndent(){
return this.baseIndentFor(this.node)}baseIndentFor(e){
let t=this.state.doc.lineAt(e.from);for(;;){let n=e.resolve(t.from)
;for(;n.parent&&n.parent.from==n.from;)n=n.parent;if(yfe(n,e))break
;t=this.state.doc.lineAt(n.from)}return this.lineIndent(t.from)}continue(){
return mfe(this.context.next,this.base,this.pos)}}function yfe(e,t){
for(let n=t;n;n=n.parent)if(e==n)return!0;return!1}
function Ofe({closing:e,align:t=!0,units:n=1}){return r=>wfe(r,t,n,e)}
function wfe(e,t,n,r,o){
let a=e.textAfter,i=a.match(/^\s*/)[0].length,s=r&&a.slice(i,i+r.length)==r||o==e.pos+i,l=t?function(e){
let t=e.node,n=t.childAfter(t.from),r=t.lastChild;if(!n)return null
;let o=e.options.simulateBreak,a=e.state.doc.lineAt(n.from),i=null==o||o<=a.from?a.to:Math.min(a.to,o)
;for(let s=n.to;;){let e=t.childAfter(s);if(!e||e==r)return null
;if(!e.type.isSkipped){if(e.from>=i)return null
;let t=/^ */.exec(a.text.slice(n.to-a.from))[0].length;return{from:n.from,
to:n.to+t}}s=e.to}}(e):null
;return l?s?e.column(l.from):e.column(l.to):e.baseIndent+(s?0:e.unit*n)}
function xfe({except:e,units:t=1}={}){return n=>{let r=e&&e.test(n.textAfter)
;return n.baseIndent+(r?0:t*n.unit)}}const kfe=200
;const Sfe=Xae.define(),_fe=new Ape;function Tfe(e){
let t=e.firstChild,n=e.lastChild;return t&&t.to<n.from?{from:t.to,
to:n.type.isError?e.to:n.from}:null}function Efe(e){let t=e.lastChild
;return t&&t.to==e.to&&t.type.isError}function Afe(e,t,n){
for(let r of e.facet(Sfe)){let o=r(e,t,n);if(o)return o}return function(e,t,n){
let r=Yhe(e);if(r.length<n)return null;let o=null
;for(let a=r.resolveStack(n,1);a;a=a.next){let i=a.node
;if(i.to<=n||i.from>n)continue;if(o&&i.from<t)break;let s=i.type.prop(_fe)
;if(s&&(i.to<r.length-50||r.length==e.doc.length||!Efe(i))){let r=s(i,e)
;r&&r.from<=n&&r.from>=t&&r.to>n&&(o=r)}}return o}(e,t,n)}function Cfe(e,t){
let n=t.mapPos(e.from,1),r=t.mapPos(e.to,-1);return n>=r?void 0:{from:n,to:r}}
const $fe=_ie.define({map:Cfe}),Pfe=_ie.define({map:Cfe}),Dfe=nie.define({
create:()=>mle.none,update(e,t){e=e.map(t.changes)
;for(let n of t.effects)if(n.is($fe)&&!Mfe(e,n.value.from,n.value.to)){
let{preparePlaceholder:r}=t.state.facet(Rfe),o=r?mle.replace({
widget:new jfe(r(t.state,n.value))}):Bfe;e=e.update({
add:[o.range(n.value.from,n.value.to)]})}else n.is(Pfe)&&(e=e.update({
filter:(e,t)=>n.value.from!=e||n.value.to!=t,filterFrom:n.value.from,
filterTo:n.value.to}));if(t.selection){let n=!1,{head:r}=t.selection.main
;e.between(r,r,((e,t)=>{e<r&&t>r&&(n=!0)})),n&&(e=e.update({filterFrom:r,
filterTo:r,filter:(e,t)=>t<=r||e>=r}))}return e},
provide:e=>cde.decorations.from(e),toJSON(e,t){let n=[]
;return e.between(0,t.doc.length,((e,t)=>{n.push(e,t)})),n},fromJSON(e){
if(!Array.isArray(e)||e.length%2)throw new RangeError("Invalid JSON for fold state")
;let t=[];for(let n=0;n<e.length;){let r=e[n++],o=e[n++]
;if("number"!=typeof r||"number"!=typeof o)throw new RangeError("Invalid JSON for fold state")
;t.push(Bfe.range(r,o))}return mle.set(t,!0)}});function Ife(e,t,n){var r
;let o=null
;return null===(r=e.field(Dfe,!1))||void 0===r||r.between(t,n,((e,t)=>{
(!o||o.from>e)&&(o={from:e,to:t})})),o}function Mfe(e,t,n){let r=!1
;return e.between(t,t,((e,o)=>{e==t&&o==n&&(r=!0)})),r}const Nfe={
placeholderDOM:null,preparePlaceholder:null,placeholderText:"…"
},Rfe=Xae.define({combine:e=>Bie(e,Nfe)});function Lfe(e,t){
let{state:n}=e,r=n.facet(Rfe),o=t=>{
let n=e.lineBlockAt(e.posAtDOM(t.target)),r=Ife(e.state,n.from,n.to)
;r&&e.dispatch({effects:Pfe.of(r)}),t.preventDefault()}
;if(r.placeholderDOM)return r.placeholderDOM(e,o,t)
;let a=document.createElement("span")
;return a.textContent=r.placeholderText,a.setAttribute("aria-label",n.phrase("folded code")),
a.title=n.phrase("unfold"),a.className="cm-foldPlaceholder",a.onclick=o,a}
const Bfe=mle.replace({widget:new class extends hle{toDOM(e){return Lfe(e,null)}
}});class jfe extends hle{constructor(e){super(),this.value=e}eq(e){
return this.value==e.value}toDOM(e){return Lfe(e,this.value)}}const Ufe={
openText:"⌄",closedText:"›",markerDOM:null,domEventHandlers:{},
foldingChanged:()=>!1};class zfe extends ope{constructor(e,t){
super(),this.config=e,this.open=t}eq(e){
return this.config==e.config&&this.open==e.open}toDOM(e){
if(this.config.markerDOM)return this.config.markerDOM(this.open)
;let t=document.createElement("span")
;return t.textContent=this.open?this.config.openText:this.config.closedText,
t.title=e.state.phrase(this.open?"Fold line":"Unfold line"),t}}
function Ffe(e={}){
let t=Object.assign(Object.assign({},Ufe),e),n=new zfe(t,!0),r=new zfe(t,!1),o=dce.fromClass(class{
constructor(e){this.from=e.viewport.from,this.markers=this.buildMarkers(e)}
update(e){
(e.docChanged||e.viewportChanged||e.startState.facet(ife)!=e.state.facet(ife)||e.startState.field(Dfe,!1)!=e.state.field(Dfe,!1)||Yhe(e.startState)!=Yhe(e.state)||t.foldingChanged(e))&&(this.markers=this.buildMarkers(e.view))
}buildMarkers(e){let t=new Qie;for(let o of e.viewportLineBlocks){
let a=Ife(e.state,o.from,o.to)?r:Afe(e.state,o.from,o.to)?n:null
;a&&t.add(o.from,o.from,a)}return t.finish()}}),{domEventHandlers:a}=t
;return[o,cpe({class:"cm-foldGutter",markers(e){var t
;return(null===(t=e.plugin(o))||void 0===t?void 0:t.markers)||Zie.empty},
initialSpacer:()=>new zfe(t,!1),
domEventHandlers:Object.assign(Object.assign({},a),{click:(e,t,n)=>{
if(a.click&&a.click(e,t,n))return!0;let r=Ife(e.state,t.from,t.to)
;if(r)return e.dispatch({effects:Pfe.of(r)}),!0;let o=Afe(e.state,t.from,t.to)
;return!!o&&(e.dispatch({effects:$fe.of(o)}),!0)}})}),[Dfe,Zfe]]}
const Zfe=cde.baseTheme({".cm-foldPlaceholder":{backgroundColor:"#eee",
border:"1px solid #ddd",color:"#888",borderRadius:".2em",margin:"0 1px",
padding:"0 1px",cursor:"pointer"},".cm-foldGutter span":{padding:"0 1px",
cursor:"pointer"}});class Qfe{constructor(e,t){let n;function r(e){
let t=ase.newName();return(n||(n=Object.create(null)))["."+t]=e,t}this.specs=e
;const o="string"==typeof t.all?t.all:t.all?r(t.all):void 0,a=t.scope
;this.scope=a instanceof Whe?e=>e.prop(Hhe)==a.data:a?e=>e==a:void 0,
this.style=_he(e.map((e=>({tag:e.tag,class:e.class||r(Object.assign({},e,{
tag:null}))}))),{all:o
}).style,this.module=n?new ase(n):null,this.themeType=t.themeType}
static define(e,t){return new Qfe(e,t||{})}}
const Hfe=Xae.define(),Vfe=Xae.define({combine:e=>e.length?[e[0]]:null})
;function qfe(e){let t=e.facet(Hfe);return t.length?t:e.facet(Vfe)}
function Wfe(e,t){let n,r=[Gfe]
;return e instanceof Qfe&&(e.module&&r.push(cde.styleModule.of(e.module)),
n=e.themeType),
(null==t?void 0:t.fallback)?r.push(Vfe.of(e)):n?r.push(Hfe.computeN([cde.darkTheme],(t=>t.facet(cde.darkTheme)==("dark"==n)?[e]:[]))):r.push(Hfe.of(e)),
r}class Xfe{constructor(e){
this.markCache=Object.create(null),this.tree=Yhe(e.state),
this.decorations=this.buildDeco(e,qfe(e.state)),this.decoratedTo=e.viewport.to}
update(e){
let t=Yhe(e.state),n=qfe(e.state),r=n!=qfe(e.startState),{viewport:o}=e.view,a=e.changes.mapPos(this.decoratedTo,1)
;t.length<o.to&&!r&&t.type==this.tree.type&&a>=o.to?(this.decorations=this.decorations.map(e.changes),
this.decoratedTo=a):(t!=this.tree||e.viewportChanged||r)&&(this.tree=t,
this.decorations=this.buildDeco(e.view,n),this.decoratedTo=o.to)}buildDeco(e,t){
if(!t||!this.tree.length)return mle.none;let n=new Qie
;for(let{from:r,to:o}of e.visibleRanges)The(this.tree,t,((e,t,r)=>{
n.add(e,t,this.markCache[r]||(this.markCache[r]=mle.mark({class:r})))}),r,o)
;return n.finish()}}const Gfe=lie.high(dce.fromClass(Xfe,{
decorations:e=>e.decorations})),Yfe=Qfe.define([{tag:Zhe.meta,color:"#404740"},{
tag:Zhe.link,textDecoration:"underline"},{tag:Zhe.heading,
textDecoration:"underline",fontWeight:"bold"},{tag:Zhe.emphasis,
fontStyle:"italic"},{tag:Zhe.strong,fontWeight:"bold"},{tag:Zhe.strikethrough,
textDecoration:"line-through"},{tag:Zhe.keyword,color:"#708"},{
tag:[Zhe.atom,Zhe.bool,Zhe.url,Zhe.contentSeparator,Zhe.labelName],color:"#219"
},{tag:[Zhe.literal,Zhe.inserted],color:"#164"},{tag:[Zhe.string,Zhe.deleted],
color:"#a11"},{tag:[Zhe.regexp,Zhe.escape,Zhe.special(Zhe.string)],color:"#e40"
},{tag:Zhe.definition(Zhe.variableName),color:"#00f"},{
tag:Zhe.local(Zhe.variableName),color:"#30a"},{tag:[Zhe.typeName,Zhe.namespace],
color:"#085"},{tag:Zhe.className,color:"#167"},{
tag:[Zhe.special(Zhe.variableName),Zhe.macroName],color:"#256"},{
tag:Zhe.definition(Zhe.propertyName),color:"#00c"},{tag:Zhe.comment,color:"#940"
},{tag:Zhe.invalid,color:"#f00"}]),Kfe=cde.baseTheme({
"&.cm-focused .cm-matchingBracket":{backgroundColor:"#328c8252"},
"&.cm-focused .cm-nonmatchingBracket":{backgroundColor:"#bb555544"}
}),Jfe="()[]{}",eme=Xae.define({combine:e=>Bie(e,{afterCursor:!0,brackets:Jfe,
maxScanDistance:1e4,renderMatch:rme})}),tme=mle.mark({class:"cm-matchingBracket"
}),nme=mle.mark({class:"cm-nonmatchingBracket"});function rme(e){
let t=[],n=e.matched?tme:nme
;return t.push(n.range(e.start.from,e.start.to)),e.end&&t.push(n.range(e.end.from,e.end.to)),
t}const ome=[nie.define({create:()=>mle.none,update(e,t){
if(!t.docChanged&&!t.selection)return e;let n=[],r=t.state.facet(eme)
;for(let o of t.state.selection.ranges){if(!o.empty)continue
;let e=cme(t.state,o.head,-1,r)||o.head>0&&cme(t.state,o.head-1,1,r)||r.afterCursor&&(cme(t.state,o.head,1,r)||o.head<t.state.doc.length&&cme(t.state,o.head+1,-1,r))
;e&&(n=n.concat(r.renderMatch(e,t.state)))}return mle.set(n,!0)},
provide:e=>cde.decorations.from(e)}),Kfe];function ame(e={}){
return[eme.of(e),ome]}const ime=new Ape;function sme(e,t,n){
let r=e.prop(t<0?Ape.openedBy:Ape.closedBy);if(r)return r;if(1==e.name.length){
let r=n.indexOf(e.name);if(r>-1&&r%2==(t<0?1:0))return[n[r+t]]}return null}
function lme(e){let t=e.type.prop(ime);return t?t(e.node):e}
function cme(e,t,n,r={}){
let o=r.maxScanDistance||1e4,a=r.brackets||Jfe,i=Yhe(e),s=i.resolveInner(t,n)
;for(let l=s;l;l=l.parent){let r=sme(l.type,n,a);if(r&&l.from<l.to){let o=lme(l)
;if(o&&(n>0?t>=o.from&&t<o.to:t>o.from&&t<=o.to))return ume(e,t,n,l,o,r,a)}}
return function(e,t,n,r,o,a,i){
let s=n<0?e.sliceDoc(t-1,t):e.sliceDoc(t,t+1),l=i.indexOf(s)
;if(l<0||l%2==0!=n>0)return null;let c={from:n<0?t-1:t,to:n>0?t+1:t
},u=e.doc.iterRange(t,n>0?e.doc.length:0),d=0
;for(let p=0;!u.next().done&&p<=a;){let e=u.value;n<0&&(p+=e.length);let a=t+p*n
;for(let t=n>0?0:e.length-1,s=n>0?e.length:-1;t!=s;t+=n){let s=i.indexOf(e[t])
;if(!(s<0||r.resolveInner(a+t,1).type!=o))if(s%2==0==n>0)d++;else{
if(1==d)return{start:c,end:{from:a+t,to:a+t+1},matched:s>>1==l>>1};d--}}
n>0&&(p+=e.length)}return u.done?{start:c,matched:!1}:null}(e,t,n,i,s.type,o,a)}
function ume(e,t,n,r,o,a,i){let s=r.parent,l={from:o.from,to:o.to
},c=0,u=null==s?void 0:s.cursor()
;if(u&&(n<0?u.childBefore(r.from):u.childAfter(r.to)))do{
if(n<0?u.to<=r.from:u.from>=r.to){
if(0==c&&a.indexOf(u.type.name)>-1&&u.from<u.to){let e=lme(u);return{start:l,
end:e?{from:e.from,to:e.to}:void 0,matched:!0}}
if(sme(u.type,n,i))c++;else if(sme(u.type,-n,i)){if(0==c){let e=lme(u);return{
start:l,end:e&&e.from<e.to?{from:e.from,to:e.to}:void 0,matched:!1}}c--}}
}while(n<0?u.prevSibling():u.nextSibling());return{start:l,matched:!1}}
const dme=Object.create(null),pme=[Ppe.none],hme=[],fme=Object.create(null),mme=Object.create(null)
;for(let[v5e,b5e]of[["variable","variableName"],["variable-2","variableName.special"],["string-2","string.special"],["def","variableName.definition"],["tag","tagName"],["attribute","attributeName"],["type","typeName"],["builtin","variableName.standard"],["qualifier","modifier"],["error","invalid"],["header","heading"],["property","propertyName"]])mme[v5e]=vme(dme,b5e)
;function gme(e,t){hme.indexOf(e)>-1||(hme.push(e),console.warn(t))}
function vme(e,t){let n=[];for(let s of t.split(" ")){let t=[]
;for(let n of s.split(".")){let r=e[n]||Zhe[n]
;r?"function"==typeof r?t.length?t=t.map(r):gme(n,`Modifier ${n} used at start of tag`):t.length?gme(n,`Tag ${n} used as modifier`):t=Array.isArray(r)?r:[r]:gme(n,`Unknown highlighting tag ${n}`)
}for(let e of t)n.push(e)}if(!n.length)return 0
;let r=t.replace(/ /g,"_"),o=r+" "+n.map((e=>e.id)),a=fme[o];if(a)return a.id
;let i=fme[o]=Ppe.define({id:pme.length,name:r,props:[xhe({[r]:n})]})
;return pme.push(i),i.id}Ele.RTL,Ele.LTR
;const bme=new Map([["aliceblue","#f0f8ff"],["antiquewhite","#faebd7"],["aqua","#00ffff"],["aquamarine","#7fffd4"],["azure","#f0ffff"],["beige","#f5f5dc"],["bisque","#ffe4c4"],["black","#000000"],["blanchedalmond","#ffebcd"],["blue","#0000ff"],["blueviolet","#8a2be2"],["brown","#a52a2a"],["burlywood","#deb887"],["cadetblue","#5f9ea0"],["chartreuse","#7fff00"],["chocolate","#d2691e"],["coral","#ff7f50"],["cornflowerblue","#6495ed"],["cornsilk","#fff8dc"],["crimson","#dc143c"],["cyan","#00ffff"],["darkblue","#00008b"],["darkcyan","#008b8b"],["darkgoldenrod","#b8860b"],["darkgray","#a9a9a9"],["darkgreen","#006400"],["darkgrey","#a9a9a9"],["darkkhaki","#bdb76b"],["darkmagenta","#8b008b"],["darkolivegreen","#556b2f"],["darkorange","#ff8c00"],["darkorchid","#9932cc"],["darkred","#8b0000"],["darksalmon","#e9967a"],["darkseagreen","#8fbc8f"],["darkslateblue","#483d8b"],["darkslategray","#2f4f4f"],["darkslategrey","#2f4f4f"],["darkturquoise","#00ced1"],["darkviolet","#9400d3"],["deeppink","#ff1493"],["deepskyblue","#00bfff"],["dimgray","#696969"],["dimgrey","#696969"],["dodgerblue","#1e90ff"],["firebrick","#b22222"],["floralwhite","#fffaf0"],["forestgreen","#228b22"],["fuchsia","#ff00ff"],["gainsboro","#dcdcdc"],["ghostwhite","#f8f8ff"],["goldenrod","#daa520"],["gold","#ffd700"],["gray","#808080"],["green","#008000"],["greenyellow","#adff2f"],["grey","#808080"],["honeydew","#f0fff0"],["hotpink","#ff69b4"],["indianred","#cd5c5c"],["indigo","#4b0082"],["ivory","#fffff0"],["khaki","#f0e68c"],["lavenderblush","#fff0f5"],["lavender","#e6e6fa"],["lawngreen","#7cfc00"],["lemonchiffon","#fffacd"],["lightblue","#add8e6"],["lightcoral","#f08080"],["lightcyan","#e0ffff"],["lightgoldenrodyellow","#fafad2"],["lightgray","#d3d3d3"],["lightgreen","#90ee90"],["lightgrey","#d3d3d3"],["lightpink","#ffb6c1"],["lightsalmon","#ffa07a"],["lightseagreen","#20b2aa"],["lightskyblue","#87cefa"],["lightslategray","#778899"],["lightslategrey","#778899"],["lightsteelblue","#b0c4de"],["lightyellow","#ffffe0"],["lime","#00ff00"],["limegreen","#32cd32"],["linen","#faf0e6"],["magenta","#ff00ff"],["maroon","#800000"],["mediumaquamarine","#66cdaa"],["mediumblue","#0000cd"],["mediumorchid","#ba55d3"],["mediumpurple","#9370db"],["mediumseagreen","#3cb371"],["mediumslateblue","#7b68ee"],["mediumspringgreen","#00fa9a"],["mediumturquoise","#48d1cc"],["mediumvioletred","#c71585"],["midnightblue","#191970"],["mintcream","#f5fffa"],["mistyrose","#ffe4e1"],["moccasin","#ffe4b5"],["navajowhite","#ffdead"],["navy","#000080"],["oldlace","#fdf5e6"],["olive","#808000"],["olivedrab","#6b8e23"],["orange","#ffa500"],["orangered","#ff4500"],["orchid","#da70d6"],["palegoldenrod","#eee8aa"],["palegreen","#98fb98"],["paleturquoise","#afeeee"],["palevioletred","#db7093"],["papayawhip","#ffefd5"],["peachpuff","#ffdab9"],["peru","#cd853f"],["pink","#ffc0cb"],["plum","#dda0dd"],["powderblue","#b0e0e6"],["purple","#800080"],["rebeccapurple","#663399"],["red","#ff0000"],["rosybrown","#bc8f8f"],["royalblue","#4169e1"],["saddlebrown","#8b4513"],["salmon","#fa8072"],["sandybrown","#f4a460"],["seagreen","#2e8b57"],["seashell","#fff5ee"],["sienna","#a0522d"],["silver","#c0c0c0"],["skyblue","#87ceeb"],["slateblue","#6a5acd"],["slategray","#708090"],["slategrey","#708090"],["snow","#fffafa"],["springgreen","#00ff7f"],["steelblue","#4682b4"],["tan","#d2b48c"],["teal","#008080"],["thistle","#d8bfd8"],["tomato","#ff6347"],["turquoise","#40e0d0"],["violet","#ee82ee"],["wheat","#f5deb3"],["white","#ffffff"],["whitesmoke","#f5f5f5"],["yellow","#ffff00"],["yellowgreen","#9acd32"]])
;const yme=new WeakMap;var Ome=function(e){
return e.rgb="RGB",e.hex="HEX",e.named="NAMED",e.hsl="HSL",e}(Ome||(Ome={}))
;const wme=/rgb(?:a)?\(\s*(\d{1,3}%?)\s*,?\s*(\d{1,3}%?)\s*,?\s*(\d{1,3}%?)\s*([,/]\s*0?\.?\d+%?)?\)/,xme=/hsl\(\s*(\d{1,3})\s*,\s*(\d{1,3})%\s*,\s*(\d{1,3})%\s*(,\s*0?\.\d+)?\)/,kme=/(^|\b)(#[0-9a-f]{3,9})(\b|$)/i
;function Sme(e,t){const n=[],r=Yhe(e.state)
;for(const o of e.visibleRanges)r.iterate({from:o.from,to:o.to,
enter:({type:o,from:a,to:i})=>{var s
;const l=t(r,a,i,o.name,e.state.doc,null===(s=e.state.facet(ife))||void 0===s?void 0:s.name)
;if(l)if(Array.isArray(l))for(const e of l)n.push(mle.widget({widget:new Pme(e),
side:1}).range(e.from));else n.push(mle.widget({widget:new Pme(l),side:1
}).range(l.from))}});return mle.set(n)}function _me(e){let t
;if(e.endsWith("%")){const n=Number(e.slice(0,-1));t=Math.round(n/100*255)
}else t=Number(e);return Tme(t)}function Tme(e){const t=e.toString(16)
;return 1===t.length?"0"+t:t}function Eme(e){
const t=e.slice(1,3),n=e.slice(3,5),r=e.slice(5,7)
;return[parseInt(t,16),parseInt(n,16),parseInt(r,16)]}function Ame(e){
return e<0?e+1:e>1?e-1:e}function Cme(e,t,n){
return 6*n<1?t+6*(e-t)*n:2*n<1?e:3*n<2?t+(e-t)*(.666-n)*6:t}
const $me="cm-css-color-picker-wrapper";class Pme extends hle{constructor(e){
var{color:t}=e,n=function(e,t){var n={}
;for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r])
;if(null!=e&&"function"==typeof Object.getOwnPropertySymbols){var o=0
;for(r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]])
}return n}(e,["color"]);super(),this.state=n,this.color=t}eq(e){
return e.state.colorType===this.state.colorType&&e.color===this.color&&e.state.from===this.state.from&&e.state.to===this.state.to&&e.state.alpha===this.state.alpha
}toDOM(){const e=document.createElement("input")
;yme.set(e,this.state),e.type="color",e.value=this.color
;const t=document.createElement("span");return t.appendChild(e),t.className=$me,
t}ignoreEvent(){return!1}}const Dme=cde.baseTheme({[`.${$me}`]:{
display:"inline-block",outline:"1px solid #eee",marginRight:"0.6ch",
height:"1em",width:"1em",transform:"translateY(1px)"},
[`.${$me} input[type="color"]`]:{cursor:"pointer",height:"100%",width:"100%",
padding:0,border:"none","&::-webkit-color-swatch-wrapper":{padding:0},
"&::-webkit-color-swatch":{border:"none"},"&::-moz-color-swatch":{border:"none"}
}}),Ime=e=>dce.fromClass(class{constructor(t){
this.decorations=Sme(t,e.discoverColors)}update(t){
(t.docChanged||t.viewportChanged)&&(this.decorations=Sme(t.view,e.discoverColors))
}},{decorations:e=>e.decorations,eventHandlers:{change:(e,t)=>{const n=e.target
;if("INPUT"!==n.nodeName||!n.parentElement||!n.parentElement.classList.contains($me))return!1
;const r=yme.get(n);let o=n.value+r.alpha
;if(r.colorType===Ome.rgb)o=`rgb(${Eme(n.value).join(", ")}${r.alpha})`;else if(r.colorType===Ome.named)for(const[a,i]of bme.entries())i===n.value&&(o=a);else if(r.colorType===Ome.hsl){
const[e,t,a]=Eme(n.value),[i,s,l]=function(e,t,n){
const r=e/255,o=t/255,a=n/255,i=Math.min(r,o,a),s=Math.max(r,o,a),l=(s+i)/2
;if(s===i)return[0,0,l];let c,u
;for(c=l<=.5?(s-i)/(s+i):(s-i)/(2-s-i),u=s===r?(o-a)/(s-i):o===s?2+(a-r)/(s-i):4+(r-o)/(s-i),
u=Math.round(60*u);u<0;)u+=360;return[u,c,l]}(e,t,a)
;o=`hsl(${i}, ${Math.round(100*s)}%, ${Math.round(100*l)}%${r.alpha})`}
return t.dispatch({changes:{from:r.from,to:r.to,insert:o}}),!0}}}),Mme=[Ime({
discoverColors:function e(t,n,r,o,a,i){var s;switch(o){case"AttributeValue":{
const r=t.resolveInner(n,0).tree;if(!r)return null
;const o=null===(s=r.prop(Ape.mounted))||void 0===s?void 0:s.tree
;if("Styles"!==(null==o?void 0:o.type.name))return null;const i=[]
;return o.iterate({from:0,to:o.length,enter:({type:r,from:o,to:s})=>{
const l=e(t,n+1+o,n+1+s,r.name,a);if(l){
if(Array.isArray(l))throw new Error("Unexpected nested overlays");i.push(l)}}}),
i}case"CallExpression":{const e=function(e){switch(e.slice(0,3)){case"rgb":{
const t=wme.exec(e);if(!t)return null;const[n,r,o,a,i]=t,s=function(e,t,n){
return`#${_me(e)}${_me(t)}${_me(n)}`}(r,o,a);return{colorType:Ome.rgb,color:s,
alpha:i||""}}case"hsl":{const t=xme.exec(e);if(!t)return null
;const[n,r,o,a,i]=t,s=function(e,t,n){
const r=Number(t)/100,o=Number(n)/100,[a,i,s]=function(e,t,n){if(0===t){
const e=Math.round(255*n);return[e,e,e]}let r;r=n<.5?n*(1+t):n+t-n*t
;const o=2*n-r,a=Ame(.333+(e/=360)),i=e,s=Ame(e-.333),l=Cme(r,o,a),c=Cme(r,o,i),u=Cme(r,o,s)
;return[Math.round(255*l),Math.round(255*c),Math.round(255*u)]}(Number(e),r,o)
;return`#${Tme(a)}${Tme(i)}${Tme(s)}`}(r,o,a);return{colorType:Ome.hsl,color:s,
alpha:i||""}}default:return null}}(a.sliceString(n,r))
;return e?Object.assign(Object.assign({},e),{from:n,to:r}):null}
case"ColorLiteral":{const e=function(e){if(!kme.exec(e))return null
;const[t,n]=function(e){
if(4===e.length)return[`#${e[1].repeat(2)}${e[2].repeat(2)}${e[3].repeat(2)}`,""]
;if(5===e.length)return[`#${e[1].repeat(2)}${e[2].repeat(2)}${e[3].repeat(2)}`,e[4].repeat(2)]
;if(9===e.length)return[`#${e.slice(1,-2)}`,e.slice(-2)];return[e,""]}(e)
;return{colorType:Ome.hex,color:t,alpha:n}}(a.sliceString(n,r))
;return e?Object.assign(Object.assign({},e),{from:n,to:r}):null}case"ValueName":
{const e=function(e){const t=bme.get(e);if(!t)return null;return{
colorType:Ome.named,color:t,alpha:""}}(a.sliceString(n,r))
;return e?Object.assign(Object.assign({},e),{from:n,to:r}):null}default:
return null}}}),Dme];class Nme{constructor(e,t,n,r){
this.state=e,this.pos=t,this.explicit=n,
this.view=r,this.abortListeners=[],this.abortOnDocChange=!1}tokenBefore(e){
let t=Yhe(this.state).resolveInner(this.pos,-1)
;for(;t&&e.indexOf(t.name)<0;)t=t.parent;return t?{from:t.from,to:this.pos,
text:this.state.sliceDoc(t.from,this.pos),type:t.type}:null}matchBefore(e){
let t=this.state.doc.lineAt(this.pos),n=Math.max(t.from,this.pos-250),r=t.text.slice(n-t.from,this.pos-t.from),o=r.search(Ume(e,!1))
;return o<0?null:{from:n+o,to:this.pos,text:r.slice(o)}}get aborted(){
return null==this.abortListeners}addEventListener(e,t,n){
"abort"==e&&this.abortListeners&&(this.abortListeners.push(t),
n&&n.onDocChange&&(this.abortOnDocChange=!0))}}function Rme(e){
let t=Object.keys(e).join(""),n=/\w/.test(t)
;return n&&(t=t.replace(/\w/g,"")),`[${n?"\\w":""}${t.replace(/[^\w\s]/g,"\\$&")}]`
}function Lme(e){let t=e.map((e=>"string"==typeof e?{label:e
}:e)),[n,r]=t.every((e=>/^\w+$/.test(e.label)))?[/\w*$/,/\w+$/]:function(e){
let t=Object.create(null),n=Object.create(null);for(let{label:o}of e){t[o[0]]=!0
;for(let e=1;e<o.length;e++)n[o[e]]=!0}let r=Rme(t)+Rme(n)+"*$"
;return[new RegExp("^"+r),new RegExp(r)]}(t);return e=>{let o=e.matchBefore(r)
;return o||e.explicit?{from:o?o.from:e.pos,options:t,validFor:n}:null}}
class Bme{constructor(e,t,n,r){
this.completion=e,this.source=t,this.match=n,this.score=r}}function jme(e){
return e.selection.main.from}function Ume(e,t){var n
;let{source:r}=e,o=t&&"^"!=r[0],a="$"!=r[r.length-1]
;return o||a?new RegExp(`${o?"^":""}(?:${r})${a?"$":""}`,null!==(n=e.flags)&&void 0!==n?n:e.ignoreCase?"i":""):e
}const zme=xie.define();const Fme=new WeakMap;function Zme(e){
if(!Array.isArray(e))return e;let t=Fme.get(e);return t||Fme.set(e,t=Lme(e)),t}
const Qme=_ie.define(),Hme=_ie.define();class Vme{constructor(e){this.pattern=e,
this.chars=[],
this.folded=[],this.any=[],this.precise=[],this.byWord=[],this.score=0,
this.matched=[];for(let t=0;t<e.length;){let n=Dae(e,t),r=Mae(n)
;this.chars.push(n);let o=e.slice(t,t+r),a=o.toUpperCase()
;this.folded.push(Dae(a==o?o.toLowerCase():a,0)),t+=r}
this.astral=e.length!=this.chars.length}ret(e,t){
return this.score=e,this.matched=t,this}match(e){
if(0==this.pattern.length)return this.ret(-100,[])
;if(e.length<this.pattern.length)return null
;let{chars:t,folded:n,any:r,precise:o,byWord:a}=this;if(1==t.length){
let r=Dae(e,0),o=Mae(r),a=o==e.length?0:-100;if(r==t[0]);else{
if(r!=n[0])return null;a+=-200}return this.ret(a,[0,o])}
let i=e.indexOf(this.pattern)
;if(0==i)return this.ret(e.length==this.pattern.length?0:-100,[0,this.pattern.length])
;let s=t.length,l=0;if(i<0){for(let o=0,a=Math.min(e.length,200);o<a&&l<s;){
let a=Dae(e,o);a!=t[l]&&a!=n[l]||(r[l++]=o),o+=Mae(a)}if(l<s)return null}
let c=0,u=0,d=!1,p=0,h=-1,f=-1,m=/[a-z]/.test(e),g=!0
;for(let v=0,b=Math.min(e.length,200),y=0;v<b&&u<s;){let r=Dae(e,v)
;i<0&&(c<s&&r==t[c]&&(o[c++]=v),
p<s&&(r==t[p]||r==n[p]?(0==p&&(h=v),f=v+1,p++):p=0))
;let l,b=r<255?r>=48&&r<=57||r>=97&&r<=122?2:r>=65&&r<=90?1:0:(l=Iae(r))!=l.toLowerCase()?1:l!=l.toUpperCase()?2:0
;(!v||1==b&&m||0==y&&0!=b)&&(t[u]==r||n[u]==r&&(d=!0)?a[u++]=v:a.length&&(g=!1)),
y=b,v+=Mae(r)}
return u==s&&0==a[0]&&g?this.result((d?-200:0)-100,a,e):p==s&&0==h?this.ret(-200-e.length+(f==e.length?0:-100),[0,f]):i>-1?this.ret(-700-e.length,[i,i+this.pattern.length]):p==s?this.ret(-900-e.length,[h,f]):u==s?this.result((d?-200:0)-100-700+(g?0:-1100),a,e):2==t.length?null:this.result((r[0]?-700:0)-200-1100,r,e)
}result(e,t,n){let r=[],o=0;for(let a of t){
let e=a+(this.astral?Mae(Dae(n,a)):1);o&&r[o-1]==a?r[o-1]=e:(r[o++]=a,r[o++]=e)}
return this.ret(e-n.length,r)}}class qme{constructor(e){
this.pattern=e,this.matched=[],this.score=0,this.folded=e.toLowerCase()}
match(e){if(e.length<this.pattern.length)return null
;let t=e.slice(0,this.pattern.length),n=t==this.pattern?0:t.toLowerCase()==this.folded?-200:null
;return null==n?null:(this.matched=[0,t.length],
this.score=n+(e.length==this.pattern.length?0:-100),this)}}
const Wme=Xae.define({combine:e=>Bie(e,{activateOnTyping:!0,
activateOnCompletion:()=>!1,activateOnTypingDelay:100,selectOnOpen:!0,
override:null,closeOnBlur:!0,maxRenderedOptions:100,defaultKeymap:!0,
tooltipClass:()=>"",optionClass:()=>"",aboveCursor:!1,icons:!0,addToOptions:[],
positionInfo:Gme,filterStrict:!1,
compareCompletions:(e,t)=>e.label.localeCompare(t.label),interactionDelay:75,
updateSyncTime:100},{defaultKeymap:(e,t)=>e&&t,closeOnBlur:(e,t)=>e&&t,
icons:(e,t)=>e&&t,tooltipClass:(e,t)=>n=>Xme(e(n),t(n)),
optionClass:(e,t)=>n=>Xme(e(n),t(n)),addToOptions:(e,t)=>e.concat(t),
filterStrict:(e,t)=>e||t})});function Xme(e,t){return e?t?e+" "+t:e:t}
function Gme(e,t,n,r,o,a){
let i,s,l=e.textDirection==Ele.RTL,c=l,u=!1,d="top",p=t.left-o.left,h=o.right-t.right,f=r.right-r.left,m=r.bottom-r.top
;if(c&&p<Math.min(f,h)?c=!1:!c&&h<Math.min(f,p)&&(c=!0),
f<=(c?p:h))i=Math.max(o.top,Math.min(n.top,o.bottom-m))-t.top,
s=Math.min(400,c?p:h);else{u=!0,s=Math.min(400,(l?t.right:o.right-t.left)-30)
;let e=o.bottom-t.bottom
;e>=m||e>t.top?i=n.bottom-t.top:(d="bottom",i=t.bottom-n.top)}return{
style:`${d}: ${i/((t.bottom-t.top)/a.offsetHeight)}px; max-width: ${s/((t.right-t.left)/a.offsetWidth)}px`,
class:"cm-completionInfo-"+(u?l?"left-narrow":"right-narrow":c?"left":"right")}}
function Yme(e,t,n){if(e<=n)return{from:0,to:e};if(t<0&&(t=0),t<=e>>1){
let e=Math.floor(t/n);return{from:e*n,to:(e+1)*n}}let r=Math.floor((e-t)/n)
;return{from:e-(r+1)*n,to:e-r*n}}class Kme{constructor(e,t,n){
this.view=e,this.stateField=t,
this.applyCompletion=n,this.info=null,this.infoDestroy=null,this.placeInfoReq={
read:()=>this.measureInfo(),write:e=>this.placeInfo(e),key:this
},this.space=null,this.currentClass=""
;let r=e.state.field(t),{options:o,selected:a}=r.open,i=e.state.facet(Wme)
;this.optionContent=function(e){let t=e.addToOptions.slice()
;return e.icons&&t.push({render(e){let t=document.createElement("div")
;return t.classList.add("cm-completionIcon"),
e.type&&t.classList.add(...e.type.split(/\s+/g).map((e=>"cm-completionIcon-"+e))),
t.setAttribute("aria-hidden","true"),t},position:20}),t.push({render(e,t,n,r){
let o=document.createElement("span");o.className="cm-completionLabel"
;let a=e.displayLabel||e.label,i=0;for(let s=0;s<r.length;){
let e=r[s++],t=r[s++];e>i&&o.appendChild(document.createTextNode(a.slice(i,e)))
;let n=o.appendChild(document.createElement("span"))
;n.appendChild(document.createTextNode(a.slice(e,t))),
n.className="cm-completionMatchedText",i=t}
return i<a.length&&o.appendChild(document.createTextNode(a.slice(i))),o},
position:50},{render(e){if(!e.detail)return null
;let t=document.createElement("span")
;return t.className="cm-completionDetail",t.textContent=e.detail,t},position:80
}),t.sort(((e,t)=>e.position-t.position)).map((e=>e.render))
}(i),this.optionClass=i.optionClass,
this.tooltipClass=i.tooltipClass,this.range=Yme(o.length,a,i.maxRenderedOptions),
this.dom=document.createElement("div"),
this.dom.className="cm-tooltip-autocomplete",
this.updateTooltipClass(e.state),this.dom.addEventListener("mousedown",(n=>{
let{options:r}=e.state.field(t).open
;for(let t,o=n.target;o&&o!=this.dom;o=o.parentNode)if("LI"==o.nodeName&&(t=/-(\d+)$/.exec(o.id))&&+t[1]<r.length)return this.applyCompletion(e,r[+t[1]]),
void n.preventDefault()})),this.dom.addEventListener("focusout",(t=>{
let n=e.state.field(this.stateField,!1)
;n&&n.tooltip&&e.state.facet(Wme).closeOnBlur&&t.relatedTarget!=e.contentDOM&&e.dispatch({
effects:Hme.of(null)})})),this.showOptions(o,r.id)}mount(){this.updateSel()}
showOptions(e,t){
this.list&&this.list.remove(),this.list=this.dom.appendChild(this.createListBox(e,t,this.range)),
this.list.addEventListener("scroll",(()=>{
this.info&&this.view.requestMeasure(this.placeInfoReq)}))}update(e){var t
;let n=e.state.field(this.stateField),r=e.startState.field(this.stateField)
;if(this.updateTooltipClass(e.state),n!=r){
let{options:o,selected:a,disabled:i}=n.open
;r.open&&r.open.options==o||(this.range=Yme(o.length,a,e.state.facet(Wme).maxRenderedOptions),
this.showOptions(o,n.id)),
this.updateSel(),i!=(null===(t=r.open)||void 0===t?void 0:t.disabled)&&this.dom.classList.toggle("cm-tooltip-autocomplete-disabled",!!i)
}}updateTooltipClass(e){let t=this.tooltipClass(e);if(t!=this.currentClass){
for(let e of this.currentClass.split(" "))e&&this.dom.classList.remove(e)
;for(let e of t.split(" "))e&&this.dom.classList.add(e);this.currentClass=t}}
positioned(e){
this.space=e,this.info&&this.view.requestMeasure(this.placeInfoReq)}updateSel(){
let e=this.view.state.field(this.stateField),t=e.open
;if((t.selected>-1&&t.selected<this.range.from||t.selected>=this.range.to)&&(this.range=Yme(t.options.length,t.selected,this.view.state.facet(Wme).maxRenderedOptions),
this.showOptions(t.options,e.id)),this.updateSelectedOption(t.selected)){
this.destroyInfo();let{completion:n}=t.options[t.selected],{info:r}=n
;if(!r)return;let o="string"==typeof r?document.createTextNode(r):r(n)
;if(!o)return;"then"in o?o.then((t=>{
t&&this.view.state.field(this.stateField,!1)==e&&this.addInfoPane(t,n)
})).catch((e=>sce(this.view.state,e,"completion info"))):this.addInfoPane(o,n)}}
addInfoPane(e,t){this.destroyInfo()
;let n=this.info=document.createElement("div")
;if(n.className="cm-tooltip cm-completionInfo",
null!=e.nodeType)n.appendChild(e),this.infoDestroy=null;else{
let{dom:t,destroy:r}=e;n.appendChild(t),this.infoDestroy=r||null}
this.dom.appendChild(n),this.view.requestMeasure(this.placeInfoReq)}
updateSelectedOption(e){let t=null
;for(let n=this.list.firstChild,r=this.range.from;n;n=n.nextSibling,
r++)"LI"==n.nodeName&&n.id?r==e?n.hasAttribute("aria-selected")||(n.setAttribute("aria-selected","true"),
t=n):n.hasAttribute("aria-selected")&&n.removeAttribute("aria-selected"):r--
;return t&&function(e,t){
let n=e.getBoundingClientRect(),r=t.getBoundingClientRect(),o=n.height/e.offsetHeight
;r.top<n.top?e.scrollTop-=(n.top-r.top)/o:r.bottom>n.bottom&&(e.scrollTop+=(r.bottom-n.bottom)/o)
}(this.list,t),t}measureInfo(){let e=this.dom.querySelector("[aria-selected]")
;if(!e||!this.info)return null
;let t=this.dom.getBoundingClientRect(),n=this.info.getBoundingClientRect(),r=e.getBoundingClientRect(),o=this.space
;if(!o){let e=this.dom.ownerDocument.defaultView||window;o={left:0,top:0,
right:e.innerWidth,bottom:e.innerHeight}}
return r.top>Math.min(o.bottom,t.bottom)-10||r.bottom<Math.max(o.top,t.top)+10?null:this.view.state.facet(Wme).positionInfo(this.view,t,r,n,o,this.dom)
}placeInfo(e){
this.info&&(e?(e.style&&(this.info.style.cssText=e.style),this.info.className="cm-tooltip cm-completionInfo "+(e.class||"")):this.info.style.cssText="top: -1e6px")
}createListBox(e,t,n){const r=document.createElement("ul")
;r.id=t,r.setAttribute("role","listbox"),r.setAttribute("aria-expanded","true"),
r.setAttribute("aria-label",this.view.state.phrase("Completions"));let o=null
;for(let a=n.from;a<n.to;a++){let{completion:i,match:s}=e[a],{section:l}=i
;if(l){let e="string"==typeof l?l:l.name
;if(e!=o&&(a>n.from||0==n.from))if(o=e,"string"!=typeof l&&l.header)r.appendChild(l.header(l));else{
r.appendChild(document.createElement("completion-section")).textContent=e}}
const c=r.appendChild(document.createElement("li"))
;c.id=t+"-"+a,c.setAttribute("role","option");let u=this.optionClass(i)
;u&&(c.className=u);for(let e of this.optionContent){
let t=e(i,this.view.state,this.view,s);t&&c.appendChild(t)}}
return n.from&&r.classList.add("cm-completionListIncompleteTop"),
n.to<e.length&&r.classList.add("cm-completionListIncompleteBottom"),r}
destroyInfo(){
this.info&&(this.infoDestroy&&this.infoDestroy(),this.info.remove(),
this.info=null)}destroy(){this.destroyInfo()}}function Jme(e,t){
return n=>new Kme(n,e,t)}function ege(e){
return 100*(e.boost||0)+(e.apply?10:0)+(e.info?5:0)+(e.type?1:0)}class tge{
constructor(e,t,n,r,o,a){
this.options=e,this.attrs=t,this.tooltip=n,this.timestamp=r,
this.selected=o,this.disabled=a}setSelected(e,t){
return e==this.selected||e>=this.options.length?this:new tge(this.options,age(t,e),this.tooltip,this.timestamp,e,this.disabled)
}static build(e,t,n,r,o,a){
if(r&&!a&&e.some((e=>e.isPending)))return r.setDisabled();let i=function(e,t){
let n=[],r=null,o=e=>{n.push(e);let{section:t}=e.completion;if(t){r||(r=[])
;let e="string"==typeof t?t:t.name
;r.some((t=>t.name==e))||r.push("string"==typeof t?{name:e}:t)}},a=t.facet(Wme)
;for(let c of e)if(c.hasResult()){let e=c.result.getMatch
;if(!1===c.result.filter)for(let t of c.result.options)o(new Bme(t,c.source,e?e(t):[],1e9-n.length));else{
let n,r=t.sliceDoc(c.from,c.to),i=a.filterStrict?new qme(r):new Vme(r)
;for(let t of c.result.options)if(n=i.match(t.label)){
let r=t.displayLabel?e?e(t,n.matched):[]:n.matched
;o(new Bme(t,c.source,r,n.score+(t.boost||0)))}}}if(r){
let e=Object.create(null),t=0,o=(e,t)=>{var n,r
;return(null!==(n=e.rank)&&void 0!==n?n:1e9)-(null!==(r=t.rank)&&void 0!==r?r:1e9)||(e.name<t.name?-1:1)
};for(let n of r.sort(o))t-=1e5,e[n.name]=t;for(let r of n){
let{section:t}=r.completion;t&&(r.score+=e["string"==typeof t?t:t.name])}}
let i=[],s=null,l=a.compareCompletions
;for(let c of n.sort(((e,t)=>t.score-e.score||l(e.completion,t.completion)))){
let e=c.completion
;!s||s.label!=e.label||s.detail!=e.detail||null!=s.type&&null!=e.type&&s.type!=e.type||s.apply!=e.apply||s.boost!=e.boost?i.push(c):ege(c.completion)>ege(s)&&(i[i.length-1]=c),
s=c.completion}return i}(e,t)
;if(!i.length)return r&&e.some((e=>e.isPending))?r.setDisabled():null
;let s=t.facet(Wme).selectOnOpen?0:-1;if(r&&r.selected!=s&&-1!=r.selected){
let e=r.options[r.selected].completion
;for(let t=0;t<i.length;t++)if(i[t].completion==e){s=t;break}}
return new tge(i,age(n,s),{
pos:e.reduce(((e,t)=>t.hasResult()?Math.min(e,t.from):e),1e8),create:fge,
above:o.aboveCursor},r?r.timestamp:Date.now(),s,!1)}map(e){
return new tge(this.options,this.attrs,Object.assign(Object.assign({},this.tooltip),{
pos:e.mapPos(this.tooltip.pos)}),this.timestamp,this.selected,this.disabled)}
setDisabled(){
return new tge(this.options,this.attrs,this.tooltip,this.timestamp,this.selected,!0)
}}class nge{constructor(e,t,n){this.active=e,this.id=t,this.open=n}
static start(){
return new nge(ige,"cm-ac-"+Math.floor(2e6*Math.random()).toString(36),null)}
update(e){
let{state:t}=e,n=t.facet(Wme),r=(n.override||t.languageDataAt("autocomplete",jme(t)).map(Zme)).map((t=>{
let r=this.active.find((e=>e.source==t))||new lge(t,this.active.some((e=>0!=e.state))?1:0)
;return r.update(e,n)}))
;r.length==this.active.length&&r.every(((e,t)=>e==this.active[t]))&&(r=this.active)
;let o=this.open,a=e.effects.some((e=>e.is(uge)))
;o&&e.docChanged&&(o=o.map(e.changes)),
e.selection||r.some((t=>t.hasResult()&&e.changes.touchesRange(t.from,t.to)))||!function(e,t){
if(e==t)return!0;for(let n=0,r=0;;){for(;n<e.length&&!e[n].hasResult();)n++
;for(;r<t.length&&!t[r].hasResult();)r++;let o=n==e.length,a=r==t.length
;if(o||a)return o==a;if(e[n++].result!=t[r++].result)return!1}
}(r,this.active)||a?o=tge.build(r,t,this.id,o,n,a):o&&o.disabled&&!r.some((e=>e.isPending))&&(o=null),
!o&&r.every((e=>!e.isPending))&&r.some((e=>e.hasResult()))&&(r=r.map((e=>e.hasResult()?new lge(e.source,0):e)))
;for(let i of e.effects)i.is(dge)&&(o=o&&o.setSelected(i.value,this.id))
;return r==this.active&&o==this.open?this:new nge(r,this.id,o)}get tooltip(){
return this.open?this.open.tooltip:null}get attrs(){
return this.open?this.open.attrs:this.active.length?rge:oge}}const rge={
"aria-autocomplete":"list"},oge={};function age(e,t){let n={
"aria-autocomplete":"list","aria-haspopup":"listbox","aria-controls":e}
;return t>-1&&(n["aria-activedescendant"]=e+"-"+t),n}const ige=[]
;function sge(e,t){if(e.isUserEvent("input.complete")){let n=e.annotation(zme)
;if(n&&t.activateOnCompletion(n))return 12}let n=e.isUserEvent("input.type")
;return n&&t.activateOnTyping?5:n?1:e.isUserEvent("delete.backward")?2:e.selection?8:e.docChanged?16:0
}class lge{constructor(e,t,n=!1){this.source=e,this.state=t,this.explicit=n}
hasResult(){return!1}get isPending(){return 1==this.state}update(e,t){
let n=sge(e,t),r=this
;(8&n||16&n&&this.touches(e))&&(r=new lge(r.source,0)),4&n&&0==r.state&&(r=new lge(this.source,1)),
r=r.updateFor(e,n)
;for(let o of e.effects)if(o.is(Qme))r=new lge(r.source,1,o.value);else if(o.is(Hme))r=new lge(r.source,0);else if(o.is(uge))for(let e of o.value)e.source==r.source&&(r=e)
;return r}updateFor(e,t){return this.map(e.changes)}map(e){return this}
touches(e){return e.changes.touchesRange(jme(e.state))}}class cge extends lge{
constructor(e,t,n,r,o,a){
super(e,3,t),this.limit=n,this.result=r,this.from=o,this.to=a}hasResult(){
return!0}updateFor(e,t){var n;if(!(3&t))return this.map(e.changes)
;let r=this.result;r.map&&!e.changes.empty&&(r=r.map(r,e.changes))
;let o=e.changes.mapPos(this.from),a=e.changes.mapPos(this.to,1),i=jme(e.state)
;if(i>a||!r||2&t&&(jme(e.startState)==this.from||i<this.limit))return new lge(this.source,4&t?1:0)
;let s=e.changes.mapPos(this.limit);return function(e,t,n,r){if(!e)return!1
;let o=t.sliceDoc(n,r);return"function"==typeof e?e(o,n,r,t):Ume(e,!0).test(o)
}(r.validFor,e.state,o,a)?new cge(this.source,this.explicit,s,r,o,a):r.update&&(r=r.update(r,o,a,new Nme(e.state,i,!1)))?new cge(this.source,this.explicit,s,r,r.from,null!==(n=r.to)&&void 0!==n?n:jme(e.state)):new lge(this.source,1,this.explicit)
}map(e){if(e.empty)return this
;return(this.result.map?this.result.map(this.result,e):this.result)?new cge(this.source,this.explicit,e.mapPos(this.limit),this.result,e.mapPos(this.from),e.mapPos(this.to,1)):new lge(this.source,0)
}touches(e){return e.changes.touchesRange(this.from,this.to)}}
const uge=_ie.define({map:(e,t)=>e.map((e=>e.map(t)))
}),dge=_ie.define(),pge=nie.define({create:()=>nge.start(),
update:(e,t)=>e.update(t),
provide:e=>[Qde.from(e,(e=>e.tooltip)),cde.contentAttributes.from(e,(e=>e.attrs))]
});function hge(e,t){const n=t.completion.apply||t.completion.label
;let r=e.state.field(pge).active.find((e=>e.source==t.source))
;return r instanceof cge&&("string"==typeof n?e.dispatch(Object.assign(Object.assign({},function(e,t,n,r){
let{main:o}=e.selection,a=n-o.from,i=r-o.from
;return Object.assign(Object.assign({},e.changeByRange((s=>{
if(s!=o&&n!=r&&e.sliceDoc(s.from+a,s.from+i)!=e.sliceDoc(n,r))return{range:s}
;let l=e.toText(t);return{changes:{from:s.from+a,to:r==o.from?s.to:s.from+i,
insert:l},range:Vae.cursor(s.from+a+l.length)}}))),{scrollIntoView:!0,
userEvent:"input.complete"})}(e.state,n,r.from,r.to)),{
annotations:zme.of(t.completion)})):n(e,t.completion,r.from,r.to),!0)}
const fge=Jme(pge,hge);function mge(e,t="option"){return n=>{
let r=n.state.field(pge,!1)
;if(!r||!r.open||r.open.disabled||Date.now()-r.open.timestamp<n.state.facet(Wme).interactionDelay)return!1
;let o,a=1
;"page"==t&&(o=Yde(n,r.open.tooltip))&&(a=Math.max(2,Math.floor(o.dom.offsetHeight/o.dom.querySelector("li").offsetHeight)-1))
;let{length:i}=r.open.options,s=r.open.selected>-1?r.open.selected+a*(e?1:-1):e?0:i-1
;return s<0?s="page"==t?0:i-1:s>=i&&(s="page"==t?i-1:0),n.dispatch({
effects:dge.of(s)}),!0}}const gge=e=>!!e.state.field(pge,!1)&&(e.dispatch({
effects:Qme.of(!0)}),!0);class vge{constructor(e,t){
this.active=e,this.context=t,
this.time=Date.now(),this.updates=[],this.done=void 0}}
const bge=dce.fromClass(class{constructor(e){this.view=e,this.debounceUpdate=-1,
this.running=[],this.debounceAccept=-1,this.pendingStart=!1,this.composing=0
;for(let t of e.state.field(pge).active)t.isPending&&this.startQuery(t)}
update(e){let t=e.state.field(pge),n=e.state.facet(Wme)
;if(!e.selectionSet&&!e.docChanged&&e.startState.field(pge)==t)return
;let r=e.transactions.some((e=>{let t=sge(e,n)
;return 8&t||(e.selection||e.docChanged)&&!(3&t)}))
;for(let a=0;a<this.running.length;a++){let t=this.running[a]
;if(r||t.context.abortOnDocChange&&e.docChanged||t.updates.length+e.transactions.length>50&&Date.now()-t.time>1e3){
for(let e of t.context.abortListeners)try{e()}catch(Bw){sce(this.view.state,Bw)}
t.context.abortListeners=null,this.running.splice(a--,1)
}else t.updates.push(...e.transactions)}
this.debounceUpdate>-1&&clearTimeout(this.debounceUpdate),
e.transactions.some((e=>e.effects.some((e=>e.is(Qme)))))&&(this.pendingStart=!0)
;let o=this.pendingStart?50:n.activateOnTypingDelay
;if(this.debounceUpdate=t.active.some((e=>e.isPending&&!this.running.some((t=>t.active.source==e.source))))?setTimeout((()=>this.startUpdate()),o):-1,
0!=this.composing)for(let a of e.transactions)a.isUserEvent("input.type")?this.composing=2:2==this.composing&&a.selection&&(this.composing=3)
}startUpdate(){this.debounceUpdate=-1,this.pendingStart=!1
;let{state:e}=this.view,t=e.field(pge)
;for(let n of t.active)n.isPending&&!this.running.some((e=>e.active.source==n.source))&&this.startQuery(n)
;this.running.length&&t.open&&t.open.disabled&&(this.debounceAccept=setTimeout((()=>this.accept()),this.view.state.facet(Wme).updateSyncTime))
}startQuery(e){
let{state:t}=this.view,n=jme(t),r=new Nme(t,n,e.explicit,this.view),o=new vge(e,r)
;this.running.push(o),Promise.resolve(e.source(r)).then((e=>{
o.context.aborted||(o.done=e||null,this.scheduleAccept())}),(e=>{
this.view.dispatch({effects:Hme.of(null)}),sce(this.view.state,e)}))}
scheduleAccept(){
this.running.every((e=>void 0!==e.done))?this.accept():this.debounceAccept<0&&(this.debounceAccept=setTimeout((()=>this.accept()),this.view.state.facet(Wme).updateSyncTime))
}accept(){var e
;this.debounceAccept>-1&&clearTimeout(this.debounceAccept),this.debounceAccept=-1
;let t=[],n=this.view.state.facet(Wme),r=this.view.state.field(pge)
;for(let o=0;o<this.running.length;o++){let a=this.running[o]
;if(void 0===a.done)continue;if(this.running.splice(o--,1),a.done){
let r=jme(a.updates.length?a.updates[0].startState:this.view.state),o=Math.min(r,a.done.from+(a.active.explicit?0:1)),i=new cge(a.active.source,a.active.explicit,o,a.done,a.done.from,null!==(e=a.done.to)&&void 0!==e?e:r)
;for(let e of a.updates)i=i.update(e,n);if(i.hasResult()){t.push(i);continue}}
let i=r.active.find((e=>e.source==a.active.source))
;if(i&&i.isPending)if(null==a.done){let e=new lge(a.active.source,0)
;for(let t of a.updates)e=e.update(t,n);e.isPending||t.push(e)
}else this.startQuery(i)}
(t.length||r.open&&r.open.disabled)&&this.view.dispatch({effects:uge.of(t)})}},{
eventHandlers:{blur(e){let t=this.view.state.field(pge,!1)
;if(t&&t.tooltip&&this.view.state.facet(Wme).closeOnBlur){
let n=t.open&&Yde(this.view,t.open.tooltip)
;n&&n.dom.contains(e.relatedTarget)||setTimeout((()=>this.view.dispatch({
effects:Hme.of(null)})),10)}},compositionstart(){this.composing=1},
compositionend(){3==this.composing&&setTimeout((()=>this.view.dispatch({
effects:Qme.of(!1)})),20),this.composing=0}}
}),yge="object"==typeof navigator&&/Win/.test(navigator.platform),Oge=lie.highest(cde.domEventHandlers({
keydown(e,t){let n=t.state.field(pge,!1)
;if(!n||!n.open||n.open.disabled||n.open.selected<0||e.key.length>1||e.ctrlKey&&(!yge||!e.altKey)||e.metaKey)return!1
;let r=n.open.options[n.open.selected],o=n.active.find((e=>e.source==r.source)),a=r.completion.commitCharacters||o.result.commitCharacters
;return a&&a.indexOf(e.key)>-1&&hge(t,r),!1}})),wge=cde.baseTheme({
".cm-tooltip.cm-tooltip-autocomplete":{"& > ul":{fontFamily:"monospace",
whiteSpace:"nowrap",overflow:"hidden auto",maxWidth_fallback:"700px",
maxWidth:"min(700px, 95vw)",minWidth:"250px",maxHeight:"10em",height:"100%",
listStyle:"none",margin:0,padding:0,"& > li, & > completion-section":{
padding:"1px 3px",lineHeight:1.2},"& > li":{overflowX:"hidden",
textOverflow:"ellipsis",cursor:"pointer"},"& > completion-section":{
display:"list-item",borderBottom:"1px solid silver",paddingLeft:"0.5em",
opacity:.7}}},"&light .cm-tooltip-autocomplete ul li[aria-selected]":{
background:"#17c",color:"white"},
"&light .cm-tooltip-autocomplete-disabled ul li[aria-selected]":{
background:"#777"},"&dark .cm-tooltip-autocomplete ul li[aria-selected]":{
background:"#347",color:"white"},
"&dark .cm-tooltip-autocomplete-disabled ul li[aria-selected]":{
background:"#444"},
".cm-completionListIncompleteTop:before, .cm-completionListIncompleteBottom:after":{
content:'"···"',opacity:.5,display:"block",textAlign:"center"},
".cm-tooltip.cm-completionInfo":{position:"absolute",padding:"3px 9px",
width:"max-content",maxWidth:"400px",boxSizing:"border-box",
whiteSpace:"pre-line"},".cm-completionInfo.cm-completionInfo-left":{right:"100%"
},".cm-completionInfo.cm-completionInfo-right":{left:"100%"},
".cm-completionInfo.cm-completionInfo-left-narrow":{right:"30px"},
".cm-completionInfo.cm-completionInfo-right-narrow":{left:"30px"},
"&light .cm-snippetField":{backgroundColor:"#00000022"},
"&dark .cm-snippetField":{backgroundColor:"#ffffff22"},
".cm-snippetFieldPosition":{verticalAlign:"text-top",width:0,height:"1.15em",
display:"inline-block",margin:"0 -0.7px -.7em",borderLeft:"1.4px dotted #888"},
".cm-completionMatchedText":{textDecoration:"underline"},
".cm-completionDetail":{marginLeft:"0.5em",fontStyle:"italic"},
".cm-completionIcon":{fontSize:"90%",width:".8em",display:"inline-block",
textAlign:"center",paddingRight:".6em",opacity:"0.6",boxSizing:"content-box"},
".cm-completionIcon-function, .cm-completionIcon-method":{"&:after":{
content:"'ƒ'"}},".cm-completionIcon-class":{"&:after":{content:"'○'"}},
".cm-completionIcon-interface":{"&:after":{content:"'◌'"}},
".cm-completionIcon-variable":{"&:after":{content:"'𝑥'"}},
".cm-completionIcon-constant":{"&:after":{content:"'𝐶'"}},
".cm-completionIcon-type":{"&:after":{content:"'𝑡'"}},
".cm-completionIcon-enum":{"&:after":{content:"'∪'"}},
".cm-completionIcon-property":{"&:after":{content:"'□'"}},
".cm-completionIcon-keyword":{"&:after":{content:"'🔑︎'"}},
".cm-completionIcon-namespace":{"&:after":{content:"'▢'"}},
".cm-completionIcon-text":{"&:after":{content:"'abc'",fontSize:"50%",
verticalAlign:"middle"}}});class xge{constructor(e,t,n,r){
this.field=e,this.line=t,this.from=n,this.to=r}}class kge{constructor(e,t,n){
this.field=e,this.from=t,this.to=n}map(e){
let t=e.mapPos(this.from,-1,Rae.TrackDel),n=e.mapPos(this.to,1,Rae.TrackDel)
;return null==t||null==n?null:new kge(this.field,t,n)}}class Sge{
constructor(e,t){this.lines=e,this.fieldPositions=t}instantiate(e,t){
let n=[],r=[t],o=e.doc.lineAt(t),a=/^\s*/.exec(o.text)[0]
;for(let i of this.lines){if(n.length){let n=a,o=/^\t*/.exec(i)[0].length
;for(let t=0;t<o;t++)n+=e.facet(cfe);r.push(t+n.length-o),i=n+i.slice(o)}
n.push(i),t+=i.length+1}return{text:n,
ranges:this.fieldPositions.map((e=>new kge(e.field,r[e.line]+e.from,r[e.line]+e.to)))
}}static parse(e){let t,n=[],r=[],o=[];for(let a of e.split(/\r\n?|\n/)){
for(;t=/[#$]\{(?:(\d+)(?::([^}]*))?|((?:\\[{}]|[^}])*))\}/.exec(a);){
let e=t[1]?+t[1]:null,i=t[2]||t[3]||"",s=-1,l=i.replace(/\\[{}]/g,(e=>e[1]))
;for(let t=0;t<n.length;t++)(null!=e?n[t].seq==e:l&&n[t].name==l)&&(s=t)
;if(s<0){let t=0;for(;t<n.length&&(null==e||null!=n[t].seq&&n[t].seq<e);)t++
;n.splice(t,0,{seq:e,name:l}),s=t;for(let e of o)e.field>=s&&e.field++}
o.push(new xge(s,r.length,t.index,t.index+l.length)),
a=a.slice(0,t.index)+i+a.slice(t.index+t[0].length)}
a=a.replace(/\\([{}])/g,((e,t,n)=>{
for(let a of o)a.line==r.length&&a.from>n&&(a.from--,a.to--);return t
})),r.push(a)}return new Sge(r,o)}}let _ge=mle.widget({
widget:new class extends hle{toDOM(){let e=document.createElement("span")
;return e.className="cm-snippetFieldPosition",e}ignoreEvent(){return!1}}
}),Tge=mle.mark({class:"cm-snippetField"});class Ege{constructor(e,t){
this.ranges=e,
this.active=t,this.deco=mle.set(e.map((e=>(e.from==e.to?_ge:Tge).range(e.from,e.to))))
}map(e){let t=[];for(let n of this.ranges){let r=n.map(e);if(!r)return null
;t.push(r)}return new Ege(t,this.active)}selectionInsideField(e){
return e.ranges.every((e=>this.ranges.some((t=>t.field==this.active&&t.from<=e.from&&t.to>=e.to))))
}}const Age=_ie.define({map:(e,t)=>e&&e.map(t)
}),Cge=_ie.define(),$ge=nie.define({create:()=>null,update(e,t){
for(let n of t.effects){if(n.is(Age))return n.value
;if(n.is(Cge)&&e)return new Ege(e.ranges,n.value)}
return e&&t.docChanged&&(e=e.map(t.changes)),
e&&t.selection&&!e.selectionInsideField(t.selection)&&(e=null),e},
provide:e=>cde.decorations.from(e,(e=>e?e.deco:mle.none))});function Pge(e,t){
return Vae.create(e.filter((e=>e.field==t)).map((e=>Vae.range(e.from,e.to))))}
function Dge(e){let t=Sge.parse(e);return(e,n,r,o)=>{
let{text:a,ranges:i}=t.instantiate(e.state,r),s={changes:{from:r,to:o,
insert:wae.of(a)},scrollIntoView:!0,
annotations:n?[zme.of(n),Tie.userEvent.of("input.complete")]:void 0}
;if(i.length&&(s.selection=Pge(i,0)),i.some((e=>e.field>0))){
let t=new Ege(i,0),n=s.effects=[Age.of(t)]
;void 0===e.state.field($ge,!1)&&n.push(_ie.appendConfig.of([$ge,Rge,Bge,wge]))}
e.dispatch(e.state.update(s))}}function Ige(e){return({state:t,dispatch:n})=>{
let r=t.field($ge,!1);if(!r||e<0&&0==r.active)return!1
;let o=r.active+e,a=e>0&&!r.ranges.some((t=>t.field==o+e));return n(t.update({
selection:Pge(r.ranges,o),effects:Age.of(a?null:new Ege(r.ranges,o)),
scrollIntoView:!0})),!0}}const Mge=[{key:"Tab",run:Ige(1),shift:Ige(-1)},{
key:"Escape",run:({state:e,dispatch:t})=>!!e.field($ge,!1)&&(t(e.update({
effects:Age.of(null)})),!0)}],Nge=Xae.define({combine:e=>e.length?e[0]:Mge
}),Rge=lie.highest(vde.compute([Nge],(e=>e.facet(Nge))));function Lge(e,t){
return Object.assign(Object.assign({},t),{apply:Dge(e)})}
const Bge=cde.domEventHandlers({mousedown(e,t){let n,r=t.state.field($ge,!1)
;if(!r||null==(n=t.posAtCoords({x:e.clientX,y:e.clientY})))return!1
;let o=r.ranges.find((e=>e.from<=n&&e.to>=n))
;return!(!o||o.field==r.active)&&(t.dispatch({selection:Pge(r.ranges,o.field),
effects:Age.of(r.ranges.some((e=>e.field>o.field))?new Ege(r.ranges,o.field):null),
scrollIntoView:!0}),!0)}}),jge={brackets:["(","[","{","'",'"'],before:")]}:;>",
stringPrefixes:[]},Uge=_ie.define({map(e,t){let n=t.mapPos(e,-1,Rae.TrackAfter)
;return null==n?void 0:n}}),zge=new class extends jie{}
;zge.startSide=1,zge.endSide=-1;const Fge=nie.define({create:()=>Zie.empty,
update(e,t){if(e=e.map(t.changes),t.selection){
let n=t.state.doc.lineAt(t.selection.main.head);e=e.update({
filter:e=>e>=n.from&&e<=n.to})}for(let n of t.effects)n.is(Uge)&&(e=e.update({
add:[zge.range(n.value,n.value+1)]}));return e}});const Zge="()[]{}<>"
;function Qge(e){
for(let t=0;t<Zge.length;t+=2)if(Zge.charCodeAt(t)==e)return Zge.charAt(t+1)
;return Iae(e<128?e:e+1)}function Hge(e,t){
return e.languageDataAt("closeBrackets",t)[0]||jge}
const Vge="object"==typeof navigator&&/Android\b/.test(navigator.userAgent),qge=cde.inputHandler.of(((e,t,n,r)=>{
if((Vge?e.composing:e.compositionStarted)||e.state.readOnly)return!1
;let o=e.state.selection.main
;if(r.length>2||2==r.length&&1==Mae(Dae(r,0))||t!=o.from||n!=o.to)return!1
;let a=function(e,t){
let n=Hge(e,e.selection.main.head),r=n.brackets||jge.brackets;for(let o of r){
let a=Qge(Dae(o,0))
;if(t==o)return a==o?Jge(e,o,r.indexOf(o+o+o)>-1,n):Yge(e,o,a,n.before||jge.before)
;if(t==a&&Xge(e,e.selection.main.from))return Kge(e,o,a)}return null}(e.state,r)
;return!!a&&(e.dispatch(a),!0)})),Wge=[{key:"Backspace",
run:({state:e,dispatch:t})=>{if(e.readOnly)return!1
;let n=Hge(e,e.selection.main.head).brackets||jge.brackets,r=null,o=e.changeByRange((t=>{
if(t.empty){let r=function(e,t){let n=e.sliceString(t-2,t)
;return Mae(Dae(n,0))==n.length?n:n.slice(1)}(e.doc,t.head)
;for(let o of n)if(o==r&&Gge(e.doc,t.head)==Qge(Dae(o,0)))return{changes:{
from:t.head-o.length,to:t.head+o.length},range:Vae.cursor(t.head-o.length)}}
return{range:r=t}}));return r||t(e.update(o,{scrollIntoView:!0,
userEvent:"delete.backward"})),!r}}];function Xge(e,t){let n=!1
;return e.field(Fge).between(0,e.doc.length,(e=>{e==t&&(n=!0)})),n}
function Gge(e,t){let n=e.sliceString(t,t+2);return n.slice(0,Mae(Dae(n,0)))}
function Yge(e,t,n,r){let o=null,a=e.changeByRange((a=>{if(!a.empty)return{
changes:[{insert:t,from:a.from},{insert:n,from:a.to}],
effects:Uge.of(a.to+t.length),range:Vae.range(a.anchor+t.length,a.head+t.length)
};let i=Gge(e.doc,a.head);return!i||/\s/.test(i)||r.indexOf(i)>-1?{changes:{
insert:t+n,from:a.head},effects:Uge.of(a.head+t.length),
range:Vae.cursor(a.head+t.length)}:{range:o=a}}));return o?null:e.update(a,{
scrollIntoView:!0,userEvent:"input.type"})}function Kge(e,t,n){
let r=null,o=e.changeByRange((t=>t.empty&&Gge(e.doc,t.head)==n?{changes:{
from:t.head,to:t.head+n.length,insert:n},range:Vae.cursor(t.head+n.length)}:r={
range:t}));return r?null:e.update(o,{scrollIntoView:!0,userEvent:"input.type"})}
function Jge(e,t,n,r){
let o=r.stringPrefixes||jge.stringPrefixes,a=null,i=e.changeByRange((r=>{
if(!r.empty)return{changes:[{insert:t,from:r.from},{insert:t,from:r.to}],
effects:Uge.of(r.to+t.length),range:Vae.range(r.anchor+t.length,r.head+t.length)
};let i,s=r.head,l=Gge(e.doc,s);if(l==t){if(eve(e,s))return{changes:{insert:t+t,
from:s},effects:Uge.of(s+t.length),range:Vae.cursor(s+t.length)};if(Xge(e,s)){
let r=n&&e.sliceDoc(s,s+3*t.length)==t+t+t?t+t+t:t;return{changes:{from:s,
to:s+r.length,insert:r},range:Vae.cursor(s+r.length)}}}else{
if(n&&e.sliceDoc(s-2*t.length,s)==t+t&&(i=tve(e,s-2*t.length,o))>-1&&eve(e,i))return{
changes:{insert:t+t+t+t,from:s},effects:Uge.of(s+t.length),
range:Vae.cursor(s+t.length)}
;if(e.charCategorizer(s)(l)!=Iie.Word&&tve(e,s,o)>-1&&!function(e,t,n,r){
let o=Yhe(e).resolveInner(t,-1),a=r.reduce(((e,t)=>Math.max(e,t.length)),0)
;for(let i=0;i<5;i++){
let i=e.sliceDoc(o.from,Math.min(o.to,o.from+n.length+a)),s=i.indexOf(n)
;if(!s||s>-1&&r.indexOf(i.slice(0,s))>-1){let t=o.firstChild
;for(;t&&t.from==o.from&&t.to-t.from>n.length+s;){
if(e.sliceDoc(t.to-n.length,t.to)==n)return!1;t=t.firstChild}return!0}
let l=o.to==t&&o.parent;if(!l)break;o=l}return!1}(e,s,t,o))return{changes:{
insert:t+t,from:s},effects:Uge.of(s+t.length),range:Vae.cursor(s+t.length)}}
return{range:a=r}}));return a?null:e.update(i,{scrollIntoView:!0,
userEvent:"input.type"})}function eve(e,t){let n=Yhe(e).resolveInner(t+1)
;return n.parent&&n.from==t}function tve(e,t,n){let r=e.charCategorizer(t)
;if(r(e.sliceDoc(t-1,t))!=Iie.Word)return t;for(let o of n){let n=t-o.length
;if(e.sliceDoc(n,t)==o&&r(e.sliceDoc(n-1,n))!=Iie.Word)return n}return-1}
const nve=[{key:"Ctrl-Space",run:gge},{mac:"Alt-`",run:gge},{key:"Escape",
run:e=>{let t=e.state.field(pge,!1)
;return!(!t||!t.active.some((e=>0!=e.state)))&&(e.dispatch({effects:Hme.of(null)
}),!0)}},{key:"ArrowDown",run:mge(!0)},{key:"ArrowUp",run:mge(!1)},{
key:"PageDown",run:mge(!0,"page")},{key:"PageUp",run:mge(!1,"page")},{
key:"Enter",run:e=>{let t=e.state.field(pge,!1)
;return!(e.state.readOnly||!t||!t.open||t.open.selected<0||t.open.disabled||Date.now()-t.open.timestamp<e.state.facet(Wme).interactionDelay)&&hge(e,t.open.options[t.open.selected])
}
}],rve=lie.highest(vde.computeN([Wme],(e=>e.facet(Wme).defaultKeymap?[nve]:[]))),ove=xie.define(),ave=xie.define(),ive=Xae.define(),sve=Xae.define({
combine:e=>Bie(e,{minDepth:100,newGroupDelay:500,joinToEvent:(e,t)=>t},{
minDepth:Math.max,newGroupDelay:Math.min,
joinToEvent:(e,t)=>(n,r)=>e(n,r)||t(n,r)})}),lve=nie.define({
create:()=>_ve.empty,update(e,t){let n=t.state.facet(sve),r=t.annotation(ove)
;if(r){let o=mve.fromTransaction(t,r.selection),a=r.side,i=0==a?e.undone:e.done
;return i=o?gve(i,i.length,n.minDepth,o):Ove(i,t.startState.selection),
new _ve(0==a?r.rest:i,0==a?i:r.rest)}let o=t.annotation(ave)
;if("full"!=o&&"before"!=o||(e=e.isolate()),
!1===t.annotation(Tie.addToHistory))return t.changes.empty?e:e.addMapping(t.changes.desc)
;let a=mve.fromTransaction(t),i=t.annotation(Tie.time),s=t.annotation(Tie.userEvent)
;return a?e=e.addChanges(a,i,s,n,t):t.selection&&(e=e.addSelection(t.startState.selection,i,s,n.newGroupDelay)),
"full"!=o&&"after"!=o||(e=e.isolate()),e},toJSON:e=>({
done:e.done.map((e=>e.toJSON())),undone:e.undone.map((e=>e.toJSON()))}),
fromJSON:e=>new _ve(e.done.map(mve.fromJSON),e.undone.map(mve.fromJSON))})
;function cve(e={}){return[lve,sve.of(e),cde.domEventHandlers({beforeinput(e,t){
let n="historyUndo"==e.inputType?dve:"historyRedo"==e.inputType?pve:null
;return!!n&&(e.preventDefault(),n(t))}})]}function uve(e,t){
return function({state:n,dispatch:r}){if(!t&&n.readOnly)return!1
;let o=n.field(lve,!1);if(!o)return!1;let a=o.pop(e,n,t);return!!a&&(r(a),!0)}}
const dve=uve(0,!1),pve=uve(1,!1),hve=uve(0,!0),fve=uve(1,!0);class mve{
constructor(e,t,n,r,o){
this.changes=e,this.effects=t,this.mapped=n,this.startSelection=r,
this.selectionsAfter=o}setSelAfter(e){
return new mve(this.changes,this.effects,this.mapped,this.startSelection,e)}
toJSON(){var e,t,n;return{
changes:null===(e=this.changes)||void 0===e?void 0:e.toJSON(),
mapped:null===(t=this.mapped)||void 0===t?void 0:t.toJSON(),
startSelection:null===(n=this.startSelection)||void 0===n?void 0:n.toJSON(),
selectionsAfter:this.selectionsAfter.map((e=>e.toJSON()))}}static fromJSON(e){
return new mve(e.changes&&Bae.fromJSON(e.changes),[],e.mapped&&Lae.fromJSON(e.mapped),e.startSelection&&Vae.fromJSON(e.startSelection),e.selectionsAfter.map(Vae.fromJSON))
}static fromTransaction(e,t){let n=bve;for(let r of e.startState.facet(ive)){
let t=r(e);t.length&&(n=n.concat(t))}
return!n.length&&e.changes.empty?null:new mve(e.changes.invert(e.startState.doc),n,void 0,t||e.startState.selection,bve)
}static selection(e){return new mve(void 0,bve,void 0,void 0,e)}}
function gve(e,t,n,r){let o=t+1>n+20?t-n-1:0,a=e.slice(o,t);return a.push(r),a}
function vve(e,t){return e.length?t.length?e.concat(t):e:t}const bve=[],yve=200
;function Ove(e,t){if(e.length){
let n=e[e.length-1],r=n.selectionsAfter.slice(Math.max(0,n.selectionsAfter.length-yve))
;return r.length&&r[r.length-1].eq(t)?e:(r.push(t),
gve(e,e.length-1,1e9,n.setSelAfter(r)))}return[mve.selection([t])]}
function wve(e){let t=e[e.length-1],n=e.slice()
;return n[e.length-1]=t.setSelAfter(t.selectionsAfter.slice(0,t.selectionsAfter.length-1)),
n}function xve(e,t){if(!e.length)return e;let n=e.length,r=bve;for(;n;){
let o=kve(e[n-1],t,r);if(o.changes&&!o.changes.empty||o.effects.length){
let t=e.slice(0,n);return t[n-1]=o,t}t=o.mapped,n--,r=o.selectionsAfter}
return r.length?[mve.selection(r)]:bve}function kve(e,t,n){
let r=vve(e.selectionsAfter.length?e.selectionsAfter.map((e=>e.map(t))):bve,n)
;if(!e.changes)return mve.selection(r)
;let o=e.changes.map(t),a=t.mapDesc(e.changes,!0),i=e.mapped?e.mapped.composeDesc(a):a
;return new mve(o,_ie.mapEffects(e.effects,t),i,e.startSelection.map(a),r)}
const Sve=/^(input\.type|delete)($|\.)/;class _ve{constructor(e,t,n=0,r=void 0){
this.done=e,this.undone=t,this.prevTime=n,this.prevUserEvent=r}isolate(){
return this.prevTime?new _ve(this.done,this.undone):this}addChanges(e,t,n,r,o){
let a=this.done,i=a[a.length-1]
;return a=i&&i.changes&&!i.changes.empty&&e.changes&&(!n||Sve.test(n))&&(!i.selectionsAfter.length&&t-this.prevTime<r.newGroupDelay&&r.joinToEvent(o,function(e,t){
let n=[],r=!1
;return e.iterChangedRanges(((e,t)=>n.push(e,t))),t.iterChangedRanges(((e,t,o,a)=>{
for(let i=0;i<n.length;){let e=n[i++],t=n[i++];a>=e&&o<=t&&(r=!0)}})),r
}(i.changes,e.changes))||"input.type.compose"==n)?gve(a,a.length-1,r.minDepth,new mve(e.changes.compose(i.changes),vve(_ie.mapEffects(e.effects,i.changes),i.effects),i.mapped,i.startSelection,bve)):gve(a,a.length,r.minDepth,e),
new _ve(a,bve,t,n)}addSelection(e,t,n,r){
let o=this.done.length?this.done[this.done.length-1].selectionsAfter:bve
;return o.length>0&&t-this.prevTime<r&&n==this.prevUserEvent&&n&&/^select($|\.)/.test(n)&&(a=o[o.length-1],
i=e,
a.ranges.length==i.ranges.length&&0===a.ranges.filter(((e,t)=>e.empty!=i.ranges[t].empty)).length)?this:new _ve(Ove(this.done,e),this.undone,t,n)
;var a,i}addMapping(e){
return new _ve(xve(this.done,e),xve(this.undone,e),this.prevTime,this.prevUserEvent)
}pop(e,t,n){let r=0==e?this.done:this.undone;if(0==r.length)return null
;let o=r[r.length-1],a=o.selectionsAfter[0]||t.selection
;if(n&&o.selectionsAfter.length)return t.update({
selection:o.selectionsAfter[o.selectionsAfter.length-1],annotations:ove.of({
side:e,rest:wve(r),selection:a}),userEvent:0==e?"select.undo":"select.redo",
scrollIntoView:!0});if(o.changes){let n=1==r.length?bve:r.slice(0,r.length-1)
;return o.mapped&&(n=xve(n,o.mapped)),t.update({changes:o.changes,
selection:o.startSelection,effects:o.effects,annotations:ove.of({side:e,rest:n,
selection:a}),filter:!1,userEvent:0==e?"undo":"redo",scrollIntoView:!0})}
return null}}_ve.empty=new _ve(bve,bve);const Tve=[{key:"Mod-z",run:dve,
preventDefault:!0},{key:"Mod-y",mac:"Mod-Shift-z",run:pve,preventDefault:!0},{
linux:"Ctrl-Shift-z",run:pve,preventDefault:!0},{key:"Mod-u",run:hve,
preventDefault:!0},{key:"Alt-u",mac:"Mod-Shift-u",run:fve,preventDefault:!0
}],Eve=({state:e,dispatch:t})=>(t(e.update(e.replaceSelection(e.lineBreak),{
scrollIntoView:!0,userEvent:"input"})),!0);function Ave(e,t){let n=-1
;return e.changeByRange((r=>{let o=[];for(let i=r.from;i<=r.to;){
let a=e.doc.lineAt(i);a.number>n&&(r.empty||r.to>a.from)&&(t(a,o,r),n=a.number),
i=a.to+1}let a=e.changes(o);return{changes:o,
range:Vae.range(a.mapPos(r.anchor,1),a.mapPos(r.head,1))}}))}const Cve={
key:"Tab",run:({state:e,dispatch:t})=>!e.readOnly&&(t(e.update(Ave(e,((t,n)=>{
n.push({from:t.from,insert:e.facet(cfe)})})),{userEvent:"input.indent"})),!0),
shift:({state:e,dispatch:t})=>!e.readOnly&&(t(e.update(Ave(e,((t,n)=>{
let r=/^\s*/.exec(t.text)[0];if(!r)return
;let o=tse(r,e.tabSize),a=0,i=dfe(e,Math.max(0,o-ufe(e)))
;for(;a<r.length&&a<i.length&&r.charCodeAt(a)==i.charCodeAt(a);)a++;n.push({
from:t.from+a,to:t.from+r.length,insert:i.slice(a)})})),{
userEvent:"delete.dedent"})),!0)};class $ve{
constructor(e,t,n,r,o,a,i,s,l,c=0,u){
this.p=e,this.stack=t,this.state=n,this.reducePos=r,
this.pos=o,this.score=a,this.buffer=i,
this.bufferBase=s,this.curContext=l,this.lookAhead=c,this.parent=u}toString(){
return`[${this.stack.filter(((e,t)=>t%3==0)).concat(this.state)}]@${this.pos}${this.score?"!"+this.score:""}`
}static start(e,t,n=0){let r=e.parser.context
;return new $ve(e,[],t,n,n,0,[],0,r?new Pve(r,r.start):null,0,null)}
get context(){return this.curContext?this.curContext.context:null}
pushState(e,t){this.stack.push(this.state,t,this.bufferBase+this.buffer.length),
this.state=e}reduce(e){var t
;let n=e>>19,r=65535&e,{parser:o}=this.p,a=this.reducePos<this.pos-25
;a&&this.setLookAhead(this.pos);let i=o.dynamicPrecedence(r)
;if(i&&(this.score+=i),
0==n)return this.pushState(o.getGoto(this.state,r,!0),this.reducePos),
r<o.minRepeatTerm&&this.storeNode(r,this.reducePos,this.reducePos,a?8:4,!0),
void this.reduceContext(r,this.reducePos)
;let s=this.stack.length-3*(n-1)-(262144&e?6:0),l=s?this.stack[s-2]:this.p.ranges[0].from,c=this.reducePos-l
;c>=2e3&&!(null===(t=this.p.parser.nodeSet.types[r])||void 0===t?void 0:t.isAnonymous)&&(l==this.p.lastBigReductionStart?(this.p.bigReductionCount++,
this.p.lastBigReductionSize=c):this.p.lastBigReductionSize<c&&(this.p.bigReductionCount=1,
this.p.lastBigReductionStart=l,this.p.lastBigReductionSize=c))
;let u=s?this.stack[s-1]:0,d=this.bufferBase+this.buffer.length-u
;if(r<o.minRepeatTerm||131072&e){
let e=o.stateFlag(this.state,1)?this.pos:this.reducePos
;this.storeNode(r,l,e,d+4,!0)}if(262144&e)this.state=this.stack[s];else{
let e=this.stack[s-3];this.state=o.getGoto(e,r,!0)}
for(;this.stack.length>s;)this.stack.pop();this.reduceContext(r,l)}
storeNode(e,t,n,r=4,o=!1){
if(0==e&&(!this.stack.length||this.stack[this.stack.length-1]<this.buffer.length+this.bufferBase)){
let e=this,r=this.buffer.length
;if(0==r&&e.parent&&(r=e.bufferBase-e.parent.bufferBase,
e=e.parent),r>0&&0==e.buffer[r-4]&&e.buffer[r-1]>-1){if(t==n)return
;if(e.buffer[r-2]>=t)return void(e.buffer[r-2]=n)}}if(o&&this.pos!=n){
let o=this.buffer.length;if(o>0&&0!=this.buffer[o-4]){let e=!1
;for(let t=o;t>0&&this.buffer[t-2]>n;t-=4)if(this.buffer[t-1]>=0){e=!0;break}
if(e)for(;o>0&&this.buffer[o-2]>n;)this.buffer[o]=this.buffer[o-4],
this.buffer[o+1]=this.buffer[o-3],
this.buffer[o+2]=this.buffer[o-2],this.buffer[o+3]=this.buffer[o-1],
o-=4,r>4&&(r-=4)}
this.buffer[o]=e,this.buffer[o+1]=t,this.buffer[o+2]=n,this.buffer[o+3]=r
}else this.buffer.push(e,t,n,r)}shift(e,t,n,r){
if(131072&e)this.pushState(65535&e,this.pos);else if(262144&e)this.pos=r,
this.shiftContext(t,n),t<=this.p.parser.maxNode&&this.buffer.push(t,n,r,4);else{
let o=e,{parser:a}=this.p
;(r>this.pos||t<=a.maxNode)&&(this.pos=r,a.stateFlag(o,1)||(this.reducePos=r)),
this.pushState(o,n),
this.shiftContext(t,n),t<=a.maxNode&&this.buffer.push(t,n,r,4)}}apply(e,t,n,r){
65536&e?this.reduce(e):this.shift(e,t,n,r)}useNode(e,t){
let n=this.p.reused.length-1;(n<0||this.p.reused[n]!=e)&&(this.p.reused.push(e),
n++);let r=this.pos
;this.reducePos=this.pos=r+e.length,this.pushState(t,r),this.buffer.push(n,r,this.reducePos,-1),
this.curContext&&this.updateContext(this.curContext.tracker.reuse(this.curContext.context,e,this,this.p.stream.reset(this.pos-e.length)))
}split(){let e=this,t=e.buffer.length;for(;t>0&&e.buffer[t-2]>e.reducePos;)t-=4
;let n=e.buffer.slice(t),r=e.bufferBase+t;for(;e&&r==e.bufferBase;)e=e.parent
;return new $ve(this.p,this.stack.slice(),this.state,this.reducePos,this.pos,this.score,n,r,this.curContext,this.lookAhead,e)
}recoverByDelete(e,t){let n=e<=this.p.parser.maxNode
;n&&this.storeNode(e,this.pos,t,4),
this.storeNode(0,this.pos,t,n?8:4),this.pos=this.reducePos=t,this.score-=190}
canShift(e){for(let t=new Dve(this);;){
let n=this.p.parser.stateSlot(t.state,4)||this.p.parser.hasAction(t.state,e)
;if(0==n)return!1;if(!(65536&n))return!0;t.reduce(n)}}recoverByInsert(e){
if(this.stack.length>=300)return[];let t=this.p.parser.nextStates(this.state)
;if(t.length>8||this.stack.length>=120){let n=[]
;for(let r,o=0;o<t.length;o+=2)(r=t[o+1])!=this.state&&this.p.parser.hasAction(r,e)&&n.push(t[o],r)
;if(this.stack.length<120)for(let e=0;n.length<8&&e<t.length;e+=2){let r=t[e+1]
;n.some(((e,t)=>1&t&&e==r))||n.push(t[e],r)}t=n}let n=[]
;for(let r=0;r<t.length&&n.length<4;r+=2){let e=t[r+1];if(e==this.state)continue
;let o=this.split()
;o.pushState(e,this.pos),o.storeNode(0,o.pos,o.pos,4,!0),o.shiftContext(t[r],this.pos),
o.reducePos=this.pos,o.score-=200,n.push(o)}return n}forceReduce(){
let{parser:e}=this.p,t=e.stateSlot(this.state,5);if(!(65536&t))return!1
;if(!e.validAction(this.state,t)){let n=t>>19,r=65535&t,o=this.stack.length-3*n
;if(o<0||e.getGoto(this.stack[o],r,!1)<0){let e=this.findForcedReduction()
;if(null==e)return!1;t=e}
this.storeNode(0,this.pos,this.pos,4,!0),this.score-=100}
return this.reducePos=this.pos,this.reduce(t),!0}findForcedReduction(){
let{parser:e}=this.p,t=[],n=(r,o)=>{
if(!t.includes(r))return t.push(r),e.allActions(r,(t=>{
if(393216&t);else if(65536&t){let n=(t>>19)-o;if(n>1){
let r=65535&t,o=this.stack.length-3*n
;if(o>=0&&e.getGoto(this.stack[o],r,!1)>=0)return n<<19|65536|r}}else{
let e=n(t,o+1);if(null!=e)return e}}))};return n(this.state,0)}forceAll(){
for(;!this.p.parser.stateFlag(this.state,2);)if(!this.forceReduce()){
this.storeNode(0,this.pos,this.pos,4,!0);break}return this}get deadEnd(){
if(3!=this.stack.length)return!1;let{parser:e}=this.p
;return 65535==e.data[e.stateSlot(this.state,1)]&&!e.stateSlot(this.state,4)}
restart(){
this.storeNode(0,this.pos,this.pos,4,!0),this.state=this.stack[0],this.stack.length=0
}sameState(e){if(this.state!=e.state||this.stack.length!=e.stack.length)return!1
;for(let t=0;t<this.stack.length;t+=3)if(this.stack[t]!=e.stack[t])return!1
;return!0}get parser(){return this.p.parser}dialectEnabled(e){
return this.p.parser.dialect.flags[e]}shiftContext(e,t){
this.curContext&&this.updateContext(this.curContext.tracker.shift(this.curContext.context,e,this,this.p.stream.reset(t)))
}reduceContext(e,t){
this.curContext&&this.updateContext(this.curContext.tracker.reduce(this.curContext.context,e,this,this.p.stream.reset(t)))
}emitContext(){let e=this.buffer.length-1
;(e<0||-3!=this.buffer[e])&&this.buffer.push(this.curContext.hash,this.pos,this.pos,-3)
}emitLookAhead(){let e=this.buffer.length-1
;(e<0||-4!=this.buffer[e])&&this.buffer.push(this.lookAhead,this.pos,this.pos,-4)
}updateContext(e){if(e!=this.curContext.context){
let t=new Pve(this.curContext.tracker,e)
;t.hash!=this.curContext.hash&&this.emitContext(),this.curContext=t}}
setLookAhead(e){e>this.lookAhead&&(this.emitLookAhead(),this.lookAhead=e)}
close(){
this.curContext&&this.curContext.tracker.strict&&this.emitContext(),this.lookAhead>0&&this.emitLookAhead()
}}class Pve{constructor(e,t){
this.tracker=e,this.context=t,this.hash=e.strict?e.hash(t):0}}class Dve{
constructor(e){
this.start=e,this.state=e.state,this.stack=e.stack,this.base=this.stack.length}
reduce(e){let t=65535&e,n=e>>19
;0==n?(this.stack==this.start.stack&&(this.stack=this.stack.slice()),
this.stack.push(this.state,0,0),this.base+=3):this.base-=3*(n-1)
;let r=this.start.p.parser.getGoto(this.stack[this.base-3],t,!0);this.state=r}}
class Ive{constructor(e,t,n){
this.stack=e,this.pos=t,this.index=n,this.buffer=e.buffer,
0==this.index&&this.maybeNext()}static create(e,t=e.bufferBase+e.buffer.length){
return new Ive(e,t,t-e.bufferBase)}maybeNext(){let e=this.stack.parent
;null!=e&&(this.index=this.stack.bufferBase-e.bufferBase,
this.stack=e,this.buffer=e.buffer)}get id(){return this.buffer[this.index-4]}
get start(){return this.buffer[this.index-3]}get end(){
return this.buffer[this.index-2]}get size(){return this.buffer[this.index-1]}
next(){this.index-=4,this.pos-=4,0==this.index&&this.maybeNext()}fork(){
return new Ive(this.stack,this.pos,this.index)}}function Mve(e,t=Uint16Array){
if("string"!=typeof e)return e;let n=null;for(let r=0,o=0;r<e.length;){let a=0
;for(;;){let t=e.charCodeAt(r++),n=!1;if(126==t){a=65535;break}
t>=92&&t--,t>=34&&t--;let o=t-32;if(o>=46&&(o-=46,n=!0),a+=o,n)break;a*=46}
n?n[o++]=a:n=new t(a)}return n}class Nve{constructor(){
this.start=-1,this.value=-1,
this.end=-1,this.extended=-1,this.lookAhead=0,this.mask=0,this.context=0}}
const Rve=new Nve;class Lve{constructor(e,t){
this.input=e,this.ranges=t,this.chunk="",
this.chunkOff=0,this.chunk2="",this.chunk2Pos=0,
this.next=-1,this.token=Rve,this.rangeIndex=0,
this.pos=this.chunkPos=t[0].from,this.range=t[0],
this.end=t[t.length-1].to,this.readNext()}resolveOffset(e,t){
let n=this.range,r=this.rangeIndex,o=this.pos+e;for(;o<n.from;){
if(!r)return null;let e=this.ranges[--r];o-=n.from-e.to,n=e}
for(;t<0?o>n.to:o>=n.to;){if(r==this.ranges.length-1)return null
;let e=this.ranges[++r];o+=e.from-n.to,n=e}return o}clipPos(e){
if(e>=this.range.from&&e<this.range.to)return e
;for(let t of this.ranges)if(t.to>e)return Math.max(e,t.from);return this.end}
peek(e){let t,n,r=this.chunkOff+e
;if(r>=0&&r<this.chunk.length)t=this.pos+e,n=this.chunk.charCodeAt(r);else{
let r=this.resolveOffset(e,1);if(null==r)return-1
;if(t=r,t>=this.chunk2Pos&&t<this.chunk2Pos+this.chunk2.length)n=this.chunk2.charCodeAt(t-this.chunk2Pos);else{
let e=this.rangeIndex,r=this.range;for(;r.to<=t;)r=this.ranges[++e]
;this.chunk2=this.input.chunk(this.chunk2Pos=t),
t+this.chunk2.length>r.to&&(this.chunk2=this.chunk2.slice(0,r.to-t)),
n=this.chunk2.charCodeAt(0)}}
return t>=this.token.lookAhead&&(this.token.lookAhead=t+1),n}acceptToken(e,t=0){
let n=t?this.resolveOffset(t,-1):this.pos
;if(null==n||n<this.token.start)throw new RangeError("Token end out of bounds")
;this.token.value=e,this.token.end=n}acceptTokenTo(e,t){
this.token.value=e,this.token.end=t}getChunk(){
if(this.pos>=this.chunk2Pos&&this.pos<this.chunk2Pos+this.chunk2.length){
let{chunk:e,chunkPos:t}=this
;this.chunk=this.chunk2,this.chunkPos=this.chunk2Pos,
this.chunk2=e,this.chunk2Pos=t,this.chunkOff=this.pos-this.chunkPos}else{
this.chunk2=this.chunk,this.chunk2Pos=this.chunkPos
;let e=this.input.chunk(this.pos),t=this.pos+e.length
;this.chunk=t>this.range.to?e.slice(0,this.range.to-this.pos):e,
this.chunkPos=this.pos,this.chunkOff=0}}readNext(){
return this.chunkOff>=this.chunk.length&&(this.getChunk(),
this.chunkOff==this.chunk.length)?this.next=-1:this.next=this.chunk.charCodeAt(this.chunkOff)
}advance(e=1){for(this.chunkOff+=e;this.pos+e>=this.range.to;){
if(this.rangeIndex==this.ranges.length-1)return this.setDone()
;e-=this.range.to-this.pos,
this.range=this.ranges[++this.rangeIndex],this.pos=this.range.from}
return this.pos+=e,
this.pos>=this.token.lookAhead&&(this.token.lookAhead=this.pos+1),
this.readNext()}setDone(){
return this.pos=this.chunkPos=this.end,this.range=this.ranges[this.rangeIndex=this.ranges.length-1],
this.chunk="",this.next=-1}reset(e,t){
if(t?(this.token=t,t.start=e,t.lookAhead=e+1,
t.value=t.extended=-1):this.token=Rve,this.pos!=e){
if(this.pos=e,e==this.end)return this.setDone(),this
;for(;e<this.range.from;)this.range=this.ranges[--this.rangeIndex]
;for(;e>=this.range.to;)this.range=this.ranges[++this.rangeIndex]
;e>=this.chunkPos&&e<this.chunkPos+this.chunk.length?this.chunkOff=e-this.chunkPos:(this.chunk="",
this.chunkOff=0),this.readNext()}return this}read(e,t){
if(e>=this.chunkPos&&t<=this.chunkPos+this.chunk.length)return this.chunk.slice(e-this.chunkPos,t-this.chunkPos)
;if(e>=this.chunk2Pos&&t<=this.chunk2Pos+this.chunk2.length)return this.chunk2.slice(e-this.chunk2Pos,t-this.chunk2Pos)
;if(e>=this.range.from&&t<=this.range.to)return this.input.read(e,t);let n=""
;for(let r of this.ranges){if(r.from>=t)break
;r.to>e&&(n+=this.input.read(Math.max(r.from,e),Math.min(r.to,t)))}return n}}
class Bve{constructor(e,t){this.data=e,this.id=t}token(e,t){let{parser:n}=t.p
;zve(this.data,e,t,this.id,n.data,n.tokenPrecTable)}}
Bve.prototype.contextual=Bve.prototype.fallback=Bve.prototype.extend=!1
;class jve{constructor(e,t,n){
this.precTable=t,this.elseToken=n,this.data="string"==typeof e?Mve(e):e}
token(e,t){let n=e.pos,r=0;for(;;){let n=e.next<0,o=e.resolveOffset(1,1)
;if(zve(this.data,e,t,0,this.data,this.precTable),e.token.value>-1)break
;if(null==this.elseToken)return;if(n||r++,null==o)break;e.reset(o,e.token)}
r&&(e.reset(n,e.token),e.acceptToken(this.elseToken,r))}}
jve.prototype.contextual=Bve.prototype.fallback=Bve.prototype.extend=!1
;class Uve{constructor(e,t={}){
this.token=e,this.contextual=!!t.contextual,this.fallback=!!t.fallback,
this.extend=!!t.extend}}function zve(e,t,n,r,o,a){
let i=0,s=1<<r,{dialect:l}=n.p.parser;e:for(;s&e[i];){let n=e[i+1]
;for(let d=i+3;d<n;d+=2)if((e[d+1]&s)>0){let n=e[d]
;if(l.allows(n)&&(-1==t.token.value||t.token.value==n||Zve(n,t.token.value,o,a))){
t.acceptToken(n);break}}let r=t.next,c=0,u=e[i+2]
;if(!(t.next<0&&u>c&&65535==e[n+3*u-3])){for(;c<u;){
let o=c+u>>1,a=n+o+(o<<1),s=e[a],l=e[a+1]||65536;if(r<s)u=o;else{if(!(r>=l)){
i=e[a+2],t.advance();continue e}c=o+1}}break}i=e[n+3*u-1]}}function Fve(e,t,n){
for(let r,o=t;65535!=(r=e[o]);o++)if(r==n)return o-t;return-1}
function Zve(e,t,n,r){let o=Fve(n,r,t);return o<0||Fve(n,r,e)<o}
const Qve="undefined"!=typeof process&&process.env&&/\bparse\b/.test(process.env.LOG)
;let Hve=null;function Vve(e,t,n){let r=e.cursor(Npe.IncludeAnonymous)
;for(r.moveTo(t);;)if(!(n<0?r.childBefore(t):r.childAfter(t)))for(;;){
if((n<0?r.to<t:r.from>t)&&!r.type.isError)return n<0?Math.max(0,Math.min(r.to-1,t-25)):Math.min(e.length,Math.max(r.from+1,t+25))
;if(n<0?r.prevSibling():r.nextSibling())break
;if(!r.parent())return n<0?0:e.length}}class qve{constructor(e,t){
this.fragments=e,
this.nodeSet=t,this.i=0,this.fragment=null,this.safeFrom=-1,this.safeTo=-1,
this.trees=[],this.start=[],this.index=[],this.nextFragment()}nextFragment(){
let e=this.fragment=this.i==this.fragments.length?null:this.fragments[this.i++]
;if(e){
for(this.safeFrom=e.openStart?Vve(e.tree,e.from+e.offset,1)-e.offset:e.from,
this.safeTo=e.openEnd?Vve(e.tree,e.to+e.offset,-1)-e.offset:e.to;this.trees.length;)this.trees.pop(),
this.start.pop(),this.index.pop()
;this.trees.push(e.tree),this.start.push(-e.offset),
this.index.push(0),this.nextStart=this.safeFrom}else this.nextStart=1e9}
nodeAt(e){if(e<this.nextStart)return null
;for(;this.fragment&&this.safeTo<=e;)this.nextFragment()
;if(!this.fragment)return null;for(;;){let t=this.trees.length-1
;if(t<0)return this.nextFragment(),null;let n=this.trees[t],r=this.index[t]
;if(r==n.children.length){this.trees.pop(),this.start.pop(),this.index.pop()
;continue}let o=n.children[r],a=this.start[t]+n.positions[r]
;if(a>e)return this.nextStart=a,null;if(o instanceof Lpe){if(a==e){
if(a<this.safeFrom)return null;let e=a+o.length;if(e<=this.safeTo){
let t=o.prop(Ape.lookAhead);if(!t||e+t<this.fragment.to)return o}}
this.index[t]++,
a+o.length>=Math.max(this.safeFrom,e)&&(this.trees.push(o),this.start.push(a),
this.index.push(0))}else this.index[t]++,this.nextStart=a+o.length}}}class Wve{
constructor(e,t){
this.stream=t,this.tokens=[],this.mainToken=null,this.actions=[],
this.tokens=e.tokenizers.map((e=>new Nve))}getActions(e){
let t=0,n=null,{parser:r}=e.p,{tokenizers:o}=r,a=r.stateSlot(e.state,3),i=e.curContext?e.curContext.hash:0,s=0
;for(let l=0;l<o.length;l++){if(!(1<<l&a))continue;let r=o[l],c=this.tokens[l]
;if((!n||r.fallback)&&((r.contextual||c.start!=e.pos||c.mask!=a||c.context!=i)&&(this.updateCachedToken(c,r,e),
c.mask=a,
c.context=i),c.lookAhead>c.end+25&&(s=Math.max(c.lookAhead,s)),0!=c.value)){
let o=t
;if(c.extended>-1&&(t=this.addActions(e,c.extended,c.end,t)),t=this.addActions(e,c.value,c.end,t),
!r.extend&&(n=c,t>o))break}}for(;this.actions.length>t;)this.actions.pop()
;return s&&e.setLookAhead(s),
n||e.pos!=this.stream.end||(n=new Nve,n.value=e.p.parser.eofTerm,
n.start=n.end=e.pos,
t=this.addActions(e,n.value,n.end,t)),this.mainToken=n,this.actions}
getMainToken(e){if(this.mainToken)return this.mainToken
;let t=new Nve,{pos:n,p:r}=e
;return t.start=n,t.end=Math.min(n+1,r.stream.end),t.value=n==r.stream.end?r.parser.eofTerm:0,
t}updateCachedToken(e,t,n){let r=this.stream.clipPos(n.pos)
;if(t.token(this.stream.reset(r,e),n),e.value>-1){let{parser:t}=n.p
;for(let r=0;r<t.specialized.length;r++)if(t.specialized[r]==e.value){
let o=t.specializers[r](this.stream.read(e.start,e.end),n)
;if(o>=0&&n.p.parser.dialect.allows(o>>1)){1&o?e.extended=o>>1:e.value=o>>1
;break}}}else e.value=0,e.end=this.stream.clipPos(r+1)}putAction(e,t,n,r){
for(let o=0;o<r;o+=3)if(this.actions[o]==e)return r
;return this.actions[r++]=e,this.actions[r++]=t,this.actions[r++]=n,r}
addActions(e,t,n,r){let{state:o}=e,{parser:a}=e.p,{data:i}=a
;for(let s=0;s<2;s++)for(let e=a.stateSlot(o,s?2:1);;e+=3){if(65535==i[e]){
if(1!=i[e+1]){0==r&&2==i[e+1]&&(r=this.putAction(tbe(i,e+2),t,n,r));break}
e=tbe(i,e+2)}i[e]==t&&(r=this.putAction(tbe(i,e+1),t,n,r))}return r}}class Xve{
constructor(e,t,n,r){this.parser=e,this.input=t,this.ranges=r,this.recovering=0,
this.nextStackID=9812,
this.minStackPos=0,this.reused=[],this.stoppedAt=null,this.lastBigReductionStart=-1,
this.lastBigReductionSize=0,
this.bigReductionCount=0,this.stream=new Lve(t,r),this.tokens=new Wve(e,this.stream),
this.topTerm=e.top[1];let{from:o}=r[0];this.stacks=[$ve.start(this,e.top[0],o)],
this.fragments=n.length&&this.stream.end-o>4*e.bufferLength?new qve(n,e.nodeSet):null
}get parsedPos(){return this.minStackPos}advance(){
let e,t,n=this.stacks,r=this.minStackPos,o=this.stacks=[]
;if(this.bigReductionCount>300&&1==n.length){let[e]=n
;for(;e.forceReduce()&&e.stack.length&&e.stack[e.stack.length-2]>=this.lastBigReductionStart;);
this.bigReductionCount=this.lastBigReductionSize=0}for(let a=0;a<n.length;a++){
let i=n[a];for(;;){if(this.tokens.mainToken=null,i.pos>r)o.push(i);else{
if(this.advanceStack(i,o,n))continue;{e||(e=[],t=[]),e.push(i)
;let n=this.tokens.getMainToken(i);t.push(n.value,n.end)}}break}}if(!o.length){
let t=e&&function(e){let t=null;for(let n of e){let e=n.p.stoppedAt
;(n.pos==n.p.stream.end||null!=e&&n.pos>e)&&n.p.parser.stateFlag(n.state,2)&&(!t||t.score<n.score)&&(t=n)
}return t}(e)
;if(t)return Qve&&console.log("Finish with "+this.stackID(t)),this.stackToTree(t)
;if(this.parser.strict)throw Qve&&e&&console.log("Stuck with token "+(this.tokens.mainToken?this.parser.getName(this.tokens.mainToken.value):"none")),
new SyntaxError("No parse at "+r);this.recovering||(this.recovering=5)}
if(this.recovering&&e){
let n=null!=this.stoppedAt&&e[0].pos>this.stoppedAt?e[0]:this.runRecovery(e,t,o)
;if(n)return Qve&&console.log("Force-finish "+this.stackID(n)),
this.stackToTree(n.forceAll())}if(this.recovering){
let e=1==this.recovering?1:3*this.recovering
;if(o.length>e)for(o.sort(((e,t)=>t.score-e.score));o.length>e;)o.pop()
;o.some((e=>e.reducePos>r))&&this.recovering--}else if(o.length>1){
e:for(let e=0;e<o.length-1;e++){let t=o[e];for(let n=e+1;n<o.length;n++){
let r=o[n];if(t.sameState(r)||t.buffer.length>500&&r.buffer.length>500){
if(!((t.score-r.score||t.buffer.length-r.buffer.length)>0)){o.splice(e--,1)
;continue e}o.splice(n--,1)}}}o.length>12&&o.splice(12,o.length-12)}
this.minStackPos=o[0].pos
;for(let a=1;a<o.length;a++)o[a].pos<this.minStackPos&&(this.minStackPos=o[a].pos)
;return null}stopAt(e){
if(null!=this.stoppedAt&&this.stoppedAt<e)throw new RangeError("Can't move stoppedAt forward")
;this.stoppedAt=e}advanceStack(e,t,n){
let r=e.pos,{parser:o}=this,a=Qve?this.stackID(e)+" -> ":""
;if(null!=this.stoppedAt&&r>this.stoppedAt)return e.forceReduce()?e:null
;if(this.fragments){
let t=e.curContext&&e.curContext.tracker.strict,n=t?e.curContext.hash:0
;for(let i=this.fragments.nodeAt(r);i;){
let r=this.parser.nodeSet.types[i.type.id]==i.type?o.getGoto(e.state,i.type.id):-1
;if(r>-1&&i.length&&(!t||(i.prop(Ape.contextHash)||0)==n))return e.useNode(i,r),
Qve&&console.log(a+this.stackID(e)+` (via reuse of ${o.getName(i.type.id)})`),!0
;if(!(i instanceof Lpe)||0==i.children.length||i.positions[0]>0)break
;let s=i.children[0];if(!(s instanceof Lpe&&0==i.positions[0]))break;i=s}}
let i=o.stateSlot(e.state,4)
;if(i>0)return e.reduce(i),Qve&&console.log(a+this.stackID(e)+` (via always-reduce ${o.getName(65535&i)})`),
!0;if(e.stack.length>=8400)for(;e.stack.length>6e3&&e.forceReduce(););
let s=this.tokens.getActions(e);for(let l=0;l<s.length;){
let i=s[l++],c=s[l++],u=s[l++],d=l==s.length||!n,p=d?e:e.split(),h=this.tokens.mainToken
;if(p.apply(i,c,h?h.start:p.pos,u),
Qve&&console.log(a+this.stackID(p)+` (via ${65536&i?`reduce of ${o.getName(65535&i)}`:"shift"} for ${o.getName(c)} @ ${r}${p==e?"":", split"})`),
d)return!0;p.pos>r?t.push(p):n.push(p)}return!1}advanceFully(e,t){let n=e.pos
;for(;;){if(!this.advanceStack(e,null,null))return!1;if(e.pos>n)return Gve(e,t),
!0}}runRecovery(e,t,n){let r=null,o=!1;for(let a=0;a<e.length;a++){
let i=e[a],s=t[a<<1],l=t[1+(a<<1)],c=Qve?this.stackID(i)+" -> ":""
;if(i.deadEnd){if(o)continue
;if(o=!0,i.restart(),Qve&&console.log(c+this.stackID(i)+" (restarted)"),
this.advanceFully(i,n))continue}let u=i.split(),d=c
;for(let e=0;u.forceReduce()&&e<10;e++){
if(Qve&&console.log(d+this.stackID(u)+" (via force-reduce)"),
this.advanceFully(u,n))break;Qve&&(d=this.stackID(u)+" -> ")}
for(let e of i.recoverByInsert(s))Qve&&console.log(c+this.stackID(e)+" (via recover-insert)"),
this.advanceFully(e,n)
;this.stream.end>i.pos?(l==i.pos&&(l++,s=0),i.recoverByDelete(s,l),
Qve&&console.log(c+this.stackID(i)+` (via recover-delete ${this.parser.getName(s)})`),
Gve(i,n)):(!r||r.score<i.score)&&(r=i)}return r}stackToTree(e){return e.close(),
Lpe.build({buffer:Ive.create(e),nodeSet:this.parser.nodeSet,topID:this.topTerm,
maxBufferLength:this.parser.bufferLength,reused:this.reused,
start:this.ranges[0].from,length:e.pos-this.ranges[0].from,
minRepeatType:this.parser.minRepeatTerm})}stackID(e){
let t=(Hve||(Hve=new WeakMap)).get(e)
;return t||Hve.set(e,t=String.fromCodePoint(this.nextStackID++)),t+e}}
function Gve(e,t){for(let n=0;n<t.length;n++){let r=t[n]
;if(r.pos==e.pos&&r.sameState(e))return void(t[n].score<e.score&&(t[n]=e))}
t.push(e)}class Yve{constructor(e,t,n){
this.source=e,this.flags=t,this.disabled=n}allows(e){
return!this.disabled||0==this.disabled[e]}}const Kve=e=>e;class Jve{
constructor(e){
this.start=e.start,this.shift=e.shift||Kve,this.reduce=e.reduce||Kve,
this.reuse=e.reuse||Kve,this.hash=e.hash||(()=>0),this.strict=!1!==e.strict}}
class ebe extends rhe{constructor(e){
if(super(),this.wrappers=[],14!=e.version)throw new RangeError(`Parser version (${e.version}) doesn't match runtime version (14)`)
;let t=e.nodeNames.split(" ");this.minRepeatTerm=t.length
;for(let i=0;i<e.repeatNodeCount;i++)t.push("")
;let n=Object.keys(e.topRules).map((t=>e.topRules[t][1])),r=[]
;for(let i=0;i<t.length;i++)r.push([]);function o(e,t,n){
r[e].push([t,t.deserialize(String(n))])}
if(e.nodeProps)for(let i of e.nodeProps){let e=i[0]
;"string"==typeof e&&(e=Ape[e]);for(let t=1;t<i.length;){let n=i[t++]
;if(n>=0)o(n,e,i[t++]);else{let r=i[t+-n];for(let a=-n;a>0;a--)o(i[t++],e,r);t++
}}}this.nodeSet=new Dpe(t.map(((t,o)=>Ppe.define({
name:o>=this.minRepeatTerm?void 0:t,id:o,props:r[o],top:n.indexOf(o)>-1,
error:0==o,skipped:e.skippedNodes&&e.skippedNodes.indexOf(o)>-1
})))),e.propSources&&(this.nodeSet=this.nodeSet.extend(...e.propSources)),
this.strict=!1,this.bufferLength=_pe;let a=Mve(e.tokenData)
;this.context=e.context,
this.specializerSpecs=e.specialized||[],this.specialized=new Uint16Array(this.specializerSpecs.length)
;for(let i=0;i<this.specializerSpecs.length;i++)this.specialized[i]=this.specializerSpecs[i].term
;this.specializers=this.specializerSpecs.map(nbe),
this.states=Mve(e.states,Uint32Array),
this.data=Mve(e.stateData),this.goto=Mve(e.goto),
this.maxTerm=e.maxTerm,this.tokenizers=e.tokenizers.map((e=>"number"==typeof e?new Bve(a,e):e)),
this.topRules=e.topRules,
this.dialects=e.dialects||{},this.dynamicPrecedences=e.dynamicPrecedences||null,
this.tokenPrecTable=e.tokenPrec,
this.termNames=e.termNames||null,this.maxNode=this.nodeSet.types.length-1,
this.dialect=this.parseDialect(),
this.top=this.topRules[Object.keys(this.topRules)[0]]}createParse(e,t,n){
let r=new Xve(this,e,t,n);for(let o of this.wrappers)r=o(r,e,t,n);return r}
getGoto(e,t,n=!1){let r=this.goto;if(t>=r[0])return-1;for(let o=r[t+1];;){
let t=r[o++],a=1&t,i=r[o++];if(a&&n)return i
;for(let n=o+(t>>1);o<n;o++)if(r[o]==e)return i;if(a)return-1}}hasAction(e,t){
let n=this.data;for(let r=0;r<2;r++)for(let o,a=this.stateSlot(e,r?2:1);;a+=3){
if(65535==(o=n[a])){if(1!=n[a+1]){if(2==n[a+1])return tbe(n,a+2);break}
o=n[a=tbe(n,a+2)]}if(o==t||0==o)return tbe(n,a+1)}return 0}stateSlot(e,t){
return this.states[6*e+t]}stateFlag(e,t){return(this.stateSlot(e,0)&t)>0}
validAction(e,t){return!!this.allActions(e,(e=>e==t||null))}allActions(e,t){
let n=this.stateSlot(e,4),r=n?t(n):void 0
;for(let o=this.stateSlot(e,1);null==r;o+=3){if(65535==this.data[o]){
if(1!=this.data[o+1])break;o=tbe(this.data,o+2)}r=t(tbe(this.data,o+1))}return r
}nextStates(e){let t=[];for(let n=this.stateSlot(e,1);;n+=3){
if(65535==this.data[n]){if(1!=this.data[n+1])break;n=tbe(this.data,n+2)}
if(!(1&this.data[n+2])){let e=this.data[n+1]
;t.some(((t,n)=>1&n&&t==e))||t.push(this.data[n],e)}}return t}configure(e){
let t=Object.assign(Object.create(ebe.prototype),this)
;if(e.props&&(t.nodeSet=this.nodeSet.extend(...e.props)),e.top){
let n=this.topRules[e.top]
;if(!n)throw new RangeError(`Invalid top rule name ${e.top}`);t.top=n}
return e.tokenizers&&(t.tokenizers=this.tokenizers.map((t=>{
let n=e.tokenizers.find((e=>e.from==t));return n?n.to:t
}))),e.specializers&&(t.specializers=this.specializers.slice(),
t.specializerSpecs=this.specializerSpecs.map(((n,r)=>{
let o=e.specializers.find((e=>e.from==n.external));if(!o)return n
;let a=Object.assign(Object.assign({},n),{external:o.to})
;return t.specializers[r]=nbe(a),a
}))),e.contextTracker&&(t.context=e.contextTracker),
e.dialect&&(t.dialect=this.parseDialect(e.dialect)),
null!=e.strict&&(t.strict=e.strict),
e.wrap&&(t.wrappers=t.wrappers.concat(e.wrap)),
null!=e.bufferLength&&(t.bufferLength=e.bufferLength),t}hasWrappers(){
return this.wrappers.length>0}getName(e){
return this.termNames?this.termNames[e]:String(e<=this.maxNode&&this.nodeSet.types[e].name||e)
}get eofTerm(){return this.maxNode+1}get topNode(){
return this.nodeSet.types[this.top[1]]}dynamicPrecedence(e){
let t=this.dynamicPrecedences;return null==t?0:t[e]||0}parseDialect(e){
let t=Object.keys(this.dialects),n=t.map((()=>!1))
;if(e)for(let o of e.split(" ")){let e=t.indexOf(o);e>=0&&(n[e]=!0)}let r=null
;for(let o=0;o<t.length;o++)if(!n[o])for(let e,n=this.dialects[t[o]];65535!=(e=this.data[n++]);)(r||(r=new Uint8Array(this.maxTerm+1)))[e]=1
;return new Yve(e,n,r)}static deserialize(e){return new ebe(e)}}
function tbe(e,t){return e[t]|e[t+1]<<16}function nbe(e){if(e.external){
let t=e.extend?1:0;return(n,r)=>e.external(n,r)<<1|t}return e.get}
const rbe=[9,10,11,12,13,32,133,160,5760,8192,8193,8194,8195,8196,8197,8198,8199,8200,8201,8202,8232,8233,8239,8287,12288]
;function obe(e){return e>=65&&e<=90||e>=97&&e<=122||e>=161}function abe(e){
return e>=48&&e<=57}const ibe=new Uve(((e,t)=>{for(let n=!1,r=0,o=0;;o++){
let{next:a}=e
;if(obe(a)||45==a||95==a||n&&abe(a))!n&&(45!=a||o>0)&&(n=!0),r===o&&45==a&&r++,
e.advance();else{if(92!=a||10==e.peek(1)){
n&&e.acceptToken(40==a?100:2==r&&t.canShift(2)?2:101);break}
e.advance(),e.next>-1&&e.advance(),n=!0}}})),sbe=new Uve((e=>{
if(rbe.includes(e.peek(-1))){let{next:t}=e
;(obe(t)||95==t||35==t||46==t||91==t||58==t&&obe(e.peek(1))||45==t||38==t)&&e.acceptToken(99)
}})),lbe=new Uve((e=>{if(!rbe.includes(e.peek(-1))){let{next:t}=e
;if(37==t&&(e.advance(),e.acceptToken(1)),obe(t)){do{e.advance()
}while(obe(e.next)||abe(e.next));e.acceptToken(1)}}})),cbe=xhe({
"AtKeyword import charset namespace keyframes media supports":Zhe.definitionKeyword,
"from to selector":Zhe.keyword,NamespaceName:Zhe.namespace,
KeyframeName:Zhe.labelName,KeyframeRangeName:Zhe.operatorKeyword,
TagName:Zhe.tagName,ClassName:Zhe.className,
PseudoClassName:Zhe.constant(Zhe.className),IdName:Zhe.labelName,
"FeatureName PropertyName":Zhe.propertyName,AttributeName:Zhe.attributeName,
NumberLiteral:Zhe.number,KeywordQuery:Zhe.keyword,
UnaryQueryOp:Zhe.operatorKeyword,"CallTag ValueName":Zhe.atom,
VariableName:Zhe.variableName,Callee:Zhe.operatorKeyword,Unit:Zhe.unit,
"UniversalSelector NestingSelector":Zhe.definitionOperator,
MatchOp:Zhe.compareOperator,"ChildOp SiblingOp, LogicOp":Zhe.logicOperator,
BinOp:Zhe.arithmeticOperator,Important:Zhe.modifier,Comment:Zhe.blockComment,
ColorLiteral:Zhe.color,"ParenthesizedContent StringLiteral":Zhe.string,
":":Zhe.punctuation,"PseudoOp #":Zhe.derefOperator,"; ,":Zhe.separator,
"( )":Zhe.paren,"[ ]":Zhe.squareBracket,"{ }":Zhe.brace}),ube={__proto__:null,
lang:32,"nth-child":32,"nth-last-child":32,"nth-of-type":32,
"nth-last-of-type":32,dir:32,"host-context":32,url:60,"url-prefix":60,domain:60,
regexp:60,selector:138},dbe={__proto__:null,"@import":118,"@media":142,
"@charset":146,"@namespace":150,"@keyframes":156,"@supports":168},pbe={
__proto__:null,not:132,only:132},hbe=ebe.deserialize({version:14,
states:":^QYQ[OOO#_Q[OOP#fOWOOOOQP'#Cd'#CdOOQP'#Cc'#CcO#kQ[O'#CfO$_QXO'#CaO$fQ[O'#ChO$qQ[O'#DTO$vQ[O'#DWOOQP'#Em'#EmO${QdO'#DgO%jQ[O'#DtO${QdO'#DvO%{Q[O'#DxO&WQ[O'#D{O&`Q[O'#ERO&nQ[O'#ETOOQS'#El'#ElOOQS'#EW'#EWQYQ[OOO&uQXO'#CdO'jQWO'#DcO'oQWO'#EsO'zQ[O'#EsQOQWOOP(UO#tO'#C_POOO)C@[)C@[OOQP'#Cg'#CgOOQP,59Q,59QO#kQ[O,59QO(aQ[O'#E[O({QWO,58{O)TQ[O,59SO$qQ[O,59oO$vQ[O,59rO(aQ[O,59uO(aQ[O,59wO(aQ[O,59xO)`Q[O'#DbOOQS,58{,58{OOQP'#Ck'#CkOOQO'#DR'#DROOQP,59S,59SO)gQWO,59SO)lQWO,59SOOQP'#DV'#DVOOQP,59o,59oOOQO'#DX'#DXO)qQ`O,59rOOQS'#Cp'#CpO${QdO'#CqO)yQvO'#CsO+ZQtO,5:ROOQO'#Cx'#CxO)lQWO'#CwO+oQWO'#CyO+tQ[O'#DOOOQS'#Ep'#EpOOQO'#Dj'#DjO+|Q[O'#DqO,[QWO'#EtO&`Q[O'#DoO,jQWO'#DrOOQO'#Eu'#EuO)OQWO,5:`O,oQpO,5:bOOQS'#Dz'#DzO,wQWO,5:dO,|Q[O,5:dOOQO'#D}'#D}O-UQWO,5:gO-ZQWO,5:mO-cQWO,5:oOOQS-E8U-E8UO${QdO,59}O-kQ[O'#E^O-xQWO,5;_O-xQWO,5;_POOO'#EV'#EVP.TO#tO,58yPOOO,58y,58yOOQP1G.l1G.lO.zQXO,5:vOOQO-E8Y-E8YOOQS1G.g1G.gOOQP1G.n1G.nO)gQWO1G.nO)lQWO1G.nOOQP1G/Z1G/ZO/XQ`O1G/^O/rQXO1G/aO0YQXO1G/cO0pQXO1G/dO1WQWO,59|O1]Q[O'#DSO1dQdO'#CoOOQP1G/^1G/^O${QdO1G/^O1kQpO,59]OOQS,59_,59_O${QdO,59aO1sQWO1G/mOOQS,59c,59cO1xQ!bO,59eOOQS'#DP'#DPOOQS'#EY'#EYO2QQ[O,59jOOQS,59j,59jO2YQWO'#DjO2eQWO,5:VO2jQWO,5:]O&`Q[O,5:XO&`Q[O'#E_O2rQWO,5;`O2}QWO,5:ZO(aQ[O,5:^OOQS1G/z1G/zOOQS1G/|1G/|OOQS1G0O1G0OO3`QWO1G0OO3eQdO'#EOOOQS1G0R1G0ROOQS1G0X1G0XOOQS1G0Z1G0ZO3pQtO1G/iOOQO,5:x,5:xO4WQ[O,5:xOOQO-E8[-E8[O4eQWO1G0yPOOO-E8T-E8TPOOO1G.e1G.eOOQP7+$Y7+$YOOQP7+$x7+$xO${QdO7+$xOOQS1G/h1G/hO4pQXO'#ErO4wQWO,59nO4|QtO'#EXO5tQdO'#EoO6OQWO,59ZO6TQpO7+$xOOQS1G.w1G.wOOQS1G.{1G.{OOQS7+%X7+%XO6]QWO1G/POOQS-E8W-E8WOOQS1G/U1G/UO${QdO1G/qOOQO1G/w1G/wOOQO1G/s1G/sO6bQWO,5:yOOQO-E8]-E8]O6pQXO1G/xOOQS7+%j7+%jO6wQYO'#CsOOQO'#EQ'#EQO7SQ`O'#EPOOQO'#EP'#EPO7_QWO'#E`O7gQdO,5:jOOQS,5:j,5:jO7rQtO'#E]O${QdO'#E]O8sQdO7+%TOOQO7+%T7+%TOOQO1G0d1G0dO9WQpO<<HdO9`QWO,5;^OOQP1G/Y1G/YOOQS-E8V-E8VO${QdO'#EZO9hQWO,5;ZOOQT1G.u1G.uOOQP<<Hd<<HdOOQS7+$k7+$kO9pQdO7+%]OOQO7+%d7+%dOOQO,5:k,5:kO3hQdO'#EaO7_QWO,5:zOOQS,5:z,5:zOOQS-E8^-E8^OOQS1G0U1G0UO9wQtO,5:wOOQS-E8Z-E8ZOOQO<<Ho<<HoOOQPAN>OAN>OO:xQdO,5:uOOQO-E8X-E8XOOQO<<Hw<<HwOOQO,5:{,5:{OOQO-E8_-E8_OOQS1G0f1G0f",
stateData:";[~O#ZOS#[QQ~OUYOXYO]VO^VOqXOxWO![aO!]ZO!i[O!k]O!m^O!p_O!v`O#XRO#bTO~OQfOUYOXYO]VO^VOqXOxWO![aO!]ZO!i[O!k]O!m^O!p_O!v`O#XeO#bTO~O#U#gP~P!ZO#[jO~O#XlO~O]qO^qOqsOtoOxrO!OtO!RvO#VuO#bnO~O!TwO~P#pO`}O#WzO#XyO~O#X!OO~O#X!QO~OQ![Ob!TOf![Oh![On!YOq!ZO#W!WO#X!SO#e!UO~Ob!^O!d!`O!g!aO#X!]O!T#hP~Oh!fOn!YO#X!eO~Oh!hO#X!hO~Ob!^O!d!`O!g!aO#X!]O~O!Y#hP~P%jO]WX]!WX^WXqWXtWXxWX!OWX!RWX!TWX#VWX#bWX~O]!mO~O!Y!nO#U#gX!S#gX~O#U#gX!S#gX~P!ZO#]!qO#^!qO#_!sO~OUYOXYO]VO^VOqXOxWO#XRO#bTO~OtoO!TwO~O`!zO#WzO#XyO~O!S#gP~P!ZOb#RO~Ob#SO~Op#TO|#UO~OP#WObgXjgX!YgX!dgX!ggX#XgXagXQgXfgXhgXngXqgXtgX!XgX#UgX#WgX#egXpgX!SgX~Ob!^Oj#XO!d!`O!g!aO#X!]O!Y#hP~Ob#[O~Op#`O#X#]O~Ob!^O!d!`O!g!aO#X#aO~Ot#eO!b#dO!T#hX!Y#hX~Ob#hO~Oj#XO!Y#jO~O!Y#kO~Oh#lOn!YO~O!T#mO~O!TwO!b#dO~O!TwO!Y#pO~O!Y#QX#U#QX!S#QX~P!ZO!Y!nO#U#ga!S#ga~O#]!qO#^!qO#_#wO~O]qO^qOqsOxrO!OtO!RvO#VuO#bnO~Ot#Oa!T#Oaa#Oa~P.`Op#yO|#zO~O]qO^qOqsOxrO#bnO~Ot}i!O}i!R}i!T}i#V}ia}i~P/aOt!Pi!O!Pi!R!Pi!T!Pi#V!Pia!Pi~P/aOt!Qi!O!Qi!R!Qi!T!Qi#V!Qia!Qi~P/aO!S#{O~Oa#fP~P(aOa#cP~P${Oa$SOj#XO~O!Y$UO~Oh$VOo$VO~Op$XO#X#]O~O]!`Xa!^X!b!^X~O]$YO~Oa$ZO!b#dO~Ot#eO!T#ha!Y#ha~O!b#dOt!ca!T!ca!Y!caa!ca~O!Y$`O~O!S$gO#X$bO#e$aO~Oj#XOt$iO!X$kO!Y!Vi#U!Vi!S!Vi~P${O!Y#Qa#U#Qa!S#Qa~P!ZO!Y!nO#U#gi!S#gi~Oa#fX~P#pOa$oO~Oj#XOQ!{Xa!{Xb!{Xf!{Xh!{Xn!{Xq!{Xt!{X#W!{X#X!{X#e!{X~Ot$qOa#cX~P${Oa$sO~Oj#XOp$tO~Oa$uO~O!b#dOt#Ra!T#Ra!Y#Ra~Oa$wO~P.`OP#WOtgX!TgX~O#e$aOt!sX!T!sX~Ot$yO!TwO~O!S$}O#X$bO#e$aO~Oj#XOQ#PXb#PXf#PXh#PXn#PXq#PXt#PX!X#PX!Y#PX#U#PX#W#PX#X#PX#e#PX!S#PX~Ot$iO!X%QO!Y!Vq#U!Vq!S!Vq~P${Oj#XOp%RO~OtoOa#fa~Ot$qOa#ca~Oa%UO~P${Oj#XOQ#Pab#Paf#Pah#Pan#Paq#Pat#Pa!X#Pa!Y#Pa#U#Pa#W#Pa#X#Pa#e#Pa!S#Pa~Oa!}at!}a~P${O#Zo#[#ej!R#e~",
goto:"-g#jPPP#kP#nP#w$WP#w$g#wPP$mPPP$s$|$|P%`P$|P$|%z&^PPPP$|&vP&z'Q#wP'W#w'^P#wP#w#wPPP'd'y(WPP#nPP(_(_(i(_P(_P(_(_P#nP#nP#nP(l#nP(o(r(u(|#nP#nP)R)X)h)v)|*S*^*d*n*t*zPPPPPPPPPP+Q+ZP+v+yP,o,r,x-RRkQ_bOPdhw!n#skYOPdhotuvw!n#R#h#skSOPdhotuvw!n#R#h#sQmTR!tnQ{VR!xqQ!x}Q#Z!XR#x!zq![Z]!T!m#S#U#X#q#z$P$Y$i$j$q$v%Sp![Z]!T!m#S#U#X#q#z$P$Y$i$j$q$v%SU$d#m$f$yR$x$cq!XZ]!T!m#S#U#X#q#z$P$Y$i$j$q$v%Sp![Z]!T!m#S#U#X#q#z$P$Y$i$j$q$v%SQ!f^R#l!gT#^!Z#_Q|VR!yqQ!x|R#x!yQ!PWR!{rQ!RXR!|sQxUQ!wpQ#i!cQ#o!jQ#p!kQ${$eR%X$zSgPwQ!phQ#r!nR$l#sZfPhw!n#sa!b[`a!V!^!`#d#eR#b!^R!g^R!i_R#n!iS$e#m$fR%V$yV$c#m$f$yQ!rjR#v!rQdOShPwU!ldh#sR#s!nQ$P#SU$p$P$v%SQ$v$YR%S$qQ#_!ZR$W#_Q$r$PR%T$rQpUS!vp$nR$n#|Q$j#qR%P$jQ!ogS#t!o#uR#u!pQ#f!_R$^#fQ$f#mR$|$fQ$z$eR%W$z_cOPdhw!n#s^UOPdhw!n#sQ!uoQ!}tQ#OuQ#PvQ#|#RR$_#hR$Q#SQ!VZQ!d]Q#V!TQ#q!m[$O#S$P$Y$q$v%SQ$R#UQ$T#XS$h#q$jQ$m#zR%O$iR#}#RQiPR#QwQ!c[Q!kaR#Y!VU!_[a!VQ!j`Q#c!^Q#g!`Q$[#dR$]#e",
nodeNames:"⚠ Unit VariableName Comment StyleSheet RuleSet UniversalSelector TagSelector TagName NestingSelector ClassSelector ClassName PseudoClassSelector : :: PseudoClassName PseudoClassName ) ( ArgList ValueName ParenthesizedValue ColorLiteral NumberLiteral StringLiteral BinaryExpression BinOp CallExpression Callee CallLiteral CallTag ParenthesizedContent ] [ LineNames LineName , PseudoClassName ArgList IdSelector # IdName AttributeSelector AttributeName MatchOp ChildSelector ChildOp DescendantSelector SiblingSelector SiblingOp } { Block Declaration PropertyName Important ; ImportStatement AtKeyword import KeywordQuery FeatureQuery FeatureName BinaryQuery LogicOp UnaryQuery UnaryQueryOp ParenthesizedQuery SelectorQuery selector MediaStatement media CharsetStatement charset NamespaceStatement namespace NamespaceName KeyframesStatement keyframes KeyframeName KeyframeList KeyframeSelector KeyframeRangeName SupportsStatement supports AtRule Styles",
maxTerm:117,
nodeProps:[["isolate",-2,3,24,""],["openedBy",17,"(",32,"[",50,"{"],["closedBy",18,")",33,"]",51,"}"]],
propSources:[cbe],skippedNodes:[0,3,87],repeatNodeCount:11,
tokenData:"J^~R!^OX$}X^%u^p$}pq%uqr)Xrs.Rst/utu6duv$}vw7^wx7oxy9^yz9oz{9t{|:_|}?Q}!O?c!O!P@Q!P!Q@i!Q![Ab![!]B]!]!^CX!^!_$}!_!`Cj!`!aC{!a!b$}!b!cDw!c!}$}!}#OFa#O#P$}#P#QFr#Q#R6d#R#T$}#T#UGT#U#c$}#c#dHf#d#o$}#o#pH{#p#q6d#q#rI^#r#sIo#s#y$}#y#z%u#z$f$}$f$g%u$g#BY$}#BY#BZ%u#BZ$IS$}$IS$I_%u$I_$I|$}$I|$JO%u$JO$JT$}$JT$JU%u$JU$KV$}$KV$KW%u$KW&FU$}&FU&FV%u&FV;'S$};'S;=`JW<%lO$}`%QSOy%^z;'S%^;'S;=`%o<%lO%^`%cSo`Oy%^z;'S%^;'S;=`%o<%lO%^`%rP;=`<%l%^~%zh#Z~OX%^X^'f^p%^pq'fqy%^z#y%^#y#z'f#z$f%^$f$g'f$g#BY%^#BY#BZ'f#BZ$IS%^$IS$I_'f$I_$I|%^$I|$JO'f$JO$JT%^$JT$JU'f$JU$KV%^$KV$KW'f$KW&FU%^&FU&FV'f&FV;'S%^;'S;=`%o<%lO%^~'mh#Z~o`OX%^X^'f^p%^pq'fqy%^z#y%^#y#z'f#z$f%^$f$g'f$g#BY%^#BY#BZ'f#BZ$IS%^$IS$I_'f$I_$I|%^$I|$JO'f$JO$JT%^$JT$JU'f$JU$KV%^$KV$KW'f$KW&FU%^&FU&FV'f&FV;'S%^;'S;=`%o<%lO%^l)[UOy%^z#]%^#]#^)n#^;'S%^;'S;=`%o<%lO%^l)sUo`Oy%^z#a%^#a#b*V#b;'S%^;'S;=`%o<%lO%^l*[Uo`Oy%^z#d%^#d#e*n#e;'S%^;'S;=`%o<%lO%^l*sUo`Oy%^z#c%^#c#d+V#d;'S%^;'S;=`%o<%lO%^l+[Uo`Oy%^z#f%^#f#g+n#g;'S%^;'S;=`%o<%lO%^l+sUo`Oy%^z#h%^#h#i,V#i;'S%^;'S;=`%o<%lO%^l,[Uo`Oy%^z#T%^#T#U,n#U;'S%^;'S;=`%o<%lO%^l,sUo`Oy%^z#b%^#b#c-V#c;'S%^;'S;=`%o<%lO%^l-[Uo`Oy%^z#h%^#h#i-n#i;'S%^;'S;=`%o<%lO%^l-uS!X[o`Oy%^z;'S%^;'S;=`%o<%lO%^~.UWOY.RZr.Rrs.ns#O.R#O#P.s#P;'S.R;'S;=`/o<%lO.R~.sOh~~.vRO;'S.R;'S;=`/P;=`O.R~/SXOY.RZr.Rrs.ns#O.R#O#P.s#P;'S.R;'S;=`/o;=`<%l.R<%lO.R~/rP;=`<%l.Rn/zYxQOy%^z!Q%^!Q![0j![!c%^!c!i0j!i#T%^#T#Z0j#Z;'S%^;'S;=`%o<%lO%^l0oYo`Oy%^z!Q%^!Q![1_![!c%^!c!i1_!i#T%^#T#Z1_#Z;'S%^;'S;=`%o<%lO%^l1dYo`Oy%^z!Q%^!Q![2S![!c%^!c!i2S!i#T%^#T#Z2S#Z;'S%^;'S;=`%o<%lO%^l2ZYf[o`Oy%^z!Q%^!Q![2y![!c%^!c!i2y!i#T%^#T#Z2y#Z;'S%^;'S;=`%o<%lO%^l3QYf[o`Oy%^z!Q%^!Q![3p![!c%^!c!i3p!i#T%^#T#Z3p#Z;'S%^;'S;=`%o<%lO%^l3uYo`Oy%^z!Q%^!Q![4e![!c%^!c!i4e!i#T%^#T#Z4e#Z;'S%^;'S;=`%o<%lO%^l4lYf[o`Oy%^z!Q%^!Q![5[![!c%^!c!i5[!i#T%^#T#Z5[#Z;'S%^;'S;=`%o<%lO%^l5aYo`Oy%^z!Q%^!Q![6P![!c%^!c!i6P!i#T%^#T#Z6P#Z;'S%^;'S;=`%o<%lO%^l6WSf[o`Oy%^z;'S%^;'S;=`%o<%lO%^d6gUOy%^z!_%^!_!`6y!`;'S%^;'S;=`%o<%lO%^d7QS|So`Oy%^z;'S%^;'S;=`%o<%lO%^b7cSXQOy%^z;'S%^;'S;=`%o<%lO%^~7rWOY7oZw7owx.nx#O7o#O#P8[#P;'S7o;'S;=`9W<%lO7o~8_RO;'S7o;'S;=`8h;=`O7o~8kXOY7oZw7owx.nx#O7o#O#P8[#P;'S7o;'S;=`9W;=`<%l7o<%lO7o~9ZP;=`<%l7on9cSb^Oy%^z;'S%^;'S;=`%o<%lO%^~9tOa~n9{UUQjWOy%^z!_%^!_!`6y!`;'S%^;'S;=`%o<%lO%^n:fWjW!RQOy%^z!O%^!O!P;O!P!Q%^!Q![>T![;'S%^;'S;=`%o<%lO%^l;TUo`Oy%^z!Q%^!Q![;g![;'S%^;'S;=`%o<%lO%^l;nYo`#e[Oy%^z!Q%^!Q![;g![!g%^!g!h<^!h#X%^#X#Y<^#Y;'S%^;'S;=`%o<%lO%^l<cYo`Oy%^z{%^{|=R|}%^}!O=R!O!Q%^!Q![=j![;'S%^;'S;=`%o<%lO%^l=WUo`Oy%^z!Q%^!Q![=j![;'S%^;'S;=`%o<%lO%^l=qUo`#e[Oy%^z!Q%^!Q![=j![;'S%^;'S;=`%o<%lO%^l>[[o`#e[Oy%^z!O%^!O!P;g!P!Q%^!Q![>T![!g%^!g!h<^!h#X%^#X#Y<^#Y;'S%^;'S;=`%o<%lO%^n?VSt^Oy%^z;'S%^;'S;=`%o<%lO%^l?hWjWOy%^z!O%^!O!P;O!P!Q%^!Q![>T![;'S%^;'S;=`%o<%lO%^n@VU#bQOy%^z!Q%^!Q![;g![;'S%^;'S;=`%o<%lO%^~@nTjWOy%^z{@}{;'S%^;'S;=`%o<%lO%^~AUSo`#[~Oy%^z;'S%^;'S;=`%o<%lO%^lAg[#e[Oy%^z!O%^!O!P;g!P!Q%^!Q![>T![!g%^!g!h<^!h#X%^#X#Y<^#Y;'S%^;'S;=`%o<%lO%^bBbU]QOy%^z![%^![!]Bt!];'S%^;'S;=`%o<%lO%^bB{S^Qo`Oy%^z;'S%^;'S;=`%o<%lO%^nC^S!Y^Oy%^z;'S%^;'S;=`%o<%lO%^dCoS|SOy%^z;'S%^;'S;=`%o<%lO%^bDQU!OQOy%^z!`%^!`!aDd!a;'S%^;'S;=`%o<%lO%^bDkS!OQo`Oy%^z;'S%^;'S;=`%o<%lO%^bDzWOy%^z!c%^!c!}Ed!}#T%^#T#oEd#o;'S%^;'S;=`%o<%lO%^bEk[![Qo`Oy%^z}%^}!OEd!O!Q%^!Q![Ed![!c%^!c!}Ed!}#T%^#T#oEd#o;'S%^;'S;=`%o<%lO%^nFfSq^Oy%^z;'S%^;'S;=`%o<%lO%^nFwSp^Oy%^z;'S%^;'S;=`%o<%lO%^bGWUOy%^z#b%^#b#cGj#c;'S%^;'S;=`%o<%lO%^bGoUo`Oy%^z#W%^#W#XHR#X;'S%^;'S;=`%o<%lO%^bHYS!bQo`Oy%^z;'S%^;'S;=`%o<%lO%^bHiUOy%^z#f%^#f#gHR#g;'S%^;'S;=`%o<%lO%^fIQS!TUOy%^z;'S%^;'S;=`%o<%lO%^nIcS!S^Oy%^z;'S%^;'S;=`%o<%lO%^fItU!RQOy%^z!_%^!_!`6y!`;'S%^;'S;=`%o<%lO%^`JZP;=`<%l$}",
tokenizers:[sbe,lbe,ibe,1,2,3,4,new jve("m~RRYZ[z{a~~g~aO#^~~dP!P!Qg~lO#_~~",28,105)],
topRules:{StyleSheet:[0,4],Styles:[1,86]},specialized:[{term:100,
get:e=>ube[e]||-1},{term:58,get:e=>dbe[e]||-1},{term:101,get:e=>pbe[e]||-1}],
tokenPrec:1200});let fbe=null;function mbe(){
if(!fbe&&"object"==typeof document&&document.body){
let{style:e}=document.body,t=[],n=new Set
;for(let r in e)"cssText"!=r&&"cssFloat"!=r&&"string"==typeof e[r]&&(/[A-Z]/.test(r)&&(r=r.replace(/[A-Z]/g,(e=>"-"+e.toLowerCase()))),
n.has(r)||(t.push(r),n.add(r)));fbe=t.sort().map((e=>({type:"property",label:e,
apply:e+": "})))}return fbe||[]}
const gbe=["active","after","any-link","autofill","backdrop","before","checked","cue","default","defined","disabled","empty","enabled","file-selector-button","first","first-child","first-letter","first-line","first-of-type","focus","focus-visible","focus-within","fullscreen","has","host","host-context","hover","in-range","indeterminate","invalid","is","lang","last-child","last-of-type","left","link","marker","modal","not","nth-child","nth-last-child","nth-last-of-type","nth-of-type","only-child","only-of-type","optional","out-of-range","part","placeholder","placeholder-shown","read-only","read-write","required","right","root","scope","selection","slotted","target","target-text","valid","visited","where"].map((e=>({
type:"class",label:e
}))),vbe=["above","absolute","activeborder","additive","activecaption","after-white-space","ahead","alias","all","all-scroll","alphabetic","alternate","always","antialiased","appworkspace","asterisks","attr","auto","auto-flow","avoid","avoid-column","avoid-page","avoid-region","axis-pan","background","backwards","baseline","below","bidi-override","blink","block","block-axis","bold","bolder","border","border-box","both","bottom","break","break-all","break-word","bullets","button","button-bevel","buttonface","buttonhighlight","buttonshadow","buttontext","calc","capitalize","caps-lock-indicator","caption","captiontext","caret","cell","center","checkbox","circle","cjk-decimal","clear","clip","close-quote","col-resize","collapse","color","color-burn","color-dodge","column","column-reverse","compact","condensed","contain","content","contents","content-box","context-menu","continuous","copy","counter","counters","cover","crop","cross","crosshair","currentcolor","cursive","cyclic","darken","dashed","decimal","decimal-leading-zero","default","default-button","dense","destination-atop","destination-in","destination-out","destination-over","difference","disc","discard","disclosure-closed","disclosure-open","document","dot-dash","dot-dot-dash","dotted","double","down","e-resize","ease","ease-in","ease-in-out","ease-out","element","ellipse","ellipsis","embed","end","ethiopic-abegede-gez","ethiopic-halehame-aa-er","ethiopic-halehame-gez","ew-resize","exclusion","expanded","extends","extra-condensed","extra-expanded","fantasy","fast","fill","fill-box","fixed","flat","flex","flex-end","flex-start","footnotes","forwards","from","geometricPrecision","graytext","grid","groove","hand","hard-light","help","hidden","hide","higher","highlight","highlighttext","horizontal","hsl","hsla","hue","icon","ignore","inactiveborder","inactivecaption","inactivecaptiontext","infinite","infobackground","infotext","inherit","initial","inline","inline-axis","inline-block","inline-flex","inline-grid","inline-table","inset","inside","intrinsic","invert","italic","justify","keep-all","landscape","large","larger","left","level","lighter","lighten","line-through","linear","linear-gradient","lines","list-item","listbox","listitem","local","logical","loud","lower","lower-hexadecimal","lower-latin","lower-norwegian","lowercase","ltr","luminosity","manipulation","match","matrix","matrix3d","medium","menu","menutext","message-box","middle","min-intrinsic","mix","monospace","move","multiple","multiple_mask_images","multiply","n-resize","narrower","ne-resize","nesw-resize","no-close-quote","no-drop","no-open-quote","no-repeat","none","normal","not-allowed","nowrap","ns-resize","numbers","numeric","nw-resize","nwse-resize","oblique","opacity","open-quote","optimizeLegibility","optimizeSpeed","outset","outside","outside-shape","overlay","overline","padding","padding-box","painted","page","paused","perspective","pinch-zoom","plus-darker","plus-lighter","pointer","polygon","portrait","pre","pre-line","pre-wrap","preserve-3d","progress","push-button","radial-gradient","radio","read-only","read-write","read-write-plaintext-only","rectangle","region","relative","repeat","repeating-linear-gradient","repeating-radial-gradient","repeat-x","repeat-y","reset","reverse","rgb","rgba","ridge","right","rotate","rotate3d","rotateX","rotateY","rotateZ","round","row","row-resize","row-reverse","rtl","run-in","running","s-resize","sans-serif","saturation","scale","scale3d","scaleX","scaleY","scaleZ","screen","scroll","scrollbar","scroll-position","se-resize","self-start","self-end","semi-condensed","semi-expanded","separate","serif","show","single","skew","skewX","skewY","skip-white-space","slide","slider-horizontal","slider-vertical","sliderthumb-horizontal","sliderthumb-vertical","slow","small","small-caps","small-caption","smaller","soft-light","solid","source-atop","source-in","source-out","source-over","space","space-around","space-between","space-evenly","spell-out","square","start","static","status-bar","stretch","stroke","stroke-box","sub","subpixel-antialiased","svg_masks","super","sw-resize","symbolic","symbols","system-ui","table","table-caption","table-cell","table-column","table-column-group","table-footer-group","table-header-group","table-row","table-row-group","text","text-bottom","text-top","textarea","textfield","thick","thin","threeddarkshadow","threedface","threedhighlight","threedlightshadow","threedshadow","to","top","transform","translate","translate3d","translateX","translateY","translateZ","transparent","ultra-condensed","ultra-expanded","underline","unidirectional-pan","unset","up","upper-latin","uppercase","url","var","vertical","vertical-text","view-box","visible","visibleFill","visiblePainted","visibleStroke","visual","w-resize","wait","wave","wider","window","windowframe","windowtext","words","wrap","wrap-reverse","x-large","x-small","xor","xx-large","xx-small"].map((e=>({
type:"keyword",label:e
}))).concat(["aliceblue","antiquewhite","aqua","aquamarine","azure","beige","bisque","black","blanchedalmond","blue","blueviolet","brown","burlywood","cadetblue","chartreuse","chocolate","coral","cornflowerblue","cornsilk","crimson","cyan","darkblue","darkcyan","darkgoldenrod","darkgray","darkgreen","darkkhaki","darkmagenta","darkolivegreen","darkorange","darkorchid","darkred","darksalmon","darkseagreen","darkslateblue","darkslategray","darkturquoise","darkviolet","deeppink","deepskyblue","dimgray","dodgerblue","firebrick","floralwhite","forestgreen","fuchsia","gainsboro","ghostwhite","gold","goldenrod","gray","grey","green","greenyellow","honeydew","hotpink","indianred","indigo","ivory","khaki","lavender","lavenderblush","lawngreen","lemonchiffon","lightblue","lightcoral","lightcyan","lightgoldenrodyellow","lightgray","lightgreen","lightpink","lightsalmon","lightseagreen","lightskyblue","lightslategray","lightsteelblue","lightyellow","lime","limegreen","linen","magenta","maroon","mediumaquamarine","mediumblue","mediumorchid","mediumpurple","mediumseagreen","mediumslateblue","mediumspringgreen","mediumturquoise","mediumvioletred","midnightblue","mintcream","mistyrose","moccasin","navajowhite","navy","oldlace","olive","olivedrab","orange","orangered","orchid","palegoldenrod","palegreen","paleturquoise","palevioletred","papayawhip","peachpuff","peru","pink","plum","powderblue","purple","rebeccapurple","red","rosybrown","royalblue","saddlebrown","salmon","sandybrown","seagreen","seashell","sienna","silver","skyblue","slateblue","slategray","snow","springgreen","steelblue","tan","teal","thistle","tomato","turquoise","violet","wheat","white","whitesmoke","yellow","yellowgreen"].map((e=>({
type:"constant",label:e
})))),bbe=["a","abbr","address","article","aside","b","bdi","bdo","blockquote","body","br","button","canvas","caption","cite","code","col","colgroup","dd","del","details","dfn","dialog","div","dl","dt","em","figcaption","figure","footer","form","header","hgroup","h1","h2","h3","h4","h5","h6","hr","html","i","iframe","img","input","ins","kbd","label","legend","li","main","meter","nav","ol","output","p","pre","ruby","section","select","small","source","span","strong","sub","summary","sup","table","tbody","td","template","textarea","tfoot","th","thead","tr","u","ul"].map((e=>({
type:"type",label:e
}))),ybe=["@charset","@color-profile","@container","@counter-style","@font-face","@font-feature-values","@font-palette-values","@import","@keyframes","@layer","@media","@namespace","@page","@position-try","@property","@scope","@starting-style","@supports","@view-transition"].map((e=>({
type:"keyword",label:e}))),Obe=/^(\w[\w-]*|-\w[\w-]*|)$/,wbe=/^-(-[\w-]*)?$/
;const xbe=new the,kbe=["Declaration"];function Sbe(e){for(let t=e;;){
if(t.type.isTop)return t;if(!(t=t.parent))return e}}function _be(e,t,n){
if(t.to-t.from>4096){let r=xbe.get(t);if(r)return r
;let o=[],a=new Set,i=t.cursor(Npe.IncludeAnonymous);if(i.firstChild())do{
for(let t of _be(e,i.node,n))a.has(t.label)||(a.add(t.label),o.push(t))
}while(i.nextSibling());return xbe.set(t,o),o}{let r=[],o=new Set
;return t.cursor().iterate((t=>{var a
;if(n(t)&&t.matchContext(kbe)&&":"==(null===(a=t.node.nextSibling)||void 0===a?void 0:a.name)){
let n=e.sliceString(t.from,t.to);o.has(n)||(o.add(n),r.push({label:n,
type:"variable"}))}})),r}}const Tbe=(e=>t=>{
let{state:n,pos:r}=t,o=Yhe(n).resolveInner(r,-1),a=o.type.isError&&o.from==o.to-1&&"-"==n.doc.sliceString(o.from,o.to)
;if("PropertyName"==o.name||(a||"TagName"==o.name)&&/^(Block|Styles)$/.test(o.resolve(o.to).name))return{
from:o.from,options:mbe(),validFor:Obe};if("ValueName"==o.name)return{
from:o.from,options:vbe,validFor:Obe};if("PseudoClassName"==o.name)return{
from:o.from,options:gbe,validFor:Obe};if(e(o)||(t.explicit||a)&&function(e,t){
var n
;if(("("==e.name||e.type.isError)&&(e=e.parent||e),"ArgList"!=e.name)return!1
;let r=null===(n=e.parent)||void 0===n?void 0:n.firstChild
;return"Callee"==(null==r?void 0:r.name)&&"var"==t.sliceString(r.from,r.to)
}(o,n.doc))return{from:e(o)||a?o.from:r,options:_be(n.doc,Sbe(o),e),validFor:wbe
};if("TagName"==o.name){
for(let{parent:e}=o;e;e=e.parent)if("Block"==e.name)return{from:o.from,
options:mbe(),validFor:Obe};return{from:o.from,options:bbe,validFor:Obe}}
if("AtKeyword"==o.name)return{from:o.from,options:ybe,validFor:Obe}
;if(!t.explicit)return null;let i=o.resolve(r),s=i.childBefore(r)
;return s&&":"==s.name&&"PseudoClassSelector"==i.name?{from:r,options:gbe,
validFor:Obe}:s&&":"==s.name&&"Declaration"==i.name||"ArgList"==i.name?{from:r,
options:vbe,validFor:Obe}:"Block"==i.name||"Styles"==i.name?{from:r,
options:mbe(),validFor:Obe}:null})((e=>"VariableName"==e.name)),Ebe=Ghe.define({
name:"css",parser:hbe.configure({props:[ffe.add({Declaration:xfe()}),_fe.add({
"Block KeyframeList":Tfe})]}),languageData:{commentTokens:{block:{open:"/*",
close:"*/"}},indentOnInput:/^\s*\}$/,wordChars:"-"}});function Abe(){
return new sfe(Ebe,Ebe.data.of({autocomplete:Tbe}))}
const Cbe=20,$be=22,Pbe=23,Dbe=24,Ibe=26,Mbe=27,Nbe=28,Rbe=31,Lbe=34,Bbe=37,jbe={
area:!0,base:!0,br:!0,col:!0,command:!0,embed:!0,frame:!0,hr:!0,img:!0,input:!0,
keygen:!0,link:!0,meta:!0,param:!0,source:!0,track:!0,wbr:!0,menuitem:!0},Ube={
dd:!0,li:!0,optgroup:!0,option:!0,p:!0,rp:!0,rt:!0,tbody:!0,td:!0,tfoot:!0,
th:!0,tr:!0},zbe={dd:{dd:!0,dt:!0},dt:{dd:!0,dt:!0},li:{li:!0},option:{
option:!0,optgroup:!0},optgroup:{optgroup:!0},p:{address:!0,article:!0,aside:!0,
blockquote:!0,dir:!0,div:!0,dl:!0,fieldset:!0,footer:!0,form:!0,h1:!0,h2:!0,
h3:!0,h4:!0,h5:!0,h6:!0,header:!0,hgroup:!0,hr:!0,menu:!0,nav:!0,ol:!0,p:!0,
pre:!0,section:!0,table:!0,ul:!0},rp:{rp:!0,rt:!0},rt:{rp:!0,rt:!0},tbody:{
tbody:!0,tfoot:!0},td:{td:!0,th:!0},tfoot:{tbody:!0},th:{td:!0,th:!0},thead:{
tbody:!0,tfoot:!0},tr:{tr:!0}};function Fbe(e){return 9==e||10==e||13==e||32==e}
let Zbe=null,Qbe=null,Hbe=0;function Vbe(e,t){let n=e.pos+t
;if(Hbe==n&&Qbe==e)return Zbe;let r=e.peek(t);for(;Fbe(r);)r=e.peek(++t)
;let o=""
;for(;45==(a=r)||46==a||58==a||a>=65&&a<=90||95==a||a>=97&&a<=122||a>=161;)o+=String.fromCharCode(r),
r=e.peek(++t);var a
;return Qbe=e,Hbe=n,Zbe=o?o.toLowerCase():r==qbe||r==Wbe?void 0:null}
const qbe=63,Wbe=33;function Xbe(e,t){this.name=e,this.parent=t}
const Gbe=[6,10,7,8,9],Ybe=new Jve({start:null,
shift:(e,t,n,r)=>Gbe.indexOf(t)>-1?new Xbe(Vbe(r,1)||"",e):e,
reduce:(e,t)=>t==Cbe&&e?e.parent:e,reuse(e,t,n,r){let o=t.type.id
;return 6==o||36==o?new Xbe(Vbe(r,1)||"",e):e},strict:!1}),Kbe=new Uve(((e,t)=>{
if(60!=e.next)return void(e.next<0&&t.context&&e.acceptToken(57));e.advance()
;let n=47==e.next;n&&e.advance();let r=Vbe(e,0);if(void 0===r)return
;if(!r)return e.acceptToken(n?14:6);let o=t.context?t.context.name:null;if(n){
if(r==o)return e.acceptToken(11);if(o&&Ube[o])return e.acceptToken(57,-2)
;if(t.dialectEnabled(0))return e.acceptToken(12)
;for(let e=t.context;e;e=e.parent)if(e.name==r)return;e.acceptToken(13)}else{
if("script"==r)return e.acceptToken(7);if("style"==r)return e.acceptToken(8)
;if("textarea"==r)return e.acceptToken(9)
;if(jbe.hasOwnProperty(r))return e.acceptToken(10)
;o&&zbe[o]&&zbe[o][r]?e.acceptToken(57,-1):e.acceptToken(6)}}),{contextual:!0
}),Jbe=new Uve((e=>{for(let t=0,n=0;;n++){if(e.next<0){n&&e.acceptToken(58)
;break}if(45==e.next)t++;else{if(62==e.next&&t>=2){n>=3&&e.acceptToken(58,-2)
;break}t=0}e.advance()}}));const eye=new Uve(((e,t)=>{
if(47==e.next&&62==e.peek(1)){let n=t.dialectEnabled(1)||function(e){
for(;e;e=e.parent)if("svg"==e.name||"math"==e.name)return!0;return!1}(t.context)
;e.acceptToken(n?5:4,2)}else 62==e.next&&e.acceptToken(4,1)}))
;function tye(e,t,n){let r=2+e.length;return new Uve((o=>{
for(let a=0,i=0,s=0;;s++){if(o.next<0){s&&o.acceptToken(t);break}
if(0==a&&60==o.next||1==a&&47==o.next||a>=2&&a<r&&o.next==e.charCodeAt(a-2))a++,
i++;else if(2!=a&&a!=r||!Fbe(o.next)){if(a==r&&62==o.next){
s>i?o.acceptToken(t,-i):o.acceptToken(n,-(i-2));break}
if((10==o.next||13==o.next)&&s){o.acceptToken(t,1);break}a=i=0}else i++
;o.advance()}}))}
const nye=tye("script",54,1),rye=tye("style",55,2),oye=tye("textarea",56,3),aye=xhe({
"Text RawText":Zhe.content,
"StartTag StartCloseTag SelfClosingEndTag EndTag":Zhe.angleBracket,
TagName:Zhe.tagName,"MismatchedCloseTag/TagName":[Zhe.tagName,Zhe.invalid],
AttributeName:Zhe.attributeName,
"AttributeValue UnquotedAttributeValue":Zhe.attributeValue,
Is:Zhe.definitionOperator,"EntityReference CharacterReference":Zhe.character,
Comment:Zhe.blockComment,ProcessingInst:Zhe.processingInstruction,
DoctypeDecl:Zhe.documentMeta}),iye=ebe.deserialize({version:14,
states:",xOVO!rOOO!WQ#tO'#CqO!]Q#tO'#CzO!bQ#tO'#C}O!gQ#tO'#DQO!lQ#tO'#DSO!qOaO'#CpO!|ObO'#CpO#XOdO'#CpO$eO!rO'#CpOOO`'#Cp'#CpO$lO$fO'#DTO$tQ#tO'#DVO$yQ#tO'#DWOOO`'#Dk'#DkOOO`'#DY'#DYQVO!rOOO%OQ&rO,59]O%ZQ&rO,59fO%fQ&rO,59iO%qQ&rO,59lO%|Q&rO,59nOOOa'#D^'#D^O&XOaO'#CxO&dOaO,59[OOOb'#D_'#D_O&lObO'#C{O&wObO,59[OOOd'#D`'#D`O'POdO'#DOO'[OdO,59[OOO`'#Da'#DaO'dO!rO,59[O'kQ#tO'#DROOO`,59[,59[OOOp'#Db'#DbO'pO$fO,59oOOO`,59o,59oO'xQ#|O,59qO'}Q#|O,59rOOO`-E7W-E7WO(SQ&rO'#CsOOQW'#DZ'#DZO(bQ&rO1G.wOOOa1G.w1G.wOOO`1G/Y1G/YO(mQ&rO1G/QOOOb1G/Q1G/QO(xQ&rO1G/TOOOd1G/T1G/TO)TQ&rO1G/WOOO`1G/W1G/WO)`Q&rO1G/YOOOa-E7[-E7[O)kQ#tO'#CyOOO`1G.v1G.vOOOb-E7]-E7]O)pQ#tO'#C|OOOd-E7^-E7^O)uQ#tO'#DPOOO`-E7_-E7_O)zQ#|O,59mOOOp-E7`-E7`OOO`1G/Z1G/ZOOO`1G/]1G/]OOO`1G/^1G/^O*PQ,UO,59_OOQW-E7X-E7XOOOa7+$c7+$cOOO`7+$t7+$tOOOb7+$l7+$lOOOd7+$o7+$oOOO`7+$r7+$rO*[Q#|O,59eO*aQ#|O,59hO*fQ#|O,59kOOO`1G/X1G/XO*kO7[O'#CvO*|OMhO'#CvOOQW1G.y1G.yOOO`1G/P1G/POOO`1G/S1G/SOOO`1G/V1G/VOOOO'#D['#D[O+_O7[O,59bOOQW,59b,59bOOOO'#D]'#D]O+pOMhO,59bOOOO-E7Y-E7YOOQW1G.|1G.|OOOO-E7Z-E7Z",
stateData:",]~O!^OS~OUSOVPOWQOXROYTO[]O][O^^O`^Oa^Ob^Oc^Ox^O{_O!dZO~OfaO~OfbO~OfcO~OfdO~OfeO~O!WfOPlP!ZlP~O!XiOQoP!ZoP~O!YlORrP!ZrP~OUSOVPOWQOXROYTOZqO[]O][O^^O`^Oa^Ob^Oc^Ox^O!dZO~O!ZrO~P#dO![sO!euO~OfvO~OfwO~OS|OT}OhyO~OS!POT}OhyO~OS!ROT}OhyO~OS!TOT}OhyO~OS}OT}OhyO~O!WfOPlX!ZlX~OP!WO!Z!XO~O!XiOQoX!ZoX~OQ!ZO!Z!XO~O!YlORrX!ZrX~OR!]O!Z!XO~O!Z!XO~P#dOf!_O~O![sO!e!aO~OS!bO~OS!cO~Oi!dOSgXTgXhgX~OS!fOT!gOhyO~OS!hOT!gOhyO~OS!iOT!gOhyO~OS!jOT!gOhyO~OS!gOT!gOhyO~Of!kO~Of!lO~Of!mO~OS!nO~Ok!qO!`!oO!b!pO~OS!rO~OS!sO~OS!tO~Oa!uOb!uOc!uO!`!wO!a!uO~Oa!xOb!xOc!xO!b!wO!c!xO~Oa!uOb!uOc!uO!`!{O!a!uO~Oa!xOb!xOc!xO!b!{O!c!xO~OT~bac!dx{!d~",
goto:"%p!`PPPPPPPPPPPPPPPPPPPP!a!gP!mPP!yP!|#P#S#Y#]#`#f#i#l#r#x!aP!a!aP$O$U$l$r$x%O%U%[%bPPPPPPPP%hX^OX`pXUOX`pezabcde{!O!Q!S!UR!q!dRhUR!XhXVOX`pRkVR!XkXWOX`pRnWR!XnXXOX`pQrXR!XpXYOX`pQ`ORx`Q{aQ!ObQ!QcQ!SdQ!UeZ!e{!O!Q!S!UQ!v!oR!z!vQ!y!pR!|!yQgUR!VgQjVR!YjQmWR![mQpXR!^pQtZR!`tS_O`ToXp",
nodeNames:"⚠ StartCloseTag StartCloseTag StartCloseTag EndTag SelfClosingEndTag StartTag StartTag StartTag StartTag StartTag StartCloseTag StartCloseTag StartCloseTag IncompleteCloseTag Document Text EntityReference CharacterReference InvalidEntity Element OpenTag TagName Attribute AttributeName Is AttributeValue UnquotedAttributeValue ScriptText CloseTag OpenTag StyleText CloseTag OpenTag TextareaText CloseTag OpenTag CloseTag SelfClosingTag Comment ProcessingInst MismatchedCloseTag CloseTag DoctypeDecl",
maxTerm:67,context:Ybe,
nodeProps:[["closedBy",-10,1,2,3,7,8,9,10,11,12,13,"EndTag",6,"EndTag SelfClosingEndTag",-4,21,30,33,36,"CloseTag"],["openedBy",4,"StartTag StartCloseTag",5,"StartTag",-4,29,32,35,37,"OpenTag"],["group",-9,14,17,18,19,20,39,40,41,42,"Entity",16,"Entity TextContent",-3,28,31,34,"TextContent Entity"],["isolate",-11,21,29,30,32,33,35,36,37,38,41,42,"ltr",-3,26,27,39,""]],
propSources:[aye],skippedNodes:[0],repeatNodeCount:9,
tokenData:"!<p!aR!YOX$qXY,QYZ,QZ[$q[]&X]^,Q^p$qpq,Qqr-_rs3_sv-_vw3}wxHYx}-_}!OH{!O!P-_!P!Q$q!Q![-_![!]Mz!]!^-_!^!_!$S!_!`!;x!`!a&X!a!c-_!c!}Mz!}#R-_#R#SMz#S#T1k#T#oMz#o#s-_#s$f$q$f%W-_%W%oMz%o%p-_%p&aMz&a&b-_&b1pMz1p4U-_4U4dMz4d4e-_4e$ISMz$IS$I`-_$I`$IbMz$Ib$Kh-_$Kh%#tMz%#t&/x-_&/x&EtMz&Et&FV-_&FV;'SMz;'S;:j!#|;:j;=`3X<%l?&r-_?&r?AhMz?Ah?BY$q?BY?MnMz?MnO$q!Z$|c`PkW!a`!cpOX$qXZ&XZ[$q[^&X^p$qpq&Xqr$qrs&}sv$qvw+Pwx(tx!^$q!^!_*V!_!a&X!a#S$q#S#T&X#T;'S$q;'S;=`+z<%lO$q!R&bX`P!a`!cpOr&Xrs&}sv&Xwx(tx!^&X!^!_*V!_;'S&X;'S;=`*y<%lO&Xq'UV`P!cpOv&}wx'kx!^&}!^!_(V!_;'S&};'S;=`(n<%lO&}P'pT`POv'kw!^'k!_;'S'k;'S;=`(P<%lO'kP(SP;=`<%l'kp([S!cpOv(Vx;'S(V;'S;=`(h<%lO(Vp(kP;=`<%l(Vq(qP;=`<%l&}a({W`P!a`Or(trs'ksv(tw!^(t!^!_)e!_;'S(t;'S;=`*P<%lO(t`)jT!a`Or)esv)ew;'S)e;'S;=`)y<%lO)e`)|P;=`<%l)ea*SP;=`<%l(t!Q*^V!a`!cpOr*Vrs(Vsv*Vwx)ex;'S*V;'S;=`*s<%lO*V!Q*vP;=`<%l*V!R*|P;=`<%l&XW+UYkWOX+PZ[+P^p+Pqr+Psw+Px!^+P!a#S+P#T;'S+P;'S;=`+t<%lO+PW+wP;=`<%l+P!Z+}P;=`<%l$q!a,]``P!a`!cp!^^OX&XXY,QYZ,QZ]&X]^,Q^p&Xpq,Qqr&Xrs&}sv&Xwx(tx!^&X!^!_*V!_;'S&X;'S;=`*y<%lO&X!_-ljhS`PkW!a`!cpOX$qXZ&XZ[$q[^&X^p$qpq&Xqr-_rs&}sv-_vw/^wx(tx!P-_!P!Q$q!Q!^-_!^!_*V!_!a&X!a#S-_#S#T1k#T#s-_#s$f$q$f;'S-_;'S;=`3X<%l?Ah-_?Ah?BY$q?BY?Mn-_?MnO$q[/ebhSkWOX+PZ[+P^p+Pqr/^sw/^x!P/^!P!Q+P!Q!^/^!a#S/^#S#T0m#T#s/^#s$f+P$f;'S/^;'S;=`1e<%l?Ah/^?Ah?BY+P?BY?Mn/^?MnO+PS0rXhSqr0msw0mx!P0m!Q!^0m!a#s0m$f;'S0m;'S;=`1_<%l?Ah0m?BY?Mn0mS1bP;=`<%l0m[1hP;=`<%l/^!V1vchS`P!a`!cpOq&Xqr1krs&}sv1kvw0mwx(tx!P1k!P!Q&X!Q!^1k!^!_*V!_!a&X!a#s1k#s$f&X$f;'S1k;'S;=`3R<%l?Ah1k?Ah?BY&X?BY?Mn1k?MnO&X!V3UP;=`<%l1k!_3[P;=`<%l-_!Z3hV!`h`P!cpOv&}wx'kx!^&}!^!_(V!_;'S&};'S;=`(n<%lO&}!_4WihSkWc!ROX5uXZ7SZ[5u[^7S^p5uqr8trs7Sst>]tw8twx7Sx!P8t!P!Q5u!Q!]8t!]!^/^!^!a7S!a#S8t#S#T;{#T#s8t#s$f5u$f;'S8t;'S;=`>V<%l?Ah8t?Ah?BY5u?BY?Mn8t?MnO5u!Z5zbkWOX5uXZ7SZ[5u[^7S^p5uqr5urs7Sst+Ptw5uwx7Sx!]5u!]!^7w!^!a7S!a#S5u#S#T7S#T;'S5u;'S;=`8n<%lO5u!R7VVOp7Sqs7St!]7S!]!^7l!^;'S7S;'S;=`7q<%lO7S!R7qOa!R!R7tP;=`<%l7S!Z8OYkWa!ROX+PZ[+P^p+Pqr+Psw+Px!^+P!a#S+P#T;'S+P;'S;=`+t<%lO+P!Z8qP;=`<%l5u!_8{ihSkWOX5uXZ7SZ[5u[^7S^p5uqr8trs7Sst/^tw8twx7Sx!P8t!P!Q5u!Q!]8t!]!^:j!^!a7S!a#S8t#S#T;{#T#s8t#s$f5u$f;'S8t;'S;=`>V<%l?Ah8t?Ah?BY5u?BY?Mn8t?MnO5u!_:sbhSkWa!ROX+PZ[+P^p+Pqr/^sw/^x!P/^!P!Q+P!Q!^/^!a#S/^#S#T0m#T#s/^#s$f+P$f;'S/^;'S;=`1e<%l?Ah/^?Ah?BY+P?BY?Mn/^?MnO+P!V<QchSOp7Sqr;{rs7Sst0mtw;{wx7Sx!P;{!P!Q7S!Q!];{!]!^=]!^!a7S!a#s;{#s$f7S$f;'S;{;'S;=`>P<%l?Ah;{?Ah?BY7S?BY?Mn;{?MnO7S!V=dXhSa!Rqr0msw0mx!P0m!Q!^0m!a#s0m$f;'S0m;'S;=`1_<%l?Ah0m?BY?Mn0m!V>SP;=`<%l;{!_>YP;=`<%l8t!_>dhhSkWOX@OXZAYZ[@O[^AY^p@OqrBwrsAYswBwwxAYx!PBw!P!Q@O!Q!]Bw!]!^/^!^!aAY!a#SBw#S#TE{#T#sBw#s$f@O$f;'SBw;'S;=`HS<%l?AhBw?Ah?BY@O?BY?MnBw?MnO@O!Z@TakWOX@OXZAYZ[@O[^AY^p@Oqr@OrsAYsw@OwxAYx!]@O!]!^Az!^!aAY!a#S@O#S#TAY#T;'S@O;'S;=`Bq<%lO@O!RA]UOpAYq!]AY!]!^Ao!^;'SAY;'S;=`At<%lOAY!RAtOb!R!RAwP;=`<%lAY!ZBRYkWb!ROX+PZ[+P^p+Pqr+Psw+Px!^+P!a#S+P#T;'S+P;'S;=`+t<%lO+P!ZBtP;=`<%l@O!_COhhSkWOX@OXZAYZ[@O[^AY^p@OqrBwrsAYswBwwxAYx!PBw!P!Q@O!Q!]Bw!]!^Dj!^!aAY!a#SBw#S#TE{#T#sBw#s$f@O$f;'SBw;'S;=`HS<%l?AhBw?Ah?BY@O?BY?MnBw?MnO@O!_DsbhSkWb!ROX+PZ[+P^p+Pqr/^sw/^x!P/^!P!Q+P!Q!^/^!a#S/^#S#T0m#T#s/^#s$f+P$f;'S/^;'S;=`1e<%l?Ah/^?Ah?BY+P?BY?Mn/^?MnO+P!VFQbhSOpAYqrE{rsAYswE{wxAYx!PE{!P!QAY!Q!]E{!]!^GY!^!aAY!a#sE{#s$fAY$f;'SE{;'S;=`G|<%l?AhE{?Ah?BYAY?BY?MnE{?MnOAY!VGaXhSb!Rqr0msw0mx!P0m!Q!^0m!a#s0m$f;'S0m;'S;=`1_<%l?Ah0m?BY?Mn0m!VHPP;=`<%lE{!_HVP;=`<%lBw!ZHcW!bx`P!a`Or(trs'ksv(tw!^(t!^!_)e!_;'S(t;'S;=`*P<%lO(t!aIYlhS`PkW!a`!cpOX$qXZ&XZ[$q[^&X^p$qpq&Xqr-_rs&}sv-_vw/^wx(tx}-_}!OKQ!O!P-_!P!Q$q!Q!^-_!^!_*V!_!a&X!a#S-_#S#T1k#T#s-_#s$f$q$f;'S-_;'S;=`3X<%l?Ah-_?Ah?BY$q?BY?Mn-_?MnO$q!aK_khS`PkW!a`!cpOX$qXZ&XZ[$q[^&X^p$qpq&Xqr-_rs&}sv-_vw/^wx(tx!P-_!P!Q$q!Q!^-_!^!_*V!_!`&X!`!aMS!a#S-_#S#T1k#T#s-_#s$f$q$f;'S-_;'S;=`3X<%l?Ah-_?Ah?BY$q?BY?Mn-_?MnO$q!TM_X`P!a`!cp!eQOr&Xrs&}sv&Xwx(tx!^&X!^!_*V!_;'S&X;'S;=`*y<%lO&X!aNZ!ZhSfQ`PkW!a`!cpOX$qXZ&XZ[$q[^&X^p$qpq&Xqr-_rs&}sv-_vw/^wx(tx}-_}!OMz!O!PMz!P!Q$q!Q![Mz![!]Mz!]!^-_!^!_*V!_!a&X!a!c-_!c!}Mz!}#R-_#R#SMz#S#T1k#T#oMz#o#s-_#s$f$q$f$}-_$}%OMz%O%W-_%W%oMz%o%p-_%p&aMz&a&b-_&b1pMz1p4UMz4U4dMz4d4e-_4e$ISMz$IS$I`-_$I`$IbMz$Ib$Je-_$Je$JgMz$Jg$Kh-_$Kh%#tMz%#t&/x-_&/x&EtMz&Et&FV-_&FV;'SMz;'S;:j!#|;:j;=`3X<%l?&r-_?&r?AhMz?Ah?BY$q?BY?MnMz?MnO$q!a!$PP;=`<%lMz!R!$ZY!a`!cpOq*Vqr!$yrs(Vsv*Vwx)ex!a*V!a!b!4t!b;'S*V;'S;=`*s<%lO*V!R!%Q]!a`!cpOr*Vrs(Vsv*Vwx)ex}*V}!O!%y!O!f*V!f!g!']!g#W*V#W#X!0`#X;'S*V;'S;=`*s<%lO*V!R!&QX!a`!cpOr*Vrs(Vsv*Vwx)ex}*V}!O!&m!O;'S*V;'S;=`*s<%lO*V!R!&vV!a`!cp!dPOr*Vrs(Vsv*Vwx)ex;'S*V;'S;=`*s<%lO*V!R!'dX!a`!cpOr*Vrs(Vsv*Vwx)ex!q*V!q!r!(P!r;'S*V;'S;=`*s<%lO*V!R!(WX!a`!cpOr*Vrs(Vsv*Vwx)ex!e*V!e!f!(s!f;'S*V;'S;=`*s<%lO*V!R!(zX!a`!cpOr*Vrs(Vsv*Vwx)ex!v*V!v!w!)g!w;'S*V;'S;=`*s<%lO*V!R!)nX!a`!cpOr*Vrs(Vsv*Vwx)ex!{*V!{!|!*Z!|;'S*V;'S;=`*s<%lO*V!R!*bX!a`!cpOr*Vrs(Vsv*Vwx)ex!r*V!r!s!*}!s;'S*V;'S;=`*s<%lO*V!R!+UX!a`!cpOr*Vrs(Vsv*Vwx)ex!g*V!g!h!+q!h;'S*V;'S;=`*s<%lO*V!R!+xY!a`!cpOr!+qrs!,hsv!+qvw!-Swx!.[x!`!+q!`!a!/j!a;'S!+q;'S;=`!0Y<%lO!+qq!,mV!cpOv!,hvx!-Sx!`!,h!`!a!-q!a;'S!,h;'S;=`!.U<%lO!,hP!-VTO!`!-S!`!a!-f!a;'S!-S;'S;=`!-k<%lO!-SP!-kO{PP!-nP;=`<%l!-Sq!-xS!cp{POv(Vx;'S(V;'S;=`(h<%lO(Vq!.XP;=`<%l!,ha!.aX!a`Or!.[rs!-Ssv!.[vw!-Sw!`!.[!`!a!.|!a;'S!.[;'S;=`!/d<%lO!.[a!/TT!a`{POr)esv)ew;'S)e;'S;=`)y<%lO)ea!/gP;=`<%l!.[!R!/sV!a`!cp{POr*Vrs(Vsv*Vwx)ex;'S*V;'S;=`*s<%lO*V!R!0]P;=`<%l!+q!R!0gX!a`!cpOr*Vrs(Vsv*Vwx)ex#c*V#c#d!1S#d;'S*V;'S;=`*s<%lO*V!R!1ZX!a`!cpOr*Vrs(Vsv*Vwx)ex#V*V#V#W!1v#W;'S*V;'S;=`*s<%lO*V!R!1}X!a`!cpOr*Vrs(Vsv*Vwx)ex#h*V#h#i!2j#i;'S*V;'S;=`*s<%lO*V!R!2qX!a`!cpOr*Vrs(Vsv*Vwx)ex#m*V#m#n!3^#n;'S*V;'S;=`*s<%lO*V!R!3eX!a`!cpOr*Vrs(Vsv*Vwx)ex#d*V#d#e!4Q#e;'S*V;'S;=`*s<%lO*V!R!4XX!a`!cpOr*Vrs(Vsv*Vwx)ex#X*V#X#Y!+q#Y;'S*V;'S;=`*s<%lO*V!R!4{Y!a`!cpOr!4trs!5ksv!4tvw!6Vwx!8]x!a!4t!a!b!:]!b;'S!4t;'S;=`!;r<%lO!4tq!5pV!cpOv!5kvx!6Vx!a!5k!a!b!7W!b;'S!5k;'S;=`!8V<%lO!5kP!6YTO!a!6V!a!b!6i!b;'S!6V;'S;=`!7Q<%lO!6VP!6lTO!`!6V!`!a!6{!a;'S!6V;'S;=`!7Q<%lO!6VP!7QOxPP!7TP;=`<%l!6Vq!7]V!cpOv!5kvx!6Vx!`!5k!`!a!7r!a;'S!5k;'S;=`!8V<%lO!5kq!7yS!cpxPOv(Vx;'S(V;'S;=`(h<%lO(Vq!8YP;=`<%l!5ka!8bX!a`Or!8]rs!6Vsv!8]vw!6Vw!a!8]!a!b!8}!b;'S!8];'S;=`!:V<%lO!8]a!9SX!a`Or!8]rs!6Vsv!8]vw!6Vw!`!8]!`!a!9o!a;'S!8];'S;=`!:V<%lO!8]a!9vT!a`xPOr)esv)ew;'S)e;'S;=`)y<%lO)ea!:YP;=`<%l!8]!R!:dY!a`!cpOr!4trs!5ksv!4tvw!6Vwx!8]x!`!4t!`!a!;S!a;'S!4t;'S;=`!;r<%lO!4t!R!;]V!a`!cpxPOr*Vrs(Vsv*Vwx)ex;'S*V;'S;=`*s<%lO*V!R!;uP;=`<%l!4t!V!<TXiS`P!a`!cpOr&Xrs&}sv&Xwx(tx!^&X!^!_*V!_;'S&X;'S;=`*y<%lO&X",
tokenizers:[nye,rye,oye,eye,Kbe,Jbe,0,1,2,3,4,5],topRules:{Document:[0,15]},
dialects:{noMatch:0,selfClosing:509},tokenPrec:511});function sye(e,t){
let n=Object.create(null);for(let r of e.getChildren(Pbe)){
let e=r.getChild(Dbe),o=r.getChild(Ibe)||r.getChild(Mbe)
;e&&(n[t.read(e.from,e.to)]=o?o.type.id==Ibe?t.read(o.from+1,o.to-1):t.read(o.from,o.to):"")
}return n}function lye(e,t){let n=e.getChild($be)
;return n?t.read(n.from,n.to):" "}function cye(e,t,n){let r
;for(let o of n)if(!o.attrs||o.attrs(r||(r=sye(e.node.parent.firstChild,t))))return{
parser:o.parser};return null}function uye(e=[],t=[]){let n=[],r=[],o=[],a=[]
;for(let l of e){
("script"==l.tag?n:"style"==l.tag?r:"textarea"==l.tag?o:a).push(l)}
let i=t.length?Object.create(null):null
;for(let l of t)(i[l.name]||(i[l.name]=[])).push(l);return s=(e,t)=>{
let s=e.type.id;if(s==Nbe)return cye(e,t,n);if(s==Rbe)return cye(e,t,r)
;if(s==Lbe)return cye(e,t,o);if(s==Cbe&&a.length){
let n,r=e.node,o=r.firstChild,i=o&&lye(o,t)
;if(i)for(let e of a)if(e.tag==i&&(!e.attrs||e.attrs(n||(n=sye(o,t))))){
let t=r.lastChild,n=t.type.id==Bbe?t.from:r.to;if(n>o.to)return{parser:e.parser,
overlay:[{from:o.to,to:n}]}}}if(i&&s==Pbe){let n,r=e.node;if(n=r.firstChild){
let e=i[t.read(n.from,n.to)];if(e)for(let n of e){
if(n.tagName&&n.tagName!=lye(r.parent,t))continue;let e=r.lastChild
;if(e.type.id==Ibe){let t=e.from+1,r=e.lastChild,o=e.to-(r&&r.isError?0:1)
;if(o>t)return{parser:n.parser,overlay:[{from:t,to:o}]}
}else if(e.type.id==Mbe)return{parser:n.parser,overlay:[{from:e.from,to:e.to}]}}
}}return null},(e,t,n,r)=>new che(e,s,t,n,r);var s}
const dye=[9,10,11,12,13,32,133,160,5760,8192,8193,8194,8195,8196,8197,8198,8199,8200,8201,8202,8232,8233,8239,8287,12288],pye=new Jve({
start:!1,shift:(e,t)=>5==t||6==t||315==t?e:316==t,strict:!1
}),hye=new Uve(((e,t)=>{let{next:n}=e
;(125==n||-1==n||t.context)&&e.acceptToken(313)}),{contextual:!0,fallback:!0
}),fye=new Uve(((e,t)=>{let n,{next:r}=e
;dye.indexOf(r)>-1||(47!=r||47!=(n=e.peek(1))&&42!=n)&&(125==r||59==r||-1==r||t.context||e.acceptToken(312))
}),{contextual:!0}),mye=new Uve(((e,t)=>{let{next:n}=e;if(43==n||45==n){
if(e.advance(),n==e.next){e.advance();let n=!t.context&&t.canShift(1)
;e.acceptToken(n?1:2)}
}else 63==n&&46==e.peek(1)&&(e.advance(),e.advance(),(e.next<48||e.next>57)&&e.acceptToken(3))
}),{contextual:!0});function gye(e,t){
return e>=65&&e<=90||e>=97&&e<=122||95==e||e>=192||!t&&e>=48&&e<=57}
const vye=new Uve(((e,t)=>{if(60!=e.next||!t.dialectEnabled(0))return
;if(e.advance(),47==e.next)return;let n=0
;for(;dye.indexOf(e.next)>-1;)e.advance(),n++;if(gye(e.next,!0)){
for(e.advance(),n++;gye(e.next,!1);)e.advance(),n++
;for(;dye.indexOf(e.next)>-1;)e.advance(),n++;if(44==e.next)return
;for(let t=0;;t++){if(7==t){if(!gye(e.next,!0))return;break}
if(e.next!="extends".charCodeAt(t))break;e.advance(),n++}}e.acceptToken(4,-n)
})),bye=xhe({"get set async static":Zhe.modifier,
"for while do if else switch try catch finally return throw break continue default case":Zhe.controlKeyword,
"in of await yield void typeof delete instanceof":Zhe.operatorKeyword,
"let var const using function class extends":Zhe.definitionKeyword,
"import export from":Zhe.moduleKeyword,"with debugger as new":Zhe.keyword,
TemplateString:Zhe.special(Zhe.string),super:Zhe.atom,BooleanLiteral:Zhe.bool,
this:Zhe.self,null:Zhe.null,Star:Zhe.modifier,VariableName:Zhe.variableName,
"CallExpression/VariableName TaggedTemplateExpression/VariableName":Zhe.function(Zhe.variableName),
VariableDefinition:Zhe.definition(Zhe.variableName),Label:Zhe.labelName,
PropertyName:Zhe.propertyName,PrivatePropertyName:Zhe.special(Zhe.propertyName),
"CallExpression/MemberExpression/PropertyName":Zhe.function(Zhe.propertyName),
"FunctionDeclaration/VariableDefinition":Zhe.function(Zhe.definition(Zhe.variableName)),
"ClassDeclaration/VariableDefinition":Zhe.definition(Zhe.className),
PropertyDefinition:Zhe.definition(Zhe.propertyName),
PrivatePropertyDefinition:Zhe.definition(Zhe.special(Zhe.propertyName)),
UpdateOp:Zhe.updateOperator,"LineComment Hashbang":Zhe.lineComment,
BlockComment:Zhe.blockComment,Number:Zhe.number,String:Zhe.string,
Escape:Zhe.escape,ArithOp:Zhe.arithmeticOperator,LogicOp:Zhe.logicOperator,
BitOp:Zhe.bitwiseOperator,CompareOp:Zhe.compareOperator,RegExp:Zhe.regexp,
Equals:Zhe.definitionOperator,Arrow:Zhe.function(Zhe.punctuation),
": Spread":Zhe.punctuation,"( )":Zhe.paren,"[ ]":Zhe.squareBracket,
"{ }":Zhe.brace,"InterpolationStart InterpolationEnd":Zhe.special(Zhe.brace),
".":Zhe.derefOperator,", ;":Zhe.separator,"@":Zhe.meta,TypeName:Zhe.typeName,
TypeDefinition:Zhe.definition(Zhe.typeName),
"type enum interface implements namespace module declare":Zhe.definitionKeyword,
"abstract global Privacy readonly override":Zhe.modifier,
"is keyof unique infer":Zhe.operatorKeyword,
JSXAttributeValue:Zhe.attributeValue,JSXText:Zhe.content,
"JSXStartTag JSXStartCloseTag JSXSelfCloseEndTag JSXEndTag":Zhe.angleBracket,
"JSXIdentifier JSXNameSpacedName":Zhe.tagName,
"JSXAttribute/JSXIdentifier JSXAttribute/JSXNameSpacedName":Zhe.attributeName,
"JSXBuiltin/JSXIdentifier":Zhe.standard(Zhe.tagName)}),yye={__proto__:null,
export:20,as:25,from:33,default:36,async:41,function:42,extends:54,this:58,
true:66,false:66,null:78,void:82,typeof:86,super:102,new:136,delete:148,
yield:157,await:161,class:166,public:229,private:229,protected:229,readonly:231,
instanceof:250,satisfies:253,in:254,const:256,import:290,keyof:345,unique:349,
infer:355,is:391,abstract:411,implements:413,type:415,let:418,var:420,using:423,
interface:429,enum:433,namespace:439,module:441,declare:445,global:449,for:468,
of:477,while:480,with:484,do:488,if:492,else:494,switch:498,case:504,try:510,
catch:514,finally:518,return:522,throw:526,break:530,continue:534,debugger:538
},Oye={__proto__:null,async:123,get:125,set:127,declare:189,public:191,
private:191,protected:191,static:193,abstract:195,override:197,readonly:203,
accessor:205,new:395},wye={__proto__:null,"<":187},xye=ebe.deserialize({
version:14,
states:"$@QO%TQ^OOO%[Q^OOO'_Q`OOP(lOWOOO*zQ?NdO'#CiO+RO!bO'#CjO+aO#tO'#CjO+oO!0LbO'#D^O.QQ^O'#DdO.bQ^O'#DoO%[Q^O'#DwO0fQ^O'#EPOOQ?Mr'#EX'#EXO1PQWO'#EUOOQO'#Em'#EmOOQO'#Ih'#IhO1XQWO'#GpO1dQWO'#ElO1iQWO'#ElO3hQ?NdO'#JmO6[Q?NdO'#JnO6uQWO'#F[O6zQ&jO'#FsOOQ?Mr'#Fe'#FeO7VO,YO'#FeO7eQ7[O'#FzO9RQWO'#FyOOQ?Mr'#Jn'#JnOOQ?Mp'#Jm'#JmO9WQWO'#GtOOQU'#KZ'#KZO9cQWO'#IUO9hQ?MxO'#IVOOQU'#JZ'#JZOOQU'#IZ'#IZQ`Q^OOO`Q^OOO9pQMnO'#DsO9wQ^O'#D{O:OQ^O'#D}O9^QWO'#GpO:VQ7[O'#CoO:eQWO'#EkO:pQWO'#EvO:uQ7[O'#FdO;dQWO'#GpOOQO'#K['#K[O;iQWO'#K[O;wQWO'#GxO;wQWO'#GyO;wQWO'#G{O9^QWO'#HOO<nQWO'#HRO>VQWO'#CeO>gQWO'#H_O>oQWO'#HeO>oQWO'#HgO`Q^O'#HiO>oQWO'#HkO>oQWO'#HnO>tQWO'#HtO>yQ?MyO'#HzO%[Q^O'#H|O?UQ?MyO'#IOO?aQ?MyO'#IQO9hQ?MxO'#ISO?lQ?NdO'#CiO@nQ`O'#DiQOQWOOO%[Q^O'#D}OAUQWO'#EQO:VQ7[O'#EkOAaQWO'#EkOAlQpO'#FdOOQU'#Cg'#CgOOQ?Mp'#Dn'#DnOOQ?Mp'#Jq'#JqO%[Q^O'#JqOOQO'#Jt'#JtOOQO'#Id'#IdOBlQ`O'#EdOOQ?Mp'#Ec'#EcOOQ?Mp'#Jx'#JxOChQ?NQO'#EdOCrQ`O'#ETOOQO'#Js'#JsODWQ`O'#JtOEeQ`O'#ETOCrQ`O'#EdPErO#@ItO'#CbPOOO)CDx)CDxOOOO'#I['#I[OE}O!bO,59UOOQ?Mr,59U,59UOOOO'#I]'#I]OF]O#tO,59UO%[Q^O'#D`OOOO'#I_'#I_OFkO!0LbO,59xOOQ?Mr,59x,59xOFyQ^O'#I`OG^QWO'#JoOI]QrO'#JoO+}Q^O'#JoOIdQWO,5:OOIzQWO'#EmOJXQWO'#KOOJdQWO'#J}OJdQWO'#J}OJlQWO,5;ZOJqQWO'#J|OOQ?Mv,5:Z,5:ZOJxQ^O,5:ZOLvQ?NdO,5:cOMgQWO,5:kONQQ?MxO'#J{ONXQWO'#JzO9WQWO'#JzONmQWO'#JzONuQWO,5;YONzQWO'#JzO!#PQrO'#JnOOQ?Mr'#Ci'#CiO%[Q^O'#EPO!#oQrO,5:pOOQQ'#Ju'#JuOOQO-E<f-E<fO9^QWO,5=[O!$VQWO,5=[O!$[Q^O,5;WO!&_Q7[O'#EhO!'xQWO,5;WO!'}Q^O'#DvO!(XQ`O,5;aO!(aQ`O,5;aO%[Q^O,5;aOOQU'#FS'#FSOOQU'#FU'#FUO%[Q^O,5;bO%[Q^O,5;bO%[Q^O,5;bO%[Q^O,5;bO%[Q^O,5;bO%[Q^O,5;bO%[Q^O,5;bO%[Q^O,5;bO%[Q^O,5;bO%[Q^O,5;bOOQU'#FY'#FYO!(oQ^O,5;sOOQ?Mr,5;x,5;xOOQ?Mr,5;y,5;yOOQ?Mr,5;{,5;{O%[Q^O'#IlO!*rQ?MxO,5<gO%[Q^O,5;bO!&_Q7[O,5;bO!+aQ7[O,5;bO!-RQ7[O'#EZO%[Q^O,5;vOOQ?Mr,5;z,5;zO!-YQ&jO'#FiO!.VQ&jO'#KSO!-qQ&jO'#KSO!.^Q&jO'#KSOOQO'#KS'#KSO!.rQ&jO,5<ROOOS,5<_,5<_O!/TQ^O'#FuOOOS'#Ik'#IkO7VO,YO,5<PO!/[Q&jO'#FwOOQ?Mr,5<P,5<PO!/{Q!LQO'#CvOOQ?Mr'#Cz'#CzO!0`O!0LbO'#DOO!0|Q7[O,5<dO!1TQWO,5<fO!2pQ$ISO'#GVO!2}QWO'#GWO!3SQWO'#GWO!4rQ$ISO'#G[O!5nQ`O'#G`OOQO'#Gk'#GkO!+hQ7[O'#GjOOQO'#Gm'#GmO!+hQ7[O'#GlO!6aQ!LQO'#JgOOQ?Mr'#Jg'#JgO!6kQWO'#JfO!6yQWO'#JeO!7RQWO'#CuOOQ?Mr'#Cx'#CxO!7ZQWO'#CzOOQ?Mr'#DS'#DSOOQ?Mr'#DU'#DUO1SQWO'#DWO!+hQ7[O'#F}O!+hQ7[O'#GPO!7`QWO'#GRO!7eQWO'#GSO!3SQWO'#GYO!+hQ7[O'#G_O!7jQWO'#EnO!8XQWO,5<eOOQ?Mp'#Cr'#CrO!8aQWO'#EoO!9ZQ`O'#EpOOQ?Mp'#J|'#J|O!9bQ?MxO'#K]O9hQ?MxO,5=`O`Q^O,5>pOOQU'#Jc'#JcOOQU,5>q,5>qOOQU-E<X-E<XO!;aQ?NdO,5:_O!9UQ`O,5:]O!=zQ?NdO,5:gO%[Q^O,5:gO!@bQ?NdO,5:iOOQO,5@v,5@vO!ARQ7[O,5=[O!AaQ?MxO'#JdO9RQWO'#JdO!ArQ?MxO,59ZO!A}Q`O,59ZO!BVQ7[O,59ZO:VQ7[O,59ZO!BbQWO,5;WO!BjQWO'#H^O!COQWO'#K`O%[Q^O,5;|O!9UQ`O,5<OO!CWQWO,5=wO!C]QWO,5=wO!CbQWO,5=wO9hQ?MxO,5=wO;wQWO,5=gOOQO'#Cv'#CvO!CpQ`O,5=dO!CxQ7[O,5=eO!DTQWO,5=gO!DYQpO,5=jO!DbQWO'#K[O>tQWO'#HTO9^QWO'#HVO!DgQWO'#HVO:VQ7[O'#HXO!DlQWO'#HXOOQU,5=m,5=mO!DqQWO'#HYO!ESQWO'#CoO!EXQWO,59PO!EcQWO,59PO!GhQ^O,59POOQU,59P,59PO!GxQ?MxO,59PO%[Q^O,59PO!JTQ^O'#HaOOQU'#Hb'#HbOOQU'#Hc'#HcO`Q^O,5=yO!JkQWO,5=yO`Q^O,5>PO`Q^O,5>RO!JpQWO,5>TO`Q^O,5>VO!JuQWO,5>YO!JzQ^O,5>`OOQU,5>f,5>fO%[Q^O,5>fO9hQ?MxO,5>hOOQU,5>j,5>jO# UQWO,5>jOOQU,5>l,5>lO# UQWO,5>lOOQU,5>n,5>nO# rQ`O'#D[O%[Q^O'#JqO# |Q`O'#JqO#!kQ`O'#DjO#!|Q`O'#DjO#%_Q^O'#DjO#%fQWO'#JpO#%nQWO,5:TO#%sQWO'#EqO#&RQWO'#KPO#&ZQWO,5;[O#&`Q`O'#DjO#&mQ`O'#ESOOQ?Mr,5:l,5:lO%[Q^O,5:lO#&tQWO,5:lO>tQWO,5;VO!A}Q`O,5;VO!BVQ7[O,5;VO:VQ7[O,5;VO#&|QWO,5@]O#'RQ(CYO,5:pOOQO-E<b-E<bO#(XQ?NQO,5;OOCrQ`O,5:oO#(cQ`O,5:oOCrQ`O,5;OO!ArQ?MxO,5:oOOQ?Mp'#Eg'#EgOOQO,5;O,5;OO%[Q^O,5;OO#(pQ?MxO,5;OO#({Q?MxO,5;OO!A}Q`O,5:oOOQO,5;U,5;UO#)ZQ?MxO,5;OPOOO'#IY'#IYP#)oO#@ItO,58|POOO,58|,58|OOOO-E<Y-E<YOOQ?Mr1G.p1G.pOOOO-E<Z-E<ZO#)zQpO,59zOOOO-E<]-E<]OOQ?Mr1G/d1G/dO#*PQrO,5>zO+}Q^O,5>zOOQO,5?Q,5?QO#*ZQ^O'#I`OOQO-E<^-E<^O#*hQWO,5@ZO#*pQrO,5@ZO#*wQWO,5@iOOQ?Mr1G/j1G/jO%[Q^O,5@jO#+PQWO'#IfOOQO-E<d-E<dO#*wQWO,5@iOOQ?Mp1G0u1G0uOOQ?Mv1G/u1G/uOOQ?Mv1G0V1G0VO%[Q^O,5@gO#+eQ?MxO,5@gO#+vQ?MxO,5@gO#+}QWO,5@fO9WQWO,5@fO#,VQWO,5@fO#,eQWO'#IiO#+}QWO,5@fOOQ?Mp1G0t1G0tO!(XQ`O,5:rO!(dQ`O,5:rOOQQ,5:t,5:tO#-VQYO,5:tO#-_Q7[O1G2vO9^QWO1G2vOOQ?Mr1G0r1G0rO#-mQ?NdO1G0rO#.rQ?NbO,5;SOOQ?Mr'#GU'#GUO#/`Q?NdO'#JgO!$[Q^O1G0rO#1hQrO'#JrO%[Q^O'#JrO#1rQWO,5:bOOQ?Mr'#D['#D[OOQ?Mr1G0{1G0{O%[Q^O1G0{OOQ?Mr1G1e1G1eO#1wQWO1G0{O#4]Q?NdO1G0|O#4dQ?NdO1G0|O#6zQ?NdO1G0|O#7RQ?NdO1G0|O#9iQ?NdO1G0|O#<PQ?NdO1G0|O#<WQ?NdO1G0|O#<_Q?NdO1G0|O#>uQ?NdO1G0|O#>|Q?NdO1G0|O#AZQ07bO'#CiO#CUQ07bO1G1_O#C]Q07bO'#JnO#CpQ?NdO,5?WOOQ?Mp-E<j-E<jO#E}Q?NdO1G0|O#FzQ?NdO1G0|OOQ?Mr1G0|1G0|O#GzQ7[O'#JwO#HUQWO,5:uO#HZQ?NdO1G1bO#H}Q&jO,5<VO#IVQ&jO,5<WO#I_Q&jO'#FnO#IvQWO'#FmOOQO'#KT'#KTOOQO'#Ij'#IjO#I{Q&jO1G1mOOQ?Mr1G1m1G1mOOOS1G1x1G1xO#J^Q07bO'#JmO#JhQWO,5<aO!(oQ^O,5<aOOOS-E<i-E<iOOQ?Mr1G1k1G1kO#JmQ`O'#KSOOQ?Mr,5<c,5<cO#JuQ`O,5<cO!&_Q7[O'#DQOOOO'#I^'#I^O#JzO!0LbO,59jOOQ?Mr,59j,59jO%[Q^O1G2OO!7eQWO'#InO#KVQ7[O,5<xOOQ?Mr,5<u,5<uO!+hQ7[O'#IqO#KuQ7[O,5=UO!+hQ7[O'#IsO#LhQ7[O,5=WO!&_Q7[O,5=YOOQO1G2Q1G2QO#LrQpO'#CrO#MVQ$ISO'#EoO#NUQ`O'#G`O#NrQpO,5<qO#NyQWO'#KWO9WQWO'#KWO$ XQWO,5<sO!+hQ7[O,5<rO$ ^QWO'#GXO$ oQWO,5<rO$ tQpO'#GUO$!RQpO'#KXO$!]QWO'#KXO!&_Q7[O'#KXO$!bQWO,5<vO$!gQ`O'#GaO!5iQ`O'#GaO$!xQWO'#GcO$!}QWO'#GeO!3SQWO'#GhO$#SQ?MxO'#IpO$#_Q`O,5<zOOQ?Mv,5<z,5<zO$#fQ`O'#GaO$#tQ`O'#GbO$#|Q`O'#GbO$$RQ7[O,5=UO$$cQ7[O,5=WOOQ?Mr,5=Z,5=ZO!+hQ7[O,5@QO!+hQ7[O,5@QO$$sQWO'#IuO$%OQWO,5@PO$%WQWO,59aOOQ?Mr,59f,59fO$%zQ!LSO,59rOOQ?Mr'#Jk'#JkO$&mQ7[O,5<iO$'`Q7[O,5<kO@fQWO,5<mOOQ?Mr,5<n,5<nO$'jQWO,5<tO$'oQ7[O,5<yO$(PQWO'#JzO!$[Q^O1G2PO$(UQWO1G2PO9WQWO'#J}O9WQWO'#EqO%[Q^O'#EqO9WQWO'#IwO$(ZQ?MxO,5@wOOQU1G2z1G2zOOQU1G4[1G4[OOQ?Mr1G/y1G/yOOQ?Mr1G/w1G/wO$*]Q?NdO1G0ROOQU1G2v1G2vO!&_Q7[O1G2vO%[Q^O1G2vO#-bQWO1G2vO$,aQ7[O'#EhOOQ?Mp,5@O,5@OO$,kQ?MxO,5@OOOQU1G.u1G.uO!ArQ?MxO1G.uO!A}Q`O1G.uO!BVQ7[O1G.uO$,|QWO1G0rO$-RQWO'#CiO$-^QWO'#KaO$-fQWO,5=xO$-kQWO'#KaO$-pQWO'#KaO$.OQWO'#I}O$.^QWO,5@zO$.fQrO1G1hOOQ?Mr1G1j1G1jO9^QWO1G3cO@fQWO1G3cO$.mQWO1G3cO$.rQWO1G3cOOQU1G3c1G3cO!DTQWO1G3RO!&_Q7[O1G3OO$.wQWO1G3OOOQU1G3P1G3PO!&_Q7[O1G3PO$.|QWO1G3PO$/UQ`O'#G}OOQU1G3R1G3RO!5iQ`O'#IyO!DYQpO1G3UOOQU1G3U1G3UOOQU,5=o,5=oO$/^Q7[O,5=qO9^QWO,5=qO$!}QWO,5=sO9RQWO,5=sO!A}Q`O,5=sO!BVQ7[O,5=sO:VQ7[O,5=sO$/lQWO'#K_O$/wQWO,5=tOOQU1G.k1G.kO$/|Q?MxO1G.kO@fQWO1G.kO$0XQWO1G.kO9hQ?MxO1G.kO$2aQrO,5@|O$2nQWO,5@|O9WQWO,5@|O$2yQ^O,5={O$3QQWO,5={OOQU1G3e1G3eO`Q^O1G3eOOQU1G3k1G3kOOQU1G3m1G3mO>oQWO1G3oO$3VQ^O1G3qO$7ZQ^O'#HpOOQU1G3t1G3tO$7hQWO'#HvO>tQWO'#HxOOQU1G3z1G3zO$7pQ^O1G3zO9hQ?MxO1G4QOOQU1G4S1G4SOOQ?Mp'#G]'#G]O9hQ?MxO1G4UO9hQ?MxO1G4WO$;wQWO,5@]O!(oQ^O,5;]O9WQWO,5;]O>tQWO,5:UO!(oQ^O,5:UO!A}Q`O,5:UO$;|Q07bO,5:UOOQO,5;],5;]O$<WQ`O'#IaO$<nQWO,5@[OOQ?Mr1G/o1G/oO$<vQ`O'#IgO$=QQWO,5@kOOQ?Mp1G0v1G0vO#!|Q`O,5:UOOQO'#Ic'#IcO$=YQ`O,5:nOOQ?Mv,5:n,5:nO#&wQWO1G0WOOQ?Mr1G0W1G0WO%[Q^O1G0WOOQ?Mr1G0q1G0qO>tQWO1G0qO!A}Q`O1G0qO!BVQ7[O1G0qOOQ?Mp1G5w1G5wO!ArQ?MxO1G0ZOOQO1G0j1G0jO%[Q^O1G0jO$=aQ?MxO1G0jO$=lQ?MxO1G0jO!A}Q`O1G0ZOCrQ`O1G0ZO$=zQ?MxO1G0jOOQO1G0Z1G0ZO$>`Q?NdO1G0jPOOO-E<W-E<WPOOO1G.h1G.hOOOO1G/f1G/fO$>jQpO,5<gO$>rQrO1G4fOOQO1G4l1G4lO%[Q^O,5>zO$>|QWO1G5uO$?UQWO1G6TO$?^QrO1G6UO9WQWO,5?QO$?hQ?NdO1G6RO%[Q^O1G6RO$?xQ?MxO1G6RO$@ZQWO1G6QO$@ZQWO1G6QO9WQWO1G6QO$@cQWO,5?TO9WQWO,5?TOOQO,5?T,5?TO$@wQWO,5?TO$(PQWO,5?TOOQO-E<g-E<gOOQQ1G0^1G0^OOQQ1G0`1G0`O#-YQWO1G0`OOQU7+(b7+(bO!&_Q7[O7+(bO%[Q^O7+(bO$AVQWO7+(bO$AbQ7[O7+(bO$ApQ?NdO,5=UO$CxQ?NdO,5=WO$FQQ?NdO,5=UO$H`Q?NdO,5=WO$JnQ?NdO,59rO$LsQ?NdO,5<iO$N{Q?NdO,5<kO%#TQ?NdO,5<yOOQ?Mr7+&^7+&^O%%cQ?NdO7+&^O%&VQ^O'#IbO%&dQWO,5@^O%&lQrO,5@^OOQ?Mr1G/|1G/|O%&vQWO7+&gOOQ?Mr7+&g7+&gO%&{Q07bO,5:cO%[Q^O7+&yO%'VQ07bO,5:_O%'dQ07bO,5:gO%'nQ07bO,5:iO%'xQ7[O'#IeO%(SQWO,5@cOOQ?Mr1G0a1G0aOOQO1G1q1G1qOOQO1G1r1G1rO%([QtO,5<YO!(oQ^O,5<XOOQO-E<h-E<hOOQ?Mr7+'X7+'XOOOS7+'d7+'dOOOS1G1{1G1{O%(gQWO1G1{OOQ?Mr1G1}1G1}O%(lQpO,59lOOOO-E<[-E<[OOQ?Mr1G/U1G/UO%(sQ?NdO7+'jOOQ?Mr,5?Y,5?YO%)gQpO,5?YOOQ?Mr1G2d1G2dP!&_Q7[O'#InPOQ?Mr-E<l-E<lO%*VQ7[O,5?]OOQ?Mr-E<o-E<oO%*xQ7[O,5?_OOQ?Mr-E<q-E<qO%+SQpO1G2tO%+ZQpO'#CrO%+qQ7[O'#J}O%+xQ^O'#EqOOQ?Mr1G2]1G2]O%,SQWO'#ImO%,hQWO,5@rO%,hQWO,5@rO%,pQWO,5@rO%,{QWO,5@rOOQO1G2_1G2_O%-ZQ7[O1G2^O!+hQ7[O1G2^O%-kQ$ISO'#IoO%-xQWO,5@sO!&_Q7[O,5@sO%.QQpO,5@sOOQ?Mr1G2b1G2bOOQ?Mp,5<{,5<{OOQ?Mp,5<|,5<|O$(PQWO,5<|OCcQWO,5<|O!A}Q`O,5<{OOQO'#Gd'#GdO%.[QWO,5<}OOQ?Mp,5=P,5=PO$(PQWO,5=SOOQO,5?[,5?[OOQO-E<n-E<nOOQ?Mv1G2f1G2fO!5iQ`O,5<{O%.dQWO,5<|O$!xQWO,5<}O%.oQ`O,5<|O!+hQ7[O'#IqO%/`Q7[O1G2pO!+hQ7[O'#IsO%0RQ7[O1G2rO%0]Q7[O1G5lO%0gQ7[O1G5lOOQO,5?a,5?aOOQO-E<s-E<sOOQO1G.{1G.{O!9UQ`O,59tO%[Q^O,59tOOQ?Mr,5<h,5<hO%0tQWO1G2XO!+hQ7[O1G2`O%0yQ?NdO7+'kOOQ?Mr7+'k7+'kO!$[Q^O7+'kO%1mQWO,5;]OOQ?Mp,5?c,5?cOOQ?Mp-E<u-E<uO%1rQpO'#KYO#&wQWO7+(bO4UQrO7+(bO$AYQWO7+(bO%1|Q?NbO'#CiO%2aQ?NbO,5=QO%3RQWO,5=QOOQ?Mp1G5j1G5jOOQU7+$a7+$aO!ArQ?MxO7+$aO!A}Q`O7+$aO!$[Q^O7+&^O%3WQWO'#I|O%3oQWO,5@{OOQO1G3d1G3dO9^QWO,5@{O%3oQWO,5@{O%3wQWO,5@{OOQO,5?i,5?iOOQO-E<{-E<{OOQ?Mr7+'S7+'SO%3|QWO7+(}O9hQ?MxO7+(}O9^QWO7+(}O@fQWO7+(}OOQU7+(m7+(mO%4RQ?NbO7+(jO!&_Q7[O7+(jO%4]QpO7+(kOOQU7+(k7+(kO!&_Q7[O7+(kO%4dQWO'#K^O%4oQWO,5=iOOQO,5?e,5?eOOQO-E<w-E<wOOQU7+(p7+(pO%6RQ`O'#HWOOQU1G3]1G3]O!&_Q7[O1G3]O%[Q^O1G3]O%6YQWO1G3]O%6eQ7[O1G3]O9hQ?MxO1G3_O$!}QWO1G3_O9RQWO1G3_O!A}Q`O1G3_O!BVQ7[O1G3_O%6sQWO'#I{O%7XQWO,5@yO%7aQ`O,5@yOOQ?Mp1G3`1G3`OOQU7+$V7+$VO@fQWO7+$VO9hQ?MxO7+$VO%7lQWO7+$VO%[Q^O1G6hO%[Q^O1G6iO%7qQ?MxO1G6hO%7{Q^O1G3gO%8SQWO1G3gO%8XQ^O1G3gOOQU7+)P7+)PO9hQ?MxO7+)ZO`Q^O7+)]OOQU'#Kd'#KdOOQU'#JO'#JOO%8`Q^O,5>[OOQU,5>[,5>[O%[Q^O'#HqO%8mQWO'#HsOOQU,5>b,5>bO9WQWO,5>bOOQU,5>d,5>dOOQU7+)f7+)fOOQU7+)l7+)lOOQU7+)p7+)pOOQU7+)r7+)rO%8rQ`O1G5wO%9WQ07bO1G0wO%9bQWO1G0wOOQO1G/p1G/pO%9mQ07bO1G/pO>tQWO1G/pO!(oQ^O'#DjOOQO,5>{,5>{OOQO-E<_-E<_OOQO,5?R,5?ROOQO-E<e-E<eO!A}Q`O1G/pOOQO-E<a-E<aOOQ?Mv1G0Y1G0YOOQ?Mr7+%r7+%rO#&wQWO7+%rOOQ?Mr7+&]7+&]O>tQWO7+&]O!A}Q`O7+&]OOQO7+%u7+%uO$>`Q?NdO7+&UOOQO7+&U7+&UO%[Q^O7+&UO%9wQ?MxO7+&UO!ArQ?MxO7+%uO!A}Q`O7+%uO%:SQ?MxO7+&UO%:bQ?NdO7++mO%[Q^O7++mO%:rQWO7++lO%:rQWO7++lOOQO1G4o1G4oO9WQWO1G4oO%:zQWO1G4oOOQQ7+%z7+%zO#&wQWO<<K|O4UQrO<<K|O%;YQWO<<K|OOQU<<K|<<K|O!&_Q7[O<<K|O%[Q^O<<K|O%;bQWO<<K|O%;mQ?NdO,5?]O%=uQ?NdO,5?_O%?}Q?NdO1G2^O%B]Q?NdO1G2pO%DeQ?NdO1G2rO%FmQrO,5>|O%[Q^O,5>|OOQO-E<`-E<`O%FwQWO1G5xOOQ?Mr<<JR<<JRO%GPQ07bO1G0rO%IWQ07bO1G0|O%I_Q07bO1G0|O%K`Q07bO1G0|O%KgQ07bO1G0|O%MhQ07bO1G0|O& iQ07bO1G0|O& pQ07bO1G0|O& wQ07bO1G0|O&#xQ07bO1G0|O&$PQ07bO1G0|O&$WQ?NdO<<JeO&&OQ07bO1G0|O&&{Q07bO1G0|O&'{Q07bO'#JgO&*OQ07bO1G1bO&*]Q07bO1G0RO&*gQ7[O,5?POOQO-E<c-E<cO!(oQ^O'#FpOOQO'#KU'#KUOOQO1G1t1G1tO&*qQWO1G1sO&*vQ07bO,5?WOOOS7+'g7+'gOOOO1G/W1G/WOOQ?Mr1G4t1G4tO!+hQ7[O7+(`O&-WQrO'#CiO&-bQWO,5?XO9WQWO,5?XOOQO-E<k-E<kO&-pQWO1G6^O&-pQWO1G6^O&-xQWO1G6^O&.TQ7[O7+'xO&.eQpO,5?ZO&.oQWO,5?ZO!&_Q7[O,5?ZOOQO-E<m-E<mO&.tQpO1G6_O&/OQWO1G6_OOQ?Mp1G2h1G2hO$(PQWO1G2hOOQ?Mp1G2g1G2gO&/WQWO1G2iO!&_Q7[O1G2iOOQ?Mp1G2n1G2nO!A}Q`O1G2gOCcQWO1G2hO&/]QWO1G2iO&/eQWO1G2hO$!xQWO1G2iO&0XQ7[O,5?]OOQ?Mr-E<p-E<pO&0zQ7[O,5?_OOQ?Mr-E<r-E<rO!+hQ7[O7++WOOQ?Mr1G/`1G/`O&1UQWO1G/`OOQ?Mr7+'s7+'sO&1ZQ7[O7+'zO&1kQ?NdO<<KVOOQ?Mr<<KV<<KVO&2_QWO1G0wO!&_Q7[O'#IvO&2dQWO,5@tO&4fQrO<<K|O!&_Q7[O1G2lOOQU<<G{<<G{O!ArQ?MxO<<G{O&4mQ?NdO<<IxOOQ?Mr<<Ix<<IxOOQO,5?h,5?hO&5aQWO,5?hO&5fQWO,5?hOOQO-E<z-E<zO&5tQWO1G6gO&5tQWO1G6gO9^QWO1G6gO@fQWO<<LiOOQU<<Li<<LiO&5|QWO<<LiO9hQ?MxO<<LiOOQU<<LU<<LUO%4RQ?NbO<<LUOOQU<<LV<<LVO%4]QpO<<LVO&6RQ`O'#IxO&6^QWO,5@xO!(oQ^O,5@xOOQU1G3T1G3TO%+xQ^O'#JqOOQO'#Iz'#IzO9hQ?MxO'#IzO&6fQ`O,5=rOOQU,5=r,5=rO&6mQ`O'#EdO&7RQ`O'#GcO&7WQWO7+(wO&7]QWO7+(wOOQU7+(w7+(wO!&_Q7[O7+(wO%[Q^O7+(wO&7eQWO7+(wOOQU7+(y7+(yO9hQ?MxO7+(yO$!}QWO7+(yO9RQWO7+(yO!A}Q`O7+(yO&7pQWO,5?gOOQO-E<y-E<yOOQO'#HZ'#HZO&7{QWO1G6eO9hQ?MxO<<GqOOQU<<Gq<<GqO@fQWO<<GqO&8TQWO7+,SO&8YQWO7+,TO%[Q^O7+,SO%[Q^O7+,TOOQU7+)R7+)RO&8_QWO7+)RO&8dQ^O7+)RO&8kQWO7+)ROOQU<<Lu<<LuOOQU<<Lw<<LwOOQU-E<|-E<|OOQU1G3v1G3vO&8pQWO,5>]OOQU,5>_,5>_O&8uQWO1G3|O9WQWO7+&cO!(oQ^O7+&cOOQO7+%[7+%[O&8zQ07bO1G6UO>tQWO7+%[OOQ?Mr<<I^<<I^OOQ?Mr<<Iw<<IwO>tQWO<<IwOOQO<<Ip<<IpO$>`Q?NdO<<IpO%[Q^O<<IpOOQO<<Ia<<IaO!ArQ?MxO<<IaO&9UQ?MxO<<IpO&9aQ?NdO<= XO&9qQWO<= WOOQO7+*Z7+*ZO9WQWO7+*ZOOQUANAhANAhO&9yQrOANAhO!&_Q7[OANAhO#&wQWOANAhO4UQrOANAhO&:QQWOANAhO%[Q^OANAhO&:YQ?NdO7+'xO&<hQ?NdO,5?]O&>pQ?NdO,5?_O&@xQ?NdO7+'zO&CWQrO1G4hO&CbQ07bO7+&^O&EcQ07bO,5=UO&GgQ07bO,5=WO&GwQ07bO,5=UO&HXQ07bO,5=WO&HiQ07bO,59rO&JlQ07bO,5<iO&LlQ07bO,5<kO&N}Q07bO,5<yO'!pQ07bO7+'jO'!}Q07bO7+'kO'#[QWO,5<[OOQO7+'_7+'_O'#aQ7[O<<KzOOQO1G4s1G4sO'#hQWO1G4sO'#sQWO1G4sO'$RQWO7++xO'$RQWO7++xO!&_Q7[O1G4uO'$ZQpO1G4uO'$eQWO7++yOOQ?Mp7+(S7+(SO'$mQWO7+(TO'$xQpO7+(TOOQ?Mp7+(R7+(RO$(PQWO7+(SO'%PQWO7+(TO!&_Q7[O7+(TOCcQWO7+(SO'%UQWO7+(TO'%^Q7[O<<NrOOQ?Mr7+$z7+$zO'%hQpO,5?bOOQO-E<t-E<tO'%rQ?NbO7+(WOOQUAN=gAN=gO9^QWO1G5SOOQO1G5S1G5SO'&SQWO1G5SO'&XQWO7+,RO'&XQWO7+,RO9hQ?MxOANBTO@fQWOANBTOOQUANBTANBTOOQUANApANApOOQUANAqANAqO'&aQWO,5?dOOQO-E<v-E<vO'&lQ07bO1G6dOOQO,5?f,5?fOOQO-E<x-E<xOOQU1G3^1G3^O%+xQ^O,5<}O'&vQWO,5<}OOQU<<Lc<<LcO!&_Q7[O<<LcO&7WQWO<<LcO'&{QWO<<LcO%[Q^O<<LcOOQU<<Le<<LeO9hQ?MxO<<LeO$!}QWO<<LeO9RQWO<<LeO''TQ`O1G5RO''`QWO7+,POOQUAN=]AN=]O9hQ?MxOAN=]OOQU<= n<= nOOQU<= o<= oO''hQWO<= nO''mQWO<= oOOQU<<Lm<<LmO''rQWO<<LmO''wQ^O<<LmOOQU1G3w1G3wO>tQWO7+)hO'(OQWO<<I}O'(ZQ07bO<<I}OOQO<<Hv<<HvOOQ?MrAN?cAN?cOOQOAN?[AN?[O$>`Q?NdOAN?[OOQOAN>{AN>{O%[Q^OAN?[OOQO<<Mu<<MuOOQUG27SG27SO!&_Q7[OG27SO#&wQWOG27SO'(eQrOG27SO4UQrOG27SO'(lQWOG27SO'(tQ07bO<<JeO')RQ07bO1G2^O'*tQ07bO,5?]O',tQ07bO,5?_O'.tQ07bO1G2pO'0tQ07bO1G2rO'2tQ07bO<<KVO'3RQ07bO<<IxOOQO1G1v1G1vO!+hQ7[OANAfOOQO7+*_7+*_O'3`QWO7+*_O'3kQWO<= dO'3sQpO7+*aOOQ?Mp<<Ko<<KoO$(PQWO<<KoOCcQWO<<KoO'3}QWO<<KoOOQ?Mp<<Kn<<KnO'4YQpO<<KoO$(PQWO<<KnO'4aQWO<<KoO!&_Q7[O<<KoOOQO7+*n7+*nO9^QWO7+*nO'4fQWO<= mOOQUG27oG27oO9hQ?MxOG27oO!(oQ^O1G5OO'4nQWO7+,OO&7WQWOANA}OOQUANA}ANA}O!&_Q7[OANA}O'4vQWOANA}OOQUANBPANBPO9hQ?MxOANBPO$!}QWOANBPOOQO'#H['#H[OOQO7+*m7+*mOOQUG22wG22wOOQUANEYANEYOOQUANEZANEZOOQUANBXANBXO'5OQWOANBXOOQU<<MS<<MSO!(oQ^OAN?iOOQOG24vG24vO$>`Q?NdOG24vO#&wQWOLD,nOOQULD,nLD,nO!&_Q7[OLD,nO'5TQrOLD,nO'5[Q07bO7+'xO'6}Q07bO,5?]O'8}Q07bO,5?_O':}Q07bO7+'zO'<pQ7[OG27QOOQO<<My<<MyOOQ?MpANAZANAZO$(PQWOANAZOCcQWOANAZO'=QQWOANAZOOQ?MpANAYANAYO'=]QpOANAZOOQO<<NY<<NYOOQULD-ZLD-ZO'=dQ07bO7+*jOOQUG27iG27iO&7WQWOG27iO!&_Q7[OG27iOOQUG27kG27kO9hQ?MxOG27kOOQUG27sG27sO'=nQ07bOG25TOOQOLD*bLD*bOOQU!$(!Y!$(!YO#&wQWO!$(!YO!&_Q7[O!$(!YO'=xQ?NdOG27QOOQ?MpG26uG26uO$(PQWOG26uOCcQWOG26uO'@WQWOG26uOOQULD-TLD-TO&7WQWOLD-TOOQULD-VLD-VOOQU!)9Et!)9EtO#&wQWO!)9EtOOQ?MpLD,aLD,aO$(PQWOLD,aOCcQWOLD,aOOQU!$(!o!$(!oOOQU!.K;`!.K;`O'@cQ07bOG27QOOQ?Mp!$( {!$( {O$(PQWO!$( {OOQ?Mp!)9Eg!)9EgO!(oQ^O'#DwO1PQWO'#EUO'BUQrO'#JmO'B]QMnO'#DsO'BdQ^O'#D{O'BkQrO'#CiO'ERQrO'#CiO!(oQ^O'#D}O'EcQ^O,5;WO!(oQ^O,5;bO!(oQ^O,5;bO!(oQ^O,5;bO!(oQ^O,5;bO!(oQ^O,5;bO!(oQ^O,5;bO!(oQ^O,5;bO!(oQ^O,5;bO!(oQ^O,5;bO!(oQ^O,5;bO!(oQ^O'#IlO'GfQWO,5<gO!(oQ^O,5;bO'GnQ7[O,5;bO'IXQ7[O,5;bO!(oQ^O,5;vO!&_Q7[O'#GjO'GnQ7[O'#GjO!&_Q7[O'#GlO'GnQ7[O'#GlO1SQWO'#DWO1SQWO'#DWO!&_Q7[O'#F}O'GnQ7[O'#F}O!&_Q7[O'#GPO'GnQ7[O'#GPO!&_Q7[O'#G_O'GnQ7[O'#G_O!(oQ^O,5:gO'I`Q`O'#D[O!(oQ^O,5@jO'EcQ^O1G0rO'IjQ07bO'#CiO!(oQ^O1G2OO!&_Q7[O'#IqO'GnQ7[O'#IqO!&_Q7[O'#IsO'GnQ7[O'#IsO'ItQpO'#CrO!&_Q7[O,5<rO'GnQ7[O,5<rO'EcQ^O1G2PO!(oQ^O7+&yO!&_Q7[O1G2^O'GnQ7[O1G2^O!&_Q7[O'#IqO'GnQ7[O'#IqO!&_Q7[O'#IsO'GnQ7[O'#IsO!&_Q7[O1G2`O'GnQ7[O1G2`O'EcQ^O7+'kO'EcQ^O7+&^O!&_Q7[OANAfO'GnQ7[OANAfO'JXQWO'#ElO'J^QWO'#ElO'JfQWO'#F[O'JkQWO'#EvO'JpQWO'#KOO'J{QWO'#J|O'KWQWO,5;WO'K]Q7[O,5<dO'KdQWO'#GWO'KiQWO'#GWO'KnQWO,5<eO'KvQWO,5;WO'LOQ07bO1G1_O'LVQWO,5<rO'L[QWO,5<rO'LaQWO,5<tO'LfQWO,5<tO'LkQWO1G2PO'LpQWO1G0rO'LuQ7[O<<KzO'L|Q7[O<<KzO7eQ7[O'#FzO9RQWO'#FyOAaQWO'#EkO!(oQ^O,5;sO!3SQWO'#GWO!3SQWO'#GWO!3SQWO'#GYO!3SQWO'#GYO!+hQ7[O7+(`O!+hQ7[O7+(`O%+SQpO1G2tO%+SQpO1G2tO!&_Q7[O,5=YO!&_Q7[O,5=Y",
stateData:"'NQ~O'wOS'xOSTOS'yRQ~OPYOQYOSfOY!VOaqOdzOeyOmkOoYOpkOqkOwkOyYO{YO!PWO!TkO!UkO![XO!fuO!iZO!lYO!mYO!nYO!pvO!rwO!uxO!y]O#t!PO$V|O%e}O%g!QO%i!OO%j!OO%k!OO%n!RO%p!SO%s!TO%t!TO%v!UO&S!WO&Y!XO&[!YO&^!ZO&`![O&c!]O&i!^O&o!_O&q!`O&s!aO&u!bO&w!cO(OSO(QTO(TUO([VO(j[O(yiO~OWtO~P`OPYOQYOSfOd!jOe!iOmkOoYOpkOqkOwkOyYO{YO!PWO!TkO!UkO![!eO!fuO!iZO!lYO!mYO!nYO!pvO!r!gO!u!hO$V!kO(O!dO(QTO(TUO([VO(j[O(yiO~Oa!wOp!nO!P!oO!_!yO!`!vO!a!vO!y;QO#Q!pO#R!pO#S!xO#T!pO#U!pO#X!zO#Y!zO(P!lO(QTO(TUO(`!mO(j!sO~O'y!{O~OP]XR]X[]Xa]Xo]X}]X!P]X!Y]X!i]X!m]X#O]X#P]X#]]X#hfX#k]X#l]X#m]X#n]X#o]X#p]X#q]X#r]X#s]X#u]X#w]X#y]X#z]X$P]X'u]X([]X(m]X(t]X(u]X~O!d%PX~P(qO_!}O(Q#PO(R!}O(S#PO~O_#QO(S#PO(T#PO(U#QO~Ou#SO!R#TO(]#TO(^#VO~OPYOQYOSfOd!jOe!iOmkOoYOpkOqkOwkOyYO{YO!PWO!TkO!UkO![!eO!fuO!iZO!lYO!mYO!nYO!pvO!r!gO!u!hO$V!kO(O;UO(QTO(TUO([VO(j[O(yiO~O!X#ZO!Y#WO!V(cP!V(qP~P+}O!Z#cO~P`OPYOQYOSfOd!jOe!iOoYOpkOqkOwkOyYO{YO!PWO!TkO!UkO![!eO!fuO!iZO!lYO!mYO!nYO!pvO!r!gO!u!hO$V!kO(QTO(TUO([VO(j[O(yiO~Om#mO!X#iO!y]O#f#lO#g#iO(O;VO!h(nP~P.iO!i#oO(O#nO~O!u#sO!y]O%e#tO~O#h#uO~O!d#vO#h#uO~OP$[OR#zO[$cOo$aO}#yO!P#{O!Y$_O!i#xO!m$[O#O$RO#k$OO#l$PO#m$PO#n$PO#o$QO#p$RO#q$RO#r$bO#s$RO#u$SO#w$UO#y$WO#z$XO([VO(m$YO(t#|O(u#}O~Oa(aX'u(aX's(aX!h(aX!V(aX![(aX%f(aX!d(aX~P1qO#P$dO#]$eO$P$eOP(bXR(bX[(bXo(bX}(bX!P(bX!Y(bX!i(bX!m(bX#O(bX#k(bX#l(bX#m(bX#n(bX#o(bX#p(bX#q(bX#r(bX#s(bX#u(bX#w(bX#y(bX#z(bX([(bX(m(bX(t(bX(u(bX![(bX%f(bX~Oa(bX'u(bX's(bX!V(bX!h(bXs(bX!d(bX~P4UO#]$eO~O$[$hO$^$gO$e$mO~OSfO![$nO$h$oO$j$qO~Oh%VOm%WOo%XOp$tOq$tOw%YOy%ZO{%[O!P${O![$|O!f%aO!i$xO#g%bO$V%_O$r%]O$t%^O$w%`O(O$sO(QTO(TUO([$uO(t$}O(u%POg(XP~O!i%cO~O!P%fO![%gO(O%eO~O!d%kO~Oa%lO'u%lO~O}%pO~P%[O(P!lO~P%[O%k%tO~P%[Oh%VO!i%cO(O%eO(P!lO~Oe%{O!i%cO(O%eO~O#s$RO~O}&QO![%}O!i&PO%g&TO(O%eO(P!lO(QTO(TUO`)SP~O!u#sO~O%p&VO!P)OX![)OX(O)OX~O(O&WO~O!r&]O#t!PO%g!QO%i!OO%j!OO%k!OO%n!RO%p!SO%s!TO%t!TO~Od&bOe&aO!u&_O%e&`O%x&^O~P;|Od&eOeyO![&dO!r&]O!uxO!y]O#t!PO%e}O%i!OO%j!OO%k!OO%n!RO%p!SO%s!TO%t!TO%v!UO~Ob&hO#]&kO%g&fO(P!lO~P=RO!i&lO!r&pO~O!i#oO~O![XO~Oa%lO't&xO'u%lO~Oa%lO't&{O'u%lO~Oa%lO't&}O'u%lO~O's]X!V]Xs]X!h]X&W]X![]X%f]X!d]X~P(qO!_'[O!`'TO!a'TO(P!lO(QTO(TUO~Op'RO!P'QO!X'UO(`'PO!Z(dP!Z(sP~P@YOk'_O![']O(O%eO~Oe'dO!i%cO(O%eO~O}&QO!i&PO~Op!nO!P!oO!y;QO#Q!pO#R!pO#T!pO#U!pO(P!lO(QTO(TUO(`!mO(j!sO~O!_'jO!`'iO!a'iO#S!pO#X'kO#Y'kO~PAtOa%lOh%VO!d#vO!i%cO'u%lO(m'mO~O!m'qO#]'oO~PCSOp!nO!P!oO(QTO(TUO(`!mO(j!sO~O![XOp(hX!P(hX!_(hX!`(hX!a(hX!y(hX#Q(hX#R(hX#S(hX#T(hX#U(hX#X(hX#Y(hX(P(hX(Q(hX(T(hX(`(hX(j(hX~O!`'iO!a'iO(P!lO~PCrO'z'uO'{'uO'|'wO~O_!}O(Q'yO(R!}O(S'yO~O_#QO(S'yO(T'yO(U#QO~Ou#SO!R#TO(]#TO(^'}O~O!X(PO!V'SX!V'YX!Y'SX!Y'YX~P+}O!Y(RO!V(cX~OP$[OR#zO[$cOo$aO}#yO!P#{O!Y(RO!i#xO!m$[O#O$RO#k$OO#l$PO#m$PO#n$PO#o$QO#p$RO#q$RO#r$bO#s$RO#u$SO#w$UO#y$WO#z$XO([VO(m$YO(t#|O(u#}O~O!V(cX~PGfO!V(WO~O!V(pX!Y(pX!d(pX!h(pX(m(pX~O#](pX#h#aX!Z(pX~PIiO#](XO!V(rX!Y(rX~O!Y(YO!V(qX~O!V(]O~O#]$eO~PIiO!Z(^O~P`OR#zO}#yO!P#{O!i#xO([VOP!ka[!kao!ka!Y!ka!m!ka#O!ka#k!ka#l!ka#m!ka#n!ka#o!ka#p!ka#q!ka#r!ka#s!ka#u!ka#w!ka#y!ka#z!ka(m!ka(t!ka(u!ka~Oa!ka'u!ka's!ka!V!ka!h!kas!ka![!ka%f!ka!d!ka~PKPO!h(_O~O!d#vO#](`O(m'mO!Y(oXa(oX'u(oX~O!h(oX~PMlO!P%fO![%gO!y]O#f(eO#g(dO(O%eO~O!Y(fO!h(nX~O!h(hO~O!P%fO![%gO#g(dO(O%eO~OP(bXR(bX[(bXo(bX}(bX!P(bX!Y(bX!i(bX!m(bX#O(bX#k(bX#l(bX#m(bX#n(bX#o(bX#p(bX#q(bX#r(bX#s(bX#u(bX#w(bX#y(bX#z(bX([(bX(m(bX(t(bX(u(bX~O!d#vO!h(bX~P! YOR(jO}(iO!i#xO#P$dO!y!xa!P!xa~O!u!xa%e!xa![!xa#f!xa#g!xa(O!xa~P!#ZO!u(nO~OPYOQYOSfOd!jOe!iOmkOoYOpkOqkOwkOyYO{YO!PWO!TkO!UkO![XO!fuO!iZO!lYO!mYO!nYO!pvO!r!gO!u!hO$V!kO(O!dO(QTO(TUO([VO(j[O(yiO~Oh%VOm%WOo%XOp$tOq$tOw%YOy%ZO{;nO!P${O![$|O!f=OO!i$xO#g;tO$V%_O$r;pO$t;rO$w%`O(O(rO(QTO(TUO([$uO(t$}O(u%PO~O#h(tO~O!X(vO!h(fP~P%[O(`(xO(j[O~O!P(zO!i#xO(`(xO(j[O~OP;POQ;POSfOd<zOe!iOmkOo;POpkOqkOwkOy;PO{;PO!PWO!TkO!UkO![!eO!f;SO!iZO!l;PO!m;PO!n;PO!p;TO!r;WO!u!hO$V!kO(O)XO(QTO(TUO([VO(j[O(y<xO~O!Y$_Oa$oa'u$oa's$oa!h$oa!V$oa![$oa%f$oa!d$oa~O#t)`O~P!&_Oh%VOm%WOo%XOp$tOq$tOw%YOy%ZO{%[O!P${O![$|O!f%aO!i$xO#g%bO$V%_O$r%]O$t%^O$w%`O(O(rO(QTO(TUO([$uO(t$}O(u%PO~Og(kP~P!+hO})eO!d)dO![$]X$Y$]X$[$]X$^$]X$e$]X~O!d)dO![(vX$Y(vX$[(vX$^(vX$e(vX~O})eO~P!-qO})eO![(vX$Y(vX$[(vX$^(vX$e(vX~O![)gO$Y)kO$[)fO$^)fO$e)lO~O!X)oO~P!(oO$[$hO$^$gO$e)sO~Ok$xX}$xX!P$xX#P$xX(t$xX(u$xX~OgjXg$xXkjX!YjX#]jX~P!/gOu)uO(])vO(^)xO~Ok*RO})zO!P){O(t$}O(u%PO~Og)yO~P!0kOg*SO~Oh%VOm%WOo%XOp$tOq$tOw%YOy%ZO{;nO!P*UO![*VO!f=OO!i$xO#g;tO$V%_O$r;pO$t;rO$w%`O(QTO(TUO([$uO(t$}O(u%PO~O!X*YO(O*TO!h(zP~P!1YO#h*[O~O!i*]O~Oh%VOm%WOo%XOp$tOq$tOw%YOy%ZO{;nO!P${O![$|O!f=OO!i$xO#g;tO$V%_O$r;pO$t;rO$w%`O(O*_O(QTO(TUO([$uO(t$}O(u%PO~O!X*bO!V({P~P!3XOo*nO!P*fO!_*lO!`*eO!a*eO!i*]O#X*mO%]*hO(P!lO(`!mO~O!Z*kO~P!4|O#P$dOk(ZX}(ZX!P(ZX(t(ZX(u(ZX!Y(ZX#](ZX~Og(ZX#}(ZX~P!5uOk*sO#]*rOg(YX!Y(YX~O!Y*tOg(XX~O(O&WOg(XP~Op*wO~O!i*|O~O(O(rO~Om+QO!P%fO!X#iO![%gO!y]O#f#lO#g#iO(O%eO!h(nP~O!d#vO#h+RO~O!P%fO!X+TO!Y(YO![%gO(O%eO!V(qP~Op'XO!P+VO!X+UO(QTO(TUO(`(xO~O!Z(sP~P!8uO!Y+WOa)PX'u)PX~OP$[OR#zO[$cOo$aO}#yO!P#{O!i#xO!m$[O#O$RO#k$OO#l$PO#m$PO#n$PO#o$QO#p$RO#q$RO#r$bO#s$RO#u$SO#w$UO#y$WO#z$XO([VO(m$YO(t#|O(u#}O~Oa!ga!Y!ga'u!ga's!ga!V!ga!h!gas!ga![!ga%f!ga!d!ga~P!9mOR#zO}#yO!P#{O!i#xO([VOP!oa[!oao!oa!Y!oa!m!oa#O!oa#k!oa#l!oa#m!oa#n!oa#o!oa#p!oa#q!oa#r!oa#s!oa#u!oa#w!oa#y!oa#z!oa(m!oa(t!oa(u!oa~Oa!oa'u!oa's!oa!V!oa!h!oas!oa![!oa%f!oa!d!oa~P!<TOR#zO}#yO!P#{O!i#xO([VOP!qa[!qao!qa!Y!qa!m!qa#O!qa#k!qa#l!qa#m!qa#n!qa#o!qa#p!qa#q!qa#r!qa#s!qa#u!qa#w!qa#y!qa#z!qa(m!qa(t!qa(u!qa~Oa!qa'u!qa's!qa!V!qa!h!qas!qa![!qa%f!qa!d!qa~P!>kOh%VOk+aO![']O%f+`O~O!d+cOa(WX![(WX'u(WX!Y(WX~Oa%lO![XO'u%lO~Oh%VO!i%cO~Oh%VO!i%cO(O%eO~O!d#vO#h(tO~Ob+nO%g+oO(O+kO(QTO(TUO!Z)TP~O!Y+pO`)SX~O[+tO~O`+uO~O![%}O(O%eO(P!lO`)SP~Oh%VO#]+zO~Oh%VOk+}O![$|O~O![,PO~O},RO![XO~O%k%tO~O!u,WO~Oe,]O~Ob,^O(O#nO(QTO(TUO!Z)RP~Oe%{O~O%g!QO(O&WO~P=RO[,cO`,bO~OPYOQYOSfOdzOeyOmkOoYOpkOqkOwkOyYO{YO!PWO!TkO!UkO!fuO!iZO!lYO!mYO!nYO!pvO!uxO!y]O%e}O(QTO(TUO([VO(j[O(yiO~O![!eO!r!gO$V!kO(O!dO~P!EkO`,bOa%lO'u%lO~OPYOQYOSfOd!jOe!iOmkOoYOpkOqkOwkOyYO{YO!PWO!TkO!UkO![!eO!fuO!iZO!lYO!mYO!nYO!pvO!u!hO$V!kO(O!dO(QTO(TUO([VO(j[O(yiO~Oa,hO!rwO#t!OO%i!OO%j!OO%k!OO~P!HTO!i&lO~O&Y,nO~O![,pO~O&k,rO&m,sOP&haQ&haS&haY&haa&had&hae&ham&hao&hap&haq&haw&hay&ha{&ha!P&ha!T&ha!U&ha![&ha!f&ha!i&ha!l&ha!m&ha!n&ha!p&ha!r&ha!u&ha!y&ha#t&ha$V&ha%e&ha%g&ha%i&ha%j&ha%k&ha%n&ha%p&ha%s&ha%t&ha%v&ha&S&ha&Y&ha&[&ha&^&ha&`&ha&c&ha&i&ha&o&ha&q&ha&s&ha&u&ha&w&ha's&ha(O&ha(Q&ha(T&ha([&ha(j&ha(y&ha!Z&ha&a&hab&ha&f&ha~O(O,xO~Oh!bX!Y!OX!Z!OX!d!OX!d!bX!i!bX#]!OX~O!Y!bX!Z!bX~P# ZO!d,}O#],|Oh(eX!Y#eX!Y(eX!Z#eX!Z(eX!d(eX!i(eX~Oh%VO!d-PO!i%cO!Y!^X!Z!^X~Op!nO!P!oO(QTO(TUO(`!mO~OP;POQ;POSfOd<zOe!iOmkOo;POpkOqkOwkOy;PO{;PO!PWO!TkO!UkO![!eO!f;SO!iZO!l;PO!m;PO!n;PO!p;TO!r;WO!u!hO$V!kO(QTO(TUO([VO(j[O(y<xO~O(O;zO~P##_O!Y-TO!Z(dX~O!Z-VO~O!d,}O#],|O!Y#eX!Z#eX~O!Y-WO!Z(sX~O!Z-YO~O!`-ZO!a-ZO(P!lO~P#!|O!Z-^O~P'_Ok-aO![']O~O!V-fO~Op!xa!_!xa!`!xa!a!xa#Q!xa#R!xa#S!xa#T!xa#U!xa#X!xa#Y!xa(P!xa(Q!xa(T!xa(`!xa(j!xa~P!#ZO!m-kO#]-iO~PCSO!`-mO!a-mO(P!lO~PCrOa%lO#]-iO'u%lO~Oa%lO!d#vO#]-iO'u%lO~Oa%lO!d#vO!m-kO#]-iO'u%lO(m'mO~O'z'uO'{'uO'|-rO~Os-sO~O!V'Sa!Y'Sa~P!9mO!X-wO!V'SX!Y'SX~P%[O!Y(RO!V(ca~O!V(ca~PGfO!Y(YO!V(qa~O!P%fO!X-{O![%gO(O%eO!V'YX!Y'YX~O#]-}O!Y(oa!h(oaa(oa'u(oa~O!d#vO~P#+eO!Y(fO!h(na~O!P%fO![%gO#g.RO(O%eO~Om.WO!P%fO!X.TO![%gO!y]O#f.VO#g.TO(O%eO!Y']X!h']X~OR.[O!i#xO~Oh%VOk._O![']O%f.^O~Oa#`i!Y#`i'u#`i's#`i!V#`i!h#`is#`i![#`i%f#`i!d#`i~P!9mOk=UO})zO!P){O(t$}O(u%PO~O#h#[aa#[a#]#[a'u#[a!Y#[a!h#[a![#[a!V#[a~P#.aO#h(ZXP(ZXR(ZX[(ZXa(ZXo(ZX!i(ZX!m(ZX#O(ZX#k(ZX#l(ZX#m(ZX#n(ZX#o(ZX#p(ZX#q(ZX#r(ZX#s(ZX#u(ZX#w(ZX#y(ZX#z(ZX'u(ZX([(ZX(m(ZX!h(ZX!V(ZX's(ZXs(ZX![(ZX%f(ZX!d(ZX~P!5uO!Y.lO!h(fX~P!9mO!h.oO~O!V.qO~OP$[OR#zO}#yO!P#{O!i#xO!m$[O([VO[#jia#jio#ji!Y#ji#O#ji#l#ji#m#ji#n#ji#o#ji#p#ji#q#ji#r#ji#s#ji#u#ji#w#ji#y#ji#z#ji'u#ji(m#ji(t#ji(u#ji's#ji!V#ji!h#jis#ji![#ji%f#ji!d#ji~O#k#ji~P#1|O#k$OO~P#1|OP$[OR#zOo$aO}#yO!P#{O!i#xO!m$[O#k$OO#l$PO#m$PO#n$PO([VO[#jia#ji!Y#ji#O#ji#p#ji#q#ji#r#ji#s#ji#u#ji#w#ji#y#ji#z#ji'u#ji(m#ji(t#ji(u#ji's#ji!V#ji!h#jis#ji![#ji%f#ji!d#ji~O#o#ji~P#4kO#o$QO~P#4kOP$[OR#zO[$cOo$aO}#yO!P#{O!i#xO!m$[O#O$RO#k$OO#l$PO#m$PO#n$PO#o$QO#p$RO#q$RO#r$bO#s$RO([VOa#ji!Y#ji#w#ji#y#ji#z#ji'u#ji(m#ji(t#ji(u#ji's#ji!V#ji!h#jis#ji![#ji%f#ji!d#ji~O#u#ji~P#7YOP$[OR#zO[$cOo$aO}#yO!P#{O!i#xO!m$[O#O$RO#k$OO#l$PO#m$PO#n$PO#o$QO#p$RO#q$RO#r$bO#s$RO#u$SO([VO(u#}Oa#ji!Y#ji#y#ji#z#ji'u#ji(m#ji(t#ji's#ji!V#ji!h#jis#ji![#ji%f#ji!d#ji~O#w$UO~P#9pO#w#ji~P#9pO#u$SO~P#7YOP$[OR#zO[$cOo$aO}#yO!P#{O!i#xO!m$[O#O$RO#k$OO#l$PO#m$PO#n$PO#o$QO#p$RO#q$RO#r$bO#s$RO#u$SO#w$UO([VO(t#|O(u#}Oa#ji!Y#ji#z#ji'u#ji(m#ji's#ji!V#ji!h#jis#ji![#ji%f#ji!d#ji~O#y#ji~P#<fO#y$WO~P#<fOP]XR]X[]Xo]X}]X!P]X!i]X!m]X#O]X#P]X#]]X#hfX#k]X#l]X#m]X#n]X#o]X#p]X#q]X#r]X#s]X#u]X#w]X#y]X#z]X$P]X([]X(m]X(t]X(u]X!Y]X!Z]X~O#}]X~P#?TOP$[OR#zO[;hOo;fO}#yO!P#{O!i#xO!m$[O#O;]O#k;YO#l;ZO#m;ZO#n;ZO#o;[O#p;]O#q;]O#r;gO#s;]O#u;^O#w;`O#y;bO#z;cO([VO(m$YO(t#|O(u#}O~O#}.sO~P#AbO#P$dO#];iO$P;iO#}(bX!Z(bX~P! YOa'`a!Y'`a'u'`a's'`a!h'`a!V'`as'`a!['`a%f'`a!d'`a~P!9mO[#jia#jio#ji!Y#ji#O#ji#o#ji#p#ji#q#ji#r#ji#s#ji#u#ji#w#ji#y#ji#z#ji'u#ji(m#ji's#ji!V#ji!h#jis#ji![#ji%f#ji!d#ji~OP$[OR#zO}#yO!P#{O!i#xO!m$[O#k$OO#l$PO#m$PO#n$PO([VO(t#ji(u#ji~P#DdOk=UO})zO!P){O(t$}O(u%POP#jiR#ji!i#ji!m#ji#k#ji#l#ji#m#ji#n#ji([#ji~P#DdO!Y.wOg(kX~P!0kOg.yO~Oa$Oi!Y$Oi'u$Oi's$Oi!V$Oi!h$Ois$Oi![$Oi%f$Oi!d$Oi~P!9mO$[.zO$^.zO~O$[.{O$^.{O~O!d)dO#].|O![$bX$Y$bX$[$bX$^$bX$e$bX~O!X.}O~O![)gO$Y/PO$[)fO$^)fO$e/QO~O!Y;dO!Z(aX~P#AbO!Z/RO~O!d)dO$e(vX~O$e/TO~Ou)uO(])vO(^/WO~O!V/[O~P!&_O(t$}Ok%^a}%^a!P%^a(u%^a!Y%^a#]%^a~Og%^a#}%^a~P#K^O(u%POk%`a}%`a!P%`a(t%`a!Y%`a#]%`a~Og%`a#}%`a~P#LPO!YfX!dfX!hfX!h$xX(mfX~P!/gO!X/eO!Y(YO(O/dO!V(qP!V({P~P!1YOo*nO!_*lO!`*eO!a*eO!i*]O#X*mO%]*hO(P!lO~Op'XO!P/fO!X+UO!Z*kO(QTO(TUO(`;wO!Z(sP~P#MjO!h/gO~P#.aO!Y/hO!d#vO(m'mO!h(zX~O!h/mO~O!P%fO!X*YO![%gO(O%eO!h(zP~O#h/oO~O!V$xX!Y$xX!d%PX~P!/gO!Y/pO!V({X~P#.aO!d/rO~O!V/tO~Oh%VOo/xO!d#vO!i%cO(m'mO~O(O/zO~O!d+cO~Oa%lO!Y0OO'u%lO~O!Z0QO~P!4|O!`0RO!a0RO(P!lO(`!mO~O!P0TO(`!mO~O#X0UO~Og%^a!Y%^a#]%^a#}%^a~P!0kOg%`a!Y%`a#]%`a#}%`a~P!0kO(O&WOg'iX!Y'iX~O!Y*tOg(Xa~Og0_O~OR0`O}0`O!P0aO#P$dOkza(tza(uza!Yza#]za~Ogza#}za~P$%]O})zO!P){Ok$qa(t$qa(u$qa!Y$qa#]$qa~Og$qa#}$qa~P$&UO})zO!P){Ok$sa(t$sa(u$sa!Y$sa#]$sa~Og$sa#}$sa~P$&wO#h0dO~Og%Ra!Y%Ra#]%Ra#}%Ra~P!0kO!d#vO~O#h0gO~O!Y+WOa)Pa'u)Pa~OR#zO}#yO!P#{O!i#xO([VOP!oi[!oio!oi!Y!oi!m!oi#O!oi#k!oi#l!oi#m!oi#n!oi#o!oi#p!oi#q!oi#r!oi#s!oi#u!oi#w!oi#y!oi#z!oi(m!oi(t!oi(u!oi~Oa!oi'u!oi's!oi!V!oi!h!ois!oi![!oi%f!oi!d!oi~P$(fOh%VOo%XOp$tOq$tOw%YOy%ZO{;nO!P${O![$|O!f=OO!i$xO#g;tO$V%_O$r;pO$t;rO$w%`O(QTO(TUO([$uO(t$}O(u%PO~Om0pO(O0oO~P$*|O!d+cOa(Wa![(Wa'u(Wa!Y(Wa~O#h0vO~O[]X!YfX!ZfX~O!Y0wO!Z)TX~O!Z0yO~O[0zO~Ob0|O(O+kO(QTO(TUO~O![%}O(O%eO`'qX!Y'qX~O!Y+pO`)Sa~O!h1PO~P!9mO[1SO~O`1TO~O#]1WO~Ok1ZO![$|O~O(`(xO!Z)QP~Oh%VOk1dO![1aO%f1cO~O[1nO!Y1lO!Z)RX~O!Z1oO~O`1qOa%lO'u%lO~O(O#nO(QTO(TUO~O#P$dO#]$eO$P$eOP(bXR(bX[(bXo(bX}(bX!P(bX!Y(bX!i(bX!m(bX#O(bX#k(bX#l(bX#m(bX#n(bX#o(bX#p(bX#q(bX#r(bX#u(bX#w(bX#y(bX#z(bX([(bX(m(bX(t(bX(u(bX~O#s1tO&W1uOa(bX~P$0dO#]$eO#s1tO&W1uO~Oa1wO~P%[Oa1yO~O&a1|OP&_iQ&_iS&_iY&_ia&_id&_ie&_im&_io&_ip&_iq&_iw&_iy&_i{&_i!P&_i!T&_i!U&_i![&_i!f&_i!i&_i!l&_i!m&_i!n&_i!p&_i!r&_i!u&_i!y&_i#t&_i$V&_i%e&_i%g&_i%i&_i%j&_i%k&_i%n&_i%p&_i%s&_i%t&_i%v&_i&S&_i&Y&_i&[&_i&^&_i&`&_i&c&_i&i&_i&o&_i&q&_i&s&_i&u&_i&w&_i's&_i(O&_i(Q&_i(T&_i([&_i(j&_i(y&_i!Z&_ib&_i&f&_i~Ob2SO!Z2QO&f2RO~P`O![XO!i2UO~O&m,sOP&hiQ&hiS&hiY&hia&hid&hie&him&hio&hip&hiq&hiw&hiy&hi{&hi!P&hi!T&hi!U&hi![&hi!f&hi!i&hi!l&hi!m&hi!n&hi!p&hi!r&hi!u&hi!y&hi#t&hi$V&hi%e&hi%g&hi%i&hi%j&hi%k&hi%n&hi%p&hi%s&hi%t&hi%v&hi&S&hi&Y&hi&[&hi&^&hi&`&hi&c&hi&i&hi&o&hi&q&hi&s&hi&u&hi&w&hi's&hi(O&hi(Q&hi(T&hi([&hi(j&hi(y&hi!Z&hi&a&hib&hi&f&hi~O!V2[O~O!Y!^a!Z!^a~P#AbOp!nO!P!oO!X2bO(`!mO!Y'TX!Z'TX~P@YO!Y-TO!Z(da~O!Y'ZX!Z'ZX~P!8uO!Y-WO!Z(sa~O!Z2iO~P'_Oa%lO#]2rO'u%lO~Oa%lO!d#vO#]2rO'u%lO~Oa%lO!d#vO!m2vO#]2rO'u%lO(m'mO~Oa%lO'u%lO~P!9mO!Y$_Os$oa~O!V'Si!Y'Si~P!9mO!Y(RO!V(ci~O!Y(YO!V(qi~O!V(ri!Y(ri~P!9mO!Y(oi!h(oia(oi'u(oi~P!9mO#]2xO!Y(oi!h(oia(oi'u(oi~O!Y(fO!h(ni~O!P%fO![%gO!y]O#f2}O#g2|O(O%eO~O!P%fO![%gO#g2|O(O%eO~Ok3UO![']O%f3TO~Oh%VOk3UO![']O%f3TO~O#h%^aP%^aR%^a[%^aa%^ao%^a!i%^a!m%^a#O%^a#k%^a#l%^a#m%^a#n%^a#o%^a#p%^a#q%^a#r%^a#s%^a#u%^a#w%^a#y%^a#z%^a'u%^a([%^a(m%^a!h%^a!V%^a's%^as%^a![%^a%f%^a!d%^a~P#K^O#h%`aP%`aR%`a[%`aa%`ao%`a!i%`a!m%`a#O%`a#k%`a#l%`a#m%`a#n%`a#o%`a#p%`a#q%`a#r%`a#s%`a#u%`a#w%`a#y%`a#z%`a'u%`a([%`a(m%`a!h%`a!V%`a's%`as%`a![%`a%f%`a!d%`a~P#LPO#h%^aP%^aR%^a[%^aa%^ao%^a!Y%^a!i%^a!m%^a#O%^a#k%^a#l%^a#m%^a#n%^a#o%^a#p%^a#q%^a#r%^a#s%^a#u%^a#w%^a#y%^a#z%^a'u%^a([%^a(m%^a!h%^a!V%^a's%^a#]%^as%^a![%^a%f%^a!d%^a~P#.aO#h%`aP%`aR%`a[%`aa%`ao%`a!Y%`a!i%`a!m%`a#O%`a#k%`a#l%`a#m%`a#n%`a#o%`a#p%`a#q%`a#r%`a#s%`a#u%`a#w%`a#y%`a#z%`a'u%`a([%`a(m%`a!h%`a!V%`a's%`a#]%`as%`a![%`a%f%`a!d%`a~P#.aO#hzaPza[zaazaoza!iza!mza#Oza#kza#lza#mza#nza#oza#pza#qza#rza#sza#uza#wza#yza#zza'uza([za(mza!hza!Vza'szasza![za%fza!dza~P$%]O#h$qaP$qaR$qa[$qaa$qao$qa!i$qa!m$qa#O$qa#k$qa#l$qa#m$qa#n$qa#o$qa#p$qa#q$qa#r$qa#s$qa#u$qa#w$qa#y$qa#z$qa'u$qa([$qa(m$qa!h$qa!V$qa's$qas$qa![$qa%f$qa!d$qa~P$&UO#h$saP$saR$sa[$saa$sao$sa!i$sa!m$sa#O$sa#k$sa#l$sa#m$sa#n$sa#o$sa#p$sa#q$sa#r$sa#s$sa#u$sa#w$sa#y$sa#z$sa'u$sa([$sa(m$sa!h$sa!V$sa's$sas$sa![$sa%f$sa!d$sa~P$&wO#h%RaP%RaR%Ra[%Raa%Rao%Ra!Y%Ra!i%Ra!m%Ra#O%Ra#k%Ra#l%Ra#m%Ra#n%Ra#o%Ra#p%Ra#q%Ra#r%Ra#s%Ra#u%Ra#w%Ra#y%Ra#z%Ra'u%Ra([%Ra(m%Ra!h%Ra!V%Ra's%Ra#]%Ras%Ra![%Ra%f%Ra!d%Ra~P#.aOa#`q!Y#`q'u#`q's#`q!V#`q!h#`qs#`q![#`q%f#`q!d#`q~P!9mO!X3^O!Y'UX!h'UX~P%[O!Y.lO!h(fa~O!Y.lO!h(fa~P!9mO!V3aO~O#}!ka!Z!ka~PKPO#}!ga!Y!ga!Z!ga~P#AbO#}!oa!Z!oa~P!<TO#}!qa!Z!qa~P!>kOg'XX!Y'XX~P!+hO!Y.wOg(ka~OSfO![3uO$c3vO~O!Z3zO~Os3{O~P#.aOa$lq!Y$lq'u$lq's$lq!V$lq!h$lqs$lq![$lq%f$lq!d$lq~P!9mO!V3|O~P#.aO})zO!P){O(u%POk'ea(t'ea!Y'ea#]'ea~Og'ea#}'ea~P%)nO})zO!P){Ok'ga(t'ga(u'ga!Y'ga#]'ga~Og'ga#}'ga~P%*aO(m$YO~P#.aO!VfX!V$xX!YfX!Y$xX!d%PX#]fX~P!/gO(O<QO~P!1YOmkO(O4OO~P.iO!P%fO!X4QO![%gO(O%eO!Y'aX!h'aX~O!Y/hO!h(za~O!Y/hO!d#vO!h(za~O!Y/hO!d#vO(m'mO!h(za~Og$zi!Y$zi#]$zi#}$zi~P!0kO!X4YO!V'cX!Y'cX~P!3XO!Y/pO!V({a~O!Y/pO!V({a~P#.aO!d#vO#s4bO~Oo4eO!d#vO(m'mO~O!P4hO(`!mO~O(t$}Ok%^i}%^i!P%^i(u%^i!Y%^i#]%^i~Og%^i#}%^i~P%.wO(u%POk%`i}%`i!P%`i(t%`i!Y%`i#]%`i~Og%`i#}%`i~P%/jOg(Yi!Y(Yi~P!0kO#]4mOg(Yi!Y(Yi~P!0kO!h4pO~Oa$mq!Y$mq'u$mq's$mq!V$mq!h$mqs$mq![$mq%f$mq!d$mq~P!9mO!V4tO~O!Y4uO![(|X~P#.aOa$xX![$xX%Z]X'u$xX!Y$xX~P!/gO%Z4xOalXklX}lX!PlX![lX'ulX(tlX(ulX!YlX~O%Z4xO~Ob5OO%g5PO(O+kO(QTO(TUO!Y'pX!Z'pX~O!Y0wO!Z)Ta~O[5TO~O`5UO~Oa%lO'u%lO~P#.aO![$|O~P#.aO!Y5^O#]5`O!Z)QX~O!Z5aO~Oo5hOp!nO!P5bO!_!yO!`!vO!a!vO!y;QO#Q!pO#R!pO#S!pO#T!pO#U!pO#X5gO#Y!zO(P!lO(QTO(TUO(`!mO(j!sO~O!Z5fO~P%4tOk5mO![1aO%f5lO~Oh%VOk5mO![1aO%f5lO~Ob5tO(O#nO(QTO(TUO!Y'oX!Z'oX~O!Y1lO!Z)Ra~O(QTO(TUO(`5vO~O`5zO~O#s5}O&W6OO~PMlO!h6PO~P%[Oa6RO~Oa6RO~P%[Ob2SO!Z6WO&f2RO~P`O!d6YO~O!d6[Oh(ei!Y(ei!Z(ei!d(ei!i(ei~O!Y#ei!Z#ei~P#AbO#]6]O!Y#ei!Z#ei~O!Y!^i!Z!^i~P#AbOa%lO#]6fO'u%lO~Oa%lO!d#vO#]6fO'u%lO~O!Y(oq!h(oqa(oq'u(oq~P!9mO!Y(fO!h(nq~O!P%fO![%gO#g6mO(O%eO~O![']O%f6pO~Ok6tO![']O%f6pO~O#h'eaP'eaR'ea['eaa'eao'ea!i'ea!m'ea#O'ea#k'ea#l'ea#m'ea#n'ea#o'ea#p'ea#q'ea#r'ea#s'ea#u'ea#w'ea#y'ea#z'ea'u'ea(['ea(m'ea!h'ea!V'ea's'eas'ea!['ea%f'ea!d'ea~P%)nO#h'gaP'gaR'ga['gaa'gao'ga!i'ga!m'ga#O'ga#k'ga#l'ga#m'ga#n'ga#o'ga#p'ga#q'ga#r'ga#s'ga#u'ga#w'ga#y'ga#z'ga'u'ga(['ga(m'ga!h'ga!V'ga's'gas'ga!['ga%f'ga!d'ga~P%*aO#h$ziP$ziR$zi[$zia$zio$zi!Y$zi!i$zi!m$zi#O$zi#k$zi#l$zi#m$zi#n$zi#o$zi#p$zi#q$zi#r$zi#s$zi#u$zi#w$zi#y$zi#z$zi'u$zi([$zi(m$zi!h$zi!V$zi's$zi#]$zis$zi![$zi%f$zi!d$zi~P#.aO#h%^iP%^iR%^i[%^ia%^io%^i!i%^i!m%^i#O%^i#k%^i#l%^i#m%^i#n%^i#o%^i#p%^i#q%^i#r%^i#s%^i#u%^i#w%^i#y%^i#z%^i'u%^i([%^i(m%^i!h%^i!V%^i's%^is%^i![%^i%f%^i!d%^i~P%.wO#h%`iP%`iR%`i[%`ia%`io%`i!i%`i!m%`i#O%`i#k%`i#l%`i#m%`i#n%`i#o%`i#p%`i#q%`i#r%`i#s%`i#u%`i#w%`i#y%`i#z%`i'u%`i([%`i(m%`i!h%`i!V%`i's%`is%`i![%`i%f%`i!d%`i~P%/jO!Y'Ua!h'Ua~P!9mO!Y.lO!h(fi~O#}#`i!Y#`i!Z#`i~P#AbOP$[OR#zO}#yO!P#{O!i#xO!m$[O([VO[#jio#ji#O#ji#l#ji#m#ji#n#ji#o#ji#p#ji#q#ji#r#ji#s#ji#u#ji#w#ji#y#ji#z#ji#}#ji(m#ji(t#ji(u#ji!Y#ji!Z#ji~O#k#ji~P%G^O#k;YO~P%G^OP$[OR#zOo;fO}#yO!P#{O!i#xO!m$[O#k;YO#l;ZO#m;ZO#n;ZO([VO[#ji#O#ji#p#ji#q#ji#r#ji#s#ji#u#ji#w#ji#y#ji#z#ji#}#ji(m#ji(t#ji(u#ji!Y#ji!Z#ji~O#o#ji~P%IfO#o;[O~P%IfOP$[OR#zO[;hOo;fO}#yO!P#{O!i#xO!m$[O#O;]O#k;YO#l;ZO#m;ZO#n;ZO#o;[O#p;]O#q;]O#r;gO#s;]O([VO#w#ji#y#ji#z#ji#}#ji(m#ji(t#ji(u#ji!Y#ji!Z#ji~O#u#ji~P%KnOP$[OR#zO[;hOo;fO}#yO!P#{O!i#xO!m$[O#O;]O#k;YO#l;ZO#m;ZO#n;ZO#o;[O#p;]O#q;]O#r;gO#s;]O#u;^O([VO(u#}O#y#ji#z#ji#}#ji(m#ji(t#ji!Y#ji!Z#ji~O#w;`O~P%MoO#w#ji~P%MoO#u;^O~P%KnOP$[OR#zO[;hOo;fO}#yO!P#{O!i#xO!m$[O#O;]O#k;YO#l;ZO#m;ZO#n;ZO#o;[O#p;]O#q;]O#r;gO#s;]O#u;^O#w;`O([VO(t#|O(u#}O#z#ji#}#ji(m#ji!Y#ji!Z#ji~O#y#ji~P&!OO#y;bO~P&!OOa#{y!Y#{y'u#{y's#{y!V#{y!h#{ys#{y![#{y%f#{y!d#{y~P!9mO[#jio#ji#O#ji#o#ji#p#ji#q#ji#r#ji#s#ji#u#ji#w#ji#y#ji#z#ji#}#ji(m#ji!Y#ji!Z#ji~OP$[OR#zO}#yO!P#{O!i#xO!m$[O#k;YO#l;ZO#m;ZO#n;ZO([VO(t#ji(u#ji~P&$zOk=VO})zO!P){O(t$}O(u%POP#jiR#ji!i#ji!m#ji#k#ji#l#ji#m#ji#n#ji([#ji~P&$zO#P$dOP(ZXR(ZX[(ZXk(ZXo(ZX}(ZX!P(ZX!i(ZX!m(ZX#O(ZX#k(ZX#l(ZX#m(ZX#n(ZX#o(ZX#p(ZX#q(ZX#r(ZX#s(ZX#u(ZX#w(ZX#y(ZX#z(ZX#}(ZX([(ZX(m(ZX(t(ZX(u(ZX!Y(ZX!Z(ZX~O#}$Oi!Y$Oi!Z$Oi~P#AbO#}!oi!Z!oi~P$(fOg'Xa!Y'Xa~P!0kO!Z7WO~O!Y'`a!Z'`a~P#AbOP]XR]X[]Xo]X}]X!P]X!V]X!Y]X!i]X!m]X#O]X#P]X#]]X#hfX#k]X#l]X#m]X#n]X#o]X#p]X#q]X#r]X#s]X#u]X#w]X#y]X#z]X$P]X([]X(m]X(t]X(u]X~O!d%WX#s%WX~P&+QO!d#vO(m'mO!Y'aa!h'aa~O!Y/hO!h(zi~O!Y/hO!d#vO!h(zi~Og$zq!Y$zq#]$zq#}$zq~P!0kO!V'ca!Y'ca~P#.aO!d7_O~O!Y/pO!V({i~P#.aO!Y/pO!V({i~O!V7cO~O!d#vO#s7hO~Oo7iO!d#vO(m'mO~O})zO!P){O(u%POk'fa(t'fa!Y'fa#]'fa~Og'fa#}'fa~P&/pO})zO!P){Ok'ha(t'ha(u'ha!Y'ha#]'ha~Og'ha#}'ha~P&0cO!V7lO~Og$|q!Y$|q#]$|q#}$|q~P!0kOa$my!Y$my'u$my's$my!V$my!h$mys$my![$my%f$my!d$my~P!9mO!d6[O~O!Y4uO![(|a~O![']OP$SaR$Sa[$Sao$Sa}$Sa!P$Sa!Y$Sa!i$Sa!m$Sa#O$Sa#k$Sa#l$Sa#m$Sa#n$Sa#o$Sa#p$Sa#q$Sa#r$Sa#s$Sa#u$Sa#w$Sa#y$Sa#z$Sa([$Sa(m$Sa(t$Sa(u$Sa~O%f6pO~P&2lOa#`y!Y#`y'u#`y's#`y!V#`y!h#`ys#`y![#`y%f#`y!d#`y~P!9mO[7qO~Ob7sO(O+kO(QTO(TUO~O!Y0wO!Z)Ti~O`7wO~O(`(xO!Y'lX!Z'lX~O!Y5^O!Z)Qa~O!Z8QO~P%4tOp!nO!P8RO(QTO(TUO(`!mO(j!sO~O#X8SO~O![1aO~O![1aO%f8UO~Ok8XO![1aO%f8UO~O[8^O!Y'oa!Z'oa~O!Y1lO!Z)Ri~O!h8bO~O!h8cO~O!h8fO~O!h8fO~P%[Oa8hO~O!d8iO~O!h8jO~O!Y(ri!Z(ri~P#AbOa%lO#]8rO'u%lO~O!Y(oy!h(oya(oy'u(oy~P!9mO!Y(fO!h(ny~O%f8uO~P&2lO![']O%f8uO~O#h$zqP$zqR$zq[$zqa$zqo$zq!Y$zq!i$zq!m$zq#O$zq#k$zq#l$zq#m$zq#n$zq#o$zq#p$zq#q$zq#r$zq#s$zq#u$zq#w$zq#y$zq#z$zq'u$zq([$zq(m$zq!h$zq!V$zq's$zq#]$zqs$zq![$zq%f$zq!d$zq~P#.aO#h'faP'faR'fa['faa'fao'fa!i'fa!m'fa#O'fa#k'fa#l'fa#m'fa#n'fa#o'fa#p'fa#q'fa#r'fa#s'fa#u'fa#w'fa#y'fa#z'fa'u'fa(['fa(m'fa!h'fa!V'fa's'fas'fa!['fa%f'fa!d'fa~P&/pO#h'haP'haR'ha['haa'hao'ha!i'ha!m'ha#O'ha#k'ha#l'ha#m'ha#n'ha#o'ha#p'ha#q'ha#r'ha#s'ha#u'ha#w'ha#y'ha#z'ha'u'ha(['ha(m'ha!h'ha!V'ha's'has'ha!['ha%f'ha!d'ha~P&0cO#h$|qP$|qR$|q[$|qa$|qo$|q!Y$|q!i$|q!m$|q#O$|q#k$|q#l$|q#m$|q#n$|q#o$|q#p$|q#q$|q#r$|q#s$|q#u$|q#w$|q#y$|q#z$|q'u$|q([$|q(m$|q!h$|q!V$|q's$|q#]$|qs$|q![$|q%f$|q!d$|q~P#.aO!Y'Ui!h'Ui~P!9mO#}#`q!Y#`q!Z#`q~P#AbO(t$}OP%^aR%^a[%^ao%^a!i%^a!m%^a#O%^a#k%^a#l%^a#m%^a#n%^a#o%^a#p%^a#q%^a#r%^a#s%^a#u%^a#w%^a#y%^a#z%^a#}%^a([%^a(m%^a!Y%^a!Z%^a~Ok%^a}%^a!P%^a(u%^a~P&CoO(u%POP%`aR%`a[%`ao%`a!i%`a!m%`a#O%`a#k%`a#l%`a#m%`a#n%`a#o%`a#p%`a#q%`a#r%`a#s%`a#u%`a#w%`a#y%`a#z%`a#}%`a([%`a(m%`a!Y%`a!Z%`a~Ok%`a}%`a!P%`a(t%`a~P&EsOk=VO})zO!P){O(u%PO~P&CoOk=VO})zO!P){O(t$}O~P&EsOR0`O}0`O!P0aO#P$dOPza[zakzaoza!iza!mza#Oza#kza#lza#mza#nza#oza#pza#qza#rza#sza#uza#wza#yza#zza#}za([za(mza(tza(uza!Yza!Zza~O})zO!P){OP$qaR$qa[$qak$qao$qa!i$qa!m$qa#O$qa#k$qa#l$qa#m$qa#n$qa#o$qa#p$qa#q$qa#r$qa#s$qa#u$qa#w$qa#y$qa#z$qa#}$qa([$qa(m$qa(t$qa(u$qa!Y$qa!Z$qa~O})zO!P){OP$saR$sa[$sak$sao$sa!i$sa!m$sa#O$sa#k$sa#l$sa#m$sa#n$sa#o$sa#p$sa#q$sa#r$sa#s$sa#u$sa#w$sa#y$sa#z$sa#}$sa([$sa(m$sa(t$sa(u$sa!Y$sa!Z$sa~Ok=VO})zO!P){O(t$}O(u%PO~OP%RaR%Ra[%Rao%Ra!i%Ra!m%Ra#O%Ra#k%Ra#l%Ra#m%Ra#n%Ra#o%Ra#p%Ra#q%Ra#r%Ra#s%Ra#u%Ra#w%Ra#y%Ra#z%Ra#}%Ra([%Ra(m%Ra!Y%Ra!Z%Ra~P&NlO#}$lq!Y$lq!Z$lq~P#AbO#}$mq!Y$mq!Z$mq~P#AbO!Z9SO~O#}9TO~P!0kO!d#vO!Y'ai!h'ai~O!d#vO(m'mO!Y'ai!h'ai~O!Y/hO!h(zq~O!V'ci!Y'ci~P#.aO!Y/pO!V({q~Oo9[O!d#vO(m'mO~O!V9]O~P#.aO!V9]O~O!d#vO#s9bO~Og(Yy!Y(Yy~P!0kO!Y'ja!['ja~P#.aOa%Yq![%Yq'u%Yq!Y%Yq~P#.aO[9dO~O!Y0wO!Z)Tq~O#]9hO!Y'la!Z'la~O!Y5^O!Z)Qi~P#AbO!P4hO~O![1aO%f9lO~O(QTO(TUO(`9qO~O!Y1lO!Z)Rq~O!h9tO~O!h9uO~O!h9vO~O!h9vO~P%[O#]9yO!Y#ey!Z#ey~O!Y#ey!Z#ey~P#AbO%f:OO~P&2lO![']O%f:OO~O#}#{y!Y#{y!Z#{y~P#AbOP$ziR$zi[$zio$zi!i$zi!m$zi#O$zi#k$zi#l$zi#m$zi#n$zi#o$zi#p$zi#q$zi#r$zi#s$zi#u$zi#w$zi#y$zi#z$zi#}$zi([$zi(m$zi!Y$zi!Z$zi~P&NlO})zO!P){O(u%POP'eaR'ea['eak'eao'ea!i'ea!m'ea#O'ea#k'ea#l'ea#m'ea#n'ea#o'ea#p'ea#q'ea#r'ea#s'ea#u'ea#w'ea#y'ea#z'ea#}'ea(['ea(m'ea(t'ea!Y'ea!Z'ea~O})zO!P){OP'gaR'ga['gak'gao'ga!i'ga!m'ga#O'ga#k'ga#l'ga#m'ga#n'ga#o'ga#p'ga#q'ga#r'ga#s'ga#u'ga#w'ga#y'ga#z'ga#}'ga(['ga(m'ga(t'ga(u'ga!Y'ga!Z'ga~O(t$}OP%^iR%^i[%^ik%^io%^i}%^i!P%^i!i%^i!m%^i#O%^i#k%^i#l%^i#m%^i#n%^i#o%^i#p%^i#q%^i#r%^i#s%^i#u%^i#w%^i#y%^i#z%^i#}%^i([%^i(m%^i(u%^i!Y%^i!Z%^i~O(u%POP%`iR%`i[%`ik%`io%`i}%`i!P%`i!i%`i!m%`i#O%`i#k%`i#l%`i#m%`i#n%`i#o%`i#p%`i#q%`i#r%`i#s%`i#u%`i#w%`i#y%`i#z%`i#}%`i([%`i(m%`i(t%`i!Y%`i!Z%`i~O#}$my!Y$my!Z$my~P#AbO#}#`y!Y#`y!Z#`y~P#AbO!d#vO!Y'aq!h'aq~O!Y/hO!h(zy~O!V'cq!Y'cq~P#.aOo:YO!d#vO(m'mO~O!V:ZO~P#.aO!V:ZO~O!Y0wO!Z)Ty~O!Y5^O!Z)Qq~O![1aO%f:cO~O!h:fO~O%f:kO~P&2lOP$zqR$zq[$zqo$zq!i$zq!m$zq#O$zq#k$zq#l$zq#m$zq#n$zq#o$zq#p$zq#q$zq#r$zq#s$zq#u$zq#w$zq#y$zq#z$zq#}$zq([$zq(m$zq!Y$zq!Z$zq~P&NlO})zO!P){O(u%POP'faR'fa['fak'fao'fa!i'fa!m'fa#O'fa#k'fa#l'fa#m'fa#n'fa#o'fa#p'fa#q'fa#r'fa#s'fa#u'fa#w'fa#y'fa#z'fa#}'fa(['fa(m'fa(t'fa!Y'fa!Z'fa~O})zO!P){OP'haR'ha['hak'hao'ha!i'ha!m'ha#O'ha#k'ha#l'ha#m'ha#n'ha#o'ha#p'ha#q'ha#r'ha#s'ha#u'ha#w'ha#y'ha#z'ha#}'ha(['ha(m'ha(t'ha(u'ha!Y'ha!Z'ha~OP$|qR$|q[$|qo$|q!i$|q!m$|q#O$|q#k$|q#l$|q#m$|q#n$|q#o$|q#p$|q#q$|q#r$|q#s$|q#u$|q#w$|q#y$|q#z$|q#}$|q([$|q(m$|q!Y$|q!Z$|q~P&NlOg%b!Z!Y%b!Z#]%b!Z#}%b!Z~P!0kOo:oO!d#vO(m'mO~O!V:pO~P#.aO!Y'lq!Z'lq~P#AbO!Y#e!Z!Z#e!Z~P#AbO#h%b!ZP%b!ZR%b!Z[%b!Za%b!Zo%b!Z!Y%b!Z!i%b!Z!m%b!Z#O%b!Z#k%b!Z#l%b!Z#m%b!Z#n%b!Z#o%b!Z#p%b!Z#q%b!Z#r%b!Z#s%b!Z#u%b!Z#w%b!Z#y%b!Z#z%b!Z'u%b!Z([%b!Z(m%b!Z!h%b!Z!V%b!Z's%b!Z#]%b!Zs%b!Z![%b!Z%f%b!Z!d%b!Z~P#.aOo:xO!d#vO(m'mO~OP%b!ZR%b!Z[%b!Zo%b!Z!i%b!Z!m%b!Z#O%b!Z#k%b!Z#l%b!Z#m%b!Z#n%b!Z#o%b!Z#p%b!Z#q%b!Z#r%b!Z#s%b!Z#u%b!Z#w%b!Z#y%b!Z#z%b!Z#}%b!Z([%b!Z(m%b!Z!Y%b!Z!Z%b!Z~P&NlOs(aX~P1qO}%pO~P!(oO(P!lO~P!(oO!VfX!YfX#]fX~P&+QOP]XR]X[]Xo]X}]X!P]X!Y]X!YfX!i]X!m]X#O]X#P]X#]]X#]fX#hfX#k]X#l]X#m]X#n]X#o]X#p]X#q]X#r]X#s]X#u]X#w]X#y]X#z]X$P]X([]X(m]X(t]X(u]X~O!dfX!h]X!hfX(mfX~P'BxOP;POQ;POSfOd<zOe!iOmkOo;POpkOqkOwkOy;PO{;PO!PWO!TkO!UkO![XO!f;SO!iZO!l;PO!m;PO!n;PO!p;TO!r;WO!u!hO$V!kO(O)XO(QTO(TUO([VO(j[O(y<xO~O!Y;dO!Z$oa~Oh%VOm%WOo%XOp$tOq$tOw%YOy%ZO{;oO!P${O![$|O!f=PO!i$xO#g;uO$V%_O$r;qO$t;sO$w%`O(O(rO(QTO(TUO([$uO(t$}O(u%PO~O#t)`O~P'GnOo!bX(m!bX~P# ZO!Z]X!ZfX~P'BxO!VfX!V$xX!YfX!Y$xX#]fX~P!/gO#h;XO~O!d#vO#h;XO~O#];iO~O#s;]O~O#];xO!Y(rX!Z(rX~O#];iO!Y(pX!Z(pX~O#h;yO~Og;{O~P!0kO#h<RO~O#h<SO~O!d#vO#h<TO~O!d#vO#h;yO~O#}<UO~P#AbO#h<VO~O#h<WO~O#h<]O~O#h<^O~O#h<_O~O#h<`O~O#}<aO~P!0kO#}<bO~P!0kO#P#Q#R#T#U#X#f#g#r(y$r$t$w%Z%e%f%g%n%p%s%t%v%x~'yT#l!U'w(P#mp#k#no}'x$['x(O$^(`~",
goto:"$4Q)XPPPPPP)YPP)]P)nP+O/PPPPP5xPP6`PP<V?mP@QP@QPPP@QPBRP@QP@QP@QPBVPB[PByPGrPPPGvPPPPGvJxPPPKOKzPGvPGvPPNYGvPPPGvPGvP!!aGvP!%v!&{!'UP!'x!'|!'x!+YPPPPPPP!+y!&{PP!,Z!-gP!0jGvGv!0o!3z!8b!8b!<`PPP!<hGvPPPPPPPPPPP!?vP!ATPPGv!BfPGvPGvGvGvGvGvPGv!CxP!GRP!JWP!J[!Jf!Jj!JjP!GOP!Jn!JnP!MsP!MwGvGv!M}##RBV@QP@QP@Q@QP#$_@Q@Q#&j@Q#)Z@Q#+`@Q@Q#,O#.]#.]#.b#.k#.]#.wP#.]P@Q#/a@Q#3S@Q@Q5xPPP#6{PPP#7f#7fP#7fP#7|#7fPP#8SP#7yP#7y#8g#7y#9R#9X5u)]#9[)]P#9c#9c#9cP)]P)]P)]P)]PP)]P#9i#9lP#9l)]P#9pP#9sP)]P)]P)]P)]P)]P)])]PP#9y#:P#:[#:b#:h#:n#:t#;S#;Y#;d#;j#;t#;z#<[#<b#=S#=f#=l#=r#>Q#>g#@V#@e#@l#BR#Ba#C|#D[#Db#Dh#Dn#Dx#EO#EU#E`#Er#ExPPPPPPPPPP#FOPPPPPPP#Fs#Iz#KZ#Kb#KjPPP$!sP$!|$%t$,^$,a$,d$-P$-S$-Z$-cP$-i$-lP$.Y$.^$/U$0d$0i$1PPP$1U$1[$1`P$1c$1g$1k$2a$2x$3a$3e$3h$3k$3q$3t$3x$3|R!|RoqOXst!Z#d%k&o&q&r&t,k,p1|2PY!vQ']-]1a5eQ%rvQ%zyQ&R|Q&g!VS'T!e-TQ'c!iS'i!r!yU*e$|*V*jQ+i%{Q+v&TQ,[&aQ-Z'[Q-e'dQ-m'jQ0R*lQ1k,]R;v;T%QdOPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$_$a$e%k%r&P&h&k&o&q&r&t&x'Q'_'o(P(R(X(`(t(v(z)y+R+V,h,k,p-a-i-w-}.l.s/f0a0g0v1d1t1u1w1y1|2P2R2r2x3^5b5m5}6O6R6f8R8X8h8rS#q];Q!r)Z$Z$n'U)o,|-P.}2b3u5`6]9h9y;P;S;T;W;X;Y;Z;[;];^;_;`;a;b;c;d;f;i;v;x;y;{<T<U<_<`<{U*y%[;n;oQ+n%}Q,^&dQ,e&lQ0m+aQ0q+cQ0|+oQ1s,cQ3Q._Q5O0wQ5t1lQ6r3UQ7s5PR8x6t'OkOPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$Z$_$a$e$n%k%r&P&h&k&l&o&q&r&t&x'Q'U'_'o(P(R(X(`(t(v(z)o)y+R+V+a,h,k,p,|-P-a-i-w-}._.l.s.}/f0a0g0v1d1t1u1w1y1|2P2R2b2r2x3U3^3u5`5b5m5}6O6R6]6f6t8R8X8h8r9h9y;P;S;T;W;X;Y;Z;[;];^;_;`;a;b;c;d;f;i;v;x;y;{<T<U<_<`<{t!nQ!r!v!y!z'T'[']'i'j'k-T-Z-]-m1a5e5g$|$ti#v$b$c$d$x${%O%Q%]%^%b)u){)}*P*R*U*[*b*r*s+`+c+z+}.^.w/]/e/o/p/r0V0X0d1W1Z1c3T3}4Y4b4m4u4x5l6p7_7h8U8u9T9b9l:O:c:k;g;h;j;k;l;m;p;q;r;s;t;u;|;}<O<P<R<S<V<W<X<Y<Z<[<]<^<a<b<x=Q=R=U=VQ&U|Q'R!eU'X%g*V-WQ+n%}Q,^&dQ0c*|Q0|+oQ1R+uQ1r,bQ1s,cQ5O0wQ5X1TQ5t1lQ5w1nQ5x1qQ7s5PQ7v5UQ8a5zQ9g7wR9r8^rnOXst!V!Z#d%k&f&o&q&r&t,k,p1|2PR,`&h&x^OPXYstuvwz!Z!`!g!j!o#S#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$Z$_$a$e$n%k%r&P&h&k&l&o&q&r&t&x'Q'_'o(R(X(`(t(v(z)o)y+R+V+a,h,k,p,|-P-a-i-w-}._.l.s.}/f0a0g0v1d1t1u1w1y1|2P2R2b2r2x3U3^3u5`5b5m5}6O6R6]6f6t8R8X8h8r9h9y;P;S;T;W;X;Y;Z;[;];^;_;`;a;b;c;d;f;i;v;x;y;{<T<U<_<`<z<{[#]WZ#W#Z'U(P!b%hm#h#i#l$x%c%f(Y(d(e(f*U*Y*]+T+U+W,g,}-{.R.S.T.V/e/h2U2|2}4Q6[6mQ%uxQ%yyS&O|&TQ&[!TQ'`!hQ'b!iQ(m#sS+h%z%{Q+l%}Q,V&_Q,Z&aS-d'c'dQ.a(nQ0u+iQ0{+oQ0}+pQ1Q+tQ1f,WS1j,[,]Q2n-eQ4}0wQ5R0zQ5W1SQ5s1kQ7r5PQ7u5TQ9c7qR:^9d!O$zi$d%O%Q%]%^%b)}*P*[*r*s.w/o0V0X0d3}4m9T<x=Q=R!S%wy!i!u%y%z%{'S'b'c'd'h'r*d+h+i-Q-d-e-l/y0u2g2n2u4dQ+b%uQ+{&XQ,O&YQ,Y&aQ.`(mQ1e,VU1i,Z,[,]Q3V.aQ5n1fS5r1j1kQ8]5s#^<|#v$b$c$x${)u){*R*U*b+`+c+z+}.^/]/e/p/r1W1Z1c3T4Y4b4u4x5l6p7_7h8U8u9b9l:O:c:k;j;l;p;r;t;|<O<R<V<X<Z<]<a=U=Vo<};g;h;k;m;q;s;u;}<P<S<W<Y<[<^<bW%Ti%V*t<xS&X!Q&fQ&Y!RQ&Z!SR+y&V$}%Si#v$b$c$d$x${%O%Q%]%^%b)u){)}*P*R*U*[*b*r*s+`+c+z+}.^.w/]/e/o/p/r0V0X0d1W1Z1c3T3}4Y4b4m4u4x5l6p7_7h8U8u9T9b9l:O:c:k;g;h;j;k;l;m;p;q;r;s;t;u;|;}<O<P<R<S<V<W<X<Y<Z<[<]<^<a<b<x=Q=R=U=VT)v$u)wV*y%[;n;oW'X!e%g*V-WS(y#y#zQ+]%pQ+s&QS.Y(i(jQ1[,PQ4n0`R7{5^'OkOPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$Z$_$a$e$n%k%r&P&h&k&l&o&q&r&t&x'Q'U'_'o(P(R(X(`(t(v(z)o)y+R+V+a,h,k,p,|-P-a-i-w-}._.l.s.}/f0a0g0v1d1t1u1w1y1|2P2R2b2r2x3U3^3u5`5b5m5}6O6R6]6f6t8R8X8h8r9h9y;P;S;T;W;X;Y;Z;[;];^;_;`;a;b;c;d;f;i;v;x;y;{<T<U<_<`<{$i$^c#Y#e%o%q%s(O(U(p(u(})O)P)Q)R)S)T)U)V)W)Y)[)^)c)m+^+r-R-p-u-z-|.k.n.r.t.u.v/X0e2]2`2p2w3]3b3c3d3e3f3g3h3i3j3k3l3m3n3q3r3y4r4{6_6e6j6y6z7T7U7}8l8p8z9Q9R9{:`:g;R<oT#TV#U'PkOPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$Z$_$a$e$n%k%r&P&h&k&l&o&q&r&t&x'Q'U'_'o(P(R(X(`(t(v(z)o)y+R+V+a,h,k,p,|-P-a-i-w-}._.l.s.}/f0a0g0v1d1t1u1w1y1|2P2R2b2r2x3U3^3u5`5b5m5}6O6R6]6f6t8R8X8h8r9h9y;P;S;T;W;X;Y;Z;[;];^;_;`;a;b;c;d;f;i;v;x;y;{<T<U<_<`<{Q'V!eR2c-Tv!nQ!e!r!v!y!z'T'[']'i'j'k-T-Z-]-m1a5e5gU*d$|*V*jS/y*e*lQ0S*mQ1^,RQ4d0RR4g0UnqOXst!Z#d%k&o&q&r&t,k,p1|2PQ&v!^Q's!xS(o#u;XQ+f%xQ,T&[Q,U&^Q-b'aQ-o'lS.j(t;yS0f+R<TQ0s+gQ1`,SQ2T,rQ2V,sQ2_-OQ2l-cQ2o-gS4s0g<_Q4y0tS4|0v<`Q6^2aQ6b2mQ6g2tQ7p4zQ8m6`Q8n6cQ8q6hR9x8j$d$]c#Y#e%q%s(O(U(p(u(})O)P)Q)R)S)T)U)V)W)Y)[)^)c)m+^+r-R-p-u-z-|.k.n.r.u.v/X0e2]2`2p2w3]3b3c3d3e3f3g3h3i3j3k3l3m3n3q3r3y4r4{6_6e6j6y6z7T7U7}8l8p8z9Q9R9{:`:g;R<oS(k#p'fQ({#zS+[%o.tS.Z(j(lR3O.['OkOPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$Z$_$a$e$n%k%r&P&h&k&l&o&q&r&t&x'Q'U'_'o(P(R(X(`(t(v(z)o)y+R+V+a,h,k,p,|-P-a-i-w-}._.l.s.}/f0a0g0v1d1t1u1w1y1|2P2R2b2r2x3U3^3u5`5b5m5}6O6R6]6f6t8R8X8h8r9h9y;P;S;T;W;X;Y;Z;[;];^;_;`;a;b;c;d;f;i;v;x;y;{<T<U<_<`<{S#q];QQ&q!XQ&r!YQ&t![Q&u!]R1{,nQ'^!hQ+_%uQ-`'`S.](m+bQ2j-_W3S.`.a0l0nQ6a2kW6n3P3R3V4wU8t6o6q6sU9}8v8w8yS:i9|:PQ:t:jR:z:uU!wQ']-]T5c1a5e!Q_OXZ`st!V!Z#d#h%c%k&f&h&o&q&r&t(f,k,p.S1|2P]!pQ!r']-]1a5eT#q];Q%[{OPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$_$a$e%k%r&P&h&k&l&o&q&r&t&x'Q'_'o(P(R(X(`(t(v(z)y+R+V+a,h,k,p-a-i-w-}._.l.s/f0a0g0v1d1t1u1w1y1|2P2R2r2x3U3^5b5m5}6O6R6f6t8R8X8h8rS(y#y#zS.Y(i(j!s<f$Z$n'U)o,|-P.}2b3u5`6]9h9y;P;S;T;W;X;Y;Z;[;];^;_;`;a;b;c;d;f;i;v;x;y;{<T<U<_<`<{U$fd)Z,eS(l#p'fU*q%R(s3pU0b*x.f7PQ4w0mQ6o3QQ8w6rR:P8xm!tQ!r!v!y!z']'i'j'k-]-m1a5e5gQ'q!uS(b#g1vS-k'h'tQ/k*XQ/w*dQ2v-nQ4U/lS4_/x0SQ7Z4PS7f4e4gQ9V7[Q9Z7cQ9`7iS:X9[9]S:n:Y:ZS:w:o:pR:}:xQ#wbQ'p!uS(a#g1vS(c#m+QQ+S%dQ+d%vQ+j%|U-j'h'q'tQ.O(bQ/j*XQ/v*dQ/|*gQ0r+eQ1g,XS2s-k-nQ2{.WS4T/k/lS4^/w0SQ4a/{Q4c/}Q5p1hQ6i2vQ7Y4PQ7^4US7b4_4gQ7g4fQ8Z5qS9U7Z7[Q9Y7cQ9^7fQ9a7jQ9o8[Q:V9VS:W9Z9]Q:[9`Q:e9pS:m:X:ZS:v:n:pQ:|:wQ;O:}Q<i<dQ<t<mR<u<nV!wQ']-]%[aOPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$_$a$e%k%r&P&h&k&l&o&q&r&t&x'Q'_'o(P(R(X(`(t(v(z)y+R+V+a,h,k,p-a-i-w-}._.l.s/f0a0g0v1d1t1u1w1y1|2P2R2r2x3U3^5b5m5}6O6R6f6t8R8X8h8rS#wz!j!r<c$Z$n'U)o,|-P.}2b3u5`6]9h9y;P;S;T;W;X;Y;Z;[;];^;_;`;a;b;c;d;f;i;v;x;y;{<T<U<_<`<{R<i<z%[bOPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$_$a$e%k%r&P&h&k&l&o&q&r&t&x'Q'_'o(P(R(X(`(t(v(z)y+R+V+a,h,k,p-a-i-w-}._.l.s/f0a0g0v1d1t1u1w1y1|2P2R2r2x3U3^5b5m5}6O6R6f6t8R8X8h8rQ%dj!S%vy!i!u%y%z%{'S'b'c'd'h'r*d+h+i-Q-d-e-l/y0u2g2n2u4dS%|z!jQ+e%wQ,X&aW1h,Y,Z,[,]U5q1i1j1kS8[5r5sQ9p8]!r<d$Z$n'U)o,|-P.}2b3u5`6]9h9y;P;S;T;W;X;Y;Z;[;];^;_;`;a;b;c;d;f;i;v;x;y;{<T<U<_<`<{Q<m<yR<n<z%OeOPXYstuvw!Z!`!g!o#S#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$_$a$e%k%r&P&h&k&o&q&r&t&x'Q'_'o(R(X(`(t(v(z)y+R+V+a,h,k,p-a-i-w-}._.l.s/f0a0g0v1d1t1u1w1y1|2P2R2r2x3U3^5b5m5}6O6R6f6t8R8X8h8rY#bWZ#W#Z(P!b%hm#h#i#l$x%c%f(Y(d(e(f*U*Y*]+T+U+W,g,}-{.R.S.T.V/e/h2U2|2}4Q6[6mQ,f&l!p<e$Z$n)o,|-P.}2b3u5`6]9h9y;P;S;T;W;X;Y;Z;[;];^;_;`;a;b;c;d;f;i;v;x;y;{<T<U<_<`<{R<h'UU'Y!e%g*VR2e-W%QdOPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$_$a$e%k%r&P&h&k&o&q&r&t&x'Q'_'o(P(R(X(`(t(v(z)y+R+V,h,k,p-a-i-w-}.l.s/f0a0g0v1d1t1u1w1y1|2P2R2r2x3^5b5m5}6O6R6f8R8X8h8r!r)Z$Z$n'U)o,|-P.}2b3u5`6]9h9y;P;S;T;W;X;Y;Z;[;];^;_;`;a;b;c;d;f;i;v;x;y;{<T<U<_<`<{Q,e&lQ0m+aQ3Q._Q6r3UR8x6t!b$Tc#Y%o(O(U(p(u)V)W)[)c+r-p-u-z-|.k.n/X0e2p2w3]3m4r4{6e6j6y8p9{;R!P;_)Y)m-R.t2]2`3b3k3l3q3y6_6z7T7U7}8l8z9Q9R:`:g<o!f$Vc#Y%o(O(U(p(u)S)T)V)W)[)c+r-p-u-z-|.k.n/X0e2p2w3]3m4r4{6e6j6y8p9{;R!T;a)Y)m-R.t2]2`3b3h3i3k3l3q3y6_6z7T7U7}8l8z9Q9R:`:g<o!^$Zc#Y%o(O(U(p(u)[)c+r-p-u-z-|.k.n/X0e2p2w3]3m4r4{6e6j6y8p9{;RQ3}/cz<{)Y)m-R.t2]2`3b3q3y6_6z7T7U7}8l8z9Q9R:`:g<oQ=Q=SR=R=T'OkOPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$Z$_$a$e$n%k%r&P&h&k&l&o&q&r&t&x'Q'U'_'o(P(R(X(`(t(v(z)o)y+R+V+a,h,k,p,|-P-a-i-w-}._.l.s.}/f0a0g0v1d1t1u1w1y1|2P2R2b2r2x3U3^3u5`5b5m5}6O6R6]6f6t8R8X8h8r9h9y;P;S;T;W;X;Y;Z;[;];^;_;`;a;b;c;d;f;i;v;x;y;{<T<U<_<`<{S$oh$pR3v.|'VgOPWXYZhstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$Z$_$a$e$n$p%k%r&P&h&k&l&o&q&r&t&x'Q'U'_'o(P(R(X(`(t(v(z)o)y+R+V+a,h,k,p,|-P-a-i-w-}._.l.s.|.}/f0a0g0v1d1t1u1w1y1|2P2R2b2r2x3U3^3u5`5b5m5}6O6R6]6f6t8R8X8h8r9h9y;P;S;T;W;X;Y;Z;[;];^;_;`;a;b;c;d;f;i;v;x;y;{<T<U<_<`<{T$kf$qQ$ifS)f$l)jR)r$qT$jf$qT)h$l)j'VhOPWXYZhstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$Z$_$a$e$n$p%k%r&P&h&k&l&o&q&r&t&x'Q'U'_'o(P(R(X(`(t(v(z)o)y+R+V+a,h,k,p,|-P-a-i-w-}._.l.s.|.}/f0a0g0v1d1t1u1w1y1|2P2R2b2r2x3U3^3u5`5b5m5}6O6R6]6f6t8R8X8h8r9h9y;P;S;T;W;X;Y;Z;[;];^;_;`;a;b;c;d;f;i;v;x;y;{<T<U<_<`<{T$oh$pQ$rhR)q$p%[jOPWXYZstuvw!Z!`!g!o#S#W#Z#d#o#u#x#{$O$P$Q$R$S$T$U$V$W$X$_$a$e%k%r&P&h&k&l&o&q&r&t&x'Q'_'o(P(R(X(`(t(v(z)y+R+V+a,h,k,p-a-i-w-}._.l.s/f0a0g0v1d1t1u1w1y1|2P2R2r2x3U3^5b5m5}6O6R6f6t8R8X8h8r!s<y$Z$n'U)o,|-P.}2b3u5`6]9h9y;P;S;T;W;X;Y;Z;[;];^;_;`;a;b;c;d;f;i;v;x;y;{<T<U<_<`<{#elOPXZst!Z!`!o#S#d#o#{$n%k&h&k&l&o&q&r&t&x'Q'_(z)o+V+a,h,k,p-a._.}/f0a1d1t1u1w1y1|2P2R3U3u5b5m5}6O6R6t8R8X8h!O%Ri$d%O%Q%]%^%b)}*P*[*r*s.w/o0V0X0d3}4m9T<x=Q=R#^(s#v$b$c$x${)u){*R*U*b+`+c+z+}.^/]/e/p/r1W1Z1c3T4Y4b4u4x5l6p7_7h8U8u9b9l:O:c:k;j;l;p;r;t;|<O<R<V<X<Z<]<a=U=VQ*}%`Q/Y)zo3p;g;h;k;m;q;s;u;}<P<S<W<Y<[<^<b!O$yi$d%O%Q%]%^%b)}*P*[*r*s.w/o0V0X0d3}4m9T<x=Q=RQ*^$zU*g$|*V*jQ+O%aQ/}*h#^<k#v$b$c$x${)u){*R*U*b+`+c+z+}.^/]/e/p/r1W1Z1c3T4Y4b4u4x5l6p7_7h8U8u9b9l:O:c:k;j;l;p;r;t;|<O<R<V<X<Z<]<a=U=Vn<l;g;h;k;m;q;s;u;}<P<S<W<Y<[<^<bQ<p<|Q<q<}Q<r=OR<s=P!O%Ri$d%O%Q%]%^%b)}*P*[*r*s.w/o0V0X0d3}4m9T<x=Q=R#^(s#v$b$c$x${)u){*R*U*b+`+c+z+}.^/]/e/p/r1W1Z1c3T4Y4b4u4x5l6p7_7h8U8u9b9l:O:c:k;j;l;p;r;t;|<O<R<V<X<Z<]<a=U=Vo3p;g;h;k;m;q;s;u;}<P<S<W<Y<[<^<bnoOXst!Z#d%k&o&q&r&t,k,p1|2PS*a${*UQ,y&{Q,z&}R4X/p$|%Si#v$b$c$d$x${%O%Q%]%^%b)u){)}*P*R*U*[*b*r*s+`+c+z+}.^.w/]/e/o/p/r0V0X0d1W1Z1c3T3}4Y4b4m4u4x5l6p7_7h8U8u9T9b9l:O:c:k;g;h;j;k;l;m;p;q;r;s;t;u;|;}<O<P<R<S<V<W<X<Y<Z<[<]<^<a<b<x=Q=R=U=VQ+|&YQ1Y,OQ5[1XR7z5]V*i$|*V*jU*i$|*V*jT5d1a5eU/{*f/f5bS4f0T8RR7j4hQ+d%vQ/|*gQ0r+eQ1g,XQ5p1hQ8Z5qQ9o8[R:e9p!O%Oi$d%O%Q%]%^%b)}*P*[*r*s.w/o0V0X0d3}4m9T<x=Q=Rr)}$v)a*O*p+P/n0Z0[3s4V4q7X7k:U<j<v<wS0V*o0W#^;j#v$b$c$x${)u){*R*U*b+`+c+z+}.^/]/e/p/r1W1Z1c3T4Y4b4u4x5l6p7_7h8U8u9b9l:O:c:k;j;l;p;r;t;|<O<R<V<X<Z<]<a=U=Vn;k;g;h;k;m;q;s;u;}<P<S<W<Y<[<^<b!`;|(q)_*W*`.b.e.i/U/Z/c/s0k1V1X3Y4W4[5Z5]6u6x7`7d7m7o9X9_:]:l=S=T`;}3o6{7O7S8{:Q:T:{S<X.d3ZT<Y6}9O!O%Qi$d%O%Q%]%^%b)}*P*[*r*s.w/o0V0X0d3}4m9T<x=Q=Rv*P$v)a*Q*o+P/_/n0Z0[3s4V4i4q7X7k:U<j<v<wS0X*p0Y#^;l#v$b$c$x${)u){*R*U*b+`+c+z+}.^/]/e/p/r1W1Z1c3T4Y4b4u4x5l6p7_7h8U8u9b9l:O:c:k;j;l;p;r;t;|<O<R<V<X<Z<]<a=U=Vn;m;g;h;k;m;q;s;u;}<P<S<W<Y<[<^<b!d<O(q)_*W*`.c.d.i/U/Z/c/s0k1V1X3W3Y4W4[5Z5]6u6v6x7`7d7m7o9X9_:]:l=S=Td<P3o6|6}7S8{8|:Q:R:T:{S<Z.e3[T<[7O9PrnOXst!V!Z#d%k&f&o&q&r&t,k,p1|2PQ&c!UR,h&lrnOXst!V!Z#d%k&f&o&q&r&t,k,p1|2PR&c!UQ,Q&ZR1U+ysnOXst!V!Z#d%k&f&o&q&r&t,k,p1|2PQ1b,VS5k1e1fU8T5i5j5nS9k8V8WS:a9j9mQ:q:bR:y:rQ&j!VR,a&fR5w1nS&O|&TR0}+pQ&o!WR,k&pR,q&uT1},p2PR,u&vQ,t&vR2W,uQ'v!{R-q'vSsOtQ#dXT%ns#dQ#OTR'x#OQ#RUR'z#RQ)w$uR/V)wQ#UVR'|#UQ#XWU(S#X(T-xQ(T#YR-x(UQ-U'VR2d-UQ.m(uS3_.m3`R3`.nQ-]']R2h-]Y!rQ']-]1a5eR'g!rQ.x)aR3t.xU#_W%f*UU(Z#_([-yQ([#`R-y(VQ-X'YR2f-Xt`OXst!V!Z#d%k&f&h&o&q&r&t,k,p1|2PS#hZ%cU#r`#h.SR.S(fQ(g#jQ.P(cW.X(g.P2y6kQ2y.QR6k2zQ)j$lR/O)jQ$phR)p$pQ$`cU)]$`-t;eQ-t;RR;e)mQ/i*XW4R/i4S7]9WU4S/j/k/lS7]4T4UR9W7^$Z)|$v(q)_)a*W*`*o*p*z*{+P.d.e.g.h.i/U/Z/_/a/c/n/s0Z0[0k1V1X3W3X3Y3o3s4V4W4[4i4k4q5Z5]6u6v6w6x6}7O7Q7R7S7X7`7d7k7m7o8{8|8}9X9_:Q:R:S:T:U:]:l:{<j<v<w=S=TQ/q*`U4Z/q4]7aQ4]/sR7a4[S*j$|*VR0P*jr*O$v)a*o*p+P/n0Z0[3s4V4q7X7k:U<j<v<w!`.b(q)_*W*`.d.e.i/U/Z/c/s0k1V1X3Y4W4[5Z5]6u6x7`7d7m7o9X9_:]:l=S=TU/`*O.b6{a6{3o6}7O7S8{:Q:T:{Q0W*oQ3Z.dU4j0W3Z9OR9O6}v*Q$v)a*o*p+P/_/n0Z0[3s4V4i4q7X7k:U<j<v<w!d.c(q)_*W*`.d.e.i/U/Z/c/s0k1V1X3W3Y4W4[5Z5]6u6v6x7`7d7m7o9X9_:]:l=S=TU/b*Q.c6|e6|3o6}7O7S8{8|:Q:R:T:{Q0Y*pQ3[.eU4l0Y3[9PR9P7OQ*u%UR0^*uQ4v0kR7n4vQ+X%iR0j+XQ5_1[S7|5_9iR9i7}Q,S&[R1_,SQ5e1aR8P5eQ1m,^S5u1m8_R8_5wQ0x+lW5Q0x5S7t9eQ5S0{Q7t5RR9e7uQ+q&OR1O+qQ2P,pR6V2PYrOXst#dQ&s!ZQ+Z%kQ,j&oQ,l&qQ,m&rQ,o&tQ1z,kS1},p2PR6U1|Q%mpQ&w!_Q&z!aQ&|!bQ'O!cQ'n!uQ+Y%jQ+f%xQ+x&UQ,`&jQ,w&yW-h'h'p'q'tQ-o'lQ0O*iQ0s+gS1p,a,dQ2X,vQ2Y,yQ2Z,zQ2o-gW2q-j-k-n-pQ4y0tQ5V1RQ5Y1VQ5o1gQ5y1rQ6T1{U6d2p2s2vQ6g2tQ7p4zQ7x5XQ7y5ZQ8O5dQ8Y5pQ8`5xS8o6e6iQ8q6hQ9f7vQ9n8ZQ9s8aQ9z8pQ:_9gQ:d9oQ:h9{R:s:eQ%xyQ'a!iQ'l!uU+g%y%z%{Q-O'SU-c'b'c'dS-g'h'rQ/u*dS0t+h+iQ2a-QS2m-d-eQ2t-lQ4`/yQ4z0uQ6`2gQ6c2nQ6h2uR7e4dS$wi<xR*v%VU%Ui%V<xR0]*tQ$viS(q#v+cS)_$b$cQ)a$dQ*W$xS*`${*UQ*o%OQ*p%QQ*z%]Q*{%^Q+P%bQ.d;jQ.e;lQ.g;pQ.h;rQ.i;tQ/U)uS/Z){/]Q/_)}Q/a*PQ/c*RQ/n*[S/s*b/eQ0Z*rQ0[*sh0k+`.^1c3T5l6p8U8u9l:O:c:kQ1V+zQ1X+}Q3W;|Q3X<OQ3Y<RS3o;g;hQ3s.wQ4V/oQ4W/pQ4[/rQ4i0VQ4k0XQ4q0dQ5Z1WQ5]1ZQ6u<VQ6v<XQ6w<ZQ6x<]Q6};kQ7O;mQ7Q;qQ7R;sQ7S;uQ7X3}Q7`4YQ7d4bQ7k4mQ7m4uQ7o4xQ8{<SQ8|;}Q8}<PQ9X7_Q9_7hQ:Q<WQ:R<YQ:S<[Q:T<^Q:U9TQ:]9bQ:l<aQ:{<bQ<j<xQ<v=QQ<w=RQ=S=UR=T=VQ*x%[Q.f;nR7P;onpOXst!Z#d%k&o&q&r&t,k,p1|2PQ!fPS#fZ#oQ&y!`U'e!o5b8RQ'{#SQ(|#{Q)n$nS,d&h&kQ,i&lQ,v&xQ,{'QQ-_'_Q.p(zQ/S)oS0h+V/fQ0n+aQ1x,hQ2k-aQ3R._Q3x.}Q4o0aQ5j1dQ5{1tQ5|1uQ6Q1wQ6S1yQ6X2RQ6s3UQ7V3uQ8W5mQ8d5}Q8e6OQ8g6RQ8y6tQ9m8XR9w8h#YcOPXZst!Z!`!o#d#o#{%k&h&k&l&o&q&r&t&x'Q'_(z+V+a,h,k,p-a._/f0a1d1t1u1w1y1|2P2R3U5b5m5}6O6R6t8R8X8hQ#YWQ#eYQ%ouQ%qvS%sw!gS(O#W(RQ(U#ZQ(p#uQ(u#xQ(}$OQ)O$PQ)P$QQ)Q$RQ)R$SQ)S$TQ)T$UQ)U$VQ)V$WQ)W$XQ)Y$ZQ)[$_Q)^$aQ)c$eW)m$n)o.}3uQ+^%rQ+r&PS-R'U2bQ-p'oS-u(P-wQ-z(XQ-|(`Q.k(tQ.n(vQ.r;PQ.t;SQ.u;TQ.v;WQ/X)yQ0e+RQ2],|Q2`-PQ2p-iQ2w-}Q3].lQ3b;XQ3c;YQ3d;ZQ3e;[Q3f;]Q3g;^Q3h;_Q3i;`Q3j;aQ3k;bQ3l;cQ3m.sQ3n;fQ3q;iQ3r;vQ3y;dQ4r0gQ4{0vQ6_;xQ6e2rQ6j2xQ6y3^Q6z;yQ7T;{Q7U<TQ7}5`Q8l6]Q8p6fQ8z<UQ9Q<_Q9R<`Q9{8rQ:`9hQ:g9yQ;R#SR<o<{R#[WR'W!el!tQ!r!v!y!z']'i'j'k-]-m1a5e5gS'S!e-TS-Q'T'[R2g-ZR(w#xQ!fQT-[']-]]!qQ!r']-]1a5eQ#p]R'f;QR)b$dY!uQ']-]1a5eQ'h!rS'r!v!yS't!z5gS-l'i'jQ-n'kR2u-mT#kZ%cS#jZ%cS%im,gU(c#h#i#lS.Q(d(eQ.U(fQ0i+WQ2z.RU2{.S.T.VS6l2|2}R8s6md#^W#W#Z%f(P(Y*U+T-{/er#gZm#h#i#l%c(d(e(f+W.R.S.T.V2|2}6mS*X$x*]Q/l*YQ1v,gQ2^,}Q4P/hQ6Z2UQ7[4QQ8k6[T<g'U+UV#aW%f*UU#`W%f*US(Q#W(YU(V#Z+T/eS-S'U+UT-v(P-{V'Z!e%g*VQ$lfR)t$qT)i$l)jR3w.|T*Z$x*]T*c${*UQ0l+`Q3P.^Q5i1cQ6q3TQ8V5lQ8v6pQ9j8UQ9|8uQ:b9lQ:j:OQ:r:cR:u:knqOXst!Z#d%k&o&q&r&t,k,p1|2PQ&i!VR,`&ftmOXst!U!V!Z#d%k&f&o&q&r&t,k,p1|2PR,g&lT%jm,gR1],PR,_&dQ&S|R+w&TR+m%}T&m!W&pT&n!W&pT2O,p2P",
nodeNames:"⚠ ArithOp ArithOp ?. JSXStartTag LineComment BlockComment Script Hashbang ExportDeclaration export Star as VariableName String Escape from ; default FunctionDeclaration async function VariableDefinition > < TypeParamList TypeDefinition extends ThisType this LiteralType ArithOp Number BooleanLiteral TemplateType InterpolationEnd Interpolation InterpolationStart NullType null VoidType void TypeofType typeof MemberExpression . PropertyName [ TemplateString Escape Interpolation super RegExp ] ArrayExpression Spread , } { ObjectExpression Property async get set PropertyDefinition Block : NewTarget new NewExpression ) ( ArgList UnaryExpression delete LogicOp BitOp YieldExpression yield AwaitExpression await ParenthesizedExpression ClassExpression class ClassBody MethodDeclaration Decorator @ MemberExpression PrivatePropertyName CallExpression TypeArgList CompareOp < declare Privacy static abstract override PrivatePropertyDefinition PropertyDeclaration readonly accessor Optional TypeAnnotation Equals StaticBlock FunctionExpression ArrowFunction ParamList ParamList ArrayPattern ObjectPattern PatternProperty Privacy readonly Arrow MemberExpression BinaryExpression ArithOp ArithOp ArithOp ArithOp BitOp CompareOp instanceof satisfies in const CompareOp BitOp BitOp BitOp LogicOp LogicOp ConditionalExpression LogicOp LogicOp AssignmentExpression UpdateOp PostfixExpression CallExpression InstantiationExpression TaggedTemplateExpression DynamicImport import ImportMeta JSXElement JSXSelfCloseEndTag JSXSelfClosingTag JSXIdentifier JSXBuiltin JSXIdentifier JSXNamespacedName JSXMemberExpression JSXSpreadAttribute JSXAttribute JSXAttributeValue JSXEscape JSXEndTag JSXOpenTag JSXFragmentTag JSXText JSXEscape JSXStartCloseTag JSXCloseTag PrefixCast ArrowFunction TypeParamList SequenceExpression InstantiationExpression KeyofType keyof UniqueType unique ImportType InferredType infer TypeName ParenthesizedType FunctionSignature ParamList NewSignature IndexedType TupleType Label ArrayType ReadonlyType ObjectType MethodType PropertyType IndexSignature PropertyDefinition CallSignature TypePredicate is NewSignature new UnionType LogicOp IntersectionType LogicOp ConditionalType ParameterizedType ClassDeclaration abstract implements type VariableDeclaration let var using TypeAliasDeclaration InterfaceDeclaration interface EnumDeclaration enum EnumBody NamespaceDeclaration namespace module AmbientDeclaration declare GlobalDeclaration global ClassDeclaration ClassBody AmbientFunctionDeclaration ExportGroup VariableName VariableName ImportDeclaration ImportGroup ForStatement for ForSpec ForInSpec ForOfSpec of WhileStatement while WithStatement with DoStatement do IfStatement if else SwitchStatement switch SwitchBody CaseLabel case DefaultLabel TryStatement try CatchClause catch FinallyClause finally ReturnStatement return ThrowStatement throw BreakStatement break ContinueStatement continue DebuggerStatement debugger LabeledStatement ExpressionStatement SingleExpression SingleClassItem",
maxTerm:376,context:pye,
nodeProps:[["isolate",-8,5,6,14,34,36,48,50,52,""],["group",-26,9,17,19,65,204,208,212,213,215,218,221,231,233,239,241,243,245,248,254,260,262,264,266,268,270,271,"Statement",-34,13,14,29,32,33,39,48,51,52,54,59,67,69,73,77,79,81,82,107,108,117,118,135,138,140,141,142,143,144,146,147,166,167,169,"Expression",-23,28,30,34,38,40,42,171,173,175,176,178,179,180,182,183,184,186,187,188,198,200,202,203,"Type",-3,85,100,106,"ClassItem"],["openedBy",23,"<",35,"InterpolationStart",53,"[",57,"{",70,"(",159,"JSXStartCloseTag"],["closedBy",24,">",37,"InterpolationEnd",47,"]",58,"}",71,")",164,"JSXEndTag"]],
propSources:[bye],skippedNodes:[0,5,6,274],repeatNodeCount:37,
tokenData:"$Fq07[R!bOX%ZXY+gYZ-yZ[+g[]%Z]^.c^p%Zpq+gqr/mrs3cst:_tuEruvJSvwLkwx! Yxy!'iyz!(sz{!)}{|!,q|}!.O}!O!,q!O!P!/Y!P!Q!9j!Q!R#:O!R![#<_![!]#I_!]!^#Jk!^!_#Ku!_!`$![!`!a$$v!a!b$*T!b!c$,r!c!}Er!}#O$-|#O#P$/W#P#Q$4o#Q#R$5y#R#SEr#S#T$7W#T#o$8b#o#p$<r#p#q$=h#q#r$>x#r#s$@U#s$f%Z$f$g+g$g#BYEr#BY#BZ$A`#BZ$ISEr$IS$I_$A`$I_$I|Er$I|$I}$Dk$I}$JO$Dk$JO$JTEr$JT$JU$A`$JU$KVEr$KV$KW$A`$KW&FUEr&FU&FV$A`&FV;'SEr;'S;=`I|<%l?HTEr?HT?HU$A`?HUOEr(n%d_$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z&j&hT$h&jO!^&c!_#o&c#p;'S&c;'S;=`&w<%lO&c&j&zP;=`<%l&c'|'U]$h&j(U!bOY&}YZ&cZw&}wx&cx!^&}!^!_'}!_#O&}#O#P&c#P#o&}#o#p'}#p;'S&};'S;=`(l<%lO&}!b(SU(U!bOY'}Zw'}x#O'}#P;'S'};'S;=`(f<%lO'}!b(iP;=`<%l'}'|(oP;=`<%l&}'[(y]$h&j(RpOY(rYZ&cZr(rrs&cs!^(r!^!_)r!_#O(r#O#P&c#P#o(r#o#p)r#p;'S(r;'S;=`*a<%lO(rp)wU(RpOY)rZr)rs#O)r#P;'S)r;'S;=`*Z<%lO)rp*^P;=`<%l)r'[*dP;=`<%l(r#S*nX(Rp(U!bOY*gZr*grs'}sw*gwx)rx#O*g#P;'S*g;'S;=`+Z<%lO*g#S+^P;=`<%l*g(n+dP;=`<%l%Z07[+rq$h&j(Rp(U!b'w0/lOX%ZXY+gYZ&cZ[+g[p%Zpq+gqr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p$f%Z$f$g+g$g#BY%Z#BY#BZ+g#BZ$IS%Z$IS$I_+g$I_$JT%Z$JT$JU+g$JU$KV%Z$KV$KW+g$KW&FU%Z&FU&FV+g&FV;'S%Z;'S;=`+a<%l?HT%Z?HT?HU+g?HUO%Z07[.ST(S#S$h&j'x0/lO!^&c!_#o&c#p;'S&c;'S;=`&w<%lO&c07[.n_$h&j(Rp(U!b'x0/lOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z)3p/x`$h&j!m),Q(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`0z!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(KW1V`#u(Ch$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`2X!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(KW2d_#u(Ch$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'At3l_(Q':f$h&j(U!bOY4kYZ5qZr4krs7nsw4kwx5qx!^4k!^!_8p!_#O4k#O#P5q#P#o4k#o#p8p#p;'S4k;'S;=`:X<%lO4k(^4r_$h&j(U!bOY4kYZ5qZr4krs7nsw4kwx5qx!^4k!^!_8p!_#O4k#O#P5q#P#o4k#o#p8p#p;'S4k;'S;=`:X<%lO4k&z5vX$h&jOr5qrs6cs!^5q!^!_6y!_#o5q#o#p6y#p;'S5q;'S;=`7h<%lO5q&z6jT$c`$h&jO!^&c!_#o&c#p;'S&c;'S;=`&w<%lO&c`6|TOr6yrs7]s;'S6y;'S;=`7b<%lO6y`7bO$c``7eP;=`<%l6y&z7kP;=`<%l5q(^7w]$c`$h&j(U!bOY&}YZ&cZw&}wx&cx!^&}!^!_'}!_#O&}#O#P&c#P#o&}#o#p'}#p;'S&};'S;=`(l<%lO&}!r8uZ(U!bOY8pYZ6yZr8prs9hsw8pwx6yx#O8p#O#P6y#P;'S8p;'S;=`:R<%lO8p!r9oU$c`(U!bOY'}Zw'}x#O'}#P;'S'};'S;=`(f<%lO'}!r:UP;=`<%l8p(^:[P;=`<%l4k%9[:hh$h&j(Rp(U!bOY%ZYZ&cZq%Zqr<Srs&}st%ZtuCruw%Zwx(rx!^%Z!^!_*g!_!c%Z!c!}Cr!}#O%Z#O#P&c#P#R%Z#R#SCr#S#T%Z#T#oCr#o#p*g#p$g%Z$g;'SCr;'S;=`El<%lOCr(r<__WS$h&j(Rp(U!bOY<SYZ&cZr<Srs=^sw<Swx@nx!^<S!^!_Bm!_#O<S#O#P>`#P#o<S#o#pBm#p;'S<S;'S;=`Cl<%lO<S(Q=g]WS$h&j(U!bOY=^YZ&cZw=^wx>`x!^=^!^!_?q!_#O=^#O#P>`#P#o=^#o#p?q#p;'S=^;'S;=`@h<%lO=^&n>gXWS$h&jOY>`YZ&cZ!^>`!^!_?S!_#o>`#o#p?S#p;'S>`;'S;=`?k<%lO>`S?XSWSOY?SZ;'S?S;'S;=`?e<%lO?SS?hP;=`<%l?S&n?nP;=`<%l>`!f?xWWS(U!bOY?qZw?qwx?Sx#O?q#O#P?S#P;'S?q;'S;=`@b<%lO?q!f@eP;=`<%l?q(Q@kP;=`<%l=^'`@w]WS$h&j(RpOY@nYZ&cZr@nrs>`s!^@n!^!_Ap!_#O@n#O#P>`#P#o@n#o#pAp#p;'S@n;'S;=`Bg<%lO@ntAwWWS(RpOYApZrAprs?Ss#OAp#O#P?S#P;'SAp;'S;=`Ba<%lOAptBdP;=`<%lAp'`BjP;=`<%l@n#WBvYWS(Rp(U!bOYBmZrBmrs?qswBmwxApx#OBm#O#P?S#P;'SBm;'S;=`Cf<%lOBm#WCiP;=`<%lBm(rCoP;=`<%l<S%9[C}i$h&j(j%1l(Rp(U!bOY%ZYZ&cZr%Zrs&}st%ZtuCruw%Zwx(rx!Q%Z!Q![Cr![!^%Z!^!_*g!_!c%Z!c!}Cr!}#O%Z#O#P&c#P#R%Z#R#SCr#S#T%Z#T#oCr#o#p*g#p$g%Z$g;'SCr;'S;=`El<%lOCr%9[EoP;=`<%lCr07[FRk$h&j(Rp(U!b$[#t(O,2j(`$I[OY%ZYZ&cZr%Zrs&}st%ZtuEruw%Zwx(rx}%Z}!OGv!O!Q%Z!Q![Er![!^%Z!^!_*g!_!c%Z!c!}Er!}#O%Z#O#P&c#P#R%Z#R#SEr#S#T%Z#T#oEr#o#p*g#p$g%Z$g;'SEr;'S;=`I|<%lOEr+dHRk$h&j(Rp(U!b$[#tOY%ZYZ&cZr%Zrs&}st%ZtuGvuw%Zwx(rx}%Z}!OGv!O!Q%Z!Q![Gv![!^%Z!^!_*g!_!c%Z!c!}Gv!}#O%Z#O#P&c#P#R%Z#R#SGv#S#T%Z#T#oGv#o#p*g#p$g%Z$g;'SGv;'S;=`Iv<%lOGv+dIyP;=`<%lGv07[JPP;=`<%lEr(KWJ_`$h&j(Rp(U!b#m(ChOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`Ka!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(KWKl_$h&j$P(Ch(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z,#xLva(u+JY$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sv%ZvwM{wx(rx!^%Z!^!_*g!_!`Ka!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(KWNW`$h&j#y(Ch(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`Ka!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'At! c_(T';W$h&j(RpOY!!bYZ!#hZr!!brs!#hsw!!bwx!$xx!^!!b!^!_!%z!_#O!!b#O#P!#h#P#o!!b#o#p!%z#p;'S!!b;'S;=`!'c<%lO!!b'l!!i_$h&j(RpOY!!bYZ!#hZr!!brs!#hsw!!bwx!$xx!^!!b!^!_!%z!_#O!!b#O#P!#h#P#o!!b#o#p!%z#p;'S!!b;'S;=`!'c<%lO!!b&z!#mX$h&jOw!#hwx6cx!^!#h!^!_!$Y!_#o!#h#o#p!$Y#p;'S!#h;'S;=`!$r<%lO!#h`!$]TOw!$Ywx7]x;'S!$Y;'S;=`!$l<%lO!$Y`!$oP;=`<%l!$Y&z!$uP;=`<%l!#h'l!%R]$c`$h&j(RpOY(rYZ&cZr(rrs&cs!^(r!^!_)r!_#O(r#O#P&c#P#o(r#o#p)r#p;'S(r;'S;=`*a<%lO(r!Q!&PZ(RpOY!%zYZ!$YZr!%zrs!$Ysw!%zwx!&rx#O!%z#O#P!$Y#P;'S!%z;'S;=`!']<%lO!%z!Q!&yU$c`(RpOY)rZr)rs#O)r#P;'S)r;'S;=`*Z<%lO)r!Q!'`P;=`<%l!%z'l!'fP;=`<%l!!b/5|!'t_!i/.^$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z#&U!)O_!h!Lf$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z-!n!*[b$h&j(Rp(U!b(P%&f#n(ChOY%ZYZ&cZr%Zrs&}sw%Zwx(rxz%Zz{!+d{!^%Z!^!_*g!_!`Ka!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(KW!+o`$h&j(Rp(U!b#k(ChOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`Ka!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z+;x!,|`$h&j(Rp(U!bo+4YOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`Ka!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z,$U!.Z_!Y+Jf$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z07[!/ec$h&j(Rp(U!b}.2^OY%ZYZ&cZr%Zrs&}sw%Zwx(rx!O%Z!O!P!0p!P!Q%Z!Q![!3Y![!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z#%|!0ya$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!O%Z!O!P!2O!P!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z#%|!2Z_!X!L^$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad!3eg$h&j(Rp(U!bp'9tOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!Q%Z!Q![!3Y![!^%Z!^!_*g!_!g%Z!g!h!4|!h#O%Z#O#P&c#P#R%Z#R#S!3Y#S#X%Z#X#Y!4|#Y#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad!5Vg$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx{%Z{|!6n|}%Z}!O!6n!O!Q%Z!Q![!8S![!^%Z!^!_*g!_#O%Z#O#P&c#P#R%Z#R#S!8S#S#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad!6wc$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!Q%Z!Q![!8S![!^%Z!^!_*g!_#O%Z#O#P&c#P#R%Z#R#S!8S#S#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad!8_c$h&j(Rp(U!bp'9tOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!Q%Z!Q![!8S![!^%Z!^!_*g!_#O%Z#O#P&c#P#R%Z#R#S!8S#S#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z07[!9uf$h&j(Rp(U!b#l(ChOY!;ZYZ&cZr!;Zrs!<nsw!;Zwx!Lcxz!;Zz{#-}{!P!;Z!P!Q#/d!Q!^!;Z!^!_#(i!_!`#7S!`!a#8i!a!}!;Z!}#O#,f#O#P!Dy#P#o!;Z#o#p#(i#p;'S!;Z;'S;=`#-w<%lO!;Z?O!;fb$h&j(Rp(U!b!U7`OY!;ZYZ&cZr!;Zrs!<nsw!;Zwx!Lcx!P!;Z!P!Q#&`!Q!^!;Z!^!_#(i!_!}!;Z!}#O#,f#O#P!Dy#P#o!;Z#o#p#(i#p;'S!;Z;'S;=`#-w<%lO!;Z>^!<w`$h&j(U!b!U7`OY!<nYZ&cZw!<nwx!=yx!P!<n!P!Q!Eq!Q!^!<n!^!_!Gr!_!}!<n!}#O!KS#O#P!Dy#P#o!<n#o#p!Gr#p;'S!<n;'S;=`!L]<%lO!<n<z!>Q^$h&j!U7`OY!=yYZ&cZ!P!=y!P!Q!>|!Q!^!=y!^!_!@c!_!}!=y!}#O!CW#O#P!Dy#P#o!=y#o#p!@c#p;'S!=y;'S;=`!Ek<%lO!=y<z!?Td$h&j!U7`O!^&c!_#W&c#W#X!>|#X#Z&c#Z#[!>|#[#]&c#]#^!>|#^#a&c#a#b!>|#b#g&c#g#h!>|#h#i&c#i#j!>|#j#k!>|#k#m&c#m#n!>|#n#o&c#p;'S&c;'S;=`&w<%lO&c7`!@hX!U7`OY!@cZ!P!@c!P!Q!AT!Q!}!@c!}#O!Ar#O#P!Bq#P;'S!@c;'S;=`!CQ<%lO!@c7`!AYW!U7`#W#X!AT#Z#[!AT#]#^!AT#a#b!AT#g#h!AT#i#j!AT#j#k!AT#m#n!AT7`!AuVOY!ArZ#O!Ar#O#P!B[#P#Q!@c#Q;'S!Ar;'S;=`!Bk<%lO!Ar7`!B_SOY!ArZ;'S!Ar;'S;=`!Bk<%lO!Ar7`!BnP;=`<%l!Ar7`!BtSOY!@cZ;'S!@c;'S;=`!CQ<%lO!@c7`!CTP;=`<%l!@c<z!C][$h&jOY!CWYZ&cZ!^!CW!^!_!Ar!_#O!CW#O#P!DR#P#Q!=y#Q#o!CW#o#p!Ar#p;'S!CW;'S;=`!Ds<%lO!CW<z!DWX$h&jOY!CWYZ&cZ!^!CW!^!_!Ar!_#o!CW#o#p!Ar#p;'S!CW;'S;=`!Ds<%lO!CW<z!DvP;=`<%l!CW<z!EOX$h&jOY!=yYZ&cZ!^!=y!^!_!@c!_#o!=y#o#p!@c#p;'S!=y;'S;=`!Ek<%lO!=y<z!EnP;=`<%l!=y>^!Ezl$h&j(U!b!U7`OY&}YZ&cZw&}wx&cx!^&}!^!_'}!_#O&}#O#P&c#P#W&}#W#X!Eq#X#Z&}#Z#[!Eq#[#]&}#]#^!Eq#^#a&}#a#b!Eq#b#g&}#g#h!Eq#h#i&}#i#j!Eq#j#k!Eq#k#m&}#m#n!Eq#n#o&}#o#p'}#p;'S&};'S;=`(l<%lO&}8r!GyZ(U!b!U7`OY!GrZw!Grwx!@cx!P!Gr!P!Q!Hl!Q!}!Gr!}#O!JU#O#P!Bq#P;'S!Gr;'S;=`!J|<%lO!Gr8r!Hse(U!b!U7`OY'}Zw'}x#O'}#P#W'}#W#X!Hl#X#Z'}#Z#[!Hl#[#]'}#]#^!Hl#^#a'}#a#b!Hl#b#g'}#g#h!Hl#h#i'}#i#j!Hl#j#k!Hl#k#m'}#m#n!Hl#n;'S'};'S;=`(f<%lO'}8r!JZX(U!bOY!JUZw!JUwx!Arx#O!JU#O#P!B[#P#Q!Gr#Q;'S!JU;'S;=`!Jv<%lO!JU8r!JyP;=`<%l!JU8r!KPP;=`<%l!Gr>^!KZ^$h&j(U!bOY!KSYZ&cZw!KSwx!CWx!^!KS!^!_!JU!_#O!KS#O#P!DR#P#Q!<n#Q#o!KS#o#p!JU#p;'S!KS;'S;=`!LV<%lO!KS>^!LYP;=`<%l!KS>^!L`P;=`<%l!<n=l!Ll`$h&j(Rp!U7`OY!LcYZ&cZr!Lcrs!=ys!P!Lc!P!Q!Mn!Q!^!Lc!^!_# o!_!}!Lc!}#O#%P#O#P!Dy#P#o!Lc#o#p# o#p;'S!Lc;'S;=`#&Y<%lO!Lc=l!Mwl$h&j(Rp!U7`OY(rYZ&cZr(rrs&cs!^(r!^!_)r!_#O(r#O#P&c#P#W(r#W#X!Mn#X#Z(r#Z#[!Mn#[#](r#]#^!Mn#^#a(r#a#b!Mn#b#g(r#g#h!Mn#h#i(r#i#j!Mn#j#k!Mn#k#m(r#m#n!Mn#n#o(r#o#p)r#p;'S(r;'S;=`*a<%lO(r8Q# vZ(Rp!U7`OY# oZr# ors!@cs!P# o!P!Q#!i!Q!}# o!}#O#$R#O#P!Bq#P;'S# o;'S;=`#$y<%lO# o8Q#!pe(Rp!U7`OY)rZr)rs#O)r#P#W)r#W#X#!i#X#Z)r#Z#[#!i#[#])r#]#^#!i#^#a)r#a#b#!i#b#g)r#g#h#!i#h#i)r#i#j#!i#j#k#!i#k#m)r#m#n#!i#n;'S)r;'S;=`*Z<%lO)r8Q#$WX(RpOY#$RZr#$Rrs!Ars#O#$R#O#P!B[#P#Q# o#Q;'S#$R;'S;=`#$s<%lO#$R8Q#$vP;=`<%l#$R8Q#$|P;=`<%l# o=l#%W^$h&j(RpOY#%PYZ&cZr#%Prs!CWs!^#%P!^!_#$R!_#O#%P#O#P!DR#P#Q!Lc#Q#o#%P#o#p#$R#p;'S#%P;'S;=`#&S<%lO#%P=l#&VP;=`<%l#%P=l#&]P;=`<%l!Lc?O#&kn$h&j(Rp(U!b!U7`OY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#W%Z#W#X#&`#X#Z%Z#Z#[#&`#[#]%Z#]#^#&`#^#a%Z#a#b#&`#b#g%Z#g#h#&`#h#i%Z#i#j#&`#j#k#&`#k#m%Z#m#n#&`#n#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z9d#(r](Rp(U!b!U7`OY#(iZr#(irs!Grsw#(iwx# ox!P#(i!P!Q#)k!Q!}#(i!}#O#+`#O#P!Bq#P;'S#(i;'S;=`#,`<%lO#(i9d#)th(Rp(U!b!U7`OY*gZr*grs'}sw*gwx)rx#O*g#P#W*g#W#X#)k#X#Z*g#Z#[#)k#[#]*g#]#^#)k#^#a*g#a#b#)k#b#g*g#g#h#)k#h#i*g#i#j#)k#j#k#)k#k#m*g#m#n#)k#n;'S*g;'S;=`+Z<%lO*g9d#+gZ(Rp(U!bOY#+`Zr#+`rs!JUsw#+`wx#$Rx#O#+`#O#P!B[#P#Q#(i#Q;'S#+`;'S;=`#,Y<%lO#+`9d#,]P;=`<%l#+`9d#,cP;=`<%l#(i?O#,o`$h&j(Rp(U!bOY#,fYZ&cZr#,frs!KSsw#,fwx#%Px!^#,f!^!_#+`!_#O#,f#O#P!DR#P#Q!;Z#Q#o#,f#o#p#+`#p;'S#,f;'S;=`#-q<%lO#,f?O#-tP;=`<%l#,f?O#-zP;=`<%l!;Z07[#.[b$h&j(Rp(U!b'y0/l!U7`OY!;ZYZ&cZr!;Zrs!<nsw!;Zwx!Lcx!P!;Z!P!Q#&`!Q!^!;Z!^!_#(i!_!}!;Z!}#O#,f#O#P!Dy#P#o!;Z#o#p#(i#p;'S!;Z;'S;=`#-w<%lO!;Z07[#/o_$h&j(Rp(U!bT0/lOY#/dYZ&cZr#/drs#0nsw#/dwx#4Ox!^#/d!^!_#5}!_#O#/d#O#P#1p#P#o#/d#o#p#5}#p;'S#/d;'S;=`#6|<%lO#/d06j#0w]$h&j(U!bT0/lOY#0nYZ&cZw#0nwx#1px!^#0n!^!_#3R!_#O#0n#O#P#1p#P#o#0n#o#p#3R#p;'S#0n;'S;=`#3x<%lO#0n05W#1wX$h&jT0/lOY#1pYZ&cZ!^#1p!^!_#2d!_#o#1p#o#p#2d#p;'S#1p;'S;=`#2{<%lO#1p0/l#2iST0/lOY#2dZ;'S#2d;'S;=`#2u<%lO#2d0/l#2xP;=`<%l#2d05W#3OP;=`<%l#1p01O#3YW(U!bT0/lOY#3RZw#3Rwx#2dx#O#3R#O#P#2d#P;'S#3R;'S;=`#3r<%lO#3R01O#3uP;=`<%l#3R06j#3{P;=`<%l#0n05x#4X]$h&j(RpT0/lOY#4OYZ&cZr#4Ors#1ps!^#4O!^!_#5Q!_#O#4O#O#P#1p#P#o#4O#o#p#5Q#p;'S#4O;'S;=`#5w<%lO#4O00^#5XW(RpT0/lOY#5QZr#5Qrs#2ds#O#5Q#O#P#2d#P;'S#5Q;'S;=`#5q<%lO#5Q00^#5tP;=`<%l#5Q05x#5zP;=`<%l#4O01p#6WY(Rp(U!bT0/lOY#5}Zr#5}rs#3Rsw#5}wx#5Qx#O#5}#O#P#2d#P;'S#5};'S;=`#6v<%lO#5}01p#6yP;=`<%l#5}07[#7PP;=`<%l#/d)3h#7ab$h&j$P(Ch(Rp(U!b!U7`OY!;ZYZ&cZr!;Zrs!<nsw!;Zwx!Lcx!P!;Z!P!Q#&`!Q!^!;Z!^!_#(i!_!}!;Z!}#O#,f#O#P!Dy#P#o!;Z#o#p#(i#p;'S!;Z;'S;=`#-w<%lO!;ZAt#8vb$Y#t$h&j(Rp(U!b!U7`OY!;ZYZ&cZr!;Zrs!<nsw!;Zwx!Lcx!P!;Z!P!Q#&`!Q!^!;Z!^!_#(i!_!}!;Z!}#O#,f#O#P!Dy#P#o!;Z#o#p#(i#p;'S!;Z;'S;=`#-w<%lO!;Z'Ad#:Zp$h&j(Rp(U!bp'9tOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!O%Z!O!P!3Y!P!Q%Z!Q![#<_![!^%Z!^!_*g!_!g%Z!g!h!4|!h#O%Z#O#P&c#P#R%Z#R#S#<_#S#U%Z#U#V#?i#V#X%Z#X#Y!4|#Y#b%Z#b#c#>_#c#d#Bq#d#l%Z#l#m#Es#m#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad#<jk$h&j(Rp(U!bp'9tOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!O%Z!O!P!3Y!P!Q%Z!Q![#<_![!^%Z!^!_*g!_!g%Z!g!h!4|!h#O%Z#O#P&c#P#R%Z#R#S#<_#S#X%Z#X#Y!4|#Y#b%Z#b#c#>_#c#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad#>j_$h&j(Rp(U!bp'9tOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad#?rd$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!Q%Z!Q!R#AQ!R!S#AQ!S!^%Z!^!_*g!_#O%Z#O#P&c#P#R%Z#R#S#AQ#S#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad#A]f$h&j(Rp(U!bp'9tOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!Q%Z!Q!R#AQ!R!S#AQ!S!^%Z!^!_*g!_#O%Z#O#P&c#P#R%Z#R#S#AQ#S#b%Z#b#c#>_#c#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad#Bzc$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!Q%Z!Q!Y#DV!Y!^%Z!^!_*g!_#O%Z#O#P&c#P#R%Z#R#S#DV#S#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad#Dbe$h&j(Rp(U!bp'9tOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!Q%Z!Q!Y#DV!Y!^%Z!^!_*g!_#O%Z#O#P&c#P#R%Z#R#S#DV#S#b%Z#b#c#>_#c#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad#E|g$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!Q%Z!Q![#Ge![!^%Z!^!_*g!_!c%Z!c!i#Ge!i#O%Z#O#P&c#P#R%Z#R#S#Ge#S#T%Z#T#Z#Ge#Z#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z'Ad#Gpi$h&j(Rp(U!bp'9tOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!Q%Z!Q![#Ge![!^%Z!^!_*g!_!c%Z!c!i#Ge!i#O%Z#O#P&c#P#R%Z#R#S#Ge#S#T%Z#T#Z#Ge#Z#b%Z#b#c#>_#c#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z*)x#Il_!d$b$h&j#})Lv(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z)[#Jv_al$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z04f#LS^h#)`#O-<U(Rp(U!b(y7`OY*gZr*grs'}sw*gwx)rx!P*g!P!Q#MO!Q!^*g!^!_#Mt!_!`$ f!`#O*g#P;'S*g;'S;=`+Z<%lO*g(n#MXX$j&j(Rp(U!bOY*gZr*grs'}sw*gwx)rx#O*g#P;'S*g;'S;=`+Z<%lO*g(El#M}Z#o(Ch(Rp(U!bOY*gZr*grs'}sw*gwx)rx!_*g!_!`#Np!`#O*g#P;'S*g;'S;=`+Z<%lO*g(El#NyX$P(Ch(Rp(U!bOY*gZr*grs'}sw*gwx)rx#O*g#P;'S*g;'S;=`+Z<%lO*g(El$ oX#p(Ch(Rp(U!bOY*gZr*grs'}sw*gwx)rx#O*g#P;'S*g;'S;=`+Z<%lO*g*)x$!ga#]*!Y$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`0z!`!a$#l!a#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(K[$#w_#h(Cl$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z*)x$%Vag!*r#p(Ch$e#|$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`$&[!`!a$'f!a#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(KW$&g_#p(Ch$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(KW$'qa#o(Ch$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`Ka!`!a$(v!a#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(KW$)R`#o(Ch$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`Ka!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(Kd$*`a(m(Ct$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!a%Z!a!b$+e!b#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(KW$+p`$h&j#z(Ch(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`Ka!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z%#`$,}_!y$Ip$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z04f$.X_!P0,v$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(n$/]Z$h&jO!^$0O!^!_$0f!_#i$0O#i#j$0k#j#l$0O#l#m$2^#m#o$0O#o#p$0f#p;'S$0O;'S;=`$4i<%lO$0O(n$0VT_#S$h&jO!^&c!_#o&c#p;'S&c;'S;=`&w<%lO&c#S$0kO_#S(n$0p[$h&jO!Q&c!Q![$1f![!^&c!_!c&c!c!i$1f!i#T&c#T#Z$1f#Z#o&c#o#p$3|#p;'S&c;'S;=`&w<%lO&c(n$1kZ$h&jO!Q&c!Q![$2^![!^&c!_!c&c!c!i$2^!i#T&c#T#Z$2^#Z#o&c#p;'S&c;'S;=`&w<%lO&c(n$2cZ$h&jO!Q&c!Q![$3U![!^&c!_!c&c!c!i$3U!i#T&c#T#Z$3U#Z#o&c#p;'S&c;'S;=`&w<%lO&c(n$3ZZ$h&jO!Q&c!Q![$0O![!^&c!_!c&c!c!i$0O!i#T&c#T#Z$0O#Z#o&c#p;'S&c;'S;=`&w<%lO&c#S$4PR!Q![$4Y!c!i$4Y#T#Z$4Y#S$4]S!Q![$4Y!c!i$4Y#T#Z$4Y#q#r$0f(n$4lP;=`<%l$0O#1[$4z_!V#)l$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z(KW$6U`#w(Ch$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`Ka!`#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z+;p$7c_$h&j(Rp(U!b([+4QOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z07[$8qk$h&j(Rp(U!b(O,2j$^#t(`$I[OY%ZYZ&cZr%Zrs&}st%Ztu$8buw%Zwx(rx}%Z}!O$:f!O!Q%Z!Q![$8b![!^%Z!^!_*g!_!c%Z!c!}$8b!}#O%Z#O#P&c#P#R%Z#R#S$8b#S#T%Z#T#o$8b#o#p*g#p$g%Z$g;'S$8b;'S;=`$<l<%lO$8b+d$:qk$h&j(Rp(U!b$^#tOY%ZYZ&cZr%Zrs&}st%Ztu$:fuw%Zwx(rx}%Z}!O$:f!O!Q%Z!Q![$:f![!^%Z!^!_*g!_!c%Z!c!}$:f!}#O%Z#O#P&c#P#R%Z#R#S$:f#S#T%Z#T#o$:f#o#p*g#p$g%Z$g;'S$:f;'S;=`$<f<%lO$:f+d$<iP;=`<%l$:f07[$<oP;=`<%l$8b#Jf$<{X![#Hb(Rp(U!bOY*gZr*grs'}sw*gwx)rx#O*g#P;'S*g;'S;=`+Z<%lO*g,#x$=sa(t+JY$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_!`Ka!`#O%Z#O#P&c#P#o%Z#o#p*g#p#q$+e#q;'S%Z;'S;=`+a<%lO%Z(Kd$?V_!Z(Cds`$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z?O$@a_!n7`$h&j(Rp(U!bOY%ZYZ&cZr%Zrs&}sw%Zwx(rx!^%Z!^!_*g!_#O%Z#O#P&c#P#o%Z#o#p*g#p;'S%Z;'S;=`+a<%lO%Z07[$Aq|$h&j(Rp(U!b'w0/l$[#t(O,2j(`$I[OX%ZXY+gYZ&cZ[+g[p%Zpq+gqr%Zrs&}st%ZtuEruw%Zwx(rx}%Z}!OGv!O!Q%Z!Q![Er![!^%Z!^!_*g!_!c%Z!c!}Er!}#O%Z#O#P&c#P#R%Z#R#SEr#S#T%Z#T#oEr#o#p*g#p$f%Z$f$g+g$g#BYEr#BY#BZ$A`#BZ$ISEr$IS$I_$A`$I_$JTEr$JT$JU$A`$JU$KVEr$KV$KW$A`$KW&FUEr&FU&FV$A`&FV;'SEr;'S;=`I|<%l?HTEr?HT?HU$A`?HUOEr07[$D|k$h&j(Rp(U!b'x0/l$[#t(O,2j(`$I[OY%ZYZ&cZr%Zrs&}st%ZtuEruw%Zwx(rx}%Z}!OGv!O!Q%Z!Q![Er![!^%Z!^!_*g!_!c%Z!c!}Er!}#O%Z#O#P&c#P#R%Z#R#SEr#S#T%Z#T#oEr#o#p*g#p$g%Z$g;'SEr;'S;=`I|<%lOEr",
tokenizers:[fye,mye,vye,2,3,4,5,6,7,8,9,10,11,12,13,14,hye,new jve("$S~RRtu[#O#Pg#S#T#|~_P#o#pb~gOu~~jVO#i!P#i#j!U#j#l!P#l#m!q#m;'S!P;'S;=`#v<%lO!P~!UO!R~~!XS!Q![!e!c!i!e#T#Z!e#o#p#Z~!hR!Q![!q!c!i!q#T#Z!q~!tR!Q![!}!c!i!}#T#Z!}~#QR!Q![!P!c!i!P#T#Z!P~#^R!Q![#g!c!i#g#T#Z#g~#jS!Q![#g!c!i#g#T#Z#g#q#r!P~#yP;=`<%l!P~$RO(^~~",141,335),new jve("j~RQYZXz{^~^O'{~~aP!P!Qd~iO'|~~",25,318)],
topRules:{Script:[0,7],SingleExpression:[1,272],SingleClassItem:[2,273]},
dialects:{jsx:0,ts:14725},dynamicPrecedences:{77:1,79:1,91:1,167:1,196:1},
specialized:[{term:322,get:e=>yye[e]||-1},{term:338,get:e=>Oye[e]||-1},{term:92,
get:e=>wye[e]||-1}],tokenPrec:14749
}),kye=[Lge("function ${name}(${params}) {\n\t${}\n}",{label:"function",
detail:"definition",type:"keyword"
}),Lge("for (let ${index} = 0; ${index} < ${bound}; ${index}++) {\n\t${}\n}",{
label:"for",detail:"loop",type:"keyword"
}),Lge("for (let ${name} of ${collection}) {\n\t${}\n}",{label:"for",
detail:"of loop",type:"keyword"}),Lge("do {\n\t${}\n} while (${})",{label:"do",
detail:"loop",type:"keyword"}),Lge("while (${}) {\n\t${}\n}",{label:"while",
detail:"loop",type:"keyword"
}),Lge("try {\n\t${}\n} catch (${error}) {\n\t${}\n}",{label:"try",
detail:"/ catch block",type:"keyword"}),Lge("if (${}) {\n\t${}\n}",{label:"if",
detail:"block",type:"keyword"}),Lge("if (${}) {\n\t${}\n} else {\n\t${}\n}",{
label:"if",detail:"/ else block",type:"keyword"
}),Lge("class ${name} {\n\tconstructor(${params}) {\n\t\t${}\n\t}\n}",{
label:"class",detail:"definition",type:"keyword"
}),Lge('import {${names}} from "${module}"\n${}',{label:"import",detail:"named",
type:"keyword"}),Lge('import ${name} from "${module}"\n${}',{label:"import",
detail:"default",type:"keyword"
})],Sye=kye.concat([Lge("interface ${name} {\n\t${}\n}",{label:"interface",
detail:"definition",type:"keyword"}),Lge("type ${name} = ${type}",{label:"type",
detail:"definition",type:"keyword"}),Lge("enum ${name} {\n\t${}\n}",{
label:"enum",detail:"definition",type:"keyword"
})]),_ye=new the,Tye=new Set(["Script","Block","FunctionExpression","FunctionDeclaration","ArrowFunction","MethodDeclaration","ForStatement"])
;function Eye(e){return(t,n)=>{let r=t.node.getChild("VariableDefinition")
;return r&&n(r,e),!0}}const Aye=["FunctionDeclaration"],Cye={
FunctionDeclaration:Eye("function"),ClassDeclaration:Eye("class"),
ClassExpression:()=>!0,EnumDeclaration:Eye("constant"),
TypeAliasDeclaration:Eye("type"),NamespaceDeclaration:Eye("namespace"),
VariableDefinition(e,t){e.matchContext(Aye)||t(e,"variable")},
TypeDefinition(e,t){t(e,"type")},__proto__:null};function $ye(e,t){
let n=_ye.get(t);if(n)return n;let r=[],o=!0;function a(t,n){
let o=e.sliceString(t.from,t.to);r.push({label:o,type:n})}
return t.cursor(Npe.IncludeAnonymous).iterate((t=>{if(o)o=!1;else if(t.name){
let e=Cye[t.name];if(e&&e(t,a)||Tye.has(t.name))return!1
}else if(t.to-t.from>8192){for(let n of $ye(e,t.node))r.push(n);return!1}
})),_ye.set(t,r),r}
const Pye=/^[\w$\xa1-\uffff][\w$\d\xa1-\uffff]*$/,Dye=["TemplateString","String","RegExp","LineComment","BlockComment","VariableDefinition","TypeDefinition","Label","PropertyDefinition","PropertyName","PrivatePropertyDefinition","PrivatePropertyName","JSXText","JSXAttributeValue","JSXOpenTag","JSXCloseTag","JSXSelfClosingTag",".","?."]
;function Iye(e){let t=Yhe(e.state).resolveInner(e.pos,-1)
;if(Dye.indexOf(t.name)>-1)return null
;let n="VariableName"==t.name||t.to-t.from<20&&Pye.test(e.state.sliceDoc(t.from,t.to))
;if(!n&&!e.explicit)return null;let r=[]
;for(let o=t;o;o=o.parent)Tye.has(o.name)&&(r=r.concat($ye(e.state.doc,o)))
;return{options:r,from:n?t.from:e.pos,validFor:Pye}}const Mye=Ghe.define({
name:"javascript",parser:xye.configure({props:[ffe.add({IfStatement:xfe({
except:/^\s*({|else\b)/}),TryStatement:xfe({except:/^\s*({|catch\b|finally\b)/
}),LabeledStatement:e=>e.baseIndent,SwitchBody:e=>{
let t=e.textAfter,n=/^\s*\}/.test(t),r=/^\s*(case|default)\b/.test(t)
;return e.baseIndent+(n?0:r?1:2)*e.unit},Block:Ofe({closing:"}"}),
ArrowFunction:e=>e.baseIndent+e.unit,"TemplateString BlockComment":()=>null,
"Statement Property":xfe({except:/^\s*{/}),JSXElement(e){
let t=/^\s*<\//.test(e.textAfter);return e.lineIndent(e.node.from)+(t?0:e.unit)
},JSXEscape(e){let t=/\s*\}/.test(e.textAfter)
;return e.lineIndent(e.node.from)+(t?0:e.unit)},
"JSXOpenTag JSXSelfClosingTag":e=>e.column(e.node.from)+e.unit}),_fe.add({
"Block ClassBody SwitchBody EnumBody ObjectExpression ArrayExpression ObjectType":Tfe,
BlockComment:e=>({from:e.from+2,to:e.to-2})})]}),languageData:{closeBrackets:{
brackets:["(","[","{","'",'"',"`"]},commentTokens:{line:"//",block:{open:"/*",
close:"*/"}},indentOnInput:/^\s*(?:case |default:|\{|\}|<\/)$/,wordChars:"$"}
}),Nye={test:e=>/^JSX/.test(e.name),facet:Vhe({commentTokens:{block:{open:"{/*",
close:"*/}"}}})},Rye=Mye.configure({dialect:"ts"
},"typescript"),Lye=Mye.configure({dialect:"jsx",
props:[qhe.add((e=>e.isTop?[Nye]:void 0))]}),Bye=Mye.configure({
dialect:"jsx ts",props:[qhe.add((e=>e.isTop?[Nye]:void 0))]},"typescript")
;let jye=e=>({label:e,type:"keyword"})
;const Uye="break case const continue default delete export extends false finally in instanceof let new return static super switch this throw true typeof var yield".split(" ").map(jye),zye=Uye.concat(["declare","implements","private","protected","public"].map(jye))
;function Fye(e={}){
let t=e.jsx?e.typescript?Bye:Lye:e.typescript?Rye:Mye,n=e.typescript?Sye.concat(zye):kye.concat(Uye)
;return new sfe(t,[Mye.data.of({autocomplete:(r=Dye,o=Lme(n),e=>{
for(let t=Yhe(e.state).resolveInner(e.pos,-1);t;t=t.parent){
if(r.indexOf(t.name)>-1)return null;if(t.type.isTop)break}return o(e)})
}),Mye.data.of({autocomplete:Iye}),e.jsx?Hye:[]]);var r,o}
function Zye(e,t,n=e.length){
for(let r=null==t?void 0:t.firstChild;r;r=r.nextSibling)if("JSXIdentifier"==r.name||"JSXBuiltin"==r.name||"JSXNamespacedName"==r.name||"JSXMemberExpression"==r.name)return e.sliceString(r.from,Math.min(r.to,n))
;return""}
const Qye="object"==typeof navigator&&/Android\b/.test(navigator.userAgent),Hye=cde.inputHandler.of(((e,t,n,r,o)=>{
if((Qye?e.composing:e.compositionStarted)||e.state.readOnly||t!=n||">"!=r&&"/"!=r||!Mye.isActiveAt(e.state,t,-1))return!1
;let a=o(),{state:i}=a,s=i.changeByRange((e=>{var t
;let n,{head:o}=e,a=Yhe(i).resolveInner(o-1,-1)
;if("JSXStartTag"==a.name&&(a=a.parent),
i.doc.sliceString(o-1,o)!=r||"JSXAttributeValue"==a.name&&a.to>o);else{
if(">"==r&&"JSXFragmentTag"==a.name)return{range:e,changes:{from:o,insert:"</>"}
};if("/"==r&&"JSXStartCloseTag"==a.name){let e=a.parent,r=e.parent
;if(r&&e.from==o-2&&((n=Zye(i.doc,r.firstChild,o))||"JSXFragmentTag"==(null===(t=r.firstChild)||void 0===t?void 0:t.name))){
let e=`${n}>`;return{range:Vae.cursor(o+e.length,-1),changes:{from:o,insert:e}}}
}else if(">"==r){let t=function(e){for(;;){
if("JSXOpenTag"==e.name||"JSXSelfClosingTag"==e.name||"JSXFragmentTag"==e.name)return e
;if("JSXEscape"==e.name||!e.parent)return null;e=e.parent}}(a)
;if(t&&"JSXOpenTag"==t.name&&!/^\/?>|^<\//.test(i.doc.sliceString(o,o+2))&&(n=Zye(i.doc,t,o)))return{
range:e,changes:{from:o,insert:`</${n}>`}}}}return{range:e}}))
;return!s.changes.empty&&(e.dispatch([a,i.update(s,{userEvent:"input.complete",
scrollIntoView:!0})]),!0)
})),Vye=["_blank","_self","_top","_parent"],qye=["ascii","utf-8","utf-16","latin1","latin1"],Wye=["get","post","put","delete"],Xye=["application/x-www-form-urlencoded","multipart/form-data","text/plain"],Gye=["true","false"],Yye={},Kye={
a:{attrs:{href:null,ping:null,type:null,media:null,target:Vye,hreflang:null}},
abbr:Yye,address:Yye,area:{attrs:{alt:null,coords:null,href:null,target:null,
ping:null,media:null,hreflang:null,type:null,
shape:["default","rect","circle","poly"]}},article:Yye,aside:Yye,audio:{attrs:{
src:null,mediagroup:null,crossorigin:["anonymous","use-credentials"],
preload:["none","metadata","auto"],autoplay:["autoplay"],loop:["loop"],
controls:["controls"]}},b:Yye,base:{attrs:{href:null,target:Vye}},bdi:Yye,
bdo:Yye,blockquote:{attrs:{cite:null}},body:Yye,br:Yye,button:{attrs:{form:null,
formaction:null,name:null,value:null,autofocus:["autofocus"],
disabled:["autofocus"],formenctype:Xye,formmethod:Wye,
formnovalidate:["novalidate"],formtarget:Vye,type:["submit","reset","button"]}},
canvas:{attrs:{width:null,height:null}},caption:Yye,center:Yye,cite:Yye,
code:Yye,col:{attrs:{span:null}},colgroup:{attrs:{span:null}},command:{attrs:{
type:["command","checkbox","radio"],label:null,icon:null,radiogroup:null,
command:null,title:null,disabled:["disabled"],checked:["checked"]}},data:{
attrs:{value:null}},datagrid:{attrs:{disabled:["disabled"],multiple:["multiple"]
}},datalist:{attrs:{data:null}},dd:Yye,del:{attrs:{cite:null,datetime:null}},
details:{attrs:{open:["open"]}},dfn:Yye,div:Yye,dl:Yye,dt:Yye,em:Yye,embed:{
attrs:{src:null,type:null,width:null,height:null}},eventsource:{attrs:{src:null}
},fieldset:{attrs:{disabled:["disabled"],form:null,name:null}},figcaption:Yye,
figure:Yye,footer:Yye,form:{attrs:{action:null,name:null,"accept-charset":qye,
autocomplete:["on","off"],enctype:Xye,method:Wye,novalidate:["novalidate"],
target:Vye}},h1:Yye,h2:Yye,h3:Yye,h4:Yye,h5:Yye,h6:Yye,head:{
children:["title","base","link","style","meta","script","noscript","command"]},
header:Yye,hgroup:Yye,hr:Yye,html:{attrs:{manifest:null}},i:Yye,iframe:{attrs:{
src:null,srcdoc:null,name:null,width:null,height:null,
sandbox:["allow-top-navigation","allow-same-origin","allow-forms","allow-scripts"],
seamless:["seamless"]}},img:{attrs:{alt:null,src:null,ismap:null,usemap:null,
width:null,height:null,crossorigin:["anonymous","use-credentials"]}},input:{
attrs:{alt:null,dirname:null,form:null,formaction:null,height:null,list:null,
max:null,maxlength:null,min:null,name:null,pattern:null,placeholder:null,
size:null,src:null,step:null,value:null,width:null,
accept:["audio/*","video/*","image/*"],autocomplete:["on","off"],
autofocus:["autofocus"],checked:["checked"],disabled:["disabled"],
formenctype:Xye,formmethod:Wye,formnovalidate:["novalidate"],formtarget:Vye,
multiple:["multiple"],readonly:["readonly"],required:["required"],
type:["hidden","text","search","tel","url","email","password","datetime","date","month","week","time","datetime-local","number","range","color","checkbox","radio","file","submit","image","reset","button"]
}},ins:{attrs:{cite:null,datetime:null}},kbd:Yye,keygen:{attrs:{challenge:null,
form:null,name:null,autofocus:["autofocus"],disabled:["disabled"],
keytype:["RSA"]}},label:{attrs:{for:null,form:null}},legend:Yye,li:{attrs:{
value:null}},link:{attrs:{href:null,type:null,hreflang:null,media:null,
sizes:["all","16x16","16x16 32x32","16x16 32x32 64x64"]}},map:{attrs:{name:null}
},mark:Yye,menu:{attrs:{label:null,type:["list","context","toolbar"]}},meta:{
attrs:{content:null,charset:qye,
name:["viewport","application-name","author","description","generator","keywords"],
"http-equiv":["content-language","content-type","default-style","refresh"]}},
meter:{attrs:{value:null,min:null,low:null,high:null,max:null,optimum:null}},
nav:Yye,noscript:Yye,object:{attrs:{data:null,type:null,name:null,usemap:null,
form:null,width:null,height:null,typemustmatch:["typemustmatch"]}},ol:{attrs:{
reversed:["reversed"],start:null,type:["1","a","A","i","I"]},
children:["li","script","template","ul","ol"]},optgroup:{attrs:{
disabled:["disabled"],label:null}},option:{attrs:{disabled:["disabled"],
label:null,selected:["selected"],value:null}},output:{attrs:{for:null,form:null,
name:null}},p:Yye,param:{attrs:{name:null,value:null}},pre:Yye,progress:{attrs:{
value:null,max:null}},q:{attrs:{cite:null}},rp:Yye,rt:Yye,ruby:Yye,samp:Yye,
script:{attrs:{type:["text/javascript"],src:null,async:["async"],
defer:["defer"],charset:qye}},section:Yye,select:{attrs:{form:null,name:null,
size:null,autofocus:["autofocus"],disabled:["disabled"],multiple:["multiple"]}},
slot:{attrs:{name:null}},small:Yye,source:{attrs:{src:null,type:null,media:null}
},span:Yye,strong:Yye,style:{attrs:{type:["text/css"],media:null,scoped:null}},
sub:Yye,summary:Yye,sup:Yye,table:Yye,tbody:Yye,td:{attrs:{colspan:null,
rowspan:null,headers:null}},template:Yye,textarea:{attrs:{dirname:null,
form:null,maxlength:null,name:null,placeholder:null,rows:null,cols:null,
autofocus:["autofocus"],disabled:["disabled"],readonly:["readonly"],
required:["required"],wrap:["soft","hard"]}},tfoot:Yye,th:{attrs:{colspan:null,
rowspan:null,headers:null,scope:["row","col","rowgroup","colgroup"]}},thead:Yye,
time:{attrs:{datetime:null}},title:Yye,tr:Yye,track:{attrs:{src:null,label:null,
default:null,kind:["subtitles","captions","descriptions","chapters","metadata"],
srclang:null}},ul:{children:["li","script","template","ul","ol"]},var:Yye,
video:{attrs:{src:null,poster:null,width:null,height:null,
crossorigin:["anonymous","use-credentials"],preload:["auto","metadata","none"],
autoplay:["autoplay"],mediagroup:["movie"],muted:["muted"],controls:["controls"]
}},wbr:Yye},Jye={accesskey:null,class:null,contenteditable:Gye,contextmenu:null,
dir:["ltr","rtl","auto"],draggable:["true","false","auto"],
dropzone:["copy","move","link","string:","file:"],hidden:["hidden"],id:null,
inert:["inert"],itemid:null,itemprop:null,itemref:null,itemscope:["itemscope"],
itemtype:null,
lang:["ar","bn","de","en-GB","en-US","es","fr","hi","id","ja","pa","pt","ru","tr","zh"],
spellcheck:Gye,autocorrect:Gye,autocapitalize:Gye,style:null,tabindex:null,
title:null,translate:["yes","no"],
rel:["stylesheet","alternate","author","bookmark","help","license","next","nofollow","noreferrer","prefetch","prev","search","tag"],
role:"alert application article banner button cell checkbox complementary contentinfo dialog document feed figure form grid gridcell heading img list listbox listitem main navigation region row rowgroup search switch tab table tabpanel textbox timer".split(" "),
"aria-activedescendant":null,"aria-atomic":Gye,
"aria-autocomplete":["inline","list","both","none"],"aria-busy":Gye,
"aria-checked":["true","false","mixed","undefined"],"aria-controls":null,
"aria-describedby":null,"aria-disabled":Gye,"aria-dropeffect":null,
"aria-expanded":["true","false","undefined"],"aria-flowto":null,
"aria-grabbed":["true","false","undefined"],"aria-haspopup":Gye,
"aria-hidden":Gye,"aria-invalid":["true","false","grammar","spelling"],
"aria-label":null,"aria-labelledby":null,"aria-level":null,
"aria-live":["off","polite","assertive"],"aria-multiline":Gye,
"aria-multiselectable":Gye,"aria-owns":null,"aria-posinset":null,
"aria-pressed":["true","false","mixed","undefined"],"aria-readonly":Gye,
"aria-relevant":null,"aria-required":Gye,
"aria-selected":["true","false","undefined"],"aria-setsize":null,
"aria-sort":["ascending","descending","none","other"],"aria-valuemax":null,
"aria-valuemin":null,"aria-valuenow":null,"aria-valuetext":null
},eOe="beforeunload copy cut dragstart dragover dragleave dragenter dragend drag paste focus blur change click load mousedown mouseenter mouseleave mouseup keydown keyup resize scroll unload".split(" ").map((e=>"on"+e))
;for(let v5e of eOe)Jye[v5e]=null;let tOe=class{constructor(e,t){
this.tags=Object.assign(Object.assign({},Kye),e),
this.globalAttrs=Object.assign(Object.assign({},Jye),t),
this.allTags=Object.keys(this.tags),
this.globalAttrNames=Object.keys(this.globalAttrs)}}
;function nOe(e,t,n=e.length){if(!t)return""
;let r=t.firstChild,o=r&&r.getChild("TagName")
;return o?e.sliceString(o.from,Math.min(o.to,n)):""}function rOe(e,t=!1){
for(;e;e=e.parent)if("Element"==e.name){if(!t)return e;t=!1}return null}
function oOe(e,t,n){let r=n.tags[nOe(e,rOe(t))]
;return(null==r?void 0:r.children)||n.allTags}function aOe(e,t){let n=[]
;for(let r=rOe(t);r&&!r.type.isTop;r=rOe(r.parent)){let o=nOe(e,r)
;if(o&&"CloseTag"==r.lastChild.name)break
;o&&n.indexOf(o)<0&&("EndTag"==t.name||t.from>=r.firstChild.to)&&n.push(o)}
return n}tOe.default=new tOe;const iOe=/^[:\-\.\w\u00b7-\uffff]*$/
;function sOe(e,t,n,r,o){let a=/\s*>/.test(e.sliceDoc(o,o+5))?"":">",i=rOe(n,!0)
;return{from:r,to:o,options:oOe(e.doc,i,t).map((e=>({label:e,type:"type"
}))).concat(aOe(e.doc,n).map(((e,t)=>({label:"/"+e,apply:"/"+e+a,type:"type",
boost:99-t})))),validFor:/^\/?[:\-\.\w\u00b7-\uffff]*$/}}function lOe(e,t,n,r){
let o=/\s*>/.test(e.sliceDoc(r,r+5))?"":">";return{from:n,to:r,
options:aOe(e.doc,t).map(((e,t)=>({label:e,apply:e+o,type:"type",boost:99-t}))),
validFor:iOe}}function cOe(e,t){
let{state:n,pos:r}=t,o=Yhe(n).resolveInner(r,-1),a=o.resolve(r)
;for(let i,s=r;a==o&&(i=o.childBefore(s));){let e=i.lastChild
;if(!e||!e.type.isError||e.from<e.to)break;a=o=i,s=e.from}
return"TagName"==o.name?o.parent&&/CloseTag$/.test(o.parent.name)?lOe(n,o,o.from,r):sOe(n,e,o,o.from,r):"StartTag"==o.name?sOe(n,e,o,r,r):"StartCloseTag"==o.name||"IncompleteCloseTag"==o.name?lOe(n,o,r,r):"OpenTag"==o.name||"SelfClosingTag"==o.name||"AttributeName"==o.name?function(e,t,n,r,o){
let a=rOe(n),i=a?t.tags[nOe(e.doc,a)]:null,s=i&&i.attrs?Object.keys(i.attrs):[]
;return{from:r,to:o,
options:(i&&!1===i.globalAttrs?s:s.length?s.concat(t.globalAttrNames):t.globalAttrNames).map((e=>({
label:e,type:"property"}))),validFor:iOe}
}(n,e,o,"AttributeName"==o.name?o.from:r,r):"Is"==o.name||"AttributeValue"==o.name||"UnquotedAttributeValue"==o.name?function(e,t,n,r,o){
var a
;let i,s=null===(a=n.parent)||void 0===a?void 0:a.getChild("AttributeName"),l=[]
;if(s){let a=e.sliceDoc(s.from,s.to),c=t.globalAttrs[a];if(!c){
let r=rOe(n),o=r?t.tags[nOe(e.doc,r)]:null
;c=(null==o?void 0:o.attrs)&&o.attrs[a]}if(c){
let t=e.sliceDoc(r,o).toLowerCase(),n='"',a='"'
;/^['"]/.test(t)?(i='"'==t[0]?/^[^"]*$/:/^[^']*$/,
n="",a=e.sliceDoc(o,o+1)==t[0]?"":t[0],t=t.slice(1),r++):i=/^[^\s<>='"]*$/
;for(let e of c)l.push({label:e,apply:n+e+a,type:"constant"})}}return{from:r,
to:o,options:l,validFor:i}
}(n,e,o,"Is"==o.name?r:o.from,r):!t.explicit||"Element"!=a.name&&"Text"!=a.name&&"Document"!=a.name?null:function(e,t,n,r){
let o=[],a=0;for(let i of oOe(e.doc,n,t))o.push({label:"<"+i,type:"type"})
;for(let i of aOe(e.doc,n))o.push({label:"</"+i+">",type:"type",boost:99-a++})
;return{from:r,to:r,options:o,validFor:/^<\/?[:\-\.\w\u00b7-\uffff]*$/}
}(n,e,o,r)}function uOe(e){
let{extraTags:t,extraGlobalAttributes:n}=e,r=n||t?new tOe(t,n):tOe.default
;return e=>cOe(r,e)}const dOe=Mye.parser.configure({top:"SingleExpression"
}),pOe=[{tag:"script",attrs:e=>"text/typescript"==e.type||"ts"==e.lang,
parser:Rye.parser},{tag:"script",
attrs:e=>"text/babel"==e.type||"text/jsx"==e.type,parser:Lye.parser},{
tag:"script",attrs:e=>"text/typescript-jsx"==e.type,parser:Bye.parser},{
tag:"script",
attrs:e=>/^(importmap|speculationrules|application\/(.+\+)?json)$/i.test(e.type),
parser:dOe},{tag:"script",
attrs:e=>!e.type||/^(?:text|application)\/(?:x-)?(?:java|ecma)script$|^module$|^$/i.test(e.type),
parser:Mye.parser},{tag:"style",
attrs:e=>(!e.lang||"css"==e.lang)&&(!e.type||/^(text\/)?(x-)?(stylesheet|css)$/i.test(e.type)),
parser:Ebe.parser}],hOe=[{name:"style",parser:Ebe.parser.configure({top:"Styles"
})}].concat(eOe.map((e=>({name:e,parser:Mye.parser})))),fOe=Ghe.define({
name:"html",parser:iye.configure({props:[ffe.add({Element(e){
let t=/^(\s*)(<\/)?/.exec(e.textAfter)
;return e.node.to<=e.pos+t[0].length?e.continue():e.lineIndent(e.node.from)+(t[2]?0:e.unit)
},"OpenTag CloseTag SelfClosingTag":e=>e.column(e.node.from)+e.unit,Document(e){
if(e.pos+/\s*/.exec(e.textAfter)[0].length<e.node.to)return e.continue()
;let t,n=null;for(let r=e.node;;){let e=r.lastChild
;if(!e||"Element"!=e.name||e.to!=r.to)break;n=r=e}
return n&&(!(t=n.lastChild)||"CloseTag"!=t.name&&"SelfClosingTag"!=t.name)?e.lineIndent(n.from)+e.unit:null
}}),_fe.add({Element(e){let t=e.firstChild,n=e.lastChild
;return t&&"OpenTag"==t.name?{from:t.to,to:"CloseTag"==n.name?n.from:e.to}:null}
}),ime.add({"OpenTag CloseTag":e=>e.getChild("TagName")})]}),languageData:{
commentTokens:{block:{open:"\x3c!--",close:"--\x3e"}},
indentOnInput:/^\s*<\/\w+\W$/,wordChars:"-._"}}),mOe=fOe.configure({
wrap:uye(pOe,hOe)})
;const gOe=new Set("area base br col command embed frame hr img input keygen link meta param source track wbr menuitem".split(" ")),vOe=cde.inputHandler.of(((e,t,n,r,o)=>{
if(e.composing||e.state.readOnly||t!=n||">"!=r&&"/"!=r||!mOe.isActiveAt(e.state,t,-1))return!1
;let a=o(),{state:i}=a,s=i.changeByRange((e=>{var t,n,o
;let a,s=i.doc.sliceString(e.from-1,e.to)==r,{head:l}=e,c=Yhe(i).resolveInner(l,-1)
;if(s&&">"==r&&"EndTag"==c.name){let r=c.parent
;if("CloseTag"!=(null===(n=null===(t=r.parent)||void 0===t?void 0:t.lastChild)||void 0===n?void 0:n.name)&&(a=nOe(i.doc,r.parent,l))&&!gOe.has(a)){
return{range:e,changes:{from:l,to:l+(">"===i.doc.sliceString(l,l+1)?1:0),
insert:`</${a}>`}}}}else if(s&&"/"==r&&"IncompleteCloseTag"==c.name){
let e=c.parent
;if(c.from==l-2&&"CloseTag"!=(null===(o=e.lastChild)||void 0===o?void 0:o.name)&&(a=nOe(i.doc,e,l))&&!gOe.has(a)){
let e=l+(">"===i.doc.sliceString(l,l+1)?1:0),t=`${a}>`;return{
range:Vae.cursor(l+t.length,-1),changes:{from:l,to:e,insert:t}}}}return{range:e}
}));return!s.changes.empty&&(e.dispatch([a,i.update(s,{
userEvent:"input.complete",scrollIntoView:!0})]),!0)})),bOe=xhe({
String:Zhe.string,Number:Zhe.number,"True False":Zhe.bool,
PropertyName:Zhe.propertyName,Null:Zhe.null,",":Zhe.separator,
"[ ]":Zhe.squareBracket,"{ }":Zhe.brace}),yOe=ebe.deserialize({version:14,
states:"$bOVQPOOOOQO'#Cb'#CbOnQPO'#CeOvQPO'#CjOOQO'#Cp'#CpQOQPOOOOQO'#Cg'#CgO}QPO'#CfO!SQPO'#CrOOQO,59P,59PO![QPO,59PO!aQPO'#CuOOQO,59U,59UO!iQPO,59UOVQPO,59QOqQPO'#CkO!nQPO,59^OOQO1G.k1G.kOVQPO'#ClO!vQPO,59aOOQO1G.p1G.pOOQO1G.l1G.lOOQO,59V,59VOOQO-E6i-E6iOOQO,59W,59WOOQO-E6j-E6j",
stateData:"#O~OcOS~OQSORSOSSOTSOWQO]ROePO~OVXOeUO~O[[O~PVOg^O~Oh_OVfX~OVaO~OhbO[iX~O[dO~Oh_OVfa~OhbO[ia~O",
goto:"!kjPPPPPPkPPkqwPPk{!RPPP!XP!ePP!hXSOR^bQWQRf_TVQ_Q`WRg`QcZRicQTOQZRQe^RhbRYQR]R",
nodeNames:"⚠ JsonText True False Null Number String } { Object Property PropertyName ] [ Array",
maxTerm:25,
nodeProps:[["isolate",-2,6,11,""],["openedBy",7,"{",12,"["],["closedBy",8,"}",13,"]"]],
propSources:[bOe],skippedNodes:[0],repeatNodeCount:2,
tokenData:"(|~RaXY!WYZ!W]^!Wpq!Wrs!]|}$u}!O$z!Q!R%T!R![&c![!]&t!}#O&y#P#Q'O#Y#Z'T#b#c'r#h#i(Z#o#p(r#q#r(w~!]Oc~~!`Wpq!]qr!]rs!xs#O!]#O#P!}#P;'S!];'S;=`$o<%lO!]~!}Oe~~#QXrs!]!P!Q!]#O#P!]#U#V!]#Y#Z!]#b#c!]#f#g!]#h#i!]#i#j#m~#pR!Q![#y!c!i#y#T#Z#y~#|R!Q![$V!c!i$V#T#Z$V~$YR!Q![$c!c!i$c#T#Z$c~$fR!Q![!]!c!i!]#T#Z!]~$rP;=`<%l!]~$zOh~~$}Q!Q!R%T!R![&c~%YRT~!O!P%c!g!h%w#X#Y%w~%fP!Q![%i~%nRT~!Q![%i!g!h%w#X#Y%w~%zR{|&T}!O&T!Q![&Z~&WP!Q![&Z~&`PT~!Q![&Z~&hST~!O!P%c!Q![&c!g!h%w#X#Y%w~&yOg~~'OO]~~'TO[~~'WP#T#U'Z~'^P#`#a'a~'dP#g#h'g~'jP#X#Y'm~'rOR~~'uP#i#j'x~'{P#`#a(O~(RP#`#a(U~(ZOS~~(^P#f#g(a~(dP#i#j(g~(jP#X#Y(m~(rOQ~~(wOW~~(|OV~",
tokenizers:[0],topRules:{JsonText:[0,1]},tokenPrec:0}),OOe=Ghe.define({
name:"json",parser:yOe.configure({props:[ffe.add({Object:xfe({except:/^\s*\}/}),
Array:xfe({except:/^\s*\]/})}),_fe.add({"Object Array":Tfe})]}),languageData:{
closeBrackets:{brackets:["[","{",'"']},indentOnInput:/^\s*[\}\]]$/}})
;function wOe(e){
return 45==e||46==e||58==e||e>=65&&e<=90||95==e||e>=97&&e<=122||e>=161}
let xOe=null,kOe=null,SOe=0;function _Oe(e,t){let n=e.pos+t
;if(kOe==e&&SOe==n)return xOe;for(;9==(r=e.peek(t))||10==r||13==r||32==r;)t++
;var r;let o="";for(;;){let n=e.peek(t);if(!wOe(n))break
;o+=String.fromCharCode(n),t++}return kOe=e,SOe=n,xOe=o||null}function TOe(e,t){
this.name=e,this.parent=t,this.hash=t?t.hash:0
;for(let n=0;n<e.length;n++)this.hash+=(this.hash<<4)+e.charCodeAt(n)+(e.charCodeAt(n)<<8)
}const EOe=new Jve({start:null,shift:(e,t,n,r)=>1==t?new TOe(_Oe(r,1)||"",e):e,
reduce:(e,t)=>11==t&&e?e.parent:e,reuse(e,t,n,r){let o=t.type.id
;return 1==o||13==o?new TOe(_Oe(r,1)||"",e):e},hash:e=>e?e.hash:0,strict:!1
}),AOe=new Uve(((e,t)=>{if(60==e.next)if(e.advance(),47==e.next){e.advance()
;let n=_Oe(e,0);if(!n)return e.acceptToken(5)
;if(t.context&&n==t.context.name)return e.acceptToken(2)
;for(let r=t.context;r;r=r.parent)if(r.name==n)return e.acceptToken(3,-2)
;e.acceptToken(4)}else if(33!=e.next&&63!=e.next)return e.acceptToken(1)}),{
contextual:!0});function COe(e,t){return new Uve((n=>{let r=0,o=t.charCodeAt(0)
;e:for(;!(n.next<0);n.advance(),r++)if(n.next==o){
for(let e=1;e<t.length;e++)if(n.peek(e)!=t.charCodeAt(e))continue e;break}
r&&n.acceptToken(e)}))}
const $Oe=COe(35,"--\x3e"),POe=COe(36,"?>"),DOe=COe(37,"]]>"),IOe=xhe({
Text:Zhe.content,
"StartTag StartCloseTag EndTag SelfCloseEndTag":Zhe.angleBracket,
TagName:Zhe.tagName,"MismatchedCloseTag/TagName":[Zhe.tagName,Zhe.invalid],
AttributeName:Zhe.attributeName,AttributeValue:Zhe.attributeValue,
Is:Zhe.definitionOperator,"EntityReference CharacterReference":Zhe.character,
Comment:Zhe.blockComment,ProcessingInst:Zhe.processingInstruction,
DoctypeDecl:Zhe.documentMeta,Cdata:Zhe.special(Zhe.string)
}),MOe=ebe.deserialize({version:14,
states:",SOQOaOOOrOxO'#CfOzOpO'#CiO!tOaO'#CgOOOP'#Cg'#CgO!{OrO'#CrO#TOtO'#CsO#]OpO'#CtOOOP'#DS'#DSOOOP'#Cv'#CvQQOaOOOOOW'#Cw'#CwO#eOxO,59QOOOP,59Q,59QOOOO'#Cx'#CxO#mOpO,59TO#uO!bO,59TOOOP'#C{'#C{O$TOaO,59RO$[OpO'#CoOOOP,59R,59ROOOQ'#C|'#C|O$dOrO,59^OOOP,59^,59^OOOS'#C}'#C}O$lOtO,59_OOOP,59_,59_O$tOpO,59`O$|OpO,59`OOOP-E6t-E6tOOOW-E6u-E6uOOOP1G.l1G.lOOOO-E6v-E6vO%UO!bO1G.oO%UO!bO1G.oO%dOpO'#CkO%lO!bO'#CyO%zO!bO1G.oOOOP1G.o1G.oOOOP1G.w1G.wOOOP-E6y-E6yOOOP1G.m1G.mO&VOpO,59ZO&_OpO,59ZOOOQ-E6z-E6zOOOP1G.x1G.xOOOS-E6{-E6{OOOP1G.y1G.yO&gOpO1G.zO&gOpO1G.zOOOP1G.z1G.zO&oO!bO7+$ZO&}O!bO7+$ZOOOP7+$Z7+$ZOOOP7+$c7+$cO'YOpO,59VO'bOpO,59VO'jO!bO,59eOOOO-E6w-E6wO'xOpO1G.uO'xOpO1G.uOOOP1G.u1G.uO(QOpO7+$fOOOP7+$f7+$fO(YO!bO<<GuOOOP<<Gu<<GuOOOP<<G}<<G}O'bOpO1G.qO'bOpO1G.qO(eO#tO'#CnOOOO1G.q1G.qO(sOpO7+$aOOOP7+$a7+$aOOOP<<HQ<<HQOOOPAN=aAN=aOOOPAN=iAN=iO'bOpO7+$]OOOO7+$]7+$]OOOO'#Cz'#CzO({O#tO,59YOOOO,59Y,59YOOOP<<G{<<G{OOOO<<Gw<<GwOOOO-E6x-E6xOOOO1G.t1G.t",
stateData:")Z~OPQOSVOTWOVWOWWOXWOiXOxPO}TO!PUO~OuZOw]O~O^`Oy^O~OPQOQcOSVOTWOVWOWWOXWOxPO}TO!PUO~ORdO~P!SOseO|gO~OthO!OjO~O^lOy^O~OuZOwoO~O^qOy^O~O[vO`sOdwOy^O~ORyO~P!SO^{Oy^O~OseO|}O~OthO!O!PO~O^!QOy^O~O[!SOy^O~O[!VO`sOd!WOy^O~Oa!YOy^O~Oy^O[mX`mXdmX~O[!VO`sOd!WO~O^!]Oy^O~O[!_Oy^O~O[!aOy^O~O[!cO`sOd!dOy^O~O[!cO`sOd!dO~Oa!eOy^O~Oy^Oz!gO~Oy^O[ma`madma~O[!jOy^O~O[!kOy^O~O[!lO`sOd!mO~OW!pOX!pOz!rO{!pO~O[!sOy^O~OW!pOX!pOz!vO{!pO~O",
goto:"%[wPPPPPPPPPPxxP!OP!UPP!_!iP!oxxxP!u!{#R$Z$j$p$v$|PPPP%SXWORYbXRORYb_t`qru!T!U!bQ!h!YS!o!e!fR!t!nQdRRybXSORYbQYORmYQ[PRn[Q_QQkVjp_krz!R!T!X!Z!^!`!f!i!nQr`QzcQ!RlQ!TqQ!XsQ!ZtQ!^{Q!`!QQ!f!YQ!i!]R!n!eQu`S!UqrU![u!U!bR!b!TQ!q!gR!u!qQbRRxbQfTR|fQiUR!OiSXOYTaRb",
nodeNames:"⚠ StartTag StartCloseTag MissingCloseTag StartCloseTag StartCloseTag Document Text EntityReference CharacterReference Cdata Element EndTag OpenTag TagName Attribute AttributeName Is AttributeValue CloseTag SelfCloseEndTag SelfClosingTag Comment ProcessingInst MismatchedCloseTag DoctypeDecl",
maxTerm:47,context:EOe,
nodeProps:[["closedBy",1,"SelfCloseEndTag EndTag",13,"CloseTag MissingCloseTag"],["openedBy",12,"StartTag StartCloseTag",19,"OpenTag",20,"StartTag"],["isolate",-6,13,18,19,21,22,24,""]],
propSources:[IOe],skippedNodes:[0],repeatNodeCount:8,
tokenData:"Jy~R!XOX$nXY&kYZ&kZ]$n]^&k^p$npq&kqr$nrs'ssv$nvw(Zw}$n}!O,^!O!P$n!P!Q.m!Q![$n![!]0V!]!^$n!^!_3h!_!`El!`!aF_!a!bGQ!b!c$n!c!}0V!}#P$n#P#QHj#Q#R$n#R#S0V#S#T$n#T#o0V#o%W$n%W%o0V%o%p$n%p&a0V&a&b$n&b1p0V1p4U$n4U4d0V4d4e$n4e$IS0V$IS$I`$n$I`$Ib0V$Ib$Kh$n$Kh%#t0V%#t&/x$n&/x&Et0V&Et&FV$n&FV;'S0V;'S;:j3b;:j;=`&e<%l?&r$n?&r?Ah0V?Ah?BY$n?BY?Mn0V?MnO$nX$uWVP{WOr$nrs%_sv$nw!^$n!^!_%y!_;'S$n;'S;=`&e<%lO$nP%dTVPOv%_w!^%_!_;'S%_;'S;=`%s<%lO%_P%vP;=`<%l%_W&OT{WOr%ysv%yw;'S%y;'S;=`&_<%lO%yW&bP;=`<%l%yX&hP;=`<%l$n_&t_VP{WyUOX$nXY&kYZ&kZ]$n]^&k^p$npq&kqr$nrs%_sv$nw!^$n!^!_%y!_;'S$n;'S;=`&e<%lO$nZ'zTzYVPOv%_w!^%_!_;'S%_;'S;=`%s<%lO%_~(^ast)c![!]*g!c!}*g#R#S*g#T#o*g%W%o*g%p&a*g&b1p*g4U4d*g4e$IS*g$I`$Ib*g$Kh%#t*g&/x&Et*g&FV;'S*g;'S;:j,W?&r?Ah*g?BY?Mn*g~)fQ!Q![)l#l#m)z~)oQ!Q![)l!]!^)u~)zOX~~)}R!Q![*W!c!i*W#T#Z*W~*ZS!Q![*W!]!^)u!c!i*W#T#Z*W~*jg}!O*g!O!P*g!Q![*g![!]*g!]!^,R!c!}*g#R#S*g#T#o*g$}%O*g%W%o*g%p&a*g&b1p*g1p4U*g4U4d*g4e$IS*g$I`$Ib*g$Je$Jg*g$Kh%#t*g&/x&Et*g&FV;'S*g;'S;:j,W?&r?Ah*g?BY?Mn*g~,WOW~~,ZP;=`<%l*gZ,eYVP{WOr$nrs%_sv$nw}$n}!O-T!O!^$n!^!_%y!_;'S$n;'S;=`&e<%lO$nZ-[YVP{WOr$nrs%_sv$nw!^$n!^!_%y!_!`$n!`!a-z!a;'S$n;'S;=`&e<%lO$nZ.TW|QVP{WOr$nrs%_sv$nw!^$n!^!_%y!_;'S$n;'S;=`&e<%lO$n].tYVP{WOr$nrs%_sv$nw!^$n!^!_%y!_!`$n!`!a/d!a;'S$n;'S;=`&e<%lO$n]/mWdSVP{WOr$nrs%_sv$nw!^$n!^!_%y!_;'S$n;'S;=`&e<%lO$n_0b!O`S^QVP{WOr$nrs%_sv$nw}$n}!O0V!O!P0V!P!Q$n!Q![0V![!]0V!]!^$n!^!_%y!_!c$n!c!}0V!}#R$n#R#S0V#S#T$n#T#o0V#o$}$n$}%O0V%O%W$n%W%o0V%o%p$n%p&a0V&a&b$n&b1p0V1p4U0V4U4d0V4d4e$n4e$IS0V$IS$I`$n$I`$Ib0V$Ib$Je$n$Je$Jg0V$Jg$Kh$n$Kh%#t0V%#t&/x$n&/x&Et0V&Et&FV$n&FV;'S0V;'S;:j3b;:j;=`&e<%l?&r$n?&r?Ah0V?Ah?BY$n?BY?Mn0V?MnO$n_3eP;=`<%l0VX3mW{WOq%yqr4Vsv%yw!a%y!a!bEU!b;'S%y;'S;=`&_<%lO%yX4[]{WOr%ysv%yw}%y}!O5T!O!f%y!f!g6V!g!}%y!}#O;f#O#W%y#W#XAr#X;'S%y;'S;=`&_<%lO%yX5YV{WOr%ysv%yw}%y}!O5o!O;'S%y;'S;=`&_<%lO%yX5vT}P{WOr%ysv%yw;'S%y;'S;=`&_<%lO%yX6[V{WOr%ysv%yw!q%y!q!r6q!r;'S%y;'S;=`&_<%lO%yX6vV{WOr%ysv%yw!e%y!e!f7]!f;'S%y;'S;=`&_<%lO%yX7bV{WOr%ysv%yw!v%y!v!w7w!w;'S%y;'S;=`&_<%lO%yX7|V{WOr%ysv%yw!{%y!{!|8c!|;'S%y;'S;=`&_<%lO%yX8hV{WOr%ysv%yw!r%y!r!s8}!s;'S%y;'S;=`&_<%lO%yX9SV{WOr%ysv%yw!g%y!g!h9i!h;'S%y;'S;=`&_<%lO%yX9nX{WOr9irs:Zsv9ivw:Zw!`9i!`!a:x!a;'S9i;'S;=`;`<%lO9iP:^TO!`:Z!`!a:m!a;'S:Z;'S;=`:r<%lO:ZP:rOiPP:uP;=`<%l:ZX;PTiP{WOr%ysv%yw;'S%y;'S;=`&_<%lO%yX;cP;=`<%l9iX;kX{WOr%ysv%yw!e%y!e!f<W!f#V%y#V#W?f#W;'S%y;'S;=`&_<%lO%yX<]V{WOr%ysv%yw!f%y!f!g<r!g;'S%y;'S;=`&_<%lO%yX<wV{WOr%ysv%yw!c%y!c!d=^!d;'S%y;'S;=`&_<%lO%yX=cV{WOr%ysv%yw!v%y!v!w=x!w;'S%y;'S;=`&_<%lO%yX=}V{WOr%ysv%yw!c%y!c!d>d!d;'S%y;'S;=`&_<%lO%yX>iV{WOr%ysv%yw!}%y!}#O?O#O;'S%y;'S;=`&_<%lO%yX?VT{WxPOr%ysv%yw;'S%y;'S;=`&_<%lO%yX?kV{WOr%ysv%yw#W%y#W#X@Q#X;'S%y;'S;=`&_<%lO%yX@VV{WOr%ysv%yw#T%y#T#U@l#U;'S%y;'S;=`&_<%lO%yX@qV{WOr%ysv%yw#h%y#h#iAW#i;'S%y;'S;=`&_<%lO%yXA]V{WOr%ysv%yw#T%y#T#U>d#U;'S%y;'S;=`&_<%lO%yXAwV{WOr%ysv%yw#c%y#c#dB^#d;'S%y;'S;=`&_<%lO%yXBcV{WOr%ysv%yw#V%y#V#WBx#W;'S%y;'S;=`&_<%lO%yXB}V{WOr%ysv%yw#h%y#h#iCd#i;'S%y;'S;=`&_<%lO%yXCiV{WOr%ysv%yw#m%y#m#nDO#n;'S%y;'S;=`&_<%lO%yXDTV{WOr%ysv%yw#d%y#d#eDj#e;'S%y;'S;=`&_<%lO%yXDoV{WOr%ysv%yw#X%y#X#Y9i#Y;'S%y;'S;=`&_<%lO%yXE]T!PP{WOr%ysv%yw;'S%y;'S;=`&_<%lO%yZEuWaQVP{WOr$nrs%_sv$nw!^$n!^!_%y!_;'S$n;'S;=`&e<%lO$n_FhW[UVP{WOr$nrs%_sv$nw!^$n!^!_%y!_;'S$n;'S;=`&e<%lO$nZGXYVP{WOr$nrs%_sv$nw!^$n!^!_%y!_!`$n!`!aGw!a;'S$n;'S;=`&e<%lO$nZHQW!OQVP{WOr$nrs%_sv$nw!^$n!^!_%y!_;'S$n;'S;=`&e<%lO$nZHqYVP{WOr$nrs%_sv$nw!^$n!^!_%y!_#P$n#P#QIa#Q;'S$n;'S;=`&e<%lO$nZIhYVP{WOr$nrs%_sv$nw!^$n!^!_%y!_!`$n!`!aJW!a;'S$n;'S;=`&e<%lO$nZJaWwQVP{WOr$nrs%_sv$nw!^$n!^!_%y!_;'S$n;'S;=`&e<%lO$n",
tokenizers:[AOe,$Oe,POe,DOe,0,1,2,3],topRules:{Document:[0,6]},tokenPrec:0})
;function NOe(e,t){let n=t&&t.getChild("TagName")
;return n?e.sliceString(n.from,n.to):""}function ROe(e,t){let n=t&&t.firstChild
;return n&&"OpenTag"==n.name?NOe(e,n):""}function LOe(e){
for(let t=e&&e.parent;t;t=t.parent)if("Element"==t.name)return t;return null}
let BOe=class{constructor(e,t,n){
this.attrs=t,this.attrValues=n,this.children=[],
this.name=e.name,this.completion=Object.assign(Object.assign({type:"type"
},e.completion||{}),{label:this.name
}),this.openCompletion=Object.assign(Object.assign({},this.completion),{
label:"<"+this.name
}),this.closeCompletion=Object.assign(Object.assign({},this.completion),{
label:"</"+this.name+">",boost:2
}),this.closeNameCompletion=Object.assign(Object.assign({},this.completion),{
label:this.name+">"}),this.text=e.textContent?e.textContent.map((e=>({label:e,
type:"text"}))):[]}};const jOe=/^[:\-\.\w\u00b7-\uffff]*$/;function UOe(e){
return Object.assign(Object.assign({type:"property"},e.completion||{}),{
label:e.name})}function zOe(e){return"string"==typeof e?{label:`"${e}"`,
type:"constant"}:/^"/.test(e.label)?e:Object.assign(Object.assign({},e),{
label:`"${e.label}"`})}function FOe(e,t){let n=[],r=[],o=Object.create(null)
;for(let l of t){let e=UOe(l)
;n.push(e),l.global&&r.push(e),l.values&&(o[l.name]=l.values.map(zOe))}
let a=[],i=[],s=Object.create(null);for(let l of e){let e=r,t=o
;l.attributes&&(e=e.concat(l.attributes.map((e=>"string"==typeof e?n.find((t=>t.label==e))||{
label:e,type:"property"
}:(e.values&&(t==o&&(t=Object.create(t)),t[e.name]=e.values.map(zOe)),
UOe(e))))));let c=new BOe(l,e,t);s[c.name]=c,a.push(c),l.top&&i.push(c)}
i.length||(i=a);for(let l=0;l<a.length;l++){let t=e[l],n=a[l]
;if(t.children)for(let e of t.children)s[e]&&n.children.push(s[e]);else n.children=a
}return e=>{var t;let{doc:n}=e.state,l=function(e,t){var n
;let r=Yhe(e).resolveInner(t,-1),o=null
;for(let a=r;!o&&a.parent;a=a.parent)"OpenTag"!=a.name&&"CloseTag"!=a.name&&"SelfClosingTag"!=a.name&&"MismatchedCloseTag"!=a.name||(o=a)
;if(o&&(o.to>t||o.lastChild.type.isError)){let e=o.parent
;if("TagName"==r.name)return"CloseTag"==o.name||"MismatchedCloseTag"==o.name?{
type:"closeTag",from:r.from,context:e}:{type:"openTag",from:r.from,
context:LOe(e)};if("AttributeName"==r.name)return{type:"attrName",from:r.from,
context:o};if("AttributeValue"==r.name)return{type:"attrValue",from:r.from,
context:o};let n=r==o||"Attribute"==r.name?r.childBefore(t):r
;return"StartTag"==(null==n?void 0:n.name)?{type:"openTag",from:t,context:LOe(e)
}:"StartCloseTag"==(null==n?void 0:n.name)&&n.to<=t?{type:"closeTag",from:t,
context:e}:"Is"==(null==n?void 0:n.name)?{type:"attrValue",from:t,context:o}:n?{
type:"attrName",from:t,context:o}:null}if("StartCloseTag"==r.name)return{
type:"closeTag",from:t,context:r.parent}
;for(;r.parent&&r.to==t&&!(null===(n=r.lastChild)||void 0===n?void 0:n.type.isError);)r=r.parent
;return"Element"==r.name||"Text"==r.name||"Document"==r.name?{type:"tag",from:t,
context:"Element"==r.name?r:LOe(r)}:null}(e.state,e.pos)
;if(!l||"tag"==l.type&&!e.explicit)return null;let{type:c,from:u,context:d}=l
;if("openTag"==c){let e=i,t=ROe(n,d);if(t){let n=s[t]
;e=(null==n?void 0:n.children)||a}return{from:u,
options:e.map((e=>e.completion)),validFor:jOe}}if("closeTag"==c){let r=ROe(n,d)
;return r?{from:u,to:e.pos+(">"==n.sliceString(e.pos,e.pos+1)?1:0),
options:[(null===(t=s[r])||void 0===t?void 0:t.closeNameCompletion)||{
label:r+">",type:"type"}],validFor:jOe}:null}if("attrName"==c){let e=s[NOe(n,d)]
;return{from:u,options:(null==e?void 0:e.attrs)||r,validFor:jOe}}
if("attrValue"==c){let t=function(e,t,n){
let r=t&&t.getChildren("Attribute").find((e=>e.from<=n&&e.to>=n)),o=r&&r.getChild("AttributeName")
;return o?e.sliceString(o.from,o.to):""}(n,d,u);if(!t)return null
;let r=s[NOe(n,d)],a=((null==r?void 0:r.attrValues)||o)[t];return a&&a.length?{
from:u,to:e.pos+('"'==n.sliceString(e.pos,e.pos+1)?1:0),options:a,
validFor:/^"[^"]*"?$/}:null}if("tag"==c){
let t=ROe(n,d),r=s[t],o=[],l=d&&d.lastChild
;!t||l&&"CloseTag"==l.name&&NOe(n,l)==t||o.push(r?r.closeCompletion:{
label:"</"+t+">",type:"type",boost:2})
;let c=o.concat(((null==r?void 0:r.children)||(d?a:i)).map((e=>e.openCompletion)))
;if(d&&(null==r?void 0:r.text.length)){let t=d.firstChild
;t.to>e.pos-20&&!/\S/.test(e.state.sliceDoc(t.to,e.pos))&&(c=c.concat(r.text))}
return{from:u,options:c,validFor:/^<\/?[:\-\.\w\u00b7-\uffff]*$/}}return null}}
const ZOe=Ghe.define({name:"xml",parser:MOe.configure({props:[ffe.add({
Element(e){let t=/^\s*<\//.test(e.textAfter)
;return e.lineIndent(e.node.from)+(t?0:e.unit)},
"OpenTag CloseTag SelfClosingTag":e=>e.column(e.node.from)+e.unit}),_fe.add({
Element(e){let t=e.firstChild,n=e.lastChild;return t&&"OpenTag"==t.name?{
from:t.to,to:"CloseTag"==n.name?n.from:e.to}:null}}),ime.add({
"OpenTag CloseTag":e=>e.getChild("TagName")})]}),languageData:{commentTokens:{
block:{open:"\x3c!--",close:"--\x3e"}},indentOnInput:/^\s*<\/$/}})
;function QOe(e,t,n=e.length){if(!t)return""
;let r=t.firstChild,o=r&&r.getChild("TagName")
;return o?e.sliceString(o.from,Math.min(o.to,n)):""}
const HOe=cde.inputHandler.of(((e,t,n,r,o)=>{
if(e.composing||e.state.readOnly||t!=n||">"!=r&&"/"!=r||!ZOe.isActiveAt(e.state,t,-1))return!1
;let a=o(),{state:i}=a,s=i.changeByRange((e=>{var t,n,o
;let a,{head:s}=e,l=i.doc.sliceString(s-1,s)==r,c=Yhe(i).resolveInner(s,-1)
;if(l&&">"==r&&"EndTag"==c.name){let r=c.parent
;if("CloseTag"!=(null===(n=null===(t=r.parent)||void 0===t?void 0:t.lastChild)||void 0===n?void 0:n.name)&&(a=QOe(i.doc,r.parent,s))){
return{range:e,changes:{from:s,to:s+(">"===i.doc.sliceString(s,s+1)?1:0),
insert:`</${a}>`}}}}else if(l&&"/"==r&&"StartCloseTag"==c.name){let e=c.parent
;if(c.from==s-2&&"CloseTag"!=(null===(o=e.lastChild)||void 0===o?void 0:o.name)&&(a=QOe(i.doc,e,s))){
let e=s+(">"===i.doc.sliceString(s,s+1)?1:0),t=`${a}>`;return{
range:Vae.cursor(s+t.length,-1),changes:{from:s,to:e,insert:t}}}}return{range:e}
}));return!s.changes.empty&&(e.dispatch([a,i.update(s,{
userEvent:"input.complete",scrollIntoView:!0})]),!0)})),VOe=63;class qOe{
constructor(e,t,n){
this.parent=e,this.depth=t,this.type=n,this.hash=(e?e.hash+e.hash<<8:0)+t+(t<<4)+n
}}function WOe(e,t){for(let n=0,r=t-e.pos-1;;r--,n++){let t=e.peek(r)
;if(GOe(t)||-1==t)return n}}function XOe(e){return 32==e||9==e}function GOe(e){
return 10==e||13==e}function YOe(e){return XOe(e)||GOe(e)}function KOe(e){
return e<0||YOe(e)}qOe.top=new qOe(null,-1,0);const JOe=new Jve({start:qOe.top,
reduce:(e,t)=>3!=e.type||20!=t&&34!=t?e:e.parent,shift(e,t,n,r){
if(3==t)return new qOe(e,WOe(r,r.pos),1)
;if(65==t||5==t)return new qOe(e,WOe(r,r.pos),2);if(t==VOe)return e.parent
;if(19==t||33==t)return new qOe(e,0,3);if(13==t&&4==e.type)return e.parent
;if(47==t){let t=/[1-9]/.exec(r.read(r.pos,n.pos))
;if(t)return new qOe(e,e.depth+ +t[0],4)}return e},hash:e=>e.hash})
;function ewe(e,t,n=0){
return e.peek(n)==t&&e.peek(n+1)==t&&e.peek(n+2)==t&&KOe(e.peek(n+3))}
const twe=new Uve(((e,t)=>{
if(-1==e.next&&t.canShift(64))return e.acceptToken(64);let n=e.peek(-1)
;if((GOe(n)||n<0)&&3!=t.context.type){if(ewe(e,45)){
if(!t.canShift(VOe))return e.acceptToken(1,3);e.acceptToken(VOe)}if(ewe(e,46)){
if(!t.canShift(VOe))return e.acceptToken(2,3);e.acceptToken(VOe)}let n=0
;for(;32==e.next;)n++,e.advance()
;!(n<t.context.depth)&&(n!=t.context.depth||1!=t.context.type||45==e.next&&KOe(e.peek(1)))||-1==e.next||GOe(e.next)||35==e.next||e.acceptToken(VOe,-n)
}}),{contextual:!0}),nwe=new Uve(((e,t)=>{
if(3!=t.context.type)if(45==e.next)e.advance(),
KOe(e.next)&&e.acceptToken(1==t.context.type&&t.context.depth==WOe(e,e.pos-1)?4:3);else if(63==e.next)e.advance(),
KOe(e.next)&&e.acceptToken(2==t.context.type&&t.context.depth==WOe(e,e.pos-1)?6:5);else{
let n=e.pos;for(;;)if(XOe(e.next)){if(e.pos==n)return;e.advance()
}else if(33==e.next)awe(e);else{if(38!=e.next){if(42==e.next){iwe(e);break}
if(39==e.next||34==e.next){if(swe(e,!0))break;return}
if(91==e.next||123==e.next){if(!lwe(e))return;break}pwe(e,!0,!1,0);break}iwe(e)}
for(;XOe(e.next);)e.advance();if(58==e.next){if(e.pos==n&&t.canShift(29))return
;KOe(e.peek(1))&&e.acceptTokenTo(2==t.context.type&&t.context.depth==WOe(e,n)?66:65,n)
}}else 63==e.next&&(e.advance(),KOe(e.next)&&e.acceptToken(7))}),{contextual:!0
});function rwe(e){return e>=48&&e<=57||e>=97&&e<=102||e>=65&&e<=70}
function owe(e,t){
return 37==e.next?(e.advance(),rwe(e.next)&&e.advance(),rwe(e.next)&&e.advance(),
!0):!!((n=e.next)>32&&n<127&&34!=n&&37!=n&&44!=n&&60!=n&&62!=n&&92!=n&&94!=n&&96!=n&&123!=n&&124!=n&&125!=n||t&&44==e.next)&&(e.advance(),
!0);var n}function awe(e){if(e.advance(),60==e.next){
for(e.advance();;)if(!owe(e,!0)){62==e.next&&e.advance();break}
}else for(;owe(e,!1););}function iwe(e){
for(e.advance();!KOe(e.next)&&"f"!=uwe(e.tag);)e.advance()}function swe(e,t){
let n=e.next,r=!1,o=e.pos;for(e.advance();;){let a=e.next;if(a<0)break
;if(e.advance(),a==n){if(39!=a)break;if(39!=e.next)break;e.advance()
}else if(92==a&&34==n)e.next>=0&&e.advance();else if(GOe(a)){if(t)return!1;r=!0
}else if(t&&e.pos>=o+1024)return!1}return!r}function lwe(e){
for(let t=[],n=e.pos+1024;;)if(91==e.next||123==e.next)t.push(e.next),
e.advance();else if(39==e.next||34==e.next){if(!swe(e,!0))return!1
}else if(93==e.next||125==e.next){if(t[t.length-1]!=e.next-2)return!1
;if(t.pop(),e.advance(),!t.length)return!0}else{
if(e.next<0||e.pos>n||GOe(e.next))return!1;e.advance()}}
const cwe="iiisiiissisfissssssssssssisssiiissssssssssssssssssssssssssfsfssissssssssssssssssssssssssssfif"
;function uwe(e){return e<33?"u":e>125?"s":cwe[e-33]}function dwe(e,t){
let n=uwe(e);return"u"!=n&&!(t&&"f"==n)}function pwe(e,t,n,r){
if("s"!=uwe(e.next)&&(63!=e.next&&58!=e.next&&45!=e.next||!dwe(e.peek(1),n)))return!1
;e.advance();let o=e.pos;for(;;){let a=e.next,i=0,s=r+1;for(;YOe(a);){
if(GOe(a)){if(t)return!1;s=0}else s++;a=e.peek(++i)}
if(!(a>=0&&(58==a?dwe(e.peek(i+1),n):35==a?32!=e.peek(i-1):dwe(a,n)))||!n&&s<=r||0==s&&!n&&(ewe(e,45,i)||ewe(e,46,i)))break
;if(t&&"f"==uwe(a))return!1;for(let t=i;t>=0;t--)e.advance()
;if(t&&e.pos>o+1024)return!1}return!0}const hwe=new Uve(((e,t)=>{
if(33==e.next)awe(e),e.acceptToken(12);else if(38==e.next||42==e.next){
let t=38==e.next?10:11;iwe(e),e.acceptToken(t)
}else 39==e.next||34==e.next?(swe(e,!1),
e.acceptToken(9)):pwe(e,!1,3==t.context.type,t.context.depth)&&e.acceptToken(8)
})),fwe=new Uve(((e,t)=>{let n=4==t.context.type?t.context.depth:-1,r=e.pos
;e:for(;;){let o=0,a=e.next;for(;32==a;)a=e.peek(++o)
;if(!o&&(ewe(e,45,o)||ewe(e,46,o)))break
;if(!GOe(a)&&(n<0&&(n=Math.max(t.context.depth+1,o)),o<n))break;for(;;){
if(e.next<0)break e;let t=GOe(e.next);if(e.advance(),t)continue e;r=e.pos}}
e.acceptTokenTo(13,r)})),mwe=xhe({DirectiveName:Zhe.keyword,
DirectiveContent:Zhe.attributeValue,"DirectiveEnd DocEnd":Zhe.meta,
QuotedLiteral:Zhe.string,BlockLiteralHeader:Zhe.special(Zhe.string),
BlockLiteralContent:Zhe.content,Literal:Zhe.content,
"Key/Literal Key/QuotedLiteral":Zhe.definition(Zhe.propertyName),
"Anchor Alias":Zhe.labelName,Tag:Zhe.typeName,Comment:Zhe.lineComment,
": , -":Zhe.separator,"?":Zhe.punctuation,"[ ]":Zhe.squareBracket,
"{ }":Zhe.brace}),gwe=ebe.deserialize({version:14,
states:"5lQ!ZQgOOO#PQfO'#CpO#uQfO'#DOOOQR'#Dv'#DvO$qQgO'#DRO%gQdO'#DUO%nQgO'#DUO&ROaO'#D[OOQR'#Du'#DuO&{QgO'#D^O'rQgO'#D`OOQR'#Dt'#DtO(iOqO'#DbOOQP'#Dj'#DjO(zQaO'#CmO)YQgO'#CmOOQP'#Cm'#CmQ)jQaOOQ)uQgOOQ]QgOOO*PQdO'#CrO*nQdO'#CtOOQO'#Dw'#DwO+]Q`O'#CxO+hQdO'#CwO+rQ`O'#CwOOQO'#Cv'#CvO+wQdO'#CvOOQO'#Cq'#CqO,UQ`O,59[O,^QfO,59[OOQR,59[,59[OOQO'#Cx'#CxO,eQ`O'#DPO,pQdO'#DPOOQO'#Dx'#DxO,zQdO'#DxO-XQ`O,59jO-aQfO,59jOOQR,59j,59jOOQR'#DS'#DSO-hQcO,59mO-sQgO'#DVO.TQ`O'#DVO.YQcO,59pOOQR'#DX'#DXO#|QfO'#DWO.hQcO'#DWOOQR,59v,59vO.yOWO,59vO/OOaO,59vO/WOaO,59vO/cQgO'#D_OOQR,59x,59xO0VQgO'#DaOOQR,59z,59zOOQP,59|,59|O0yOaO,59|O1ROaO,59|O1aOqO,59|OOQP-E7h-E7hO1oQgO,59XOOQP,59X,59XO2PQaO'#DeO2_QgO'#DeO2oQgO'#DkOOQP'#Dk'#DkQ)jQaOOO3PQdO'#CsOOQO,59^,59^O3kQdO'#CuOOQO,59`,59`OOQO,59c,59cO4VQdO,59cO4aQdO'#CzO4kQ`O'#CzOOQO,59b,59bOOQU,5:Q,5:QOOQR1G.v1G.vO4pQ`O1G.vOOQU-E7d-E7dO4xQdO,59kOOQO,59k,59kO5SQdO'#DQO5^Q`O'#DQOOQO,5:d,5:dOOQU,5:R,5:ROOQR1G/U1G/UO5cQ`O1G/UOOQU-E7e-E7eO5kQgO'#DhO5xQcO1G/XOOQR1G/X1G/XOOQR,59q,59qO6TQgO,59qO6eQdO'#DiO6lQgO'#DiO7PQcO1G/[OOQR1G/[1G/[OOQR,59r,59rO#|QfO,59rOOQR1G/b1G/bO7_OWO1G/bO7dOaO1G/bOOQR,59y,59yOOQR,59{,59{OOQP1G/h1G/hO7lOaO1G/hO7tOaO1G/hO8POaO1G/hOOQP1G.s1G.sO8_QgO,5:POOQP,5:P,5:POOQP,5:V,5:VOOQP-E7i-E7iOOQO,59_,59_OOQO,59a,59aOOQO1G.}1G.}OOQO,59f,59fO8oQdO,59fOOQR7+$b7+$bP,XQ`O'#DfOOQO1G/V1G/VOOQO,59l,59lO8yQdO,59lOOQR7+$p7+$pP9TQ`O'#DgOOQR'#DT'#DTOOQR,5:S,5:SOOQR-E7f-E7fOOQR7+$s7+$sOOQR1G/]1G/]O9YQgO'#DYO9jQ`O'#DYOOQR,5:T,5:TO#|QfO'#DZO9oQcO'#DZOOQR-E7g-E7gOOQR7+$v7+$vOOQR1G/^1G/^OOQR7+$|7+$|O:QOWO7+$|OOQP7+%S7+%SO:VOaO7+%SO:_OaO7+%SOOQP1G/k1G/kOOQO1G/Q1G/QOOQO1G/W1G/WOOQR,59t,59tO:jQgO,59tOOQR,59u,59uO#|QfO,59uOOQR<<Hh<<HhOOQP<<Hn<<HnO:zOaO<<HnOOQR1G/`1G/`OOQR1G/a1G/aOOQPAN>YAN>Y",
stateData:";S~O!fOS!gOS^OS~OP_OQbORSOTUOWROXROYYOZZO[XOcPOqQO!PVO!V[O!cTO~O`cO~P]OVkOWROXROYeOZfO[dOcPOmhOqQO~OboO~P!bOVtOWROXROYeOZfO[dOcPOmrOqQO~OpwO~P#WORSOTUOWROXROYYOZZO[XOcPOqQO!PVO!cTO~OSvP!avP!bvP~P#|OWROXROYeOZfO[dOcPOqQO~OmzO~P%OOm!OOUzP!azP!bzP!dzP~P#|O^!SO!b!QO!f!TO!g!RO~ORSOTUOWROXROcPOqQO!PVO!cTO~OY!UOP!QXQ!QX!V!QX!`!QXS!QX!a!QX!b!QXU!QXm!QX!d!QX~P&aO[!WOP!SXQ!SX!V!SX!`!SXS!SX!a!SX!b!SXU!SXm!SX!d!SX~P&aO^!ZO!W![O!b!YO!f!]O!g!YO~OP!_O!V[OQaX!`aX~OPaXQaX!VaX!`aX~P#|OP!bOQ!cO!V[O~OP_O!V[O~P#|OWROXROY!fOcPOqQObfXmfXofXpfX~OWROXRO[!hOcPOqQObhXmhXohXphX~ObeXmlXoeX~ObkXokX~P%OOm!kO~Om!lObnPonP~P%OOb!pOo!oO~Ob!pO~P!bOm!sOosXpsX~OosXpsX~P%OOm!uOotPptP~P%OOo!xOp!yO~Op!yO~P#WOS!|O!a#OO!b#OO~OUyX!ayX!byX!dyX~P#|Om#QO~OU#SO!a#UO!b#UO!d#RO~Om#WOUzX!azX!bzX!dzX~O]#XO~O!b#XO!g#YO~O^#ZO!b#XO!g#YO~OP!RXQ!RX!V!RX!`!RXS!RX!a!RX!b!RXU!RXm!RX!d!RX~P&aOP!TXQ!TX!V!TX!`!TXS!TX!a!TX!b!TXU!TXm!TX!d!TX~P&aO!b#^O!g#^O~O^#_O!b#^O!f#`O!g#^O~O^#_O!W#aO!b#^O!g#^O~OPaaQaa!Vaa!`aa~P#|OP#cO!V[OQ!XX!`!XX~OP!XXQ!XX!V!XX!`!XX~P#|OP_O!V[OQ!_X!`!_X~P#|OWROXROcPOqQObgXmgXogXpgX~OWROXROcPOqQObiXmiXoiXpiX~Obkaoka~P%OObnXonX~P%OOm#kO~Ob#lOo!oO~Oosapsa~P%OOotXptX~P%OOm#pO~Oo!xOp#qO~OSwP!awP!bwP~P#|OS!|O!a#vO!b#vO~OUya!aya!bya!dya~P#|Om#xO~P%OOm#{OU}P!a}P!b}P!d}P~P#|OU#SO!a$OO!b$OO!d#RO~O]$QO~O!b$QO!g$RO~O!b$SO!g$SO~O^$TO!b$SO!g$SO~O^$TO!b$SO!f$UO!g$SO~OP!XaQ!Xa!V!Xa!`!Xa~P#|Obnaona~P%OOotapta~P%OOo!xO~OU|X!a|X!b|X!d|X~P#|Om$ZO~Om$]OU}X!a}X!b}X!d}X~O]$^O~O!b$_O!g$_O~O^$`O!b$_O!g$_O~OU|a!a|a!b|a!d|a~P#|O!b$cO!g$cO~O",
goto:",]!mPPPPPPPPPPPPPPPPP!nPP!v#v#|$`#|$c$f$j$nP%VPPP!v%Y%^%a%{&O%a&R&U&X&_&b%aP&e&{&e'O'RPP']'a'g'm's'y(XPPPPPPPP(_)e*X+c,VUaObcR#e!c!{ROPQSTUXY_bcdehknrtvz!O!U!W!_!b!c!f!h!k!l!s!u!|#Q#R#S#W#c#k#p#x#{$Z$]QmPR!qnqfPQThknrtv!k!l!s!u#R#k#pR!gdR!ieTlPnTjPnSiPnSqQvQ{TQ!mkQ!trQ!vtR#y#RR!nkTsQvR!wt!RWOSUXY_bcz!O!U!W!_!b!c!|#Q#S#W#c#x#{$Z$]RySR#t!|R|TR|UQ!PUR#|#SR#z#RR#z#SyZOSU_bcz!O!_!b!c!|#Q#S#W#c#x#{$Z$]R!VXR!XYa]O^abc!a!c!eT!da!eQnPR!rnQvQR!{vQ!}yR#u!}Q#T|R#}#TW^Obc!cS!^^!aT!aa!eQ!eaR#f!eW`Obc!cQxSS}U#SQ!`_Q#PzQ#V!OQ#b!_Q#d!bQ#s!|Q#w#QQ$P#WQ$V#cQ$Y#xQ$[#{Q$a$ZR$b$]xZOSU_bcz!O!_!b!c!|#Q#S#W#c#x#{$Z$]Q!VXQ!XYQ#[!UR#]!W!QWOSUXY_bcz!O!U!W!_!b!c!|#Q#S#W#c#x#{$Z$]pfPQThknrtv!k!l!s!u#R#k#pQ!gdQ!ieQ#g!fR#h!hSgPn^pQTkrtv#RQ!jhQ#i!kQ#j!lQ#n!sQ#o!uQ$W#kR$X#pQuQR!zv",
nodeNames:"⚠ DirectiveEnd DocEnd - - ? ? ? Literal QuotedLiteral Anchor Alias Tag BlockLiteralContent Comment Stream BOM Document ] [ FlowSequence Item Tagged Anchored Anchored Tagged FlowMapping Pair Key : Pair , } { FlowMapping Pair Pair BlockSequence Item Item BlockMapping Pair Pair Key Pair Pair BlockLiteral BlockLiteralHeader Tagged Anchored Anchored Tagged Directive DirectiveName DirectiveContent Document",
maxTerm:74,context:JOe,
nodeProps:[["isolate",-3,8,9,14,""],["openedBy",18,"[",32,"{"],["closedBy",19,"]",33,"}"]],
propSources:[mwe],skippedNodes:[0],repeatNodeCount:6,
tokenData:"-Y~RnOX#PXY$QYZ$]Z]#P]^$]^p#Ppq$Qqs#Pst$btu#Puv$yv|#P|}&e}![#P![!]'O!]!`#P!`!a'i!a!}#P!}#O*g#O#P#P#P#Q+Q#Q#o#P#o#p+k#p#q'i#q#r,U#r;'S#P;'S;=`#z<%l?HT#P?HT?HU,o?HUO#PQ#UU!WQOY#PZp#Ppq#hq;'S#P;'S;=`#z<%lO#PQ#kTOY#PZs#Pt;'S#P;'S;=`#z<%lO#PQ#}P;=`<%l#P~$VQ!f~XY$Qpq$Q~$bO!g~~$gS^~OY$bZ;'S$b;'S;=`$s<%lO$b~$vP;=`<%l$bR%OX!WQOX%kXY#PZ]%k]^#P^p%kpq#hq;'S%k;'S;=`&_<%lO%kR%rX!WQ!VPOX%kXY#PZ]%k]^#P^p%kpq#hq;'S%k;'S;=`&_<%lO%kR&bP;=`<%l%kR&lUoP!WQOY#PZp#Ppq#hq;'S#P;'S;=`#z<%lO#PR'VUmP!WQOY#PZp#Ppq#hq;'S#P;'S;=`#z<%lO#PR'p[!PP!WQOY#PZp#Ppq#hq{#P{|(f|}#P}!O(f!O!R#P!R![)p![;'S#P;'S;=`#z<%lO#PR(mW!PP!WQOY#PZp#Ppq#hq!R#P!R![)V![;'S#P;'S;=`#z<%lO#PR)^U!PP!WQOY#PZp#Ppq#hq;'S#P;'S;=`#z<%lO#PR)wY!PP!WQOY#PZp#Ppq#hq{#P{|)V|}#P}!O)V!O;'S#P;'S;=`#z<%lO#PR*nUcP!WQOY#PZp#Ppq#hq;'S#P;'S;=`#z<%lO#PR+XUbP!WQOY#PZp#Ppq#hq;'S#P;'S;=`#z<%lO#PR+rUqP!WQOY#PZp#Ppq#hq;'S#P;'S;=`#z<%lO#PR,]UpP!WQOY#PZp#Ppq#hq;'S#P;'S;=`#z<%lO#PR,vU`P!WQOY#PZp#Ppq#hq;'S#P;'S;=`#z<%lO#P",
tokenizers:[twe,nwe,hwe,fwe,0,1],topRules:{Stream:[0,15]},tokenPrec:0
}),vwe=Ghe.define({name:"yaml",parser:gwe.configure({props:[ffe.add({Stream:e=>{
for(let t=e.node.resolve(e.pos,-1);t&&t.to>=e.pos;t=t.parent){
if("BlockLiteralContent"==t.name&&t.from<t.to)return e.baseIndentFor(t)
;if("BlockLiteral"==t.name)return e.baseIndentFor(t)+e.unit
;if("BlockSequence"==t.name||"BlockMapping"==t.name)return e.column(t.from,1)
;if("QuotedLiteral"==t.name)return null;if("Literal"==t.name){
let n=e.column(t.from,1);if(n==e.lineIndent(t.from,1))return n
;if(t.to>e.pos)return null}}return null},FlowMapping:Ofe({closing:"}"}),
FlowSequence:Ofe({closing:"]"})}),_fe.add({"FlowMapping FlowSequence":Tfe,
"Item Pair BlockLiteral":(e,t)=>({from:t.doc.lineAt(e.from).to,to:e.to})})]}),
languageData:{commentTokens:{line:"#"},indentOnInput:/^\s*[\]\}]$/}})
;function bwe(){var e=arguments[0]
;"string"==typeof e&&(e=document.createElement(e));var t=1,n=arguments[1]
;if(n&&"object"==typeof n&&null==n.nodeType&&!Array.isArray(n)){
for(var r in n)if(Object.prototype.hasOwnProperty.call(n,r)){var o=n[r]
;"string"==typeof o?e.setAttribute(r,o):null!=o&&(e[r]=o)}t++}
for(;t<arguments.length;t++)ywe(e,arguments[t]);return e}function ywe(e,t){
if("string"==typeof t)e.appendChild(document.createTextNode(t));else if(null==t);else if(null!=t.nodeType)e.appendChild(t);else{
if(!Array.isArray(t))throw new RangeError("Unsupported child node: "+t)
;for(var n=0;n<t.length;n++)ywe(e,t[n])}}class Owe{constructor(e,t,n){
this.from=e,this.to=t,this.diagnostic=n}}class wwe{constructor(e,t,n){
this.diagnostics=e,this.panel=t,this.selected=n}static init(e,t,n){
let r=e,o=n.facet(Iwe).markerFilter;o&&(r=o(r,n))
;let a=e.slice().sort(((e,t)=>e.from-t.from||e.to-t.to)),i=new Qie,s=[],l=0
;for(let u=0;;){let e,t,r=u==a.length?null:a[u];if(!r&&!s.length)break
;for(s.length?(e=l,
t=s.reduce(((e,t)=>Math.min(e,t.to)),r&&r.from>e?r.from:1e8)):(e=r.from,
t=r.to,s.push(r),u++);u<a.length;){let n=a[u]
;if(n.from!=e||!(n.to>n.from||n.to==e)){t=Math.min(n.from,t);break}
s.push(n),u++,t=Math.min(n.to,t)}let o=Fwe(s)
;if(s.some((e=>e.from==e.to||e.from==e.to-1&&n.doc.lineAt(e.from).to==e.from)))i.add(e,e,mle.widget({
widget:new Rwe(o),diagnostics:s.slice()}));else{
let n=s.reduce(((e,t)=>t.markClass?e+" "+t.markClass:e),"");i.add(e,t,mle.mark({
class:"cm-lintRange cm-lintRange-"+o+n,diagnostics:s.slice(),
inclusiveEnd:s.some((e=>e.to>t))}))}l=t
;for(let n=0;n<s.length;n++)s[n].to<=l&&s.splice(n--,1)}let c=i.finish()
;return new wwe(c,t,xwe(c))}}function xwe(e,t=null,n=0){let r=null
;return e.between(n,1e9,((e,n,{spec:o})=>{
if(!(t&&o.diagnostics.indexOf(t)<0))if(r){
if(o.diagnostics.indexOf(r.diagnostic)<0)return!1
;r=new Owe(r.from,n,r.diagnostic)}else r=new Owe(e,n,t||o.diagnostics[0])})),r}
function kwe(e,t){return e.field(Ewe,!1)?t:t.concat(_ie.appendConfig.of(Zwe))}
const Swe=_ie.define(),_we=_ie.define(),Twe=_ie.define(),Ewe=nie.define({
create:()=>new wwe(mle.none,null,null),update(e,t){
if(t.docChanged&&e.diagnostics.size){
let n=e.diagnostics.map(t.changes),r=null,o=e.panel;if(e.selected){
let o=t.changes.mapPos(e.selected.from,1)
;r=xwe(n,e.selected.diagnostic,o)||xwe(n,null,o)}
!n.size&&o&&t.state.facet(Iwe).autoPanel&&(o=null),e=new wwe(n,o,r)}
for(let n of t.effects)if(n.is(Swe)){
let r=t.state.facet(Iwe).autoPanel?n.value.length?Bwe.open:null:e.panel
;e=wwe.init(n.value,r,t.state)
}else n.is(_we)?e=new wwe(e.diagnostics,n.value?Bwe.open:null,e.selected):n.is(Twe)&&(e=new wwe(e.diagnostics,e.panel,n.value))
;return e},
provide:e=>[rpe.from(e,(e=>e.panel)),cde.decorations.from(e,(e=>e.diagnostics))]
}),Awe=mle.mark({class:"cm-lintRange cm-lintRange-active"});function Cwe(e,t,n){
let r,{diagnostics:o}=e.state.field(Ewe),a=-1,i=-1
;o.between(t-(n<0?1:0),t+(n>0?1:0),((e,o,{spec:s})=>{
if(t>=e&&t<=o&&(e==o||(t>e||n>0)&&(t<o||n<0)))return r=s.diagnostics,a=e,i=o,!1
}));let s=e.state.facet(Iwe).tooltipFilter;return r&&s&&(r=s(r,e.state)),r?{
pos:a,end:i,above:e.state.doc.lineAt(a).to<i,create:()=>({dom:$we(e,r)})}:null}
function $we(e,t){return bwe("ul",{class:"cm-tooltip-lint"
},t.map((t=>Nwe(e,t,!1))))}const Pwe=e=>{let t=e.state.field(Ewe,!1)
;return!(!t||!t.panel)&&(e.dispatch({effects:_we.of(!1)}),!0)
},Dwe=dce.fromClass(class{constructor(e){this.view=e,this.timeout=-1,this.set=!0
;let{delay:t}=e.state.facet(Iwe)
;this.lintTime=Date.now()+t,this.run=this.run.bind(this),
this.timeout=setTimeout(this.run,t)}run(){clearTimeout(this.timeout)
;let e=Date.now()
;if(e<this.lintTime-10)this.timeout=setTimeout(this.run,this.lintTime-e);else{
this.set=!1;let{state:e}=this.view,{sources:t}=e.facet(Iwe)
;t.length&&function(e,t,n){let r=[],o=-1;for(let a of e)a.then((n=>{
r.push(n),clearTimeout(o),r.length==e.length?t(r):o=setTimeout((()=>t(r)),200)
}),n)}(t.map((e=>Promise.resolve(e(this.view)))),(t=>{
this.view.state.doc==e.doc&&this.view.dispatch(function(e,t){return{
effects:kwe(e,[Swe.of(t)])}}(this.view.state,t.reduce(((e,t)=>e.concat(t)))))
}),(e=>{sce(this.view.state,e)}))}}update(e){let t=e.state.facet(Iwe)
;(e.docChanged||t!=e.startState.facet(Iwe)||t.needsRefresh&&t.needsRefresh(e))&&(this.lintTime=Date.now()+t.delay,
this.set||(this.set=!0,this.timeout=setTimeout(this.run,t.delay)))}force(){
this.set&&(this.lintTime=Date.now(),this.run())}destroy(){
clearTimeout(this.timeout)}});const Iwe=Xae.define({combine:e=>Object.assign({
sources:e.map((e=>e.source)).filter((e=>null!=e))},Bie(e.map((e=>e.config)),{
delay:750,markerFilter:null,tooltipFilter:null,needsRefresh:null,hideOn:()=>null
},{needsRefresh:(e,t)=>e?t?n=>e(n)||t(n):e:t}))});function Mwe(e){let t=[]
;if(e)e:for(let{name:n}of e){for(let e=0;e<n.length;e++){let r=n[e]
;if(/[a-zA-Z]/.test(r)&&!t.some((e=>e.toLowerCase()==r.toLowerCase()))){
t.push(r);continue e}}t.push("")}return t}function Nwe(e,t,n){var r
;let o=n?Mwe(t.actions):[];return bwe("li",{
class:"cm-diagnostic cm-diagnostic-"+t.severity},bwe("span",{
class:"cm-diagnosticText"
},t.renderMessage?t.renderMessage(e):t.message),null===(r=t.actions)||void 0===r?void 0:r.map(((n,r)=>{
let a=!1,i=r=>{if(r.preventDefault(),a)return;a=!0
;let o=xwe(e.state.field(Ewe).diagnostics,t);o&&n.apply(e,o.from,o.to)
},{name:s}=n,l=o[r]?s.indexOf(o[r]):-1,c=l<0?s:[s.slice(0,l),bwe("u",s.slice(l,l+1)),s.slice(l+1)]
;return bwe("button",{type:"button",class:"cm-diagnosticAction",onclick:i,
onmousedown:i,"aria-label":` Action: ${s}${l<0?"":` (access key "${o[r]})"`}.`
},c)})),t.source&&bwe("div",{class:"cm-diagnosticSource"},t.source))}
class Rwe extends hle{constructor(e){super(),this.sev=e}eq(e){
return e.sev==this.sev}toDOM(){return bwe("span",{
class:"cm-lintPoint cm-lintPoint-"+this.sev})}}class Lwe{constructor(e,t){
this.diagnostic=t,
this.id="item_"+Math.floor(4294967295*Math.random()).toString(16),
this.dom=Nwe(e,t,!0),this.dom.id=this.id,this.dom.setAttribute("role","option")}
}class Bwe{constructor(e){this.view=e,this.items=[];this.list=bwe("ul",{
tabIndex:0,role:"listbox","aria-label":this.view.state.phrase("Diagnostics"),
onkeydown:t=>{
if(27==t.keyCode)Pwe(this.view),this.view.focus();else if(38==t.keyCode||33==t.keyCode)this.moveSelection((this.selectedIndex-1+this.items.length)%this.items.length);else if(40==t.keyCode||34==t.keyCode)this.moveSelection((this.selectedIndex+1)%this.items.length);else if(36==t.keyCode)this.moveSelection(0);else if(35==t.keyCode)this.moveSelection(this.items.length-1);else if(13==t.keyCode)this.view.focus();else{
if(!(t.keyCode>=65&&t.keyCode<=90&&this.selectedIndex>=0))return;{
let{diagnostic:n}=this.items[this.selectedIndex],r=Mwe(n.actions)
;for(let o=0;o<r.length;o++)if(r[o].toUpperCase().charCodeAt(0)==t.keyCode){
let t=xwe(this.view.state.field(Ewe).diagnostics,n)
;t&&n.actions[o].apply(e,t.from,t.to)}}}t.preventDefault()},onclick:e=>{
for(let t=0;t<this.items.length;t++)this.items[t].dom.contains(e.target)&&this.moveSelection(t)
}}),this.dom=bwe("div",{class:"cm-panel-lint"},this.list,bwe("button",{
type:"button",name:"close","aria-label":this.view.state.phrase("close"),
onclick:()=>Pwe(this.view)},"×")),this.update()}get selectedIndex(){
let e=this.view.state.field(Ewe).selected;if(!e)return-1
;for(let t=0;t<this.items.length;t++)if(this.items[t].diagnostic==e.diagnostic)return t
;return-1}update(){
let{diagnostics:e,selected:t}=this.view.state.field(Ewe),n=0,r=!1,o=null,a=new Set
;for(e.between(0,this.view.state.doc.length,((e,i,{spec:s})=>{
for(let l of s.diagnostics){if(a.has(l))continue;a.add(l);let e,i=-1
;for(let t=n;t<this.items.length;t++)if(this.items[t].diagnostic==l){i=t;break}
i<0?(e=new Lwe(this.view,l),
this.items.splice(n,0,e),r=!0):(e=this.items[i],i>n&&(this.items.splice(n,i-n),
r=!0)),
t&&e.diagnostic==t.diagnostic?e.dom.hasAttribute("aria-selected")||(e.dom.setAttribute("aria-selected","true"),
o=e):e.dom.hasAttribute("aria-selected")&&e.dom.removeAttribute("aria-selected"),
n++}
}));n<this.items.length&&!(1==this.items.length&&this.items[0].diagnostic.from<0);)r=!0,
this.items.pop();0==this.items.length&&(this.items.push(new Lwe(this.view,{
from:-1,to:-1,severity:"info",message:this.view.state.phrase("No diagnostics")
})),
r=!0),o?(this.list.setAttribute("aria-activedescendant",o.id),this.view.requestMeasure({
key:this,read:()=>({sel:o.dom.getBoundingClientRect(),
panel:this.list.getBoundingClientRect()}),write:({sel:e,panel:t})=>{
let n=t.height/this.list.offsetHeight
;e.top<t.top?this.list.scrollTop-=(t.top-e.top)/n:e.bottom>t.bottom&&(this.list.scrollTop+=(e.bottom-t.bottom)/n)
}
})):this.selectedIndex<0&&this.list.removeAttribute("aria-activedescendant"),r&&this.sync()
}sync(){let e=this.list.firstChild;function t(){let t=e
;e=t.nextSibling,t.remove()}
for(let n of this.items)if(n.dom.parentNode==this.list){for(;e!=n.dom;)t()
;e=n.dom.nextSibling}else this.list.insertBefore(n.dom,e);for(;e;)t()}
moveSelection(e){if(this.selectedIndex<0)return
;let t=xwe(this.view.state.field(Ewe).diagnostics,this.items[e].diagnostic)
;t&&this.view.dispatch({selection:{anchor:t.from,head:t.to},scrollIntoView:!0,
effects:Twe.of(t)})}static open(e){return new Bwe(e)}}function jwe(e){
return function(e,t='viewBox="0 0 40 40"'){
return`url('data:image/svg+xml,<svg xmlns="http://www.w3.org/2000/svg" ${t}>${encodeURIComponent(e)}</svg>')`
}(`<path d="m0 2.5 l2 -1.5 l1 0 l2 1.5 l1 0" stroke="${e}" fill="none" stroke-width=".7"/>`,'width="6" height="3"')
}const Uwe=cde.baseTheme({".cm-diagnostic":{padding:"3px 6px 3px 8px",
marginLeft:"-1px",display:"block",whiteSpace:"pre-wrap"},
".cm-diagnostic-error":{borderLeft:"5px solid #d11"},".cm-diagnostic-warning":{
borderLeft:"5px solid orange"},".cm-diagnostic-info":{
borderLeft:"5px solid #999"},".cm-diagnostic-hint":{borderLeft:"5px solid #66d"
},".cm-diagnosticAction":{font:"inherit",border:"none",padding:"2px 4px",
backgroundColor:"#444",color:"white",borderRadius:"3px",marginLeft:"8px",
cursor:"pointer"},".cm-diagnosticSource":{fontSize:"70%",opacity:.7},
".cm-lintRange":{backgroundPosition:"left bottom",backgroundRepeat:"repeat-x",
paddingBottom:"0.7px"},".cm-lintRange-error":{backgroundImage:jwe("#d11")},
".cm-lintRange-warning":{backgroundImage:jwe("orange")},".cm-lintRange-info":{
backgroundImage:jwe("#999")},".cm-lintRange-hint":{backgroundImage:jwe("#66d")},
".cm-lintRange-active":{backgroundColor:"#ffdd9980"},".cm-tooltip-lint":{
padding:0,margin:0},".cm-lintPoint":{position:"relative","&:after":{
content:'""',position:"absolute",bottom:0,left:"-2px",
borderLeft:"3px solid transparent",borderRight:"3px solid transparent",
borderBottom:"4px solid #d11"}},".cm-lintPoint-warning":{"&:after":{
borderBottomColor:"orange"}},".cm-lintPoint-info":{"&:after":{
borderBottomColor:"#999"}},".cm-lintPoint-hint":{"&:after":{
borderBottomColor:"#66d"}},".cm-panel.cm-panel-lint":{position:"relative",
"& ul":{maxHeight:"100px",overflowY:"auto","& [aria-selected]":{
backgroundColor:"#ddd","& u":{textDecoration:"underline"}},
"&:focus [aria-selected]":{background_fallback:"#bdf",
backgroundColor:"Highlight",color_fallback:"white",color:"HighlightText"},
"& u":{textDecoration:"none"},padding:0,margin:0},"& [name=close]":{
position:"absolute",top:"0",right:"2px",background:"inherit",border:"none",
font:"inherit",padding:0,margin:0}}});function zwe(e){
return"error"==e?4:"warning"==e?3:"info"==e?2:1}function Fwe(e){let t="hint",n=1
;for(let r of e){let e=zwe(r.severity);e>n&&(n=e,t=r.severity)}return t}
const Zwe=[Ewe,cde.decorations.compute([Ewe],(e=>{
let{selected:t,panel:n}=e.field(Ewe)
;return t&&n&&t.from!=t.to?mle.set([Awe.range(t.from,t.to)]):mle.none
})),Gde(Cwe,{hideOn:function(e,t){
let n=t.pos,r=t.end||n,o=e.state.facet(Iwe).hideOn(e,n,r);if(null!=o)return o
;let a=e.startState.doc.lineAt(t.pos)
;return!(!e.effects.some((e=>e.is(Swe)))&&!e.changes.touchesRange(a.from,Math.max(a.to,r)))
}}),Uwe],Qwe=(({theme:e,settings:t={},styles:n=[]})=>{const r={".cm-gutters":{}
},o={}
;t.background&&(o.backgroundColor=t.background),t.backgroundImage&&(o.backgroundImage=t.backgroundImage),
t.foreground&&(o.color=t.foreground),
t.fontSize&&(o.fontSize=t.fontSize),(t.background||t.foreground)&&(r["&"]=o),
t.fontFamily&&(r["&.cm-editor .cm-scroller"]={fontFamily:t.fontFamily
}),t.gutterBackground&&r[".cm-gutters"]&&(r[".cm-gutters"].backgroundColor=t.gutterBackground),
t.gutterForeground&&r[".cm-gutters"]&&(r[".cm-gutters"].color=t.gutterForeground),
t.gutterBorder&&r[".cm-gutters"]&&(r[".cm-gutters"].borderRightColor=t.gutterBorder),
t.caret&&(r[".cm-content"]={caretColor:t.caret
},r[".cm-cursor, .cm-dropCursor"]={borderLeftColor:t.caret});const a={}
;t.gutterActiveForeground&&(a.color=t.gutterActiveForeground),
t.lineHighlight&&(r[".cm-activeLine"]={backgroundColor:t.lineHighlight
},a.backgroundColor=t.lineHighlight),
r[".cm-activeLineGutter"]=a,t.selection&&(r["&.cm-focused .cm-selectionBackground, & .cm-line::selection, & .cm-selectionLayer .cm-selectionBackground, .cm-content ::selection"]={
background:t.selection+" !important"
}),t.selectionMatch&&(r["& .cm-selectionMatch"]={
backgroundColor:t.selectionMatch});return[cde.theme(r,{dark:"dark"===e
}),Wfe(Qfe.define(n))]})({theme:"light",settings:{
background:"var(--scalar-background-2)",foreground:"var(--scalar-color-1)",
caret:"var(--scalar-color-1)",selectionMatch:"#e3dcce",
gutterBackground:"var(--scalar-background-2)",
gutterForeground:"var(--scalar-color-3)",gutterBorder:"transparent",
lineHighlight:"var(--scalar-background-3)",fontFamily:"var(--scalar-font-code)"
},styles:[{tag:[Zhe.standard(Zhe.tagName),Zhe.tagName],
color:"var(--scalar-color-purple)"},{tag:[Zhe.comment],
color:"var(--scalar-color-3)"},{tag:[Zhe.className],
color:"var(--scalar-color-orange)"},{
tag:[Zhe.variableName,Zhe.propertyName,Zhe.attributeName],
color:"var(--scalar-color-1)"},{tag:[Zhe.operator],color:"var(--scalar-color-2)"
},{tag:[Zhe.keyword,Zhe.typeName,Zhe.typeOperator],
color:"var(--scalar-color-green)"},{tag:[Zhe.string],
color:"var(--scalar-color-blue)"},{tag:[Zhe.bracket,Zhe.regexp,Zhe.meta],
color:"var(--scalar-color-3)"},{tag:[Zhe.number],
color:"var(--scalar-color-orange)"},{tag:[Zhe.name,Zhe.quote],
color:"var(--scalar-color-3)"},{tag:[Zhe.heading],color:"var(--scalar-color-3)",
fontWeight:"bold"},{tag:[Zhe.emphasis],color:"var(--scalar-color-3)",
fontStyle:"italic"},{tag:[Zhe.deleted],color:"var(--scalar-color-3)",
backgroundColor:"transparent"},{
tag:[Zhe.atom,Zhe.bool,Zhe.special(Zhe.variableName)],
color:"var(--scalar-color-3)"},{tag:[Zhe.url,Zhe.escape,Zhe.regexp,Zhe.link],
color:"var(--scalar-color-1)"},{tag:Zhe.link,textDecoration:"underline"},{
tag:Zhe.strikethrough,textDecoration:"line-through"},{tag:Zhe.invalid,
color:"var(--scalar-color-3)"}]}),Hwe=new Sde({regexp:/(\{[^}]+\})/g,
decoration:()=>mle.mark({attributes:{class:"api-client-url-variable"}})
}),Vwe=()=>dce.fromClass(class{variables;constructor(e){
this.variables=Hwe.createDeco(e)}update(e){
this.variables=Hwe.updateDeco(e,this.variables)}},{decorations:e=>e.variables,
provide:e=>cde.atomicRanges.of((t=>t.plugin(e)?.variables||mle.none))
}),qwe=e=>"provider"in e&&!!km(e.provider),Wwe={key:"Mod-a",run:e=>(e.dispatch({
selection:{anchor:0,head:e.state.doc.length},scrollIntoView:!1}),!0)},Xwe=e=>{
const t=bm(null),n=(e="")=>{
t.value&&t.value.state.doc.toString()!==e&&t.value.dispatch({changes:{from:0,
to:t.value.state.doc.length,insert:e},selection:{
anchor:Math.min(t.value.state.selection.main.anchor,e.length)}})},r=Sy((()=>({
onChange:e.onChange,onBlur:e.onBlur,onFocus:e.onFocus,
disableTabIndent:km(e.disableTabIndent),language:km(e.language),
classes:km(e.classes),readOnly:km(e.readOnly),lineNumbers:km(e.lineNumbers),
withVariables:km(e.withVariables),forceFoldGutter:km(e.forceFoldGutter),
disableEnter:km(e.disableEnter),disableCloseBrackets:km(e.disableCloseBrackets),
withoutTheme:km(e.withoutTheme),lint:km(e.lint),
additionalExtensions:km(e.extensions),placeholder:km(e.placeholder)})))
;function o(){if(e.codeMirrorRef.value){
const o=qwe(e)?km(e.provider):null,a=Ywe({...r.value,provider:o})
;t.value=new cde({parent:e.codeMirrorRef.value,extensions:a
}),qwe(e)||n(km(e.content))}}return mg(e.codeMirrorRef,(()=>{t.value?.destroy(),
o()}),{immediate:!0
}),cv((()=>t.value?.destroy())),mg((()=>qwe(e)?km(e.provider):null),(()=>{
qwe(e)&&(t.value?.destroy(),o())})),mg(r,(()=>{if(!t.value)return
;const n=qwe(e)?km(e.provider):null,o=Ywe({...r.value,provider:n})
;requestAnimationFrame((()=>{t.value?.dispatch({effects:_ie.reconfigure.of(o)})
}))}),{immediate:!0}),mg((()=>km(e.content)),(()=>{qwe(e)||n(km(e.content))}),{
immediate:!0}),{setCodeMirrorContent:n,codeMirror:t}},Gwe={html:function(e={}){
let t,n=""
;!1===e.matchClosingTags&&(n="noMatch"),!0===e.selfClosingTags&&(n=(n?n+" ":"")+"selfClosing"),
(e.nestedLanguages&&e.nestedLanguages.length||e.nestedAttributes&&e.nestedAttributes.length)&&(t=uye((e.nestedLanguages||[]).concat(pOe),(e.nestedAttributes||[]).concat(hOe)))
;let r=t?fOe.configure({wrap:t,dialect:n}):n?mOe.configure({dialect:n}):mOe
;return new sfe(r,[mOe.data.of({autocomplete:uOe(e)
}),!1!==e.autoCloseTags?vOe:[],Fye().support,Abe().support])},json:function(){
return new sfe(OOe)},yaml:function(){return new sfe(vwe)},css:Abe,
xml:function(e={}){let t=[ZOe.data.of({
autocomplete:FOe(e.elements||[],e.attributes||[])})]
;return!1!==e.autoCloseTags&&t.push(HOe),new sfe(ZOe,t)}}
;function Ywe({onChange:e,onBlur:t,onFocus:n,provider:r,language:o,classes:a=[],readOnly:i=!1,lineNumbers:s=!1,withVariables:l=!1,forceFoldGutter:c=!1,disableEnter:u=!1,disableCloseBrackets:d=!1,disableTabIndent:p=!1,withoutTheme:h=!1,lint:f=!1,additionalExtensions:m=[],placeholder:g}){
const v=[$de(),cve(),vde.of(Tve),Wfe(Yfe,{fallback:!0}),cde.theme({".cm-line":{
lineHeight:"22px",padding:"0 2px 0 4px"},".cm-gutterElement":{lineHeight:"22px"
},".cm-tooltip":{border:"1px solid #f5c6cb",fontSize:"12px"},
".cm-tooltip-lint":{backgroundColor:"#ffffff"},".cm-diagnostic-error":{
borderLeft:"0",color:"#dc1b19"},".cm-foldPlaceholder":{
background:"var(--scalar-background-1)",border:"none",
fontFamily:"var(--scalar-font)"}}),cde.updateListener.of((t=>{
t.docChanged&&e?.(t.state.doc.toString())})),cde.domEventHandlers({blur:(e,n)=>{
t?.(n.state.doc.toString())},focus:(e,t)=>{n?.(t.state.doc.toString())}
}),cde.editorAttributes.of({class:a.join(" ")}),...m];var b
;if(r&&v.push(r),h||v.push(Qwe),
i?v.push(cde.editable.of(!1)):(v.push(Lie.transactionFilter.of((e=>{
if(!e.docChanged||!e.isUserEvent("input.type")&&!e.isUserEvent("input.complete"))return e
;let t=e.startState.languageDataAt("indentOnInput",e.startState.selection.main.head)
;if(!t.length)return e;let n=e.newDoc,{head:r}=e.newSelection.main,o=n.lineAt(r)
;if(r>o.from+kfe)return e;let a=n.sliceString(o.from,r)
;if(!t.some((e=>e.test(a))))return e;let{state:i}=e,s=-1,l=[]
;for(let{head:c}of i.selection.ranges){let e=i.doc.lineAt(c)
;if(e.from==s)continue;s=e.from;let t=pfe(i,e.from);if(null==t)continue
;let n=/^\s*/.exec(e.text)[0],r=dfe(i,t);n!=r&&l.push({from:e.from,
to:e.from+n.length,insert:r})}return l.length?[e,{changes:l,sequential:!0}]:e
})),ame(),function(e={}){return[Oge,pge,Wme.of(e),bge,rve,wge]
}(),vde.of([...nve,Wwe]),ame()),
d||v.push([qge,Fge],vde.of([...Wge])),p?v.push(vde.of([{key:"Tab",run:()=>!1,
shift:()=>!1}])):v.push(vde.of([Cve]))),g&&v.push((b=g,dce.fromClass(class{
constructor(e){this.view=e,this.placeholder=b?mle.set([mle.widget({
widget:new Mde(b),side:1}).range(0)]):mle.none}get decorations(){
return this.view.state.doc.length?mle.none:this.placeholder}},{
decorations:e=>e.decorations}))),s&&v.push(function(e={}){
return[Ope.of(e),dpe(),kpe]}()),c&&v.push(Ffe({markerDOM:e=>{
const t=document.createElement("div");t.classList.add("cm-foldMarker")
;const n=_y(Gne,{icon:e?"ChevronDown":"ChevronRight",size:"md"});return QO(n,t),
t}})),o&&Gwe[o]&&(v.push(Gwe[o]()),c||v.push(Ffe({markerDOM:e=>{
const t=document.createElement("div");t.classList.add("cm-foldMarker")
;const n=_y(Gne,{icon:e?"ChevronDown":"ChevronRight",size:"md"});return QO(n,t),
t}}))),f&&"json"===o){const e=function(e,t={}){return[Iwe.of({source:e,config:t
}),Dwe,Zwe]}((e=>{const t=[],n=e.state.doc.toString();if(n.trim())try{
JSON.parse(n)}catch(Bw){Bw instanceof Error&&t.push({from:0,
to:e.state.doc.length,severity:"error",message:Bw.message})}return t}))
;v.push(e)}return l&&v.push(Vwe()),u?v.push(vde.of([{key:"Enter",run:()=>!0},{
key:"Ctrl-Enter",mac:"Cmd-Enter",run:()=>!0},{key:"Shift-Enter",run:()=>!0
}])):v.push(vde.of([{key:"Enter",run:Eve}])),v}function Kwe(e){
return Array.isArray?Array.isArray(e):"[object Array]"===axe(e)}function Jwe(e){
return"string"==typeof e}function exe(e){return"number"==typeof e}
function txe(e){return!0===e||!1===e||function(e){return nxe(e)&&null!==e
}(e)&&"[object Boolean]"==axe(e)}function nxe(e){return"object"==typeof e}
function rxe(e){return null!=e}function oxe(e){return!e.trim().length}
function axe(e){
return null==e?void 0===e?"[object Undefined]":"[object Null]":Object.prototype.toString.call(e)
}
const ixe=e=>`Missing ${e} property in key`,sxe=e=>`Property 'weight' in key '${e}' must be a positive integer`,lxe=Object.prototype.hasOwnProperty
;class cxe{constructor(e){this._keys=[],this._keyMap={};let t=0;e.forEach((e=>{
let n=uxe(e);this._keys.push(n),this._keyMap[n.id]=n,t+=n.weight
})),this._keys.forEach((e=>{e.weight/=t}))}get(e){return this._keyMap[e]}keys(){
return this._keys}toJSON(){return JSON.stringify(this._keys)}}function uxe(e){
let t=null,n=null,r=null,o=1,a=null
;if(Jwe(e)||Kwe(e))r=e,t=dxe(e),n=pxe(e);else{
if(!lxe.call(e,"name"))throw new Error(ixe("name"));const i=e.name
;if(r=i,lxe.call(e,"weight")&&(o=e.weight,o<=0))throw new Error(sxe(i))
;t=dxe(i),n=pxe(i),a=e.getFn}return{path:t,id:n,weight:o,src:r,getFn:a}}
function dxe(e){return Kwe(e)?e:e.split(".")}function pxe(e){
return Kwe(e)?e.join("."):e}const hxe={useExtendedSearch:!1,getFn:function(e,t){
let n=[],r=!1;const o=(e,t,a)=>{if(rxe(e))if(t[a]){const i=e[t[a]]
;if(!rxe(i))return
;if(a===t.length-1&&(Jwe(i)||exe(i)||txe(i)))n.push(function(e){
return null==e?"":function(e){if("string"==typeof e)return e;let t=e+""
;return"0"==t&&1/e==-1/0?"-0":t}(e)}(i));else if(Kwe(i)){r=!0
;for(let e=0,n=i.length;e<n;e+=1)o(i[e],t,a+1)}else t.length&&o(i,t,a+1)
}else n.push(e)};return o(e,Jwe(t)?t.split("."):t,0),r?n:n[0]},
ignoreLocation:!1,ignoreFieldNorm:!1,fieldNormWeight:1};var fxe={
isCaseSensitive:!1,ignoreDiacritics:!1,includeScore:!1,keys:[],shouldSort:!0,
sortFn:(e,t)=>e.score===t.score?e.idx<t.idx?-1:1:e.score<t.score?-1:1,
includeMatches:!1,findAllMatches:!1,minMatchCharLength:1,location:0,
threshold:.6,distance:100,...hxe};const mxe=/[^ ]+/g;class gxe{
constructor({getFn:e=fxe.getFn,fieldNormWeight:t=fxe.fieldNormWeight}={}){
this.norm=function(e=1,t=3){const n=new Map,r=Math.pow(10,t);return{get(t){
const o=t.match(mxe).length;if(n.has(o))return n.get(o)
;const a=1/Math.pow(o,.5*e),i=parseFloat(Math.round(a*r)/r);return n.set(o,i),i
},clear(){n.clear()}}
}(t,3),this.getFn=e,this.isCreated=!1,this.setIndexRecords()}setSources(e=[]){
this.docs=e}setIndexRecords(e=[]){this.records=e}setKeys(e=[]){
this.keys=e,this._keysMap={},e.forEach(((e,t)=>{this._keysMap[e.id]=t}))}
create(){
!this.isCreated&&this.docs.length&&(this.isCreated=!0,Jwe(this.docs[0])?this.docs.forEach(((e,t)=>{
this._addString(e,t)})):this.docs.forEach(((e,t)=>{this._addObject(e,t)
})),this.norm.clear())}add(e){const t=this.size()
;Jwe(e)?this._addString(e,t):this._addObject(e,t)}removeAt(e){
this.records.splice(e,1);for(let t=e,n=this.size();t<n;t+=1)this.records[t].i-=1
}getValueForItemAtKeyId(e,t){return e[this._keysMap[t]]}size(){
return this.records.length}_addString(e,t){if(!rxe(e)||oxe(e))return;let n={v:e,
i:t,n:this.norm.get(e)};this.records.push(n)}_addObject(e,t){let n={i:t,$:{}}
;this.keys.forEach(((t,r)=>{let o=t.getFn?t.getFn(e):this.getFn(e,t.path)
;if(rxe(o))if(Kwe(o)){let e=[];const t=[{nestedArrIndex:-1,value:o}]
;for(;t.length;){const{nestedArrIndex:n,value:r}=t.pop()
;if(rxe(r))if(Jwe(r)&&!oxe(r)){let t={v:r,i:n,n:this.norm.get(r)};e.push(t)
}else Kwe(r)&&r.forEach(((e,n)=>{t.push({nestedArrIndex:n,value:e})}))}n.$[r]=e
}else if(Jwe(o)&&!oxe(o)){let e={v:o,n:this.norm.get(o)};n.$[r]=e}
})),this.records.push(n)}toJSON(){return{keys:this.keys,records:this.records}}}
function vxe(e,t,{getFn:n=fxe.getFn,fieldNormWeight:r=fxe.fieldNormWeight}={}){
const o=new gxe({getFn:n,fieldNormWeight:r})
;return o.setKeys(e.map(uxe)),o.setSources(t),o.create(),o}
function bxe(e,{errors:t=0,currentLocation:n=0,expectedLocation:r=0,distance:o=fxe.distance,ignoreLocation:a=fxe.ignoreLocation}={}){
const i=t/e.length;if(a)return i;const s=Math.abs(r-n);return o?i+s/o:s?1:i}
const yxe=32
;function Oxe(e,t,n,{location:r=fxe.location,distance:o=fxe.distance,threshold:a=fxe.threshold,findAllMatches:i=fxe.findAllMatches,minMatchCharLength:s=fxe.minMatchCharLength,includeMatches:l=fxe.includeMatches,ignoreLocation:c=fxe.ignoreLocation}={}){
if(t.length>yxe)throw new Error(`Pattern length exceeds max of ${yxe}.`)
;const u=t.length,d=e.length,p=Math.max(0,Math.min(r,d));let h=a,f=p
;const m=s>1||l,g=m?Array(d):[];let v;for(;(v=e.indexOf(t,f))>-1;){let e=bxe(t,{
currentLocation:v,expectedLocation:p,distance:o,ignoreLocation:c})
;if(h=Math.min(e,h),f=v+u,m){let e=0;for(;e<u;)g[v+e]=1,e+=1}}f=-1
;let b=[],y=1,O=u+d;const w=1<<u-1;for(let k=0;k<u;k+=1){let r=0,a=O;for(;r<a;){
bxe(t,{errors:k,currentLocation:p+a,expectedLocation:p,distance:o,
ignoreLocation:c})<=h?r=a:O=a,a=Math.floor((O-r)/2+r)}O=a
;let s=Math.max(1,p-a+1),l=i?d:Math.min(p+a,d)+u,v=Array(l+2);v[l+1]=(1<<k)-1
;for(let i=l;i>=s;i-=1){let r=i-1,a=n[e.charAt(r)]
;if(m&&(g[r]=+!!a),v[i]=(v[i+1]<<1|1)&a,
k&&(v[i]|=(b[i+1]|b[i])<<1|1|b[i+1]),v[i]&w&&(y=bxe(t,{errors:k,
currentLocation:r,expectedLocation:p,distance:o,ignoreLocation:c}),y<=h)){
if(h=y,f=r,f<=p)break;s=Math.max(1,2*p-f)}}if(bxe(t,{errors:k+1,
currentLocation:p,expectedLocation:p,distance:o,ignoreLocation:c})>h)break;b=v}
const x={isMatch:f>=0,score:Math.max(.001,y)};if(m){
const e=function(e=[],t=fxe.minMatchCharLength){let n=[],r=-1,o=-1,a=0
;for(let i=e.length;a<i;a+=1){let i=e[a]
;i&&-1===r?r=a:i||-1===r||(o=a-1,o-r+1>=t&&n.push([r,o]),r=-1)}
return e[a-1]&&a-r>=t&&n.push([r,a-1]),n}(g,s)
;e.length?l&&(x.indices=e):x.isMatch=!1}return x}function wxe(e){let t={}
;for(let n=0,r=e.length;n<r;n+=1){const o=e.charAt(n);t[o]=(t[o]||0)|1<<r-n-1}
return t}
const xxe=String.prototype.normalize?e=>e.normalize("NFD").replace(/[\u0300-\u036F\u0483-\u0489\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u0610-\u061A\u064B-\u065F\u0670\u06D6-\u06DC\u06DF-\u06E4\u06E7\u06E8\u06EA-\u06ED\u0711\u0730-\u074A\u07A6-\u07B0\u07EB-\u07F3\u07FD\u0816-\u0819\u081B-\u0823\u0825-\u0827\u0829-\u082D\u0859-\u085B\u08D3-\u08E1\u08E3-\u0903\u093A-\u093C\u093E-\u094F\u0951-\u0957\u0962\u0963\u0981-\u0983\u09BC\u09BE-\u09C4\u09C7\u09C8\u09CB-\u09CD\u09D7\u09E2\u09E3\u09FE\u0A01-\u0A03\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A70\u0A71\u0A75\u0A81-\u0A83\u0ABC\u0ABE-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AE2\u0AE3\u0AFA-\u0AFF\u0B01-\u0B03\u0B3C\u0B3E-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B56\u0B57\u0B62\u0B63\u0B82\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD7\u0C00-\u0C04\u0C3E-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C62\u0C63\u0C81-\u0C83\u0CBC\u0CBE-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CE2\u0CE3\u0D00-\u0D03\u0D3B\u0D3C\u0D3E-\u0D44\u0D46-\u0D48\u0D4A-\u0D4D\u0D57\u0D62\u0D63\u0D82\u0D83\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DF2\u0DF3\u0E31\u0E34-\u0E3A\u0E47-\u0E4E\u0EB1\u0EB4-\u0EB9\u0EBB\u0EBC\u0EC8-\u0ECD\u0F18\u0F19\u0F35\u0F37\u0F39\u0F3E\u0F3F\u0F71-\u0F84\u0F86\u0F87\u0F8D-\u0F97\u0F99-\u0FBC\u0FC6\u102B-\u103E\u1056-\u1059\u105E-\u1060\u1062-\u1064\u1067-\u106D\u1071-\u1074\u1082-\u108D\u108F\u109A-\u109D\u135D-\u135F\u1712-\u1714\u1732-\u1734\u1752\u1753\u1772\u1773\u17B4-\u17D3\u17DD\u180B-\u180D\u1885\u1886\u18A9\u1920-\u192B\u1930-\u193B\u1A17-\u1A1B\u1A55-\u1A5E\u1A60-\u1A7C\u1A7F\u1AB0-\u1ABE\u1B00-\u1B04\u1B34-\u1B44\u1B6B-\u1B73\u1B80-\u1B82\u1BA1-\u1BAD\u1BE6-\u1BF3\u1C24-\u1C37\u1CD0-\u1CD2\u1CD4-\u1CE8\u1CED\u1CF2-\u1CF4\u1CF7-\u1CF9\u1DC0-\u1DF9\u1DFB-\u1DFF\u20D0-\u20F0\u2CEF-\u2CF1\u2D7F\u2DE0-\u2DFF\u302A-\u302F\u3099\u309A\uA66F-\uA672\uA674-\uA67D\uA69E\uA69F\uA6F0\uA6F1\uA802\uA806\uA80B\uA823-\uA827\uA880\uA881\uA8B4-\uA8C5\uA8E0-\uA8F1\uA8FF\uA926-\uA92D\uA947-\uA953\uA980-\uA983\uA9B3-\uA9C0\uA9E5\uAA29-\uAA36\uAA43\uAA4C\uAA4D\uAA7B-\uAA7D\uAAB0\uAAB2-\uAAB4\uAAB7\uAAB8\uAABE\uAABF\uAAC1\uAAEB-\uAAEF\uAAF5\uAAF6\uABE3-\uABEA\uABEC\uABED\uFB1E\uFE00-\uFE0F\uFE20-\uFE2F]/g,""):e=>e
;class kxe{
constructor(e,{location:t=fxe.location,threshold:n=fxe.threshold,distance:r=fxe.distance,includeMatches:o=fxe.includeMatches,findAllMatches:a=fxe.findAllMatches,minMatchCharLength:i=fxe.minMatchCharLength,isCaseSensitive:s=fxe.isCaseSensitive,ignoreDiacritics:l=fxe.ignoreDiacritics,ignoreLocation:c=fxe.ignoreLocation}={}){
if(this.options={location:t,threshold:n,distance:r,includeMatches:o,
findAllMatches:a,minMatchCharLength:i,isCaseSensitive:s,ignoreDiacritics:l,
ignoreLocation:c
},e=s?e:e.toLowerCase(),e=l?xxe(e):e,this.pattern=e,this.chunks=[],
!this.pattern.length)return;const u=(e,t)=>{this.chunks.push({pattern:e,
alphabet:wxe(e),startIndex:t})},d=this.pattern.length;if(d>yxe){let e=0
;const t=d%yxe,n=d-t;for(;e<n;)u(this.pattern.substr(e,yxe),e),e+=yxe;if(t){
const e=d-yxe;u(this.pattern.substr(e),e)}}else u(this.pattern,0)}searchIn(e){
const{isCaseSensitive:t,ignoreDiacritics:n,includeMatches:r}=this.options
;if(e=t?e:e.toLowerCase(),e=n?xxe(e):e,this.pattern===e){let t={isMatch:!0,
score:0};return r&&(t.indices=[[0,e.length-1]]),t}
const{location:o,distance:a,threshold:i,findAllMatches:s,minMatchCharLength:l,ignoreLocation:c}=this.options
;let u=[],d=0,p=!1;this.chunks.forEach((({pattern:t,alphabet:n,startIndex:h})=>{
const{isMatch:f,score:m,indices:g}=Oxe(e,t,n,{location:o+h,distance:a,
threshold:i,findAllMatches:s,minMatchCharLength:l,includeMatches:r,
ignoreLocation:c});f&&(p=!0),d+=m,f&&g&&(u=[...u,...g])}));let h={isMatch:p,
score:p?d/this.chunks.length:1};return p&&r&&(h.indices=u),h}}class Sxe{
constructor(e){this.pattern=e}static isMultiMatch(e){
return _xe(e,this.multiRegex)}static isSingleMatch(e){
return _xe(e,this.singleRegex)}search(){}}function _xe(e,t){const n=e.match(t)
;return n?n[1]:null}class Txe extends Sxe{
constructor(e,{location:t=fxe.location,threshold:n=fxe.threshold,distance:r=fxe.distance,includeMatches:o=fxe.includeMatches,findAllMatches:a=fxe.findAllMatches,minMatchCharLength:i=fxe.minMatchCharLength,isCaseSensitive:s=fxe.isCaseSensitive,ignoreDiacritics:l=fxe.ignoreDiacritics,ignoreLocation:c=fxe.ignoreLocation}={}){
super(e),this._bitapSearch=new kxe(e,{location:t,threshold:n,distance:r,
includeMatches:o,findAllMatches:a,minMatchCharLength:i,isCaseSensitive:s,
ignoreDiacritics:l,ignoreLocation:c})}static get type(){return"fuzzy"}
static get multiRegex(){return/^"(.*)"$/}static get singleRegex(){return/^(.*)$/
}search(e){return this._bitapSearch.searchIn(e)}}class Exe extends Sxe{
constructor(e){super(e)}static get type(){return"include"}
static get multiRegex(){return/^'"(.*)"$/}static get singleRegex(){
return/^'(.*)$/}search(e){let t,n=0;const r=[],o=this.pattern.length
;for(;(t=e.indexOf(this.pattern,n))>-1;)n=t+o,r.push([t,n-1]);const a=!!r.length
;return{isMatch:a,score:a?0:1,indices:r}}}const Axe=[class extends Sxe{
constructor(e){super(e)}static get type(){return"exact"}static get multiRegex(){
return/^="(.*)"$/}static get singleRegex(){return/^=(.*)$/}search(e){
const t=e===this.pattern;return{isMatch:t,score:t?0:1,
indices:[0,this.pattern.length-1]}}},Exe,class extends Sxe{constructor(e){
super(e)}static get type(){return"prefix-exact"}static get multiRegex(){
return/^\^"(.*)"$/}static get singleRegex(){return/^\^(.*)$/}search(e){
const t=e.startsWith(this.pattern);return{isMatch:t,score:t?0:1,
indices:[0,this.pattern.length-1]}}},class extends Sxe{constructor(e){super(e)}
static get type(){return"inverse-prefix-exact"}static get multiRegex(){
return/^!\^"(.*)"$/}static get singleRegex(){return/^!\^(.*)$/}search(e){
const t=!e.startsWith(this.pattern);return{isMatch:t,score:t?0:1,
indices:[0,e.length-1]}}},class extends Sxe{constructor(e){super(e)}
static get type(){return"inverse-suffix-exact"}static get multiRegex(){
return/^!"(.*)"\$$/}static get singleRegex(){return/^!(.*)\$$/}search(e){
const t=!e.endsWith(this.pattern);return{isMatch:t,score:t?0:1,
indices:[0,e.length-1]}}},class extends Sxe{constructor(e){super(e)}
static get type(){return"suffix-exact"}static get multiRegex(){
return/^"(.*)"\$$/}static get singleRegex(){return/^(.*)\$$/}search(e){
const t=e.endsWith(this.pattern);return{isMatch:t,score:t?0:1,
indices:[e.length-this.pattern.length,e.length-1]}}},class extends Sxe{
constructor(e){super(e)}static get type(){return"inverse-exact"}
static get multiRegex(){return/^!"(.*)"$/}static get singleRegex(){
return/^!(.*)$/}search(e){const t=-1===e.indexOf(this.pattern);return{isMatch:t,
score:t?0:1,indices:[0,e.length-1]}}
},Txe],Cxe=Axe.length,$xe=/ +(?=(?:[^\"]*\"[^\"]*\")*[^\"]*$)/
;const Pxe=new Set([Txe.type,Exe.type]);class Dxe{
constructor(e,{isCaseSensitive:t=fxe.isCaseSensitive,ignoreDiacritics:n=fxe.ignoreDiacritics,includeMatches:r=fxe.includeMatches,minMatchCharLength:o=fxe.minMatchCharLength,ignoreLocation:a=fxe.ignoreLocation,findAllMatches:i=fxe.findAllMatches,location:s=fxe.location,threshold:l=fxe.threshold,distance:c=fxe.distance}={}){
this.query=null,this.options={isCaseSensitive:t,ignoreDiacritics:n,
includeMatches:r,minMatchCharLength:o,findAllMatches:i,ignoreLocation:a,
location:s,threshold:l,distance:c
},e=t?e:e.toLowerCase(),e=n?xxe(e):e,this.pattern=e,this.query=function(e,t={}){
return e.split("|").map((e=>{
let n=e.trim().split($xe).filter((e=>e&&!!e.trim())),r=[]
;for(let o=0,a=n.length;o<a;o+=1){const e=n[o];let a=!1,i=-1;for(;!a&&++i<Cxe;){
const n=Axe[i];let o=n.isMultiMatch(e);o&&(r.push(new n(o,t)),a=!0)}
if(!a)for(i=-1;++i<Cxe;){const n=Axe[i];let o=n.isSingleMatch(e);if(o){
r.push(new n(o,t));break}}}return r}))}(this.pattern,this.options)}
static condition(e,t){return t.useExtendedSearch}searchIn(e){const t=this.query
;if(!t)return{isMatch:!1,score:1}
;const{includeMatches:n,isCaseSensitive:r,ignoreDiacritics:o}=this.options
;e=r?e:e.toLowerCase(),e=o?xxe(e):e;let a=0,i=[],s=0
;for(let l=0,c=t.length;l<c;l+=1){const r=t[l];i.length=0,a=0
;for(let t=0,o=r.length;t<o;t+=1){
const o=r[t],{isMatch:l,indices:c,score:u}=o.search(e);if(!l){s=0,a=0,i.length=0
;break}if(a+=1,s+=u,n){const e=o.constructor.type
;Pxe.has(e)?i=[...i,...c]:i.push(c)}}if(a){let e={isMatch:!0,score:s/a}
;return n&&(e.indices=i),e}}return{isMatch:!1,score:1}}}const Ixe=[]
;function Mxe(e,t){for(let n=0,r=Ixe.length;n<r;n+=1){let r=Ixe[n]
;if(r.condition(e,t))return new r(e,t)}return new kxe(e,t)}
const Nxe="$and",Rxe="$or",Lxe="$path",Bxe="$val",jxe=e=>!(!e[Nxe]&&!e[Rxe]),Uxe=e=>({
[Nxe]:Object.keys(e).map((t=>({[t]:e[t]})))});function zxe(e,t,{auto:n=!0}={}){
const r=e=>{let o=Object.keys(e);const a=(e=>!!e[Lxe])(e)
;if(!a&&o.length>1&&!jxe(e))return r(Uxe(e))
;if((e=>!Kwe(e)&&nxe(e)&&!jxe(e))(e)){const r=a?e[Lxe]:o[0],i=a?e[Bxe]:e[r]
;if(!Jwe(i))throw new Error((e=>`Invalid value for key ${e}`)(r));const s={
keyId:pxe(r),pattern:i};return n&&(s.searcher=Mxe(i,t)),s}let i={children:[],
operator:o[0]};return o.forEach((t=>{const n=e[t];Kwe(n)&&n.forEach((e=>{
i.children.push(r(e))}))})),i};return jxe(e)||(e=Uxe(e)),r(e)}function Fxe(e,t){
const n=e.matches;t.matches=[],rxe(n)&&n.forEach((e=>{
if(!rxe(e.indices)||!e.indices.length)return;const{indices:n,value:r}=e;let o={
indices:n,value:r}
;e.key&&(o.key=e.key.src),e.idx>-1&&(o.refIndex=e.idx),t.matches.push(o)}))}
function Zxe(e,t){t.score=e.score}class Qxe{constructor(e,t={},n){this.options={
...fxe,...t
},this.options.useExtendedSearch,this._keyStore=new cxe(this.options.keys),
this.setCollection(e,n)}setCollection(e,t){
if(this._docs=e,t&&!(t instanceof gxe))throw new Error("Incorrect 'index' type")
;this._myIndex=t||vxe(this.options.keys,this._docs,{getFn:this.options.getFn,
fieldNormWeight:this.options.fieldNormWeight})}add(e){
rxe(e)&&(this._docs.push(e),this._myIndex.add(e))}remove(e=()=>!1){const t=[]
;for(let n=0,r=this._docs.length;n<r;n+=1){const o=this._docs[n]
;e(o,n)&&(this.removeAt(n),n-=1,r-=1,t.push(o))}return t}removeAt(e){
this._docs.splice(e,1),this._myIndex.removeAt(e)}getIndex(){return this._myIndex
}search(e,{limit:t=-1}={}){
const{includeMatches:n,includeScore:r,shouldSort:o,sortFn:a,ignoreFieldNorm:i}=this.options
;let s=Jwe(e)?Jwe(this._docs[0])?this._searchStringList(e):this._searchObjectList(e):this._searchLogical(e)
;return function(e,{ignoreFieldNorm:t=fxe.ignoreFieldNorm}){e.forEach((e=>{
let n=1;e.matches.forEach((({key:e,norm:r,score:o})=>{const a=e?e.weight:null
;n*=Math.pow(0===o&&a?Number.EPSILON:o,(a||1)*(t?1:r))})),e.score=n}))}(s,{
ignoreFieldNorm:i
}),o&&s.sort(a),exe(t)&&t>-1&&(s=s.slice(0,t)),function(e,t,{includeMatches:n=fxe.includeMatches,includeScore:r=fxe.includeScore}={}){
const o=[];return n&&o.push(Fxe),r&&o.push(Zxe),e.map((e=>{const{idx:n}=e,r={
item:t[n],refIndex:n};return o.length&&o.forEach((t=>{t(e,r)})),r}))
}(s,this._docs,{includeMatches:n,includeScore:r})}_searchStringList(e){
const t=Mxe(e,this.options),{records:n}=this._myIndex,r=[]
;return n.forEach((({v:e,i:n,n:o})=>{if(!rxe(e))return
;const{isMatch:a,score:i,indices:s}=t.searchIn(e);a&&r.push({item:e,idx:n,
matches:[{score:i,value:e,norm:o,indices:s}]})})),r}_searchLogical(e){
const t=zxe(e,this.options),n=(e,t,r)=>{if(!e.children){
const{keyId:n,searcher:o}=e,a=this._findMatches({key:this._keyStore.get(n),
value:this._myIndex.getValueForItemAtKeyId(t,n),searcher:o})
;return a&&a.length?[{idx:r,item:t,matches:a}]:[]}const o=[]
;for(let a=0,i=e.children.length;a<i;a+=1){const i=e.children[a],s=n(i,t,r)
;if(s.length)o.push(...s);else if(e.operator===Nxe)return[]}return o
},r=this._myIndex.records,o={},a=[];return r.forEach((({$:e,i:r})=>{if(rxe(e)){
let i=n(t,e,r);i.length&&(o[r]||(o[r]={idx:r,item:e,matches:[]
},a.push(o[r])),i.forEach((({matches:e})=>{o[r].matches.push(...e)})))}})),a}
_searchObjectList(e){
const t=Mxe(e,this.options),{keys:n,records:r}=this._myIndex,o=[]
;return r.forEach((({$:e,i:r})=>{if(!rxe(e))return;let a=[];n.forEach(((n,r)=>{
a.push(...this._findMatches({key:n,value:e[r],searcher:t}))
})),a.length&&o.push({idx:r,item:e,matches:a})})),o}
_findMatches({key:e,value:t,searcher:n}){if(!rxe(t))return[];let r=[]
;if(Kwe(t))t.forEach((({v:t,i:o,n:a})=>{if(!rxe(t))return
;const{isMatch:i,score:s,indices:l}=n.searchIn(t);i&&r.push({score:s,key:e,
value:t,idx:o,norm:a,indices:l})}));else{
const{v:o,n:a}=t,{isMatch:i,score:s,indices:l}=n.searchIn(o);i&&r.push({score:s,
key:e,value:o,norm:a,indices:l})}return r}}
Qxe.version="7.1.0",Qxe.createIndex=vxe,
Qxe.parseIndex=function(e,{getFn:t=fxe.getFn,fieldNormWeight:n=fxe.fieldNormWeight}={}){
const{keys:r,records:o}=e,a=new gxe({getFn:t,fieldNormWeight:n})
;return a.setKeys(r),a.setIndexRecords(o),a
},Qxe.config=fxe,Qxe.parseQuery=zxe,function(...e){Ixe.push(...e)}(Dxe)
;const Hxe=()=>{},Vxe=Array.isArray;function qxe(e,t){
return(e.aliasOf||e)===(t.aliasOf||t)}function Wxe(e,t){
return Vxe(e)?Xxe(e,t):Vxe(t)?Xxe(t,e):e===t}function Xxe(e,t){
return Vxe(t)?e.length===t.length&&e.every(((e,n)=>e===t[n])):1===e.length&&e[0]===t
}const Gxe=Symbol(""),Yxe=Symbol("");function Kxe(e){
const t=ug(Gxe),n=ug(Yxe),r=Sy((()=>{const n=xm(e.to);return t.resolve(n)
})),o=Sy((()=>{const{matched:e}=r.value,{length:t}=e,o=e[t-1],a=n.matched
;if(!o||!a.length)return-1;const i=a.findIndex(qxe.bind(null,o))
;if(i>-1)return i;const s=eke(e[t-2])
;return t>1&&eke(o)===s&&a[a.length-1].path!==s?a.findIndex(qxe.bind(null,e[t-2])):i
})),a=Sy((()=>o.value>-1&&function(e,t){for(const n in t){const r=t[n],o=e[n]
;if("string"==typeof r){if(r!==o)return!1
}else if(!Vxe(o)||o.length!==r.length||r.some(((e,t)=>e!==o[t])))return!1}
return!0
}(n.params,r.value.params))),i=Sy((()=>o.value>-1&&o.value===n.matched.length-1&&function(e,t){
if(Object.keys(e).length!==Object.keys(t).length)return!1
;for(const n in e)if(!Wxe(e[n],t[n]))return!1;return!0
}(n.params,r.value.params)));return{route:r,href:Sy((()=>r.value.href)),
isActive:a,isExactActive:i,navigate:function(n={}){if(function(e){
if(e.metaKey||e.altKey||e.ctrlKey||e.shiftKey)return
;if(e.defaultPrevented)return;if(void 0!==e.button&&0!==e.button)return
;if(e.currentTarget&&e.currentTarget.getAttribute){
const t=e.currentTarget.getAttribute("target");if(/\b_blank\b/i.test(t))return}
e.preventDefault&&e.preventDefault();return!0}(n)){
const n=t[xm(e.replace)?"replace":"push"](xm(e.to)).catch(Hxe)
;return e.viewTransition&&"undefined"!=typeof document&&"startViewTransition"in document&&document.startViewTransition((()=>n)),
n}return Promise.resolve()}}}const Jxe=Qg({name:"RouterLink",compatConfig:{
MODE:3},props:{to:{type:[String,Object],required:!0},replace:Boolean,
activeClass:String,exactActiveClass:String,custom:Boolean,ariaCurrentValue:{
type:String,default:"page"},viewTransition:Boolean},useLink:Kxe,
setup(e,{slots:t}){const n=am(Kxe(e)),{options:r}=ug(Gxe),o=Sy((()=>({
[tke(e.activeClass,r.linkActiveClass,"router-link-active")]:n.isActive,
[tke(e.exactActiveClass,r.linkExactActiveClass,"router-link-exact-active")]:n.isExactActive
})));return()=>{const r=t.default&&(1===(a=t.default(n)).length?a[0]:a);var a
;return e.custom?r:_y("a",{
"aria-current":n.isExactActive?e.ariaCurrentValue:null,href:n.href,
onClick:n.navigate,class:o.value},r)}}});function eke(e){
return e?e.aliasOf?e.aliasOf.path:e.path:""}
const tke=(e,t,n)=>null!=e?e:null!=t?t:n;zc({uid:cl().brand(),
name:cl().optional().default("Default Environment"),
color:cl().optional().default("#FFFFFF"),value:cl().default(""),
isDefault:mc().optional()}),cde.domEventHandlers({keydown(e,t){
if("Backspace"===e.key){const{state:n}=t,{from:r,to:o}=n.selection.main
;if(0===r&&o===n.doc.length)return t.dispatch({changes:{from:0,to:n.doc.length},
selection:{anchor:0}}),e.preventDefault(),!0
;if(r===o&&r>0&&"}}"===n.doc.sliceString(r-2,r))return t.dispatch({changes:{
from:r-2,to:o},selection:{anchor:r-2}}),e.preventDefault(),!0}return!1}})
;const nke=Qg({__name:"HttpMethod",props:{isSquare:{type:Boolean,default:!1},
method:{},isEditable:{type:Boolean,default:!1}},emits:["change"],
setup(e,{emit:t}){
const n=e,r=t,o=Sy((()=>CH(n.method))),a=Object.entries(AH).map((([e])=>({id:e,
label:e.toUpperCase(),color:CH(e).colorClass}))),i=Sy({
get:()=>a.find((({id:e})=>e===n.method)),set:e=>e?.id&&r("change",e.id)}),s=jS({
base:"text-center font-code text-3xs justify-center items-center flex",
variants:{isSquare:{
true:"px-2.5 whitespace-nowrap font-bold border-r h-fit m-auto",
false:"rounded-full"},isEditable:{
true:"http-bg-gradient rounded-md border border-r",false:"cursor-auto"}}
}),l=Sy((()=>o.value.short));return(t,n)=>e.isEditable?(Ub(),Hb(xm(hre),{key:0,
modelValue:i.value,"onUpdate:modelValue":n[0]||(n[0]=e=>i.value=e),
class:"font-code scalar-client mt-1 text-sm",options:xm(a)},{
default:ig((()=>[Gb("div",{class:Ih(["h-full",{
"pointer-events-none":!e.isEditable}])},[Gb("button",{
class:Ih(["relative h-full",xm(US)(xm(s)({isSquare:e.isSquare,
isEditable:e.isEditable}),o.value.colorClass)]),type:"button"
},[Gb("span",null,Uh(l.value),1)],2)],2)])),_:1
},8,["modelValue","options"])):(Ub(),Qb("div",{key:1,
class:Ih(["relative gap-1 whitespace-nowrap",xm(US)(xm(s)({isSquare:e.isSquare,
isEditable:e.isEditable}),o.value.colorClass)]),type:"button"
},Uh(o.value.short),3))}
}),rke=sae(nke,[["__scopeId","data-v-076b14a1"]]),oke=(e,t=2)=>e>1e3?(e/1e3).toFixed(t)+"s":e+"ms",ake="scalar-reference-selected-client-v2",ike="scalar-reference-auth-schemes",ske="scalar-reference-selected-auth-schemes",lke=zc({
description:cl().optional()}),cke=zc({uid:jX.brand(),
nameKey:cl().optional().default("")}),uke=lke.extend({type:pu("apiKey"),
name:cl().optional().default(""),
in:cu(["query","header","cookie"]).optional().default("header").catch("header")
}),dke=zc({value:cl().default("")
}),pke=uke.merge(cke).merge(dke),hke=lke.extend({type:pu("http"),
scheme:cl().toLowerCase().pipe(cu(["basic","bearer"])).optional().default("basic"),
bearerFormat:Hc([pu("JWT"),cl()]).optional().default("JWT")}),fke=zc({
username:cl().default(""),password:cl().default(""),token:cl().default("")
}),mke=hke.merge(cke).merge(fke),gke=lke.extend({type:pu("openIdConnect"),
openIdConnectUrl:cl().optional().default("")
}),vke=gke.merge(cke),bke=cl().default(""),yke=cl().default(""),Oke=zc({
refreshUrl:cl().optional().default(""),
scopes:tu(cl(),cl().optional().default("")).optional().default({}).catch({}),
selectedScopes:Bc(cl()).optional().default([]),
"x-scalar-client-id":cl().optional().default(""),token:cl().default(""),
"x-scalar-security-query":tu(cl(),cl()).optional(),
"x-scalar-security-body":tu(cl(),cl()).optional(),"x-tokenName":cl().optional()
}),wke="undefined"!=typeof window?window.location.origin+window.location.pathname:"",xke=["SHA-256","plain","no"],kke=cu(["header","body"]).optional(),Ske=lke.extend({
type:pu("oauth2"),"x-default-scopes":Bc(cl()).optional(),flows:zc({
implicit:Oke.extend({type:pu("implicit").default("implicit"),
authorizationUrl:bke,"x-scalar-redirect-uri":cl().optional().default(wke)}),
password:Oke.extend({type:pu("password").default("password"),tokenUrl:yke,
clientSecret:cl().default(""),username:cl().default(""),
password:cl().default(""),"x-scalar-credentials-location":kke}),
clientCredentials:Oke.extend({
type:pu("clientCredentials").default("clientCredentials"),tokenUrl:yke,
clientSecret:cl().default(""),"x-scalar-credentials-location":kke}),
authorizationCode:Oke.extend({
type:pu("authorizationCode").default("authorizationCode"),authorizationUrl:bke,
"x-usePkce":cu(xke).optional().default("no"),
"x-scalar-redirect-uri":cl().optional().default(wke),tokenUrl:yke,
clientSecret:cl().default(""),"x-scalar-credentials-location":kke})
}).partial().default({implicit:{selectedScopes:[],scopes:{},
"x-scalar-client-id":"",refreshUrl:"",token:"",type:"implicit",
authorizationUrl:"http://localhost:8080","x-scalar-redirect-uri":wke}})
}),_ke=Ske.merge(cke),Tke=tu(cl(),Bc(cl()).optional().default([]))
;Hc([uke,hke,Ske,gke]),Xc("type",[pke,mke,vke,_ke]).transform((e=>{
if("oauth2"===e.type&&e["x-default-scopes"]?.length){
Object.keys(e.flows).forEach((t=>{
e.flows[t]?.selectedScopes&&e["x-default-scopes"]&&(e.flows[t].selectedScopes=[e["x-default-scopes"]].flat())
}))}return e}))
;const Eke=Hc([cl().brand(),cl().brand().array()]).array().default([]),Ake=Hc([zc({
description:cl().optional(),default:cl().default("")}),cl()]),Cke=zc({
description:cl().optional(),color:cl().optional(),variables:tu(cl(),Ake)
}),$ke=tu(cl(),Cke),Pke=zc({description:cl().optional(),example:cl().optional()
}),Dke=tu(cl(),Pke),Ike=e=>Array.isArray(e)?e.map((e=>"object"==typeof e&&null!==e?Ike(e):e)):Object.fromEntries(Object.entries(e).filter((([e,t])=>void 0!==t)).map((([e,t])=>"object"==typeof t&&null!==t?[e,Ike(t)]:[e,t]))),Mke=zc({
name:cl().optional().nullable().catch(null),
identifier:cl().optional().catch(void 0),url:cl().url().optional().catch(void 0)
}).transform(Ike),Nke=zc({name:cl().optional(),
url:cl().url().optional().catch(void 0),email:cl().optional().catch(void 0)
}).transform(Ike),Rke=zc({title:cl().catch("API"),
summary:cl().optional().catch(void 0),description:cl().optional().catch(void 0),
termsOfService:cl().url().optional().catch(void 0),
contact:Nke.optional().catch(void 0),license:Mke.optional().catch(void 0),
version:cl().catch("1.0")}).merge(DX).transform(Ike),Lke=zc({
description:cl().optional().catch(void 0),url:cl()}).transform(Ike),Bke=zc({
tagName:cl()}).array();zc({type:pu("tag").optional().default("tag"),name:cl(),
description:cl().optional().catch(void 0),externalDocs:Lke.optional(),
"x-scalar-children":Bke.default([]).optional(),"x-internal":mc().optional(),
"x-scalar-ignore":mc().optional()}).extend({uid:jX.brand(),
children:Hc([cl().brand(),cl().brand()]).array().default([])});const jke=zc({
type:pu("collection").optional().default("collection"),
openapi:Hc([cl(),pu("3.0.0"),pu("3.1.0"),pu("4.0.0")]).optional().default("3.1.0"),
jsonSchemaDialect:cl().optional(),info:Rke.catch({title:"API",version:"1.0"}),
security:Bc(Tke).optional().default([]),
externalDocs:Lke.optional().catch(void 0),components:tu(cl(),$c()).optional(),
webhooks:tu(cl(),$c()).optional(),
"x-scalar-icon":cl().optional().default("interface-content-folder"),
"x-scalar-active-environment":cl().optional(),
"x-scalar-environments":$ke.optional(),"x-scalar-secrets":Dke.optional()
}),Uke=zc({uid:jX.brand(),securitySchemes:cl().array().default([]),
selectedSecuritySchemeUids:Eke,selectedServerUid:cl().brand().optional(),
servers:cl().brand().array().default([]),
requests:cl().brand().array().default([]),tags:cl().brand().array().default([]),
children:Hc([cl().brand(),cl().brand()]).array().default([]),
documentUrl:cl().optional(),watchMode:mc().optional().default(!1),
integration:cl().nullable().optional(),
useCollectionSecurity:mc().optional().default(!1),
watchModeStatus:cu(["IDLE","WATCHING","ERROR"]).optional().default("IDLE")})
;jke.merge(Uke)
;var zke=(e=>(e.Deprecated="deprecated",e.Experimental="experimental",
e.Stable="stable",e))(zke||{})
;const Fke=cu(["path","query","header","cookie"]),Zke=cu(["matrix","simple","form","label","spaceDelimited","pipeDelimited","deepObject"]),Qke=zc({
in:Fke,name:cl(),description:cl().optional(),
required:mc().optional().default(!1),deprecated:mc().optional().default(!1),
schema:$c().optional(),content:$c().optional(),style:Zke.optional(),
explode:mc().optional(),example:$c().optional(),examples:Hc([tu(cl(),zc({
value:$c().optional(),summary:cl().optional(),externalValue:cl().optional()
})),Bc($c())]).optional()});function Hke(e,t,n){const r={}
;t.forEach(((e,t)=>r[e]=t));const o=[],a=[];return e.forEach((e=>{
const t=r[e[n]]??-1;t>=0?o[t]=e:a.push(e)})),o.filter(Boolean).concat(...a)}
const Vke=e=>e["$ref-value"],qke=(e,t=Vke)=>"object"==typeof e&&null!==e&&"$ref"in e?t(e):e,Wke=(e,t,n)=>{
const[r,o]=e.split("#",2);if(r){if(!n.has(r))return
;return o?o.startsWith("/")?`${n.get(r)}${o}`:n.get(`${r}#${o}`):n.get(r)}
if(o)return o.startsWith("/")?o.slice(1):n.get(`${t}#${o}`)},Xke=e=>{
if(e&&"object"==typeof e&&e.$id&&"string"==typeof e.$id)return e.$id
},Gke=e=>e.join("/"),Yke=(e,t="",n=[],r=new Map,o=new WeakSet)=>{
if("object"!=typeof e||null===e)return r;if(o.has(e))return r;o.add(e)
;const a=Xke(e);a&&r.set(a,Gke(n));const i=a??t
;e.$anchor&&"string"==typeof e.$anchor&&r.set(`${i}#${e.$anchor}`,Gke(n))
;for(const s in e)"object"==typeof e[s]&&null!==e[s]&&Yke(e[s],i,[...n,s],r,o)
;return r};function Kke(e,t){return t.reduce(((e,t)=>{
if(void 0===e.value)return{context:"",value:void 0}
;if("object"!=typeof e.value||null===e.value)return{context:"",value:void 0}
;return{context:Xke(e.value)??e.context,value:e.value?.[t]}}),{context:"",
value:e})}const Jke=e=>"object"==typeof e&&!Array.isArray(e)&&null!==e
;function eSe(e){return e.split("/").filter(((e,t)=>(0!==t||"#"!==e)&&e))}
const tSe=Symbol("isMagicProxy"),nSe=Symbol("magicProxyTarget"),rSe="$ref-value",oSe="$ref",aSe=(e,t,n={
root:e,proxyCache:new WeakMap,cache:new Map,schemas:Yke(e),currentContext:""
})=>{if(!Jke(e)&&!Array.isArray(e))return e
;if(n.proxyCache.has(e))return n.proxyCache.get(e);const r=new Proxy(e,{
get(e,r,o){if(r===tSe)return!0;if(r===nSe)return e
;if("string"==typeof r&&r.startsWith("__scalar_")&&!t?.showInternal)return
;const a=Reflect.get(e,oSe,o),i=Xke(e);if(r===rSe&&"string"==typeof a){
if(n.cache.has(a))return n.cache.get(a)
;const e=Wke(a,i??n.currentContext,n.schemas);if(void 0===e)return
;const r=Kke(n.root,eSe(`#/${e}`));if(iSe(r.value))return r.value
;const o=aSe(r.value,t,{...n,currentContext:r.context});return n.cache.set(a,o),
o}const s=Reflect.get(e,r,o);return iSe(s)?s:aSe(s,t,{...n,
currentContext:i??n.currentContext})},set(e,r,o,a){const i=Reflect.get(e,oSe,a)
;if("string"==typeof r&&r.startsWith("__scalar_")&&!t?.showInternal)return!0
;if(r===rSe&&"string"==typeof i){
const t=Xke(e),r=Wke(i,t??n.currentContext,n.schemas);if(void 0===r)return
;const a=eSe(`#/${r}`);if(0===a.length)return!1
;const s=()=>Kke(n.root,a.slice(0,-1)).value
;return void 0===s()&&(!function(e,t){
t.reduce(((e,t)=>(void 0===e[t]&&(isNaN(Number(t))?e[t]={}:e[t]=[]),e[t])),e)
}(n.root,a.slice(0,-1)),
console.warn(`Trying to set $ref-value for invalid reference: ${i}\n\nPlease fix your input file to fix this issue.`)),
s()[a.at(-1)]=o,!0}return Reflect.set(e,r,o,a)},
deleteProperty:(e,t)=>Reflect.deleteProperty(e,t),
has:(e,n)=>!("string"==typeof n&&n.startsWith("__scalar_")&&!t?.showInternal)&&(n===rSe&&oSe in e||Reflect.has(e,n)),
ownKeys(e){
const n=Reflect.ownKeys(e).filter((e=>"string"!=typeof e||!(e.startsWith("__scalar_")&&!t?.showInternal)))
;return oSe in e&&!n.includes(rSe)&&n.push(rSe),n},
getOwnPropertyDescriptor(e,n){
if("string"==typeof n&&n.startsWith("__scalar_")&&!t?.showInternal)return
;const r=Reflect.get(e,oSe);return n===rSe&&"string"==typeof r?{configurable:!0,
enumerable:!0,value:void 0,writable:!1}:Reflect.getOwnPropertyDescriptor(e,n)}})
;return n.proxyCache.set(e,r),r
},iSe=e=>"object"==typeof e&&null!==e&&!0===e[tSe];function sSe(e){
return"object"!=typeof e||null===e?e:e[tSe]?e[nSe]:e}function lSe(e){
return"object"==typeof e&&null!==e&&!Array.isArray(e)}const cSe=(e,t)=>{
Object.assign(e,t)
},uSe=Symbol("isOverridesProxy"),dSe=Symbol("getOverridesTarget"),pSe=(e,t,n={
cache:new WeakMap})=>{if(!e||"object"!=typeof e)return e
;if(n.cache.has(e))return n.cache.get(e)
;const{overrides:r}=t??{},o=new Proxy(e,{get(e,t,o){if(t===uSe)return!0
;if(t===dSe)return e;const a=Reflect.get(e,t,o);return hSe(a)?a:lSe(a)?pSe(a,{
overrides:Reflect.get(r??{},t)},n):Reflect.get(r??{},t)??a},set(e,t,n,o){
if(t===uSe||t===dSe)return!1
;return r&&Reflect.has(r,t)&&r&&"object"==typeof r?(r[t]=n,
!0):Reflect.set(e,t,n,o)}});return n.cache.set(e,o),o
},hSe=e=>"object"==typeof e&&null!==e&&!0===e[uSe];function fSe(e){
return"object"==typeof e&&null!==e&&e[uSe]?e[dSe]:e}
const mSe=(new Date).toISOString()
;mSe.split("T")[0],mSe.split("T")[1].split(".")[0];const gSe=zc({
key:cl().default(""),value:hd().default(""),enabled:mc().default(!0),
file:Ac().optional(),description:cl().optional(),required:mc().optional(),
enum:Bc(cl()).optional(),examples:Bc(Ac()).optional(),
type:Hc([cl(),Bc(cl())]).optional(),format:cl().optional(),
minimum:sc().optional(),maximum:sc().optional(),default:Ac().optional(),
nullable:mc().optional()}).transform((e=>{const t={...e}
;return Array.isArray(t.type)&&t.type.includes("null")&&(t.nullable=!0),
Array.isArray(t.type)&&2===t.type.length&&t.type.includes("null")&&(t.type=t.type.find((e=>"null"!==e))),
t})),vSe=zc({url:cl(),base64:cl().optional()}).nullable();Hc([zc({
type:pu("string"),value:cl()}),zc({type:pu("file"),file:vSe})]);const bSe=zc({
raw:zc({encoding:cu(["json","text","html","javascript","xml","yaml","edn"]),
value:cl().default(""),mimeType:cl().optional()}).optional(),formData:zc({
encoding:Hc([pu("form-data"),pu("urlencoded")]).default("form-data"),
value:gSe.array().default([])}).optional(),binary:rd(Blob).optional(),
activeBody:Hc([pu("raw"),pu("formData"),pu("binary")]).default("raw")}),ySe=zc({
encoding:cu(["application/json","text/plain","text/html","application/javascript","application/xml","application/yaml","application/edn","application/octet-stream","application/x-www-form-urlencoded","multipart/form-data","binary"]),
content:Hc([tu(cl(),Ac()),cl()]),file:vSe.optional()});zc({uid:jX.brand(),
type:pu("requestExample").optional().default("requestExample"),
requestUid:cl().brand().optional(),name:cl().optional().default("Name"),
body:bSe.optional().default({activeBody:"raw"}),parameters:zc({
path:gSe.array().default([]),query:gSe.array().default([]),
headers:gSe.array().default([{key:"Accept",value:"*/*",enabled:!0}]),
cookies:gSe.array().default([])}).optional().default({path:[],query:[],
headers:[{key:"Accept",value:"*/*",enabled:!0}],cookies:[]}),
serverVariables:tu(cl(),Bc(cl())).optional()})
;const OSe=tu(cl(),cl()).optional(),wSe=zc({name:cl().optional(),
body:ySe.optional(),parameters:zc({path:OSe,query:OSe,headers:OSe,cookies:OSe})
}),xSe=Ac(),kSe=zc({tags:cl().array().optional(),summary:cl().optional(),
description:cl().optional(),operationId:cl().optional(),
security:Bc(Tke).optional(),requestBody:xSe.optional(),
parameters:Qke.array().optional(),externalDocs:Lke.optional(),
deprecated:mc().optional(),responses:tu(cl(),Ac()).optional(),
callbacks:tu(cl(),tu(cl(),tu(cl(),Ac()))).optional(),
"x-scalar-examples":tu(cl(),wSe).optional(),"x-internal":mc().optional(),
"x-scalar-ignore":mc().optional()}),SSe=zc({
"x-scalar-stability":cu([zke.Deprecated,zke.Experimental,zke.Stable]).optional().catch(void 0)
}),_Se=zc({type:pu("request").optional().default("request"),uid:jX.brand(),
path:cl().optional().default(""),
method:cu(["delete","get","head","options","patch","post","put","trace"]).default("get"),
servers:cl().brand().array().default([]),
selectedServerUid:cl().brand().optional().nullable().default(null),
examples:cl().brand().array().default([]),selectedSecuritySchemeUids:Eke})
;kSe.omit({"x-scalar-examples":!0}).merge($X).merge(SSe).merge(_Se).merge(PX)
;const TSe=(e={})=>{
const{delay:t=328,maxWait:n}=e,r=new Map,o=new Map,a=new Map,i=e=>{
const t=a.get(e),n=r.get(e);void 0!==n&&(clearTimeout(n),r.delete(e))
;const i=o.get(e)
;if(void 0!==i&&(clearTimeout(i),o.delete(e)),a.delete(e),void 0!==t)try{t()
}catch{}};return{execute:(e,s)=>{a.set(e,s);const l=r.get(e)
;void 0!==l&&clearTimeout(l),
r.set(e,setTimeout((()=>i(e)),t)),void 0===n||o.has(e)||o.set(e,setTimeout((()=>i(e)),n))
},cleanup:()=>{
r.forEach(clearTimeout),o.forEach(clearTimeout),r.clear(),o.clear(),a.clear()}}}
;function ESe(){const e=new Set;function t(t){return e.add(t),()=>n(t)}
function n(t){e.delete(t)}return{on:t,once:function(e){
return t((function t(...r){n(t),e(...r)}))},off:n,emit:function(t){
e?.forEach((e=>e(t)))},reset:function(){e.clear()},listeners:()=>Array.from(e)}}
function ASe(){return{executeRequest:ESe(),focusAddressBar:ESe(),
cancelRequest:ESe(),requestStatus:ESe(),commandPalette:ESe(),hotKeys:ESe()}}
function CSe(e){return e.replace(/~/g,"~0").replace(/\//g,"~1")}
function $Se(e,t,n=[]){const r={};for(const[o,a]of Object.entries(e)){
const e=[...n,o]
;Array.isArray(a)?r[o]=a.map(((n,r)=>"object"!=typeof n||Array.isArray(n)||null===n?n:$Se(n,t,[...e,r.toString()]))):r[o]="object"!=typeof a||null===a?a:$Se(a,t,e)
}return t(r,n)}function PSe(e){const t=e["x-example"],n=e["x-examples"]
;return delete e["x-example"],delete e["x-examples"],{xExample:t,xExamples:n}}
function DSe(e){
return"object"==typeof e&&null!==e&&!Array.isArray(e)&&Object.keys(e).length>0}
const ISe=new Set(["summary","description","value","externalValue"])
;function MSe(e){if("object"!=typeof e||null===e)return!1
;const t=e,n="value"in t||"externalValue"in t,r=Object.keys(t).every((e=>ISe.has(e)))
;return n&&r}function NSe(e){return MSe(e)?e:{value:e}}const RSe=e=>{switch(e){
case"application":return"clientCredentials";case"accessCode":
return"authorizationCode";case"implicit":return"implicit";case"password":
return"password";default:return e}};function LSe(e){
return["type","format","items","maximum","exclusiveMaximum","minimum","exclusiveMinimum","maxLength","minLength","pattern","maxItems","minItems","uniqueItems","enum","multipleOf"].reduce(((t,n)=>(Object.hasOwn(e,n)&&(t[n]=e[n],
delete e[n]),t)),{})}function BSe(e){
if("formData"===e)throw new Error("Encountered a formData parameter which should have been filtered out by the caller")
;if("body"===e)throw new Error("Encountered a body parameter which should have been filtered out by the caller")
;return e}function jSe(e){if(Object.hasOwn(e,"$ref")&&"$ref"in e)return{
$ref:e.$ref};const t=function(e){
if("array"!==e.type||"query"!==e.in&&"path"!==e.in&&"header"!==e.in)return{}
;const t=e.collectionFormat??"csv"
;if(e.in in FSe&&t in FSe[e.in])return FSe[e.in][t];return{}
}(e),n=LSe(e),{xExample:r,xExamples:o}=PSe(e);if(DSe(r)?e.examples=function(e){
return Object.entries(e).reduce(((e,[t,n])=>(e[t]={value:n},e)),{})
}(r):DSe(o)&&(e.examples=Object.entries(o).reduce(((e,[t,n])=>(e[t]=NSe(n),
e)),{})),
delete e.collectionFormat,delete e.default,!e.in)throw new Error('Parameter object must have an "in" property')
;return{schema:n,...t,...e,in:BSe(e.in)}}function USe(e){
if(Object.hasOwn(e,"$ref")&&"$ref"in e)return{$ref:e.$ref};const t=LSe(e)
;return{...e,schema:t}}const zSe={ssv:{},pipes:{},multi:{},csv:{style:"simple",
explode:!1},tsv:{}},FSe={header:zSe,query:{ssv:{style:"spaceDelimited",
explode:!1},pipes:{style:"pipeDelimited",explode:!1},multi:{style:"form",
explode:!0},csv:{style:"form",explode:!1},tsv:{}},path:zSe};function ZSe(e,t){
const{xExample:n,xExamples:r}=PSe(e);delete e.name,delete e.in
;const{schema:o,...a}=e,i={content:{},...a}
;if(i.content)for(const l of t)if(i.content[l]={schema:o
},DSe(n)&&l in n&&(i.content[l].example=n[l]),DSe(r)&&l in r){const e=r[l]
;DSe(e)&&Object.values(e).every((e=>MSe(e)))?i.content[l].examples=e:DSe(s=e)&&Object.values(s).every((e=>"object"==typeof e&&null!==e&&!Array.isArray(e)))?i.content[l].examples=Object.entries(e).reduce(((e,[t,n])=>(e[t]=NSe(n),
e)),{}):i.content[l].examples={default:NSe(e)}}var s;return i}
function QSe(e,t=["multipart/form-data"]){const n={content:{}
},r=t.filter((e=>"multipart/form-data"===e||"application/x-www-form-urlencoded"===e)),o=r.length>0?r:["multipart/form-data"]
;if(n.content)for(const a of o){n.content[a]={schema:{type:"object",
properties:{},required:[]}};const t=n.content?.[a]
;if(t?.schema&&"object"==typeof t.schema&&"properties"in t.schema)for(const n of e)n.name&&t.schema.properties&&(t.schema.properties[n.name]={
type:n.type,description:n.description,...n.format?{format:n.format}:{}
},n.required&&Array.isArray(t.schema.required)&&t.schema.required.push(n.name))}
return n}function HSe(e,t){const n={
parameters:e.filter((e=>!("body"===e.in||"formData"===e.in))).map((e=>jSe(e)))
},r=structuredClone(e.find((e=>"body"===e.in))??{})
;r&&Object.keys(r).length&&(n.requestBody=ZSe(r,t))
;const o=e.filter((e=>"formData"===e.in));if(o.length>0){const e=QSe(o,t)
;"object"!=typeof n.requestBody?n.requestBody=e:n.requestBody={...n.requestBody,
content:{...n.requestBody.content,...e.content}
},"object"!=typeof n.requestBody&&(n.requestBody={content:{}})}return n}
const VSe=new Set(["properties","items","allOf","anyOf","oneOf","not","additionalProperties","schema"])
;const qSe=(e,t)=>{
void 0!==e.type&&!0===e.nullable&&(e.type=[e.type,"null"],delete e.nullable),
!0===e.exclusiveMinimum?(e.exclusiveMinimum=e.minimum,
delete e.minimum):!1===e.exclusiveMinimum&&delete e.exclusiveMinimum,
!0===e.exclusiveMaximum?(e.exclusiveMaximum=e.maximum,
delete e.maximum):!1===e.exclusiveMaximum&&delete e.exclusiveMaximum
;const n=t?.some(((e,n)=>{if("examples"===e&&n>0){return"properties"!==t[n-1]}
return!1}));if(void 0===e.example||n||(!function(e){
return!!e&&(!!e.some((e=>VSe.has(e)))||!!e.some((e=>e.endsWith("Schema")))||e.length>=2&&"components"===e[0]&&"schemas"===e[1])
}(t)?e.examples={default:{value:e.example}
}:e.examples=[e.example],delete e.example),
"object"===e.type&&void 0!==e.properties){
const n=t?.slice(0,-1),r=n?.some(((e,n)=>"content"===e&&"multipart/form-data"===t?.[n+1]))
;if(r&&null!==e.properties)for(const t of Object.values(e.properties))"object"==typeof t&&null!==t&&"type"in t&&"format"in t&&"string"===t.type&&"binary"===t.format&&(t.contentMediaType="application/octet-stream",
delete t.format)}
if(t?.includes("content")&&t?.includes("application/octet-stream"))return{}
;const{format:r,...o}=e;if("string"===e.type){if("binary"===e.format)return{
...o,type:"string",contentMediaType:"application/octet-stream"}
;if("base64"===e.format)return{...o,type:"string",contentEncoding:"base64"}
;if("byte"===e.format){
const e=t?.slice(0,-1),n=e?.find(((e,n)=>"content"===t?.[n-1]));return{...o,
type:"string",contentEncoding:"base64",contentMediaType:n}}}
return void 0!==e["x-webhooks"]&&(e.webhooks=e["x-webhooks"],
delete e["x-webhooks"]),e};function WSe(e){if(null!==e){if("string"==typeof e){
if(""===e.trim())return;try{return JSON.parse(e)}catch{
const t=/^[^:]+:/.test(e),n=e.slice(0,50).trimStart().startsWith("{")
;if(!t||n)return;return xX(e,{maxAliasCount:1e4,merge:!0})}}
return void 0!==(t=e)&&Array.isArray(t)&&t.length>0&&t.some((e=>!0===e.isEntrypoint)),
e;var t}}function XSe(e,t){let n=0;for(let r=e.length-1;r>=0;r--){const t=e[r]
;"."===t?e.splice(r,1):".."===t?(e.splice(r,1),n++):n&&(e.splice(r,1),n--)}
if(t)for(;n--;n)e.unshift("..");return e}
const GSe=/^(\/?|)([\s\S]*?)((?:\.{1,2}|[^/]+?|)(\.[^./]*|))(?:[/]*)$/,YSe=e=>GSe.exec(e).slice(1)
;function KSe(...e){let t="",n=!1;for(let r=e.length-1;r>=-1&&!n;r--){
const o=r>=0?e[r]:"/"
;if("string"!=typeof o)throw new TypeError("Arguments to path.resolve must be strings")
;o&&(t=o+"/"+t,n="/"===o.charAt(0))}
return t=XSe(t.split("/").filter((e=>!!e)),!n).join("/"),(n?"/":"")+t||"."}
function JSe(e){const t=e_e(e),n="/"===e.slice(-1)
;let r=XSe(e.split("/").filter((e=>!!e)),!t).join("/")
;return r||t||(r="."),r&&n&&(r+="/"),(t?"/":"")+r}function e_e(e){
return"/"===e.charAt(0)}const t_e={extname:function(e){return YSe(e)[3]},
basename:function(e,t){let n=YSe(e)[2]
;return t&&n.slice(-t.length)===t&&(n=n.slice(0,-t.length)),n},
dirname:function(e){const t=YSe(e),n=t[0];let r=t[1]
;return n||r?(r&&(r=r.slice(0,-1)),n+r):"."},sep:"/",delimiter:":",
relative:function(e,t){const n=KSe(e).substring(1),r=KSe(t).substring(1)
;function o(e){let t=0;for(;t<e.length&&""===e[t];t++);let n=e.length-1
;for(;n>=0&&""===e[n];n--);return t>n?[]:e.slice(t,n-t+1)}
const a=o(n.split("/")),i=o(r.split("/")),s=Math.min(a.length,i.length);let l=s
;for(let u=0;u<s;u++)if(a[u]!==i[u]){l=u;break}let c=[]
;for(let u=l;u<a.length;u++)c.push("..")
;return c=c.concat(i.slice(l)),c.join("/")},join:function(...e){
return JSe(e.filter((e=>{
if("string"!=typeof e)throw new TypeError("Arguments to path.join must be strings")
;return e})).join("/"))},isAbsolute:e_e,normalize:JSe,resolve:KSe}
;function n_e(e){return decodeURI(e.replace(/~1/g,"/").replace(/~0/g,"~"))}
function r_e(e){return e.split("/").slice(1).map(n_e)}const o_e=e=>{let t=0,n=0
;const r=e.length,o=15&r,a=r-o,i=2277735313,s=1291169091,l=1390208809,c=944331445
;for(let u=0;u<a;u+=16){
let r=255&e.charCodeAt(u)|(255&e.charCodeAt(u+1))<<8|(255&e.charCodeAt(u+2))<<16|(255&e.charCodeAt(u+3))<<24,o=255&e.charCodeAt(u+4)|(255&e.charCodeAt(u+5))<<8|(255&e.charCodeAt(u+6))<<16|(255&e.charCodeAt(u+7))<<24,a=255&e.charCodeAt(u+8)|(255&e.charCodeAt(u+9))<<8|(255&e.charCodeAt(u+10))<<16|(255&e.charCodeAt(u+11))<<24,d=255&e.charCodeAt(u+12)|(255&e.charCodeAt(u+13))<<8|(255&e.charCodeAt(u+14))<<16|(255&e.charCodeAt(u+15))<<24
;r=Math.imul(r,i),
r=r<<15|r>>>17,r=Math.imul(r,s),t^=r,t=t<<13|t>>>19,t=Math.imul(t,5)+3864292196,
o=Math.imul(o,s),
o=o<<16|o>>>16,o=Math.imul(o,l),n^=o,n=n<<17|n>>>15,n=Math.imul(n,5)+461845907,
a=Math.imul(a,l),
a=a<<17|a>>>15,a=Math.imul(a,c),t^=a,t=t<<15|t>>>17,t=Math.imul(t,5)+1390208809,
d=Math.imul(d,c),
d=d<<18|d>>>14,d=Math.imul(d,i),n^=d,n=n<<13|n>>>19,n=Math.imul(n,5)+944331445}
if(o>0){let r=0,u=0,d=0,p=0
;o>=15&&(p^=(255&e.charCodeAt(a+14))<<16),o>=14&&(p^=(255&e.charCodeAt(a+13))<<8),
o>=13&&(p^=255&e.charCodeAt(a+12),
p=Math.imul(p,c),p=p<<18|p>>>14,p=Math.imul(p,i),
n^=p),o>=12&&(d^=(255&e.charCodeAt(a+11))<<24),
o>=11&&(d^=(255&e.charCodeAt(a+10))<<16),o>=10&&(d^=(255&e.charCodeAt(a+9))<<8),
o>=9&&(d^=255&e.charCodeAt(a+8),
d=Math.imul(d,l),d=d<<17|d>>>15,d=Math.imul(d,c),
t^=d),o>=8&&(u^=(255&e.charCodeAt(a+7))<<24),
o>=7&&(u^=(255&e.charCodeAt(a+6))<<16),
o>=6&&(u^=(255&e.charCodeAt(a+5))<<8),o>=5&&(u^=255&e.charCodeAt(a+4),
u=Math.imul(u,s),
u=u<<16|u>>>16,u=Math.imul(u,l),n^=u),o>=4&&(r^=(255&e.charCodeAt(a+3))<<24),
o>=3&&(r^=(255&e.charCodeAt(a+2))<<16),
o>=2&&(r^=(255&e.charCodeAt(a+1))<<8),o>=1&&(r^=255&e.charCodeAt(a),
r=Math.imul(r,i),r=r<<15|r>>>17,r=Math.imul(r,s),t^=r)}
return t^=r,n^=r,t+=n,n+=t,
t^=t>>>16,t=Math.imul(t,2246822507),t^=t>>>13,t=Math.imul(t,3266489909),
t^=t>>>16,
n^=n>>>16,n=Math.imul(n,2246822507),n^=n>>>13,n=Math.imul(n,3266489909),
n^=n>>>16,
t+=n,n+=t,(t>>>0).toString(16).padStart(8,"0")+(n>>>0).toString(16).padStart(8,"0")
};function a_e(e){const t=o_e(e).substring(0,7)
;return t.match(/^\d+$/)?"a"+t.substring(1):t}async function i_e(e,t,n,r,o=0){
if(o>=100)throw"Can not generate unique compressed values";const a=await e(r??t)
;return void 0!==n[a]&&n[a]!==t?i_e(e,t,n,a,o+1):(n[a]=t,a)}const s_e=(e,t)=>{
const n=Object.fromEntries(Object.entries(t).map((([e,t])=>[t,e])));return{
generate:async r=>{const o=n[r];if(o)return o
;const a=await i_e(e,r,t),i=a.match(/^\d+$/)?`a${a}`:a;return n[r]=i,i}}}
;function l_e(e){try{const t=new URL(e)
;return"http:"===t.protocol||"https:"===t.protocol}catch{return!1}}
function c_e(e){return!l_e(e)&&!function(e){
return/^\s*(?:-\s*)?[\w\-]+\s*:\s*.+\n.*/.test(e)}(e)&&!function(e){
if(!/^\s*(\{)/.test(e.slice(0,500)))return!1;try{const t=JSON.parse(e)
;return Jke(t)}catch{return!1}}(e)}function u_e(e){return e.startsWith("#")}
function d_e(e,t){const n=t.find((t=>t.validate(e)))
;return n?n.exec(e):Promise.resolve({ok:!1})}function p_e(e,t,n){
if(""===t)throw new Error("Cannot set value at root ('') pointer")
;const r=r_e(t);let o=e;for(let a=0;a<r.length;a++){
const e=r[a],t=a===r.length-1,i=r[a+1],s=/^\d+$/.test(i??"")
;t?o[e]=n:(e in o&&"object"==typeof o[e]||(o[e]=s?[]:{}),o=o[e])}}
function h_e(e,t){if(!u_e(e))throw"Please provide an internal ref"
;return`#/${t.map(CSe).join("/")}${e.substring(1)}`}function f_e(e,t){
if(Jke(e)&&(Object.values(e).forEach((e=>f_e(e,t))),
"object"==typeof e&&"$ref"in e&&"string"==typeof e.$ref)){const n=e.$ref
;if(!u_e(n))return;e.$ref=h_e(n,t)}}const m_e=(e,t,n,r,o,a=!1,i=new Set)=>{
const s=Kke(t,r_e(n)).value;if(i.has(s))return;i.add(s),p_e(e,n,s);const l=n=>{
if(n&&"object"==typeof n){
"$ref"in n&&"string"==typeof n.$ref&&(n.$ref.startsWith(`#/${r}/${CSe(o)}`)||a)&&m_e(e,t,n.$ref.substring(1),r,o,a,i)
;for(const e of Object.values(n))l(e)}};l(s)},g_e="x-ext",v_e="x-ext-urls"
;async function b_e(e,t){
t.externalDocumentsKey=t.externalDocumentsKey??g_e,t.externalDocumentsMappingsKey=t.externalDocumentsMappingsKey??v_e
;const n=t.cache??new Map,r=t.plugins.filter((e=>"loader"===e.type)),o=t.plugins.filter((e=>"lifecycle"===e.type)),a=await(async()=>{
if("string"!=typeof e)return e;const t=await d_e(e,r)
;if(t.ok&&"object"==typeof t.data)return t.data
;throw new Error("Failed to resolve input: Please provide a valid string value or pass a loader to process the input")
})(),i=t.root??a,s=Yke(i),l=void 0!==t.root&&t.root!==a||void 0!==t.depth,c=t.visitedNodes??new Set
;void 0===i[t.externalDocumentsMappingsKey]&&(i[t.externalDocumentsMappingsKey]={})
;const{generate:u}=s_e(t.compress??a_e,i[t.externalDocumentsMappingsKey]),d=async(e,...n)=>{
const r=t.hooks?.[e];r&&await r(...n);for(const t of o){const r=t[e]
;r&&await r(...n)}
},p=async(o,a=(()=>t.origin?t.origin:"string"!=typeof e?"":l_e(e)||c_e(e)?e:"")(),h=!1,f=0,m=[],g=null)=>{
if(void 0!==t.depth&&f>t.depth)return;if(!Jke(o)&&!Array.isArray(o))return
;if(c.has(o))return;c.add(o);const v={path:m,resolutionCache:n,parentNode:g,
rootNode:i,loaders:r};await d("onBeforeNodeProcess",o,v);const b=Xke(o)
;if("object"==typeof o&&"$ref"in o&&"string"==typeof o.$ref){
const e=o.$ref,c="$global"in o&&"boolean"==typeof o.$global&&o.$global,m=Wke(e,b??a,s)
;if(void 0!==m){if(l){
const e=r_e(`/${m}`),t=e.length>0?Kke(i,e.slice(0,-1)).value:void 0,n=Kke(i,e)
;await p(n.value,n.context,h,f+1,e,t)}
return void(await d("onAfterNodeProcess",o,v))}
const[g,y=""]=e.split("#",2),O=function(e,t){if(l_e(t))return t;if(l_e(e)){
const n=new URL(e);if(t.startsWith("/"))return n.pathname=t,n.toString()
;const r=t_e.join(t_e.dirname(n.pathname),t);return new URL(r,e).toString()}
return t_e.join(t_e.dirname(e),t)}(b??a,g),w=await u(O),x=n.has(O)
;x||n.set(O,d_e(O,r)),await d("onResolveStart",o);const k=await n.get(O)
;return k.ok?(x||(c||f_e(k.data,[g_e,w]),
await p(k.data,c?a:O,c,f+1,[t.externalDocumentsKey,w,i[t.externalDocumentsMappingsKey]]),
p_e(i,`/${t.externalDocumentsMappingsKey}/${CSe(w)}`,O)),
!0===t.treeShake?m_e(i,{[t.externalDocumentsKey]:{[w]:k.data}
},h_e(`#${y}`,[t.externalDocumentsKey,w]).substring(1),t.externalDocumentsKey,w):x||p_e(i,`/${t.externalDocumentsKey}/${w}`,k.data),
o.$ref=h_e(`#${y}`,[t.externalDocumentsKey,w]),
await d("onResolveSuccess",o),void(await d("onAfterNodeProcess",o,v))):(await d("onResolveError",o),
await d("onAfterNodeProcess",o,v),
console.warn(`Failed to resolve external reference "${O}". The reference may be invalid, inaccessible, or missing a loader for this type of reference.`))
}await Promise.all(Object.entries(o).map((async([e,n])=>{
e!==t.externalDocumentsKey&&e!==t.externalDocumentsMappingsKey&&await p(n,b??a,h,f+1,[...m,e],o)
}))),await d("onAfterNodeProcess",o,v)}
;return await p(a),t.urlMap||l||delete i[t.externalDocumentsMappingsKey],a}
function y_e(e,t){return function(e){let t=e
;return null!==t&&"string"==typeof t.openapi&&t.openapi.startsWith("3.0")?(t.openapi="3.1.1",
t=$Se(t,qSe),t):t}(function(e){let t=e
;if(null===t||"object"!=typeof t||"string"!=typeof t.swagger||!t.swagger?.startsWith("2.0"))return t
;if(t.openapi="3.0.4",delete t.swagger,t.host){
const e=Array.isArray(t.schemes)&&t.schemes?.length?t.schemes:["http"]
;t.servers=e.map((e=>({url:`${e}://${t.host}${t.basePath??""}`
}))),delete t.basePath,delete t.schemes,delete t.host
}else t.basePath&&(t.servers=[{url:t.basePath}],delete t.basePath)
;if(t.definitions&&(t.components=Object.assign({},t.components,{
schemas:t.definitions
}),delete t.definitions,t=$Se(t,(e=>("string"==typeof e.$ref&&e.$ref.startsWith("#/definitions/")&&(e.$ref=e.$ref.replace(/^#\/definitions\//,"#/components/schemas/")),
e)))),
t=$Se(t,(e=>("file"===e.type&&(e.type="string",e.format="binary"),e))),Object.hasOwn(t,"parameters")){
t=$Se(t,(e=>{if("string"==typeof e.$ref&&e.$ref.startsWith("#/parameters/")){
const n=e.$ref.split("/")[2];if(!n)return e
;const r=t.parameters&&"object"==typeof t.parameters&&n in t.parameters?t.parameters[n]:void 0
;r&&"object"==typeof r&&"in"in r&&("body"===r.in||"formData"===r.in)?e.$ref=e.$ref.replace(/^#\/parameters\//,"#/components/requestBodies/"):e.$ref=e.$ref.replace(/^#\/parameters\//,"#/components/parameters/")
}return e})),t.components??={}
;const e={},n={},r=t.parameters&&"object"==typeof t.parameters?t.parameters:{}
;for(const[o,a]of Object.entries(r))if(a&&"object"==typeof a)if("$ref"in a){
const t=jSe(a);e[o]=t
}else if("in"in a)if("body"===a.in)n[o]=ZSe(a,t.consumes??["application/json"]);else if("formData"===a.in)n[o]=QSe([a],t.consumes);else{
const t=jSe(a);e[o]=t}
Object.keys(e).length>0&&(t.components.parameters=e),Object.keys(n).length>0&&(t.components.requestBodies=n),
delete t.parameters}
if(Object.hasOwn(t,"responses")&&"object"==typeof t.responses&&null!==t.responses){
t=$Se(t,(e=>("string"==typeof e.$ref&&e.$ref.startsWith("#/responses/")&&(e.$ref=e.$ref.replace(/^#\/responses\//,"#/components/responses/")),
e))),t.components??={};const e={},n=t.responses
;for(const[r,o]of Object.entries(n))if(o&&"object"==typeof o)if("$ref"in o)e[r]=o;else{
const n=o,a=t.produces??["application/json"];if(n.schema){
"object"!=typeof n.content&&(n.content={});for(const e of a)n.content[e]={
schema:n.schema};delete n.schema}if(n.examples&&"object"==typeof n.examples){
"object"!=typeof n.content&&(n.content={})
;for(const[e,t]of Object.entries(n.examples))"object"!=typeof n.content[e]&&(n.content[e]={}),
n.content[e].example=t;delete n.examples}
n.headers&&"object"==typeof n.headers&&(n.headers=Object.entries(n.headers).reduce(((e,[t,n])=>n&&"object"==typeof n?{
[t]:USe(n),...e}:e),{})),e[r]=n}
Object.keys(e).length>0&&(t.components.responses=e),delete t.responses}
if("object"==typeof t.paths)for(const n in t.paths)if(Object.hasOwn(t.paths,n)){
const e=t.paths&&"object"==typeof t.paths&&n in t.paths?t.paths[n]:void 0
;if(!e||"object"!=typeof e)continue;let r
;for(const n in e)if("parameters"===n&&Object.hasOwn(e,n)){
const n=HSe(e.parameters,t.consumes??["application/json"])
;e.parameters=n.parameters,r=n.requestBody}else if(Object.hasOwn(e,n)){
const o=e[n];if(r&&(o.requestBody=r),o.parameters){
const e=HSe(o.parameters,o.consumes??t.consumes??["application/json"])
;o.parameters=e.parameters,e.requestBody&&(o.requestBody=e.requestBody)}
if(delete o.consumes,
o.responses)for(const e in o.responses)if(Object.hasOwn(o.responses,e)){
const n=o.responses[e]
;if(n.headers&&"object"==typeof n.headers&&(n.headers=Object.entries(n.headers).reduce(((e,[t,n])=>n&&"object"==typeof n?{
[t]:USe(n),...e}:e),{})),n.schema){
const e=t.produces??o.produces??["application/json"]
;"object"!=typeof n.content&&(n.content={});for(const t of e)n.content[t]={
schema:n.schema};delete n.schema}if(n.examples&&"object"==typeof n.examples){
"object"!=typeof n.content&&(n.content={})
;for(const[e,t]of Object.entries(n.examples))"object"!=typeof n.content[e]&&(n.content[e]={}),
n.content[e].example=t;delete n.examples}}
delete o.produces,0===o.parameters?.length&&delete o.parameters}}
if(t.securityDefinitions){
"object"==typeof t.components&&null!==t.components||(t.components={}),
t.components&&"object"==typeof t.components&&Object.assign(t.components,{
securitySchemes:{}})
;for(const[e,n]of Object.entries(t.securityDefinitions))if("object"==typeof n)if("type"in n&&"oauth2"===n.type){
const{flow:r,authorizationUrl:o,tokenUrl:a,scopes:i}=n
;t.components&&"object"==typeof t.components&&"securitySchemes"in t.components&&t.components.securitySchemes&&Object.assign(t.components.securitySchemes,{
[e]:{type:"oauth2",flows:{[RSe(r||"implicit")]:Object.assign({},o&&{
authorizationUrl:o},a&&{tokenUrl:a},i&&{scopes:i})}}})
}else"type"in n&&"basic"===n.type?t.components&&"object"==typeof t.components&&"securitySchemes"in t.components&&t.components.securitySchemes&&Object.assign(t.components.securitySchemes,{
[e]:{type:"http",scheme:"basic"}
}):t.components&&"object"==typeof t.components&&"securitySchemes"in t.components&&t.components.securitySchemes&&Object.assign(t.components.securitySchemes,{
[e]:n});delete t.securityDefinitions}return delete t.consumes,delete t.produces,
t}(e))}
const O_e=e=>JSON.stringify(e,null,2),w_e=e=>kX(e),x_e="An error occurred while building the request",k_e="An unknown error has occurred.",S_e="The URL seems to be invalid. Try adding a valid URL.",__e="There is an invalid header present, please double check your params.",T_e="File uploads are not saved in history, you must re-upload the file.",E_e="The request has been cancelled",A_e="An error occurred while making the request",C_e="The address bar input seems to be empty. Try adding a URL.",$_e=(e,t=k_e)=>(console.error(e),
e instanceof Error?(e.message=P_e(e.message),
e):"string"==typeof e?new Error(P_e(e)):new Error(t)),P_e=e=>"Failed to execute 'append' on 'FormData': parameter 2 is not of type 'Blob'."===e?T_e:"Failed to construct 'URL': Invalid URL"===e?S_e:"Failed to execute 'fetch' on 'Window': Invalid name"===e?__e:e,D_e="/* basic theme */\n:root {\n  --scalar-text-decoration: underline;\n  --scalar-text-decoration-hover: underline;\n}\n.light-mode {\n  --scalar-background-1: #fff;\n  --scalar-background-2: #f6f6f6;\n  --scalar-background-3: #e7e7e7;\n  --scalar-background-accent: #8ab4f81f;\n\n  --scalar-color-1: #1b1b1b;\n  --scalar-color-2: #757575;\n  --scalar-color-3: #8e8e8e;\n\n  --scalar-color-accent: #0099ff;\n  --scalar-border-color: #dfdfdf;\n}\n.dark-mode {\n  --scalar-background-1: #0f0f0f;\n  --scalar-background-2: #1a1a1a;\n  --scalar-background-3: #272727;\n\n  --scalar-color-1: #e7e7e7;\n  --scalar-color-2: #a4a4a4;\n  --scalar-color-3: #797979;\n\n  --scalar-color-accent: #00aeff;\n  --scalar-background-accent: #3ea6ff1f;\n\n  --scalar-border-color: #2d2d2d;\n}\n/* Document Sidebar */\n.light-mode,\n.dark-mode {\n  --scalar-sidebar-background-1: var(--scalar-background-1);\n  --scalar-sidebar-color-1: var(--scalar-color-1);\n  --scalar-sidebar-color-2: var(--scalar-color-2);\n  --scalar-sidebar-border-color: var(--scalar-border-color);\n\n  --scalar-sidebar-item-hover-background: var(--scalar-background-2);\n  --scalar-sidebar-item-hover-color: var(--scalar-sidebar-color-2);\n\n  --scalar-sidebar-item-active-background: var(--scalar-background-2);\n  --scalar-sidebar-color-active: var(--scalar-sidebar-color-1);\n\n  --scalar-sidebar-indent-border: var(--scalar-sidebar-border-color);\n  --scalar-sidebar-indent-border-hover: var(--scalar-sidebar-border-color);\n  --scalar-sidebar-indent-border-active: var(--scalar-sidebar-border-color);\n\n  --scalar-sidebar-search-background: transparent;\n  --scalar-sidebar-search-color: var(--scalar-color-3);\n  --scalar-sidebar-search-border-color: var(--scalar-border-color);\n}\n/* advanced */\n.light-mode {\n  --scalar-color-green: #069061;\n  --scalar-color-red: #ef0006;\n  --scalar-color-yellow: #edbe20;\n  --scalar-color-blue: #0082d0;\n  --scalar-color-orange: #ff5800;\n  --scalar-color-purple: #5203d1;\n\n  --scalar-link-color: var(--scalar-color-1);\n  --scalar-link-color-hover: var(--scalar-link-color);\n\n  --scalar-button-1: rgba(0, 0, 0, 1);\n  --scalar-button-1-hover: rgba(0, 0, 0, 0.8);\n  --scalar-button-1-color: rgba(255, 255, 255, 0.9);\n\n  --scalar-tooltip-background: color-mix(in srgb, #1a1a1a, transparent 10%);\n  --scalar-tooltip-color: color-mix(in srgb, #fff, transparent 15%);\n\n  --scalar-color-alert: color-mix(in srgb, var(--scalar-color-orange), var(--scalar-color-1) 20%);\n  --scalar-color-danger: color-mix(in srgb, var(--scalar-color-red), var(--scalar-color-1) 20%);\n\n  --scalar-background-alert: color-mix(in srgb, var(--scalar-color-orange), var(--scalar-background-1) 95%);\n  --scalar-background-danger: color-mix(in srgb, var(--scalar-color-red), var(--scalar-background-1) 95%);\n}\n.dark-mode {\n  --scalar-color-green: #00b648;\n  --scalar-color-red: #dc1b19;\n  --scalar-color-yellow: #ffc90d;\n  --scalar-color-blue: #4eb3ec;\n  --scalar-color-orange: #ff8d4d;\n  --scalar-color-purple: #b191f9;\n\n  --scalar-link-color: var(--scalar-color-1);\n  --scalar-link-color-hover: var(--scalar-link-color);\n\n  --scalar-button-1: rgba(255, 255, 255, 1);\n  --scalar-button-1-hover: rgba(255, 255, 255, 0.9);\n  --scalar-button-1-color: black;\n\n  --scalar-tooltip-background: color-mix(in srgb, var(--scalar-background-1), #fff 10%);\n  --scalar-tooltip-color: color-mix(in srgb, #fff, transparent 5%);\n\n  --scalar-color-danger: color-mix(in srgb, var(--scalar-color-red), var(--scalar-background-1) 20%);\n\n  --scalar-background-alert: color-mix(in srgb, var(--scalar-color-orange), var(--scalar-background-1) 95%);\n  --scalar-background-danger: color-mix(in srgb, var(--scalar-color-red), var(--scalar-background-1) 95%);\n}\n@supports (color: color(display-p3 1 1 1)) {\n  .light-mode {\n    --scalar-color-accent: color(display-p3 0 0.6 1 / 1);\n    --scalar-color-green: color(display-p3 0.023529 0.564706 0.380392 / 1);\n    --scalar-color-red: color(display-p3 0.937255 0 0.023529 / 1);\n    --scalar-color-yellow: color(display-p3 0.929412 0.745098 0.12549 / 1);\n    --scalar-color-blue: color(display-p3 0 0.509804 0.815686 / 1);\n    --scalar-color-orange: color(display-p3 1 0.4 0.02);\n    --scalar-color-purple: color(display-p3 0.321569 0.011765 0.819608 / 1);\n  }\n  .dark-mode {\n    --scalar-color-accent: color(display-p3 0.07 0.67 1);\n    --scalar-color-green: color(display-p3 0 0.713725 0.282353 / 1);\n    --scalar-color-red: color(display-p3 0.862745 0.105882 0.098039 / 1);\n    --scalar-color-yellow: color(display-p3 1 0.788235 0.05098 / 1);\n    --scalar-color-blue: color(display-p3 0.305882 0.701961 0.92549 / 1);\n    --scalar-color-orange: color(display-p3 1 0.552941 0.301961 / 1);\n    --scalar-color-purple: color(display-p3 0.694118 0.568627 0.976471 / 1);\n  }\n}\n"
;function I_e(){if("undefined"==typeof window)return!1
;const e=document.createElement("div")
;e.setAttribute("style","width:30px;height:30px;overflow-y:scroll;"),
e.classList.add("scrollbar-test");const t=document.createElement("div")
;t.setAttribute("style","width:100%;height:40px"),
e.appendChild(t),document.body.appendChild(e)
;const n=30-e.firstChild.clientWidth;return document.body.removeChild(e),!!n}
const M_e=["alternate","default","moon","purple","solarized","bluePlanet","deepSpace","saturn","kepler","elysiajs","fastify","mars","laserwave","none"],N_e={
default:"Default",alternate:"Alternate",moon:"Moon",purple:"Purple",
solarized:"Solarized",elysiajs:"Elysia.js",fastify:"Fastify",
bluePlanet:"Blue Planet",saturn:"Saturn",kepler:"Kepler-11e",mars:"Mars",
deepSpace:"Deep Space",laserwave:"Laserwave",none:"None"},R_e={default:{
uid:"qTQR9jSM8E-LihpyZzPOi",name:"Default",description:"Default Scalar theme",
theme:D_e,slug:"default"},alternate:{uid:"2skUDSH4S8HYFF9yXysr-",
name:"Alternate",description:"Alternate Scalar theme",
theme:"/* basic theme */\n:root {\n  --scalar-text-decoration: underline;\n  --scalar-text-decoration-hover: underline;\n}\n\n.dark-mode {\n  --scalar-background-1: #131313;\n  --scalar-background-2: #1d1d1d;\n  --scalar-background-3: #272727;\n  --scalar-background-card: #1d1d1d;\n\n  --scalar-color-1: rgba(255, 255, 255, 0.9);\n  --scalar-color-2: rgba(255, 255, 255, 0.62);\n  --scalar-color-3: rgba(255, 255, 255, 0.44);\n\n  --scalar-color-accent: var(--scalar-color-1);\n  --scalar-background-accent: var(--scalar-background-3);\n\n  --scalar-border-color: #2a2b2a;\n}\n\n.light-mode,\n.light-mode .dark-mode {\n  --scalar-background-1: #f9f9f9;\n  --scalar-background-2: #f1f1f1;\n  --scalar-background-3: #e7e7e7;\n  --scalar-background-card: #fff;\n\n  --scalar-color-1: #1b1b1b;\n  --scalar-color-2: #757575;\n  --scalar-color-3: #8e8e8e;\n\n  --scalar-color-accent: var(--scalar-color-1);\n  --scalar-background-accent: var(--scalar-background-3);\n\n  --scalar-border-color: rgba(0, 0, 0, 0.1);\n}\n\n/* Document Sidebar */\n.t-doc__sidebar {\n  --scalar-color-green: var(--scalar-color-1);\n  --scalar-color-red: var(--scalar-color-1);\n  --scalar-color-yellow: var(--scalar-color-1);\n  --scalar-color-blue: var(--scalar-color-1);\n  --scalar-color-orange: var(--scalar-color-1);\n  --scalar-color-purple: var(--scalar-color-1);\n}\n\n.light-mode .t-doc__sidebar,\n.dark-mode .t-doc__sidebar {\n  --scalar-sidebar-background-1: var(--scalar-background-1);\n  --scalar-sidebar-color-1: var(--scalar-color-1);\n  --scalar-sidebar-color-2: var(--scalar-color-2);\n  --scalar-sidebar-border-color: var(--scalar-border-color);\n\n  --scalar-sidebar-item-hover-background: var(--scalar-background-2);\n  --scalar-sidebar-item-hover-color: currentColor;\n\n  --scalar-sidebar-item-active-background: var(--scalar-background-accent);\n  --scalar-sidebar-color-active: var(--scalar-color-accent);\n\n  --scalar-sidebar-search-background: transparent;\n  --scalar-sidebar-search-color: var(--scalar-color-3);\n  --scalar-sidebar-search-border-color: var(--scalar-border-color);\n}\n/* advanced */\n.light-mode .dark-mode,\n.light-mode {\n  --scalar-color-green: #069061;\n  --scalar-color-red: #ef0006;\n  --scalar-color-yellow: #edbe20;\n  --scalar-color-blue: #0082d0;\n  --scalar-color-orange: #fb892c;\n  --scalar-color-purple: #5203d1;\n\n  --scalar-button-1: rgba(0, 0, 0, 1);\n  --scalar-button-1-hover: rgba(0, 0, 0, 0.8);\n  --scalar-button-1-color: rgba(255, 255, 255, 0.9);\n}\n.dark-mode {\n  --scalar-color-green: #00b648;\n  --scalar-color-red: #dd2f2c;\n  --scalar-color-yellow: #ffc90d;\n  --scalar-color-blue: #4eb3ec;\n  --scalar-color-orange: #ff8d4d;\n  --scalar-color-purple: #b191f9;\n\n  --scalar-button-1: rgba(255, 255, 255, 1);\n  --scalar-button-1-hover: rgba(255, 255, 255, 0.9);\n  --scalar-button-1-color: black;\n}\n\n.scalar-api-client__item,\n.scalar-card,\n.dark-mode .dark-mode.scalar-card {\n  --scalar-background-1: var(--scalar-background-card);\n  --scalar-background-2: var(--scalar-background-1);\n  --scalar-background-3: var(--scalar-background-1);\n}\n.dark-mode .dark-mode.scalar-card {\n  --scalar-background-3: var(--scalar-background-3);\n}\n\n.light-mode *::selection {\n  background-color: color-mix(in srgb, var(--scalar-color-blue), transparent 70%);\n}\n.dark-mode *::selection {\n  background-color: color-mix(in srgb, var(--scalar-color-blue), transparent 50%);\n}\n",
slug:"alternate"},moon:{uid:"DG9ZUNp5lJhDeX_kPX4Bl",name:"Moon",
description:"Lunar styles",
theme:".light-mode {\n  color-scheme: light;\n  --scalar-color-1: #000000;\n  --scalar-color-2: #000000;\n  --scalar-color-3: #000000;\n  --scalar-color-accent: #645b0f;\n  --scalar-background-1: #ccc9b3;\n  --scalar-background-2: #c2bfaa;\n  --scalar-background-3: #b8b5a1;\n  --scalar-background-accent: #000000;\n\n  --scalar-border-color: rgba(0, 0, 0, 0.2);\n  --scalar-scrollbar-color: rgba(0, 0, 0, 0.18);\n  --scalar-scrollbar-color-active: rgba(0, 0, 0, 0.36);\n  --scalar-lifted-brightness: 1;\n  --scalar-backdrop-brightness: 1;\n\n  --scalar-shadow-1: 0 1px 3px 0 rgba(0, 0, 0, 0.11);\n  --scalar-shadow-2:\n    rgba(0, 0, 0, 0.08) 0px 13px 20px 0px, rgba(0, 0, 0, 0.08) 0px 3px 8px 0px, var(--scalar-border-color) 0px 0 0 1px;\n\n  --scalar-button-1: rgb(49 53 56);\n  --scalar-button-1-color: #fff;\n  --scalar-button-1-hover: rgb(28 31 33);\n\n  --scalar-color-red: #b91c1c;\n  --scalar-color-orange: #a16207;\n  --scalar-color-green: #047857;\n  --scalar-color-blue: #1d4ed8;\n  --scalar-color-orange: #c2410c;\n  --scalar-color-purple: #6d28d9;\n}\n\n.dark-mode {\n  color-scheme: dark;\n  --scalar-color-1: #fffef3;\n  --scalar-color-2: #fffef3;\n  --scalar-color-3: #fffef3;\n  --scalar-color-accent: #c3b531;\n  --scalar-background-1: #313332;\n  --scalar-background-2: #393b3a;\n  --scalar-background-3: #414342;\n  --scalar-background-accent: #fffef3;\n\n  --scalar-border-color: #505452;\n  --scalar-scrollbar-color: rgba(255, 255, 255, 0.24);\n  --scalar-scrollbar-color-active: rgba(255, 255, 255, 0.48);\n  --scalar-lifted-brightness: 1.45;\n  --scalar-backdrop-brightness: 0.5;\n\n  --scalar-shadow-1: 0 1px 3px 0 rgba(0, 0, 0, 0.11);\n  --scalar-shadow-2:\n    rgba(15, 15, 15, 0.2) 0px 3px 6px, rgba(15, 15, 15, 0.4) 0px 9px 24px, 0 0 0 1px rgba(255, 255, 255, 0.1);\n\n  --scalar-button-1: #f6f6f6;\n  --scalar-button-1-color: #000;\n  --scalar-button-1-hover: #e7e7e7;\n\n  --scalar-color-green: #00b648;\n  --scalar-color-red: #dc1b19;\n  --scalar-color-yellow: #ffc90d;\n  --scalar-color-blue: #4eb3ec;\n  --scalar-color-orange: #ff8d4d;\n  --scalar-color-purple: #b191f9;\n}\n\n/* Sidebar */\n.light-mode .t-doc__sidebar,\n.dark-mode .t-doc__sidebar {\n  --scalar-sidebar-background-1: var(--scalar-background-1);\n  --scalar-sidebar-color-1: var(--scalar-color-1);\n  --scalar-sidebar-color-2: var(--scalar-color-2);\n  --scalar-sidebar-border-color: var(--scalar-border-color);\n\n  --scalar-sidebar-item-hover-background: var(--scalar-background-2);\n  --scalar-sidebar-item-hover-color: currentColor;\n\n  --scalar-sidebar-item-active-background: var(--scalar-background-3);\n  --scalar-sidebar-color-active: var(--scalar-color-1);\n\n  --scalar-sidebar-search-background: transparent;\n  --scalar-sidebar-search-color: var(--scalar-color-3);\n  --scalar-sidebar-search-border-color: var(--scalar-border-color);\n}\n*::selection {\n  background-color: color-mix(in srgb, var(--scalar-color-accent), transparent 80%);\n}\n",
slug:"moon"},purple:{uid:"pE_1ysxcZ-y2LM1GGNBUv",name:"Purple",
description:"Purple Scalar theme",
theme:"/* basic theme */\n.light-mode {\n  --scalar-background-1: #fff;\n  --scalar-background-2: #f5f6f8;\n  --scalar-background-3: #eceef1;\n\n  --scalar-color-1: #1b1b1b;\n  --scalar-color-2: #757575;\n  --scalar-color-3: #8e8e8e;\n\n  --scalar-color-accent: #5469d4;\n  --scalar-background-accent: #5469d41f;\n\n  --scalar-border-color: rgba(215, 215, 206, 0.68);\n}\n.dark-mode {\n  --scalar-background-1: #15171c;\n  --scalar-background-2: #1c1e24;\n  --scalar-background-3: #22252b;\n\n  --scalar-color-1: #fafafa;\n  --scalar-color-2: #c9ced8;\n  --scalar-color-3: #8c99ad;\n\n  --scalar-color-accent: #5469d4;\n  --scalar-background-accent: #5469d41f;\n\n  --scalar-border-color: #3f4145;\n}\n/* Document Sidebar */\n.light-mode .t-doc__sidebar,\n.dark-mode .t-doc__sidebar {\n  --scalar-sidebar-background-1: var(--scalar-background-1);\n  --scalar-sidebar-color-1: var(--scalar-color-1);\n  --scalar-sidebar-color-2: var(--scalar-color-2);\n  --scalar-sidebar-border-color: var(--scalar-border-color);\n\n  --scalar-sidebar-item-hover-color: currentColor;\n  --scalar-sidebar-item-hover-background: var(--scalar-background-3);\n\n  --scalar-sidebar-item-active-background: var(--scalar-background-accent);\n  --scalar-sidebar-color-active: var(--scalar-color-accent);\n\n  --scalar-sidebar-search-background: var(--scalar-background-1);\n  --scalar-sidebar-search-color: var(--scalar-color-3);\n  --scalar-sidebar-search-border-color: var(--scalar-border-color);\n}\n\n/* advanced */\n.light-mode {\n  --scalar-color-green: #17803d;\n  --scalar-color-red: #e10909;\n  --scalar-color-yellow: #edbe20;\n  --scalar-color-blue: #1763a6;\n  --scalar-color-orange: #e25b09;\n  --scalar-color-purple: #5c3993;\n\n  --scalar-button-1: rgba(0, 0, 0, 1);\n  --scalar-button-1-hover: rgba(0, 0, 0, 0.8);\n  --scalar-button-1-color: rgba(255, 255, 255, 0.9);\n}\n.dark-mode {\n  --scalar-color-green: #30a159;\n  --scalar-color-red: #dc1b19;\n  --scalar-color-yellow: #eec644;\n  --scalar-color-blue: #2b7abf;\n  --scalar-color-orange: #f07528;\n  --scalar-color-purple: #7a59b1;\n\n  --scalar-button-1: rgba(255, 255, 255, 1);\n  --scalar-button-1-hover: rgba(255, 255, 255, 0.9);\n  --scalar-button-1-color: black;\n}\n.light-mode *::selection {\n  background-color: color-mix(in srgb, var(--scalar-color-accent), transparent 70%);\n}\n.dark-mode *::selection {\n  background-color: color-mix(in srgb, var(--scalar-color-accent), transparent 50%);\n}\n",
slug:"purple"},solarized:{uid:"BdGVG1vf-4nYl3wJKyj8l",name:"Solarized",
description:"Solarized Scalar theme",
theme:".light-mode {\n  color-scheme: light;\n  --scalar-color-1: #584c27;\n  --scalar-color-2: #616161;\n  --scalar-color-3: #a89f84;\n  --scalar-color-accent: #b58900;\n  --scalar-background-1: #fdf6e3;\n  --scalar-background-2: #eee8d5;\n  --scalar-background-3: #ddd6c1;\n  --scalar-background-accent: #b589001f;\n\n  --scalar-border-color: #ded8c8;\n  --scalar-scrollbar-color: rgba(0, 0, 0, 0.18);\n  --scalar-scrollbar-color-active: rgba(0, 0, 0, 0.36);\n  --scalar-lifted-brightness: 1;\n  --scalar-backdrop-brightness: 1;\n\n  --scalar-shadow-1: 0 1px 3px 0 rgba(0, 0, 0, 0.11);\n  --scalar-shadow-2: rgba(0, 0, 0, 0.08) 0px 13px 20px 0px, rgba(0, 0, 0, 0.08) 0px 3px 8px 0px, #eeeeed 0px 0 0 1px;\n\n  --scalar-button-1: rgb(49 53 56);\n  --scalar-button-1-color: #fff;\n  --scalar-button-1-hover: rgb(28 31 33);\n\n  --scalar-color-red: #b91c1c;\n  --scalar-color-orange: #a16207;\n  --scalar-color-green: #047857;\n  --scalar-color-blue: #1d4ed8;\n  --scalar-color-orange: #c2410c;\n  --scalar-color-purple: #6d28d9;\n}\n\n.dark-mode {\n  color-scheme: dark;\n  --scalar-color-1: #fff;\n  --scalar-color-2: #cccccc;\n  --scalar-color-3: #6d8890;\n  --scalar-color-accent: #007acc;\n  --scalar-background-1: #00212b;\n  --scalar-background-2: #012b36;\n  --scalar-background-3: #004052;\n  --scalar-background-accent: #015a6f;\n\n  --scalar-border-color: #2f4851;\n  --scalar-scrollbar-color: rgba(255, 255, 255, 0.24);\n  --scalar-scrollbar-color-active: rgba(255, 255, 255, 0.48);\n  --scalar-lifted-brightness: 1.45;\n  --scalar-backdrop-brightness: 0.5;\n\n  --scalar-shadow-1: 0 1px 3px 0 rgb(0, 0, 0, 0.1);\n  --scalar-shadow-2:\n    rgba(15, 15, 15, 0.2) 0px 3px 6px, rgba(15, 15, 15, 0.4) 0px 9px 24px, 0 0 0 1px rgba(255, 255, 255, 0.1);\n\n  --scalar-button-1: #f6f6f6;\n  --scalar-button-1-color: #000;\n  --scalar-button-1-hover: #e7e7e7;\n\n  --scalar-color-green: #00b648;\n  --scalar-color-red: #dc1b19;\n  --scalar-color-yellow: #ffc90d;\n  --scalar-color-blue: #4eb3ec;\n  --scalar-color-orange: #ff8d4d;\n  --scalar-color-purple: #b191f9;\n}\n\n/* Sidebar */\n.light-mode .t-doc__sidebar {\n  --scalar-sidebar-background-1: var(--scalar-background-1);\n  --scalar-sidebar-item-hover-color: currentColor;\n  --scalar-sidebar-item-hover-background: var(--scalar-background-2);\n  --scalar-sidebar-item-active-background: var(--scalar-background-accent);\n  --scalar-sidebar-border-color: var(--scalar-border-color);\n  --scalar-sidebar-color-1: var(--scalar-color-1);\n  --scalar-sidebar-color-2: var(--scalar-color-2);\n  --scalar-sidebar-color-active: var(--scalar-color-accent);\n  --scalar-sidebar-search-background: var(--scalar-background-2);\n  --scalar-sidebar-search-border-color: var(--scalar-sidebar-search-background);\n  --scalar-sidebar-search--color: var(--scalar-color-3);\n}\n\n.dark-mode .t-doc__sidebar {\n  --scalar-sidebar-background-1: var(--scalar-background-1);\n  --scalar-sidebar-item-hover-color: currentColor;\n  --scalar-sidebar-item-hover-background: var(--scalar-background-2);\n  --scalar-sidebar-item-active-background: var(--scalar-background-accent);\n  --scalar-sidebar-border-color: var(--scalar-border-color);\n  --scalar-sidebar-color-1: var(--scalar-color-1);\n  --scalar-sidebar-color-2: var(--scalar-color-2);\n  --scalar-sidebar-color-active: var(--scalar-sidebar-color-1);\n  --scalar-sidebar-search-background: var(--scalar-background-2);\n  --scalar-sidebar-search-border-color: var(--scalar-sidebar-search-background);\n  --scalar-sidebar-search--color: var(--scalar-color-3);\n}\n*::selection {\n  background-color: color-mix(in srgb, var(--scalar-color-accent), transparent 70%);\n}\n",
slug:"solarized"},bluePlanet:{uid:"X12IfAvl7ue-42V2lW40S",name:"Blue Planet",
description:"Blue Planet Scalar theme",
theme:"/* basic theme */\n:root {\n  --scalar-text-decoration: underline;\n  --scalar-text-decoration-hover: underline;\n}\n.light-mode {\n  --scalar-background-1: #f0f2f5;\n  --scalar-background-2: #eaecf0;\n  --scalar-background-3: #e0e2e6;\n  --scalar-border-color: rgb(213 213 213);\n\n  --scalar-color-1: rgb(9, 9, 11);\n  --scalar-color-2: rgb(113, 113, 122);\n  --scalar-color-3: rgba(25, 25, 28, 0.5);\n\n  --scalar-color-accent: var(--scalar-color-1);\n  --scalar-background-accent: #8ab4f81f;\n}\n.light-mode .scalar-card.dark-mode,\n.dark-mode {\n  --scalar-background-1: #000e23;\n  --scalar-background-2: #01132e;\n  --scalar-background-3: #03193b;\n  --scalar-border-color: #2e394c;\n\n  --scalar-color-1: #fafafa;\n  --scalar-color-2: rgb(161, 161, 170);\n  --scalar-color-3: rgba(255, 255, 255, 0.533);\n\n  --scalar-color-accent: var(--scalar-color-1);\n  --scalar-background-accent: #8ab4f81f;\n\n  --scalar-code-language-color-supersede: var(--scalar-color-1);\n}\n/* Document Sidebar */\n.light-mode .t-doc__sidebar,\n.dark-mode .t-doc__sidebar {\n  --scalar-sidebar-background-1: var(--scalar-background-1);\n  --scalar-sidebar-color-1: var(--scalar-color-1);\n  --scalar-sidebar-color-2: var(--scalar-color-2);\n  --scalar-sidebar-border-color: var(--scalar-border-color);\n\n  --scalar-sidebar-item-hover-background: var(--scalar-background-2);\n  --scalar-sidebar-item-hover-color: currentColor;\n\n  --scalar-sidebar-item-active-background: var(--scalar-background-3);\n  --scalar-sidebar-color-active: var(--scalar-color-accent);\n\n  --scalar-sidebar-search-background: rgba(255, 255, 255, 0.1);\n  --scalar-sidebar-search-border-color: var(--scalar-border-color);\n  --scalar-sidebar-search-color: var(--scalar-color-3);\n  z-index: 1;\n}\n.light-mode .t-doc__sidebar {\n  --scalar-sidebar-search-background: white;\n}\n/* advanced */\n.light-mode {\n  --scalar-color-green: #069061;\n  --scalar-color-red: #ef0006;\n  --scalar-color-yellow: #edbe20;\n  --scalar-color-blue: #0082d0;\n  --scalar-color-orange: #fb892c;\n  --scalar-color-purple: #5203d1;\n\n  --scalar-button-1: rgba(0, 0, 0, 1);\n  --scalar-button-1-hover: rgba(0, 0, 0, 0.8);\n  --scalar-button-1-color: rgba(255, 255, 255, 0.9);\n}\n.dark-mode {\n  --scalar-color-green: rgba(69, 255, 165, 0.823);\n  --scalar-color-red: #ff8589;\n  --scalar-color-yellow: #ffcc4d;\n  --scalar-color-blue: #6bc1fe;\n  --scalar-color-orange: #f98943;\n  --scalar-color-purple: #b191f9;\n\n  --scalar-button-1: rgba(255, 255, 255, 1);\n  --scalar-button-1-hover: rgba(255, 255, 255, 0.9);\n  --scalar-button-1-color: black;\n}\n/* Custom theme */\n/* Document header */\n@keyframes headerbackground {\n  from {\n    background: transparent;\n    backdrop-filter: none;\n  }\n  to {\n    background: var(--scalar-header-background-1);\n    backdrop-filter: blur(12px);\n  }\n}\n\n.light-mode .t-doc__header,\n.dark-mode .t-doc__header {\n  animation: headerbackground forwards;\n  animation-timeline: scroll();\n  animation-range: 0px 200px;\n}\n\n/* Document Layout */\n.dark-mode .t-doc .layout-content {\n  background: transparent;\n}\n\n.dark-mode h2.t-editor__heading,\n.dark-mode .t-editor__page-title h1,\n.dark-mode h1.section-header:not(::selection),\n.dark-mode .markdown h1,\n.dark-mode .markdown h2,\n.dark-mode .markdown h3,\n.dark-mode .markdown h4,\n.dark-mode .markdown h5,\n.dark-mode .markdown h6 {\n  -webkit-text-fill-color: transparent;\n  background-image: linear-gradient(to right bottom, rgb(255, 255, 255) 30%, rgba(255, 255, 255, 0.38));\n  -webkit-background-clip: text;\n  background-clip: text;\n}\n/* Hero Section Flare */\n.section-flare-item:nth-of-type(1) {\n  --c1: #ffffff;\n  --c2: #babfd8;\n  --c3: #2e8bb2;\n  --c4: #1a8593;\n  --c5: #0a143e;\n  --c6: #0a0f52;\n  --c7: #2341b8;\n\n  --solid: var(--c1), var(--c2), var(--c3), var(--c4), var(--c5), var(--c6), var(--c7);\n  --solid-wrap: var(--solid), var(--c1);\n  --trans:\n    var(--c1), transparent, var(--c2), transparent, var(--c3),\n    transparent, var(--c4), transparent, var(--c5), transparent, var(--c6),\n    transparent, var(--c7);\n  --trans-wrap: var(--trans), transparent, var(--c1);\n\n  background:\n    radial-gradient(circle, var(--trans)), conic-gradient(from 180deg, var(--trans-wrap)),\n    radial-gradient(circle, var(--trans)), conic-gradient(var(--solid-wrap));\n  width: 70vw;\n  height: 700px;\n  border-radius: 50%;\n  filter: blur(100px);\n  z-index: 0;\n  right: 0;\n  position: absolute;\n  transform: rotate(-45deg);\n  top: -300px;\n  opacity: 0.3;\n}\n.section-flare-item:nth-of-type(3) {\n  --star-color: #6b9acc;\n  --star-color2: #446b8d;\n  --star-color3: #3e5879;\n  background-image:\n    radial-gradient(2px 2px at 20px 30px, var(--star-color2), rgba(0, 0, 0, 0)),\n    radial-gradient(2px 2px at 40px 70px, var(--star-color), rgba(0, 0, 0, 0)),\n    radial-gradient(2px 2px at 50px 160px, var(--star-color3), rgba(0, 0, 0, 0)),\n    radial-gradient(2px 2px at 90px 40px, var(--star-color), rgba(0, 0, 0, 0)),\n    radial-gradient(2px 2px at 130px 80px, var(--star-color), rgba(0, 0, 0, 0)),\n    radial-gradient(2px 2px at 160px 120px, var(--star-color3), rgba(0, 0, 0, 0));\n  background-repeat: repeat;\n  background-size: 200px 200px;\n  width: 100%;\n  height: 100%;\n  mask-image: radial-gradient(ellipse at 100% 0%, black 40%, transparent 70%);\n}\n.section-flare {\n  top: -150px !important;\n  height: 100vh;\n  background: linear-gradient(#000, var(--scalar-background-1));\n  width: 100vw;\n  overflow-x: hidden;\n}\n.light-mode .section-flare {\n  display: none;\n}\n.light-mode .scalar-card {\n  --scalar-background-1: #fff;\n  --scalar-background-2: #fff;\n  --scalar-background-3: #fff;\n}\n\n*::selection {\n  background-color: color-mix(in srgb, var(--scalar-color-blue), transparent 60%);\n}\n\n@media (max-width: 1000px) {\n  .light-mode .t-doc__sidebar,\n  .dark-mode .t-doc__sidebar {\n    --scalar-sidebar-background-1: var(--scalar-background-1);\n  }\n  .light-mode .t-doc__header,\n  .dark-mode .t-doc__header {\n    animation: none;\n    background: var(--scalar-header-background-1);\n    backdrop-filter: blur(12px);\n  }\n}\n",
slug:"blue-planet"},deepSpace:{uid:"K8b38NWQiicq4-zXGXKdI",name:"Deep Space",
description:"Deep Space Scalar theme",
theme:'/* basic theme */\n:root {\n  --scalar-text-decoration: underline;\n  --scalar-text-decoration-hover: underline;\n}\n.light-mode {\n  --scalar-color-1: rgb(9, 9, 11);\n  --scalar-color-2: rgb(113, 113, 122);\n  --scalar-color-3: rgba(25, 25, 28, 0.5);\n  --scalar-color-accent: var(--scalar-color-1);\n\n  --scalar-background-1: #fff;\n  --scalar-background-2: #f4f4f5;\n  --scalar-background-3: #e3e3e6;\n  --scalar-background-accent: #8ab4f81f;\n\n  --scalar-border-color: rgb(228, 228, 231);\n  --scalar-code-language-color-supersede: var(--scalar-color-1);\n}\n.dark-mode {\n  --scalar-color-1: #fafafa;\n  --scalar-color-2: rgb(161, 161, 170);\n  --scalar-color-3: rgba(255, 255, 255, 0.533);\n  --scalar-color-accent: var(--scalar-color-1);\n\n  --scalar-background-1: #09090b;\n  --scalar-background-2: #18181b;\n  --scalar-background-3: #2c2c30;\n  --scalar-background-accent: #8ab4f81f;\n\n  --scalar-border-color: rgba(255, 255, 255, 0.16);\n  --scalar-code-language-color-supersede: var(--scalar-color-1);\n}\n\n/* Document Sidebar */\n.light-mode .t-doc__sidebar,\n.dark-mode .t-doc__sidebar {\n  --scalar-sidebar-background-1: var(--scalar-background-1);\n  --scalar-sidebar-color-1: var(--scalar-color-1);\n  --scalar-sidebar-color-2: var(--scalar-color-2);\n  --scalar-sidebar-border-color: var(--scalar-border-color);\n\n  --scalar-sidebar-item-hover-color: currentColor;\n  --scalar-sidebar-item-hover-background: var(--scalar-background-2);\n\n  --scalar-sidebar-item-active-background: var(--scalar-background-3);\n  --scalar-sidebar-color-active: var(--scalar-color-accent);\n\n  --scalar-sidebar-search-background: transparent;\n  --scalar-sidebar-search-border-color: var(--scalar-border-color);\n  --scalar-sidebar-search-color: var(--scalar-color-3);\n}\n.light-mode .t-doc__sidebar {\n  --scalar-sidebar-item-active-background: var(--scalar-background-2);\n}\n/* advanced */\n.light-mode {\n  --scalar-color-green: #069061;\n  --scalar-color-red: #ef0006;\n  --scalar-color-yellow: #edbe20;\n  --scalar-color-blue: #0082d0;\n  --scalar-color-orange: #fb892c;\n  --scalar-color-purple: #5203d1;\n\n  --scalar-button-1: rgba(0, 0, 0, 1);\n  --scalar-button-1-hover: rgba(0, 0, 0, 0.8);\n  --scalar-button-1-color: rgba(255, 255, 255, 0.9);\n}\n.dark-mode {\n  --scalar-color-green: rgba(69, 255, 165, 0.823);\n  --scalar-color-red: #ff8589;\n  --scalar-color-yellow: #ffcc4d;\n  --scalar-color-blue: #6bc1fe;\n  --scalar-color-orange: #f98943;\n  --scalar-color-purple: #b191f9;\n\n  --scalar-button-1: rgba(255, 255, 255, 1);\n  --scalar-button-1-hover: rgba(255, 255, 255, 0.9);\n  --scalar-button-1-color: black;\n}\n/* Custom theme */\n.dark-mode h2.t-editor__heading,\n.dark-mode .t-editor__page-title h1,\n.dark-mode h1.section-header:not(::selection),\n.dark-mode .markdown h1,\n.dark-mode .markdown h2,\n.dark-mode .markdown h3,\n.dark-mode .markdown h4,\n.dark-mode .markdown h5,\n.dark-mode .markdown h6 {\n  -webkit-text-fill-color: transparent;\n  background-image: linear-gradient(to right bottom, rgb(255, 255, 255) 30%, rgba(255, 255, 255, 0.38));\n  -webkit-background-clip: text;\n  background-clip: text;\n}\n.examples .scalar-card-footer {\n  --scalar-background-3: transparent;\n  padding-top: 0;\n}\n/* Hero section flare */\n.section-flare {\n  width: 100vw;\n  height: 550px;\n  position: absolute;\n}\n.section-flare-item:nth-of-type(1) {\n  position: absolute;\n  width: 100vw;\n  height: 550px;\n  --stripesDark: repeating-linear-gradient(100deg, #000 0%, #000 7%, transparent 10%, transparent 12%, #000 16%);\n  --rainbow: repeating-linear-gradient(100deg, #fff 10%, #fff 16%, #fff 22%, #fff 30%);\n  background-image: var(--stripesDark), var(--rainbow);\n  background-size: 300%, 200%;\n  background-position:\n    50% 50%,\n    50% 50%;\n  filter: invert(100%);\n  -webkit-mask-image: radial-gradient(ellipse at 100% 0%, black 40%, transparent 70%);\n  mask-image: radial-gradient(ellipse at 100% 0%, black 40%, transparent 70%);\n  pointer-events: none;\n  opacity: 0.07;\n}\n.dark-mode .section-flare-item:nth-of-type(1) {\n  background-image: var(--stripesDark), var(--rainbow);\n  filter: opacity(50%) saturate(200%);\n  opacity: 0.25;\n  height: 350px;\n}\n.section-flare-item:nth-of-type(1):after {\n  content: "";\n  position: absolute;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  left: 0;\n  background-image: var(--stripesDark), var(--rainbow);\n  background-size: 200%, 100%;\n  background-attachment: fixed;\n  mix-blend-mode: difference;\n}\n.dark-mode .section-flare:after {\n  background-image: var(--stripesDark), var(--rainbow);\n}\n.section-flare-item:nth-of-type(2) {\n  --star-color: #fff;\n  --star-color2: #fff;\n  --star-color3: #fff;\n  width: 100%;\n  height: 100%;\n  position: absolute;\n  background-image:\n    radial-gradient(2px 2px at 20px 30px, var(--star-color2), rgba(0, 0, 0, 0)),\n    radial-gradient(2px 2px at 40px 70px, var(--star-color), rgba(0, 0, 0, 0)),\n    radial-gradient(2px 2px at 50px 160px, var(--star-color3), rgba(0, 0, 0, 0)),\n    radial-gradient(2px 2px at 90px 40px, var(--star-color), rgba(0, 0, 0, 0)),\n    radial-gradient(2px 2px at 130px 80px, var(--star-color), rgba(0, 0, 0, 0)),\n    radial-gradient(2px 2px at 160px 120px, var(--star-color3), rgba(0, 0, 0, 0));\n  background-repeat: repeat;\n  background-size: 200px 200px;\n  mask-image: radial-gradient(ellipse at 100% 0%, black 40%, transparent 70%);\n  opacity: 0.2;\n}\n.light-mode *::selection {\n  background-color: color-mix(in srgb, var(--scalar-color-blue), transparent 70%);\n}\n.dark-mode *::selection {\n  background-color: color-mix(in srgb, var(--scalar-color-blue), transparent 50%);\n}\n\n/* document header */\n.light-mode .t-doc__header,\n.dark-mode .t-doc__header {\n  animation: headerbackground forwards;\n  animation-timeline: scroll();\n  animation-range: 0px 200px;\n}\n@keyframes headerbackground {\n  from {\n    background: transparent;\n    backdrop-filter: none;\n  }\n  to {\n    background: var(--scalar-header-background-1);\n    backdrop-filter: blur(12px);\n  }\n}\n/* remove flare on safari to prevent dropped frames on scroll */\n@supports (-webkit-hyphens: none) {\n  .section-flare {\n    display: none;\n  }\n}\n\n/* document background */\n.light-mode .t-doc .layout-content,\n.dark-mode .t-doc .layout-content {\n  background: transparent;\n}\n',
slug:"deep-space"},saturn:{uid:"1jyAjmbIZQG-RUU4Ugk9o",name:"Saturn",
description:"Saturn Scalar theme",
theme:"/* basic theme */\n.light-mode {\n  --scalar-background-1: #f3f3ee;\n  --scalar-background-2: #e8e8e3;\n  --scalar-background-3: #e4e4df;\n  --scalar-border-color: rgba(215, 215, 206, 0.85);\n\n  --scalar-color-1: #1b1b1b;\n  --scalar-color-2: #757575;\n  --scalar-color-3: #8e8e8e;\n\n  --scalar-color-accent: #1763a6;\n  --scalar-background-accent: #1f648e1f;\n}\n.dark-mode {\n  --scalar-background-1: #09090b;\n  --scalar-background-2: #18181b;\n  --scalar-background-3: #2c2c30;\n  --scalar-border-color: rgba(255, 255, 255, 0.17);\n\n  --scalar-color-1: #fafafa;\n  --scalar-color-2: rgb(161, 161, 170);\n  --scalar-color-3: rgba(255, 255, 255, 0.533);\n\n  --scalar-color-accent: #4eb3ec;\n  --scalar-background-accent: #8ab4f81f;\n}\n/* Document Sidebar */\n.light-mode .t-doc__sidebar,\n.dark-mode .t-doc__sidebar {\n  --scalar-sidebar-background-1: var(--scalar-background-1);\n  --scalar-sidebar-color-1: var(--scalar-color-1);\n  --scalar-sidebar-color-2: var(--scalar-color-2);\n  --scalar-sidebar-border-color: var(--scalar-border-color);\n\n  --scalar-sidebar-item-hover-background: var(--scalar-background-2);\n  --scalar-sidebar-item-hover-color: currentColor;\n\n  --scalar-sidebar-item-active-background: var(--scalar-background-3);\n  --scalar-sidebar-color-active: var(--scalar-color-1);\n\n  --scalar-sidebar-search-background: var(--scalar-background-1);\n  --scalar-sidebar-search-border-color: var(--scalar-border-color);\n  --scalar-sidebar-search-color: var(--scalar-color-3);\n}\n\n/* advanced */\n.light-mode {\n  --scalar-color-green: #17803d;\n  --scalar-color-red: #e10909;\n  --scalar-color-yellow: #edbe20;\n  --scalar-color-blue: #1763a6;\n  --scalar-color-orange: #e25b09;\n  --scalar-color-purple: #5c3993;\n\n  --scalar-button-1: rgba(0, 0, 0, 1);\n  --scalar-button-1-hover: rgba(0, 0, 0, 0.8);\n  --scalar-button-1-color: rgba(255, 255, 255, 0.9);\n}\n.dark-mode {\n  --scalar-color-green: #30a159;\n  --scalar-color-red: #dc1b19;\n  --scalar-color-yellow: #eec644;\n  --scalar-color-blue: #2b7abf;\n  --scalar-color-orange: #f07528;\n  --scalar-color-purple: #7a59b1;\n\n  --scalar-button-1: rgba(255, 255, 255, 1);\n  --scalar-button-1-hover: rgba(255, 255, 255, 0.9);\n  --scalar-button-1-color: black;\n}\n.dark-mode h2.t-editor__heading,\n.dark-mode .t-editor__page-title h1,\n.dark-mode h1.section-header:not(::selection),\n.dark-mode .markdown h1,\n.dark-mode .markdown h2,\n.dark-mode .markdown h3,\n.dark-mode .markdown h4,\n.dark-mode .markdown h5,\n.dark-mode .markdown h6 {\n  -webkit-text-fill-color: transparent;\n  background-image: linear-gradient(to right bottom, rgb(255, 255, 255) 30%, rgba(255, 255, 255, 0.38));\n  -webkit-background-clip: text;\n  background-clip: text;\n}\n.light-mode *::selection {\n  background-color: color-mix(in srgb, var(--scalar-color-accent), transparent 70%);\n}\n.dark-mode *::selection {\n  background-color: color-mix(in srgb, var(--scalar-color-accent), transparent 50%);\n}\n",
slug:"saturn"},kepler:{uid:"jZ6dnWbtqQ0Hz3s9jLPH0",name:"Kepler-11e",
description:"Kepler-11e Scalar theme",
theme:"/* basic theme */\n.light-mode {\n  --scalar-color-1: #1b1b1b;\n  --scalar-color-2: #757575;\n  --scalar-color-3: #8e8e8e;\n  --scalar-color-accent: #7070ff;\n\n  --scalar-background-1: #fff;\n  --scalar-background-2: #f6f6f6;\n  --scalar-background-3: #e7e7e7;\n  --scalar-background-accent: #7070ff1f;\n\n  --scalar-border-color: rgba(0, 0, 0, 0.1);\n\n  --scalar-code-language-color-supersede: var(--scalar-color-3);\n}\n.dark-mode {\n  --scalar-color-1: #f7f8f8;\n  --scalar-color-2: rgb(180, 188, 208);\n  --scalar-color-3: #b4bcd099;\n  --scalar-color-accent: #828fff;\n\n  --scalar-background-1: #000212;\n  --scalar-background-2: #0d0f1e;\n  --scalar-background-3: #232533;\n  --scalar-background-accent: #8ab4f81f;\n\n  --scalar-border-color: #313245;\n  --scalar-code-language-color-supersede: var(--scalar-color-3);\n}\n/* Document Sidebar */\n.light-mode .t-doc__sidebar {\n  --scalar-sidebar-background-1: var(--scalar-background-1);\n  --scalar-sidebar-item-hover-color: currentColor;\n  --scalar-sidebar-item-hover-background: var(--scalar-background-2);\n  --scalar-sidebar-item-active-background: var(--scalar-background-accent);\n  --scalar-sidebar-border-color: var(--scalar-border-color);\n  --scalar-sidebar-color-1: var(--scalar-color-1);\n  --scalar-sidebar-color-2: var(--scalar-color-2);\n  --scalar-sidebar-color-active: var(--scalar-color-accent);\n  --scalar-sidebar-search-background: rgba(0, 0, 0, 0.05);\n  --scalar-sidebar-search-border-color: 1px solid rgba(0, 0, 0, 0.05);\n  --scalar-sidebar-search-color: var(--scalar-color-3);\n  --scalar-background-2: rgba(0, 0, 0, 0.03);\n}\n.dark-mode .t-doc__sidebar {\n  --scalar-sidebar-background-1: var(--scalar-background-1);\n  --scalar-sidebar-item-hover-color: currentColor;\n  --scalar-sidebar-item-hover-background: var(--scalar-background-2);\n  --scalar-sidebar-item-active-background: rgba(255, 255, 255, 0.1);\n  --scalar-sidebar-border-color: var(--scalar-border-color);\n  --scalar-sidebar-color-1: var(--scalar-color-1);\n  --scalar-sidebar-color-2: var(--scalar-color-2);\n  --scalar-sidebar-color-active: var(--scalar-color-accent);\n  --scalar-sidebar-search-background: rgba(255, 255, 255, 0.1);\n  --scalar-sidebar-search-border-color: 1px solid rgba(255, 255, 255, 0.05);\n  --scalar-sidebar-search-color: var(--scalar-color-3);\n}\n/* advanced */\n.light-mode {\n  --scalar-color-green: #069061;\n  --scalar-color-red: #ef0006;\n  --scalar-color-yellow: #edbe20;\n  --scalar-color-blue: #0082d0;\n  --scalar-color-orange: #fb892c;\n  --scalar-color-purple: #5203d1;\n\n  --scalar-button-1: rgba(0, 0, 0, 1);\n  --scalar-button-1-hover: rgba(0, 0, 0, 0.8);\n  --scalar-button-1-color: rgba(255, 255, 255, 0.9);\n}\n.dark-mode {\n  --scalar-color-green: #00b648;\n  --scalar-color-red: #dc1b19;\n  --scalar-color-yellow: #ffc90d;\n  --scalar-color-blue: #4eb3ec;\n  --scalar-color-orange: #ff8d4d;\n  --scalar-color-purple: #b191f9;\n\n  --scalar-button-1: rgba(255, 255, 255, 1);\n  --scalar-button-1-hover: rgba(255, 255, 255, 0.9);\n  --scalar-button-1-color: black;\n}\n/* Custom Theme */\n.dark-mode h2.t-editor__heading,\n.dark-mode .t-editor__page-title h1,\n.dark-mode h1.section-header:not(::selection),\n.dark-mode .markdown h1,\n.dark-mode .markdown h2,\n.dark-mode .markdown h3,\n.dark-mode .markdown h4,\n.dark-mode .markdown h5,\n.dark-mode .markdown h6 {\n  -webkit-text-fill-color: transparent;\n  background-image: linear-gradient(to right bottom, rgb(255, 255, 255) 30%, rgba(255, 255, 255, 0.38));\n  -webkit-background-clip: text;\n  background-clip: text;\n}\n.sidebar-search {\n  backdrop-filter: blur(12px);\n}\n@keyframes headerbackground {\n  from {\n    background: transparent;\n    backdrop-filter: none;\n  }\n  to {\n    background: var(--scalar-header-background-1);\n    backdrop-filter: blur(12px);\n  }\n}\n.dark-mode .scalar-card {\n  background: rgba(255, 255, 255, 0.05) !important;\n}\n.dark-mode .scalar-card * {\n  --scalar-background-2: transparent !important;\n  --scalar-background-1: transparent !important;\n}\n.light-mode .dark-mode.scalar-card *,\n.light-mode .dark-mode.scalar-card {\n  --scalar-background-1: #0d0f1e !important;\n  --scalar-background-2: #0d0f1e !important;\n  --scalar-background-3: #191b29 !important;\n}\n.light-mode .dark-mode.scalar-card {\n  background: #191b29 !important;\n}\n.badge {\n  box-shadow: 0 0 0 1px var(--scalar-border-color);\n  margin-right: 6px;\n}\n\n.table-row.required-parameter .table-row-item:nth-of-type(2):after {\n  background: transparent;\n  box-shadow: none;\n}\n/* Hero Section Flare */\n.section-flare {\n  width: 100vw;\n  background: radial-gradient(ellipse 80% 50% at 50% -20%, rgba(120, 119, 198, 0.3), transparent);\n  height: 100vh;\n}\n.light-mode *::selection {\n  background-color: color-mix(in srgb, var(--scalar-color-accent), transparent 70%);\n}\n.dark-mode *::selection {\n  background-color: color-mix(in srgb, var(--scalar-color-accent), transparent 50%);\n}\n\n/* document layout */\n.light-mode .t-doc .layout-content,\n.dark-mode .t-doc .layout-content {\n  background: transparent;\n}\n",
slug:"kepler-11e"},mars:{uid:"YY4LQgwiXix55-TmMz9qd",name:"Mars",
description:"Mars Scalar theme",
theme:"/* basic theme */\n:root {\n  --scalar-text-decoration: underline;\n  --scalar-text-decoration-hover: underline;\n}\n.light-mode {\n  --scalar-background-1: #f9f6f0;\n  --scalar-background-2: #f2efe8;\n  --scalar-background-3: #e9e7e2;\n  --scalar-border-color: rgba(203, 165, 156, 0.6);\n\n  --scalar-color-1: #c75549;\n  --scalar-color-2: #c75549;\n  --scalar-color-3: #c75549;\n\n  --scalar-color-accent: #c75549;\n  --scalar-background-accent: #dcbfa81f;\n\n  --scalar-code-language-color-supersede: var(--scalar-color-1);\n}\n.dark-mode {\n  --scalar-background-1: #140507;\n  --scalar-background-2: #20090c;\n  --scalar-background-3: #321116;\n  --scalar-border-color: #3c3031;\n\n  --scalar-color-1: rgba(255, 255, 255, 0.9);\n  --scalar-color-2: rgba(255, 255, 255, 0.62);\n  --scalar-color-3: rgba(255, 255, 255, 0.44);\n\n  --scalar-color-accent: rgba(255, 255, 255, 0.9);\n  --scalar-background-accent: #441313;\n\n  --scalar-code-language-color-supersede: var(--scalar-color-1);\n}\n\n/* Document Sidebar */\n.light-mode .t-doc__sidebar,\n.dark-mode .t-doc__sidebar {\n  --scalar-sidebar-background-1: var(--scalar-background-1);\n  --scalar-sidebar-color-1: var(--scalar-color-1);\n  --scalar-sidebar-color-2: var(--scalar-color-2);\n  --scalar-sidebar-border-color: var(--scalar-border-color);\n\n  --scalar-sidebar-item-hover-color: currentColor;\n  --scalar-sidebar-item-hover-background: var(--scalar-background-2);\n\n  --scalar-sidebar-item-active-background: var(--scalar-background-3);\n  --scalar-sidebar-color-active: var(--scalar-color-accent);\n\n  --scalar-sidebar-search-background: rgba(255, 255, 255, 0.1);\n  --scalar-sidebar-search-color: var(--scalar-color-3);\n  --scalar-sidebar-search-border-color: var(--scalar-border-color);\n  z-index: 1;\n}\n/* advanced */\n.light-mode {\n  --scalar-color-green: #09533a;\n  --scalar-color-red: #aa181d;\n  --scalar-color-yellow: #ab8d2b;\n  --scalar-color-blue: #19689a;\n  --scalar-color-orange: #b26c34;\n  --scalar-color-purple: #4c2191;\n\n  --scalar-button-1: rgba(0, 0, 0, 1);\n  --scalar-button-1-hover: rgba(0, 0, 0, 0.8);\n  --scalar-button-1-color: rgba(255, 255, 255, 0.9);\n}\n.dark-mode {\n  --scalar-color-green: rgba(69, 255, 165, 0.823);\n  --scalar-color-red: #ff8589;\n  --scalar-color-yellow: #ffcc4d;\n  --scalar-color-blue: #6bc1fe;\n  --scalar-color-orange: #f98943;\n  --scalar-color-purple: #b191f9;\n\n  --scalar-button-1: rgba(255, 255, 255, 1);\n  --scalar-button-1-hover: rgba(255, 255, 255, 0.9);\n  --scalar-button-1-color: black;\n}\n/* Custom Theme */\n.dark-mode h2.t-editor__heading,\n.dark-mode .t-editor__page-title h1,\n.dark-mode h1.section-header:not(::selection),\n.dark-mode .markdown h1,\n.dark-mode .markdown h2,\n.dark-mode .markdown h3,\n.dark-mode .markdown h4,\n.dark-mode .markdown h5,\n.dark-mode .markdown h6 {\n  -webkit-text-fill-color: transparent;\n  background-image: linear-gradient(to right bottom, rgb(255, 255, 255) 30%, rgba(255, 255, 255, 0.38));\n  -webkit-background-clip: text;\n  background-clip: text;\n}\n.light-mode .t-doc__sidebar {\n  --scalar-sidebar-search-background: white;\n}\n.examples .scalar-card-footer {\n  --scalar-background-3: transparent;\n  padding-top: 0;\n}\n/* Hero section flare */\n.section-flare {\n  overflow-x: hidden;\n  height: 100vh;\n  left: initial;\n}\n.section-flare-item:nth-of-type(1) {\n  background: #d25019;\n  position: relative;\n  top: -150px;\n  right: -400px;\n  width: 80vw;\n  height: 500px;\n  margin-top: -150px;\n  border-radius: 50%;\n  filter: blur(100px);\n  z-index: 0;\n}\n.light-mode .section-flare {\n  display: none;\n}\n*::selection {\n  background-color: color-mix(in srgb, var(--scalar-color-red), transparent 75%);\n}\n\n/* document layout */\n.dark-mode .t-doc .layout-content {\n  background: transparent;\n}\n",
slug:"mars"},laserwave:{uid:"c5fZEi-K-hP-xXf885dkf",name:"Laserwave",
description:"Laserwave Scalar theme",
theme:"/* basic theme */\n.light-mode {\n  color-scheme: light;\n  --scalar-color-1: #322b3b;\n  --scalar-color-2: #645676;\n  --scalar-color-3: #9789a9;\n  --scalar-color-accent: #40b4c4;\n\n  --scalar-background-1: #fff;\n  --scalar-background-2: #f4f2f7;\n  --scalar-background-3: #cfc7dc;\n  --scalar-background-accent: #f3fafb;\n\n  --scalar-border-color: #e4e0eb;\n}\n.dark-mode {\n  color-scheme: dark;\n  --scalar-color-1: #fff;\n  --scalar-color-2: #b8b6ba;\n  --scalar-color-3: #706c74;\n  --scalar-color-accent: #ed78c2;\n\n  --scalar-background-1: #27212e;\n  --scalar-background-2: #322c39;\n  --scalar-background-3: #4c4059;\n  --scalar-background-accent: #eb64b91f;\n\n  --scalar-border-color: rgba(255, 255, 255, 0.1);\n}\n\n/* Sidebar */\n.light-mode .t-doc__sidebar {\n  --scalar-sidebar-background-1: var(--scalar-background-1);\n  --scalar-sidebar-item-hover-color: currentColor;\n  --scalar-sidebar-item-hover-background: var(--scalar-background-2);\n  --scalar-sidebar-item-active-background: var(--scalar-background-accent);\n  --scalar-sidebar-border-color: var(--scalar-border-color);\n  --scalar-sidebar-color-1: var(--scalar-color-1);\n  --scalar-sidebar-color-2: var(--scalar-color-2);\n  --scalar-sidebar-color-active: var(--scalar-color-accent);\n  --scalar-sidebar-search-background: var(--scalar-background-2);\n  --scalar-sidebar-search-border-color: var(--scalar-sidebar-border-color);\n  --scalar-sidebar-search--color: var(--scalar-color-3);\n}\n.dark-mode .t-doc__sidebar {\n  --scalar-sidebar-background-1: var(--scalar-background-1);\n  --scalar-sidebar-item-hover-color: currentColor;\n  --scalar-sidebar-item-hover-background: var(--scalar-background-2);\n  --scalar-sidebar-item-active-background: var(--scalar-background-accent);\n  --scalar-sidebar-border-color: var(--scalar-border-color);\n  --scalar-sidebar-color-1: var(--scalar-color-1);\n  --scalar-sidebar-color-2: var(--scalar-color-2);\n  --scalar-sidebar-color-active: var(--scalar-color-accent);\n  --scalar-sidebar-search-background: var(--scalar-background-2);\n  --scalar-sidebar-search-border-color: #514c56;\n  --scalar-sidebar-search--color: var(--scalar-color-3);\n}\n/* advanced */\n.light-mode {\n  --scalar-button-1: rgb(49 53 56);\n  --scalar-button-1-color: #fff;\n  --scalar-button-1-hover: rgb(28 31 33);\n\n  --scalar-color-green: #74dfc4;\n  --scalar-color-red: #d887f5;\n  --scalar-color-yellow: #ffe261;\n  --scalar-color-blue: #40b4c4;\n  --scalar-color-orange: #ff52bf;\n  --scalar-color-purple: #91889b;\n\n  --scalar-scrollbar-color: rgba(0, 0, 0, 0.18);\n  --scalar-scrollbar-color-active: rgba(0, 0, 0, 0.36);\n}\n.dark-mode {\n  --scalar-button-1: #f6f6f6;\n  --scalar-button-1-color: #27212e;\n  --scalar-button-1-hover: #e7e7e7;\n\n  --scalar-color-green: #74dfc4;\n  --scalar-color-red: #d887f5;\n  --scalar-color-yellow: #ffe261;\n  --scalar-color-blue: #40b4c4;\n  --scalar-color-orange: #ff52bf;\n  --scalar-color-purple: #91889b;\n\n  --scalar-scrollbar-color: rgba(255, 255, 255, 0.24);\n  --scalar-scrollbar-color-active: rgba(255, 255, 255, 0.48);\n}\n/* Radius */\n:root {\n  --scalar-radius: 2px;\n  --scalar-radius-lg: 3px;\n  --scalar-radius-xl: 4px;\n}\n/* P3 color support */\n@supports (color: color(display-p3 1 1 1)) {\n  .light-mode {\n    --scalar-color-accent: color(display-p3 0.25098 0.705882 0.768627 / 1);\n    --scalar-color-green: color(display-p3 0.454902 0.87451 0.768627 / 1);\n    --scalar-color-red: color(display-p3 0.847059 0.529412 0.960784 / 1);\n    --scalar-color-yellow: color(display-p3 1 0.886275 0.380392 / 1);\n    --scalar-color-blue: color(display-p3 0.25098 0.705882 0.768627 / 1);\n    --scalar-color-orange: color(display-p3 1 0.321569 0.74902 / 1);\n    --scalar-color-purple: color(display-p3 0.568627 0.533333 0.607843 / 1);\n  }\n  .dark-mode {\n    --scalar-color-accent: color(display-p3 0.929412 0.470588 0.760784 / 1);\n    --scalar-color-green: color(display-p3 0.454902 0.87451 0.768627 / 1);\n    --scalar-color-red: color(display-p3 0.847059 0.529412 0.960784 / 1);\n    --scalar-color-yellow: color(display-p3 1 0.886275 0.380392 / 1);\n    --scalar-color-blue: color(display-p3 0.25098 0.705882 0.768627 / 1);\n    --scalar-color-orange: color(display-p3 1 0.321569 0.74902 / 1);\n    --scalar-color-purple: color(display-p3 0.568627 0.533333 0.607843 / 1);\n  }\n}\n",
slug:"laserwave"},elysiajs:{uid:"nEVZkRmCylPkT0o9YJa7y",name:"Elysia.js",
description:"Elysia.js theme",
theme:'.light-mode {\n  --scalar-color-1: #1b1b1b;\n  --scalar-color-2: #757575;\n  --scalar-color-3: #8e8e8e;\n  --scalar-color-accent: #f06292;\n\n  --scalar-background-1: #fff;\n  --scalar-background-2: #f6f6f6;\n  --scalar-background-3: #e7e7e7;\n\n  --scalar-border-color: rgba(0, 0, 0, 0.1);\n}\n.dark-mode {\n  --scalar-color-1: rgba(255, 255, 255, 0.9);\n  --scalar-color-2: rgba(156, 163, 175, 1);\n  --scalar-color-3: rgba(255, 255, 255, 0.44);\n  --scalar-color-accent: #f06292;\n\n  --scalar-background-1: #111728;\n  --scalar-background-2: #1e293b;\n  --scalar-background-3: #334155;\n  --scalar-background-accent: #f062921f;\n\n  --scalar-border-color: rgba(255, 255, 255, 0.1);\n}\n\n/* Document Sidebar */\n.light-mode .t-doc__sidebar,\n.dark-mode .t-doc__sidebar {\n  --scalar-sidebar-background-1: var(--scalar-background-1);\n  --scalar-sidebar-color-1: var(--scalar-color-1);\n  --scalar-sidebar-color-2: var(--scalar-color-2);\n  --scalar-sidebar-border-color: var(--scalar-border-color);\n\n  --scalar-sidebar-item-hover-background: var(--scalar-background-2);\n  --scalar-sidebar-item-hover-color: currentColor;\n\n  --scalar-sidebar-item-active-background: #f062921f;\n  --scalar-sidebar-color-active: var(--scalar-color-accent);\n\n  --scalar-sidebar-search-background: transparent;\n  --scalar-sidebar-search-color: var(--scalar-color-3);\n  --scalar-sidebar-search-border-color: var(--scalar-border-color);\n}\n\n/* advanced */\n.light-mode {\n  --scalar-button-1: rgb(49 53 56);\n  --scalar-button-1-color: #fff;\n  --scalar-button-1-hover: rgb(28 31 33);\n\n  --scalar-color-green: #069061;\n  --scalar-color-red: #ef0006;\n  --scalar-color-yellow: #edbe20;\n  --scalar-color-blue: #0082d0;\n  --scalar-color-orange: #fb892c;\n  --scalar-color-purple: #5203d1;\n\n  --scalar-scrollbar-color: rgba(0, 0, 0, 0.18);\n  --scalar-scrollbar-color-active: rgba(0, 0, 0, 0.36);\n}\n.dark-mode {\n  --scalar-button-1: #f6f6f6;\n  --scalar-button-1-color: #000;\n  --scalar-button-1-hover: #e7e7e7;\n\n  --scalar-color-green: #a3ffa9;\n  --scalar-color-red: #ffa3a3;\n  --scalar-color-yellow: #fffca3;\n  --scalar-color-blue: #a5d6ff;\n  --scalar-color-orange: #e2ae83;\n  --scalar-color-purple: #d2a8ff;\n\n  --scalar-scrollbar-color: rgba(255, 255, 255, 0.24);\n  --scalar-scrollbar-color-active: rgba(255, 255, 255, 0.48);\n}\n.section-flare {\n  width: 100%;\n  height: 400px;\n  position: absolute;\n}\n.section-flare-item:first-of-type:before {\n  content: "";\n  position: absolute;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  left: 0;\n  --stripes: repeating-linear-gradient(100deg, #fff 0%, #fff 0%, transparent 2%, transparent 12%, #fff 17%);\n  --stripesDark: repeating-linear-gradient(100deg, #000 0%, #000 0%, transparent 10%, transparent 12%, #000 17%);\n  --rainbow: repeating-linear-gradient(100deg, #60a5fa 10%, #e879f9 16%, #5eead4 22%, #60a5fa 30%);\n  contain: strict;\n  contain-intrinsic-size: 100vw 40vh;\n  background-image: var(--stripesDark), var(--rainbow);\n  background-size: 300%, 200%;\n  background-position:\n    50% 50%,\n    50% 50%;\n  filter: opacity(20%) saturate(200%);\n  -webkit-mask-image: radial-gradient(ellipse at 100% 0%, black 40%, transparent 70%);\n  mask-image: radial-gradient(ellipse at 100% 0%, black 40%, transparent 70%);\n  pointer-events: none;\n}\n.section-flare-item:first-of-type:after {\n  content: "";\n  position: absolute;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  left: 0;\n  background-image: var(--stripes), var(--rainbow);\n  background-size: 200%, 100%;\n  background-attachment: fixed;\n  mix-blend-mode: difference;\n  background-image: var(--stripesDark), var(--rainbow);\n  pointer-events: none;\n}\n.light-mode .section-flare-item:first-of-type:after,\n.light-mode .section-flare-item:first-of-type:before {\n  background-image: var(--stripes), var(--rainbow);\n  filter: opacity(4%) saturate(200%);\n}\n',
slug:"elysiajs"},fastify:{uid:"nTZcdcM2_yHFZFxTQe9Kk",name:"Fastify",
description:"Fastify theme",
theme:".light-mode {\n  color-scheme: light;\n  --scalar-color-1: #1c1e21;\n  --scalar-color-2: #757575;\n  --scalar-color-3: #8e8e8e;\n  --scalar-color-disabled: #b4b1b1;\n  --scalar-color-ghost: #a7a7a7;\n  --scalar-color-accent: #2f8555;\n  --scalar-background-1: #fff;\n  --scalar-background-2: #f5f5f5;\n  --scalar-background-3: #ededed;\n  --scalar-background-4: rgba(0, 0, 0, 0.06);\n  --scalar-background-accent: #2f85551f;\n\n  --scalar-border-color: rgba(0, 0, 0, 0.1);\n  --scalar-scrollbar-color: rgba(0, 0, 0, 0.18);\n  --scalar-scrollbar-color-active: rgba(0, 0, 0, 0.36);\n  --scalar-lifted-brightness: 1;\n  --scalar-backdrop-brightness: 1;\n\n  --scalar-shadow-1: 0 1px 3px 0 rgba(0, 0, 0, 0.11);\n  --scalar-shadow-2: rgba(0, 0, 0, 0.08) 0px 13px 20px 0px, rgba(0, 0, 0, 0.08) 0px 3px 8px 0px, #eeeeed 0px 0 0 1px;\n\n  --scalar-button-1: rgb(49 53 56);\n  --scalar-button-1-color: #fff;\n  --scalar-button-1-hover: rgb(28 31 33);\n\n  --scalar-color-green: #007300;\n  --scalar-color-red: #af272b;\n  --scalar-color-yellow: #b38200;\n  --scalar-color-blue: #3b8ba5;\n  --scalar-color-orange: #fb892c;\n  --scalar-color-purple: #5203d1;\n}\n\n.dark-mode {\n  color-scheme: dark;\n  --scalar-color-1: rgba(255, 255, 255, 0.9);\n  --scalar-color-2: rgba(255, 255, 255, 0.62);\n  --scalar-color-3: rgba(255, 255, 255, 0.44);\n  --scalar-color-disabled: rgba(255, 255, 255, 0.34);\n  --scalar-color-ghost: rgba(255, 255, 255, 0.26);\n  --scalar-color-accent: #27c2a0;\n  --scalar-background-1: #1b1b1d;\n  --scalar-background-2: #242526;\n  --scalar-background-3: #3b3b3b;\n  --scalar-background-4: rgba(255, 255, 255, 0.06);\n  --scalar-background-accent: #27c2a01f;\n\n  --scalar-border-color: rgba(255, 255, 255, 0.1);\n  --scalar-scrollbar-color: rgba(255, 255, 255, 0.24);\n  --scalar-scrollbar-color-active: rgba(255, 255, 255, 0.48);\n  --scalar-lifted-brightness: 1.45;\n  --scalar-backdrop-brightness: 0.5;\n\n  --scalar-shadow-1: 0 1px 3px 0 rgb(0, 0, 0, 0.1);\n  --scalar-shadow-2:\n    rgba(15, 15, 15, 0.2) 0px 3px 6px, rgba(15, 15, 15, 0.4) 0px 9px 24px, 0 0 0 1px rgba(255, 255, 255, 0.1);\n\n  --scalar-button-1: #f6f6f6;\n  --scalar-button-1-color: #000;\n  --scalar-button-1-hover: #e7e7e7;\n\n  --scalar-color-green: #26b226;\n  --scalar-color-red: #fb565b;\n  --scalar-color-yellow: #ffc426;\n  --scalar-color-blue: #6ecfef;\n  --scalar-color-orange: #ff8d4d;\n  --scalar-color-purple: #b191f9;\n}\n",
slug:"fastify"}
},L_e=Bc(Hc([pu("Meta"),pu("Control"),pu("Shift"),pu("Alt"),pu("default")])).optional().default(["default"]),B_e=nu(cu(["Space","Backspace","Tab","Enter","Escape","ArrowDown","ArrowLeft","ArrowRight","ArrowUp","End","Home","PageDown","PageUp","Delete","0","1","2","3","4","5","6","7","8","9","a","b","c","d","e","f","g","h","i","j","k","l","m","n","o","p","q","r","s","t","u","v","w","x","y","z","0","1","2","3","4","5","6","7","8","9","*","+","-",".","/","F1","F2","F3","F4","F5","F6","F7","F8","F9","F10","F11","F12",";","=",",","-",".","/","`","[","\\","]",""]),zc({
modifiers:L_e.optional(),
event:cu(["addTopNav","closeModal","closeTopNav","createNew","executeRequest","focusAddressBar","focusRequestSearch","jumpToLastTab","jumpToTab","navigateSearchResultsDown","navigateSearchResultsUp","navigateTopNavLeft","navigateTopNavRight","openCommandPalette","selectSearchResult","toggleSidebar"])
})),j_e=zc({modifiers:L_e,hotKeys:B_e.optional()}).optional();zc({
uid:jX.brand(),name:cl().default("Default Workspace"),
description:cl().default("Basic Scalar Workspace"),
collections:Bc(cl().brand()).default([]),environments:tu(cl(),cl()).default({}),
hotKeyConfig:j_e,activeEnvironmentId:cl().optional().default("default"),
cookies:Bc(cl().brand()).default([]),proxyUrl:cl().optional(),
themeId:cu(M_e).optional().default("default").catch("default"),
selectedHttpClient:zc({targetKey:cl(),clientKey:cl()}).optional().default({
targetKey:"shell",clientKey:"curl"})})
;const U_e=Symbol("isDetectChangesProxy"),z_e=Symbol("detectChangesProxyTarget"),F_e=(e,t,n={
proxyCache:new WeakMap,path:[]})=>{if(!lSe(e)&&!Array.isArray(e))return e
;if(n.proxyCache.has(e))return n.proxyCache.get(e);const r=new Proxy(e,{
get(e,r,o){if(r===U_e)return!0;if(r===z_e)return e;const a=Reflect.get(e,r,o)
;return Z_e(a)?a:F_e(a,t,{...n,path:[...n.path,String(r)]})},set(e,r,o,a){
const i=[...n.path,String(r)];t?.hooks?.onBeforeChange?.(i,o)
;const s=Reflect.set(e,r,o,a);return t?.hooks?.onAfterChange?.(i,o),s}})
;return n.proxyCache.set(e,r),r
},Z_e=e=>"object"==typeof e&&null!==e&&!0===e[U_e],Q_e=(e,{depth:t=0}={})=>{
const n=(r,o=0)=>{if("object"!=typeof r||null===r)return r
;const a="object"!=typeof(i=hm(sSe(fSe(r))))||null===i?i:i[U_e]?i[z_e]:i;var i
;return null!==t&&o>=t||(0!==o&&a!==r&&(console.warn("%c⚠ Warning:%c You tried to assign a proxied object (depth: %d).\n%c💡 Tip:%c Pass a plain object instead — wrapping a proxy inside another proxy may cause weird bugs.\n%c🔍 Debug Info:%c The problematic value is shown below:","background: #fdd835; color: #000; font-weight: bold; padding: 2px 4px; border-radius: 3px;","color: inherit;",o,"color: #00bfa5; font-weight: bold;","color: inherit;","color: #03a9f4; font-weight: bold;","color: inherit;",r,e),
console.groupCollapsed("%c📜 Proxy assignment trace","color: #9c27b0; font-weight: bold;"),
console.trace({value:r,raw:a
}),console.groupEnd()),Object.entries(a).forEach((([e,t])=>{const r=n(t,o+1)
;Reflect.set(a,e,r)||console.warn('%c🚫 Readonly Property Error:%c Failed to set property "%s" on object.\n%c💡 Tip:%c This property is readonly or non-configurable. You cannot unpack a readonly property — the value was not updated.\n%c🔍 Debug Info:%c Property: %s | Value: %o | Object: %o',"background: #f44336; color: #fff; font-weight: bold; padding: 2px 4px; border-radius: 3px;","color: inherit;",e,"color: #00bfa5; font-weight: bold;","color: inherit;","color: #03a9f4; font-weight: bold;","color: inherit;",e,r,a)
}))),a};return n(e)},H_e=(e={})=>{const{debug:t=!1}=e,n=new Map,r=[];let o=null
;const{execute:a}=TSe({delay:328}),i=()=>{if(0!==r.length){
if(t)if(1===r.length){const e=r[0]
;e&&console.log(`[EventBus] ${e.message}`,...e.args)}else{
console.groupCollapsed(`[EventBus] ${r.length} operations`)
;for(const{message:e,args:t}of r)console.log(e,...t);console.groupEnd()}
r.length=0,o=null}},s=(e,...n)=>{t&&(r.push({message:e,args:n
}),o&&clearTimeout(o),o=setTimeout(i,500))},l=(e,t)=>{const r=n.get(e)
;r&&(r.delete(t),s(`Removed listener for "${String(e)}" (${r.size} remaining)`),
0===r.size&&n.delete(e))},c=(e,t,r)=>{const o=r?.skipUnpackProxy?t:Q_e(t,{
depth:5}),a=n.get(e)
;if(!a||0===a.size)return void s(`🛑 No listeners for "${String(e)}"`)
;s(`Emitting "${String(e)}" to ${a.size} listener(s)`,t);const i=Array.from(a)
;for(const n of i)try{n(o)}catch(l){
console.error(`[EventBus] Error in listener for "${String(e)}":`,l)}};return{
on:(e,t)=>{const r=(e=>{const t=n.get(e)??new Set;return n.set(e,t),t})(e)
;return r.add(t),
s(`Added listener for "${String(e)}" (${r.size} total)`),()=>l(e,t)},off:l,
emit:(...e)=>{const[t,n,r]=e;if(!r?.debounceKey)return void c(t,n,r)
;const o=`${t}-${r.debounceKey}`;a(o,(()=>c(t,n,r)))}}},V_e={key:0,
class:"sr-only"},q_e=Qg({__name:"ServerVariablesSelect",props:{enum:{},value:{},
controls:{}},emits:["change"],setup(e,{emit:t}){
const n=e,r=t,o=Sy((()=>n.enum.map((e=>({id:e,label:e}))))),a=Sy({
get:()=>o.value.find((e=>e.id===n.value)),set:e=>r("change",e?.id??"")})
;return(t,n)=>(Ub(),Hb(xm(hre),{modelValue:a.value,
"onUpdate:modelValue":n[0]||(n[0]=e=>a.value=e),options:o.value},{
default:ig((()=>[Yb(xm(WS),{"aria-controls":e.controls,
class:"group/button h-8 gap-1.5 p-1.5 text-base font-normal",variant:"ghost"},{
default:ig((()=>[Gb("span",{class:Ih({"text-c-1":e.value})
},[e.value?(Ub(),Qb("span",V_e," Selected: ")):ny("",!0),ey(" "+Uh(e.value||"Select value"),1)],2),Yb(xm(L_),{
weight:"bold",
class:"mt-0.25 size-3 transition-transform duration-100 group-aria-expanded/button:rotate-180"
})])),_:1},8,["aria-controls"])])),_:1},8,["modelValue","options"]))}}),W_e=Qg({
__name:"ServerVariablesTextbox",props:{value:{},controls:{}},emits:["change"],
setup(e,{emit:t}){const n=e,r=t,o=Sy({get:()=>n.value,set:e=>r("change",e)})
;return(t,n)=>sg((Ub(),Qb("input",iy({
"onUpdate:modelValue":n[0]||(n[0]=e=>o.value=e)},e.controls?{...t.$attrs,
"aria-controls":e.controls}:{},{autocomplete:"off",
class:"text-c-1 w-full border-transparent px-1.5 py-1.25 -outline-offset-1 group-last/label:rounded-br-lg",
placeholder:"value",spellcheck:"false",type:"text"}),null,16)),[[TO,o.value]])}
}),X_e=["for"],G_e=Qg({__name:"ServerVariablesForm",props:{variables:{},
values:{},controls:{},layout:{default:"client"}},emits:["update:variable"],
setup(e,{emit:t}){const n=t,r=Hg();function o(e,t){n("update:variable",e,t)}
const a=t=>(e.values?.[t]??e.variables?.[t]?.default??"").toString()
;return(t,n)=>e.variables&&Object.keys(e.variables??{}).length?(Ub(!0),Qb(Mb,{
key:0},wv(Object.keys(e.variables),(t=>(Ub(),Qb("div",{key:t,
class:Ih(["group/label flex h-8 w-full","reference"===e.layout&&"items-center border-x border-b last:rounded-b-lg"])
},[Gb("label",{
class:"flex items-center py-2 pl-3 group-has-[input]/label:mr-0 after:content-[':']",
for:`${xm(r)}-${t}`},Uh(t),9,X_e),e.variables?.[t]?.enum?.length?(Ub(),Hb(q_e,{
key:0,id:`${xm(r)}-${t}`,controls:e.controls,
enum:e.variables[t]?.enum?.map((e=>`${e}`))??[],value:a(t),onChange:e=>o(t,e)
},null,8,["id","controls","enum","value","onChange"])):(Ub(),Hb(W_e,{key:1,
id:`${xm(r)}-${t}`,controls:e.controls,value:a(t),onChange:e=>o(t,e)
},null,8,["id","controls","value","onChange"]))],2)))),128)):ny("",!0)}}),Y_e={
xs:"(min-width: 400px)",sm:"(min-width: 600px)",md:"(min-width: 800px)",
lg:"(min-width: 1000px)",xl:"(min-width: 1200px)",
zoomed:"(max-width: 720px) and (max-height: 480px)"};function K_e(){const e={
xs:s2(Y_e.xs),sm:s2(Y_e.sm),md:s2(Y_e.md),lg:s2(Y_e.lg),xl:s2(Y_e.xl),
zoomed:s2(Y_e.zoomed)
},t=Sy((()=>Object.fromEntries(Object.entries(e).map((([e,t])=>[e,xm(t)])))))
;return{screens:Y_e,mediaQueries:e,breakpoints:t}}const J_e=(e,t)=>{
if(t)return t.type===e?t:J_e(e,t.parent)},eTe=e=>{const t=new Map,n=(e,n)=>{
const r=t.get(e);r?r.push(n):t.set(e,[n])},r=(e,t)=>{
if(e)for(const o of e)if("operation"===o.type){const e=`${o.path}|${o.method}`
;n(e,{...o,parent:t})}else if("webhook"===o.type){
const e=`${o.name}|${o.method}`;n(e,{...o,parent:t})
}else"children"in o&&o.children&&r(o.children,{...o,parent:t})}
;return r(e.children,e),t
},tTe=/[\0-\x1F!-,\.\/:-@\[-\^`\{-\xA9\xAB-\xB4\xB6-\xB9\xBB-\xBF\xD7\xF7\u02C2-\u02C5\u02D2-\u02DF\u02E5-\u02EB\u02ED\u02EF-\u02FF\u0375\u0378\u0379\u037E\u0380-\u0385\u0387\u038B\u038D\u03A2\u03F6\u0482\u0530\u0557\u0558\u055A-\u055F\u0589-\u0590\u05BE\u05C0\u05C3\u05C6\u05C8-\u05CF\u05EB-\u05EE\u05F3-\u060F\u061B-\u061F\u066A-\u066D\u06D4\u06DD\u06DE\u06E9\u06FD\u06FE\u0700-\u070F\u074B\u074C\u07B2-\u07BF\u07F6-\u07F9\u07FB\u07FC\u07FE\u07FF\u082E-\u083F\u085C-\u085F\u086B-\u089F\u08B5\u08C8-\u08D2\u08E2\u0964\u0965\u0970\u0984\u098D\u098E\u0991\u0992\u09A9\u09B1\u09B3-\u09B5\u09BA\u09BB\u09C5\u09C6\u09C9\u09CA\u09CF-\u09D6\u09D8-\u09DB\u09DE\u09E4\u09E5\u09F2-\u09FB\u09FD\u09FF\u0A00\u0A04\u0A0B-\u0A0E\u0A11\u0A12\u0A29\u0A31\u0A34\u0A37\u0A3A\u0A3B\u0A3D\u0A43-\u0A46\u0A49\u0A4A\u0A4E-\u0A50\u0A52-\u0A58\u0A5D\u0A5F-\u0A65\u0A76-\u0A80\u0A84\u0A8E\u0A92\u0AA9\u0AB1\u0AB4\u0ABA\u0ABB\u0AC6\u0ACA\u0ACE\u0ACF\u0AD1-\u0ADF\u0AE4\u0AE5\u0AF0-\u0AF8\u0B00\u0B04\u0B0D\u0B0E\u0B11\u0B12\u0B29\u0B31\u0B34\u0B3A\u0B3B\u0B45\u0B46\u0B49\u0B4A\u0B4E-\u0B54\u0B58-\u0B5B\u0B5E\u0B64\u0B65\u0B70\u0B72-\u0B81\u0B84\u0B8B-\u0B8D\u0B91\u0B96-\u0B98\u0B9B\u0B9D\u0BA0-\u0BA2\u0BA5-\u0BA7\u0BAB-\u0BAD\u0BBA-\u0BBD\u0BC3-\u0BC5\u0BC9\u0BCE\u0BCF\u0BD1-\u0BD6\u0BD8-\u0BE5\u0BF0-\u0BFF\u0C0D\u0C11\u0C29\u0C3A-\u0C3C\u0C45\u0C49\u0C4E-\u0C54\u0C57\u0C5B-\u0C5F\u0C64\u0C65\u0C70-\u0C7F\u0C84\u0C8D\u0C91\u0CA9\u0CB4\u0CBA\u0CBB\u0CC5\u0CC9\u0CCE-\u0CD4\u0CD7-\u0CDD\u0CDF\u0CE4\u0CE5\u0CF0\u0CF3-\u0CFF\u0D0D\u0D11\u0D45\u0D49\u0D4F-\u0D53\u0D58-\u0D5E\u0D64\u0D65\u0D70-\u0D79\u0D80\u0D84\u0D97-\u0D99\u0DB2\u0DBC\u0DBE\u0DBF\u0DC7-\u0DC9\u0DCB-\u0DCE\u0DD5\u0DD7\u0DE0-\u0DE5\u0DF0\u0DF1\u0DF4-\u0E00\u0E3B-\u0E3F\u0E4F\u0E5A-\u0E80\u0E83\u0E85\u0E8B\u0EA4\u0EA6\u0EBE\u0EBF\u0EC5\u0EC7\u0ECE\u0ECF\u0EDA\u0EDB\u0EE0-\u0EFF\u0F01-\u0F17\u0F1A-\u0F1F\u0F2A-\u0F34\u0F36\u0F38\u0F3A-\u0F3D\u0F48\u0F6D-\u0F70\u0F85\u0F98\u0FBD-\u0FC5\u0FC7-\u0FFF\u104A-\u104F\u109E\u109F\u10C6\u10C8-\u10CC\u10CE\u10CF\u10FB\u1249\u124E\u124F\u1257\u1259\u125E\u125F\u1289\u128E\u128F\u12B1\u12B6\u12B7\u12BF\u12C1\u12C6\u12C7\u12D7\u1311\u1316\u1317\u135B\u135C\u1360-\u137F\u1390-\u139F\u13F6\u13F7\u13FE-\u1400\u166D\u166E\u1680\u169B-\u169F\u16EB-\u16ED\u16F9-\u16FF\u170D\u1715-\u171F\u1735-\u173F\u1754-\u175F\u176D\u1771\u1774-\u177F\u17D4-\u17D6\u17D8-\u17DB\u17DE\u17DF\u17EA-\u180A\u180E\u180F\u181A-\u181F\u1879-\u187F\u18AB-\u18AF\u18F6-\u18FF\u191F\u192C-\u192F\u193C-\u1945\u196E\u196F\u1975-\u197F\u19AC-\u19AF\u19CA-\u19CF\u19DA-\u19FF\u1A1C-\u1A1F\u1A5F\u1A7D\u1A7E\u1A8A-\u1A8F\u1A9A-\u1AA6\u1AA8-\u1AAF\u1AC1-\u1AFF\u1B4C-\u1B4F\u1B5A-\u1B6A\u1B74-\u1B7F\u1BF4-\u1BFF\u1C38-\u1C3F\u1C4A-\u1C4C\u1C7E\u1C7F\u1C89-\u1C8F\u1CBB\u1CBC\u1CC0-\u1CCF\u1CD3\u1CFB-\u1CFF\u1DFA\u1F16\u1F17\u1F1E\u1F1F\u1F46\u1F47\u1F4E\u1F4F\u1F58\u1F5A\u1F5C\u1F5E\u1F7E\u1F7F\u1FB5\u1FBD\u1FBF-\u1FC1\u1FC5\u1FCD-\u1FCF\u1FD4\u1FD5\u1FDC-\u1FDF\u1FED-\u1FF1\u1FF5\u1FFD-\u203E\u2041-\u2053\u2055-\u2070\u2072-\u207E\u2080-\u208F\u209D-\u20CF\u20F1-\u2101\u2103-\u2106\u2108\u2109\u2114\u2116-\u2118\u211E-\u2123\u2125\u2127\u2129\u212E\u213A\u213B\u2140-\u2144\u214A-\u214D\u214F-\u215F\u2189-\u24B5\u24EA-\u2BFF\u2C2F\u2C5F\u2CE5-\u2CEA\u2CF4-\u2CFF\u2D26\u2D28-\u2D2C\u2D2E\u2D2F\u2D68-\u2D6E\u2D70-\u2D7E\u2D97-\u2D9F\u2DA7\u2DAF\u2DB7\u2DBF\u2DC7\u2DCF\u2DD7\u2DDF\u2E00-\u2E2E\u2E30-\u3004\u3008-\u3020\u3030\u3036\u3037\u303D-\u3040\u3097\u3098\u309B\u309C\u30A0\u30FB\u3100-\u3104\u3130\u318F-\u319F\u31C0-\u31EF\u3200-\u33FF\u4DC0-\u4DFF\u9FFD-\u9FFF\uA48D-\uA4CF\uA4FE\uA4FF\uA60D-\uA60F\uA62C-\uA63F\uA673\uA67E\uA6F2-\uA716\uA720\uA721\uA789\uA78A\uA7C0\uA7C1\uA7CB-\uA7F4\uA828-\uA82B\uA82D-\uA83F\uA874-\uA87F\uA8C6-\uA8CF\uA8DA-\uA8DF\uA8F8-\uA8FA\uA8FC\uA92E\uA92F\uA954-\uA95F\uA97D-\uA97F\uA9C1-\uA9CE\uA9DA-\uA9DF\uA9FF\uAA37-\uAA3F\uAA4E\uAA4F\uAA5A-\uAA5F\uAA77-\uAA79\uAAC3-\uAADA\uAADE\uAADF\uAAF0\uAAF1\uAAF7-\uAB00\uAB07\uAB08\uAB0F\uAB10\uAB17-\uAB1F\uAB27\uAB2F\uAB5B\uAB6A-\uAB6F\uABEB\uABEE\uABEF\uABFA-\uABFF\uD7A4-\uD7AF\uD7C7-\uD7CA\uD7FC-\uD7FF\uE000-\uF8FF\uFA6E\uFA6F\uFADA-\uFAFF\uFB07-\uFB12\uFB18-\uFB1C\uFB29\uFB37\uFB3D\uFB3F\uFB42\uFB45\uFBB2-\uFBD2\uFD3E-\uFD4F\uFD90\uFD91\uFDC8-\uFDEF\uFDFC-\uFDFF\uFE10-\uFE1F\uFE30-\uFE32\uFE35-\uFE4C\uFE50-\uFE6F\uFE75\uFEFD-\uFF0F\uFF1A-\uFF20\uFF3B-\uFF3E\uFF40\uFF5B-\uFF65\uFFBF-\uFFC1\uFFC8\uFFC9\uFFD0\uFFD1\uFFD8\uFFD9\uFFDD-\uFFFF]|\uD800[\uDC0C\uDC27\uDC3B\uDC3E\uDC4E\uDC4F\uDC5E-\uDC7F\uDCFB-\uDD3F\uDD75-\uDDFC\uDDFE-\uDE7F\uDE9D-\uDE9F\uDED1-\uDEDF\uDEE1-\uDEFF\uDF20-\uDF2C\uDF4B-\uDF4F\uDF7B-\uDF7F\uDF9E\uDF9F\uDFC4-\uDFC7\uDFD0\uDFD6-\uDFFF]|\uD801[\uDC9E\uDC9F\uDCAA-\uDCAF\uDCD4-\uDCD7\uDCFC-\uDCFF\uDD28-\uDD2F\uDD64-\uDDFF\uDF37-\uDF3F\uDF56-\uDF5F\uDF68-\uDFFF]|\uD802[\uDC06\uDC07\uDC09\uDC36\uDC39-\uDC3B\uDC3D\uDC3E\uDC56-\uDC5F\uDC77-\uDC7F\uDC9F-\uDCDF\uDCF3\uDCF6-\uDCFF\uDD16-\uDD1F\uDD3A-\uDD7F\uDDB8-\uDDBD\uDDC0-\uDDFF\uDE04\uDE07-\uDE0B\uDE14\uDE18\uDE36\uDE37\uDE3B-\uDE3E\uDE40-\uDE5F\uDE7D-\uDE7F\uDE9D-\uDEBF\uDEC8\uDEE7-\uDEFF\uDF36-\uDF3F\uDF56-\uDF5F\uDF73-\uDF7F\uDF92-\uDFFF]|\uD803[\uDC49-\uDC7F\uDCB3-\uDCBF\uDCF3-\uDCFF\uDD28-\uDD2F\uDD3A-\uDE7F\uDEAA\uDEAD-\uDEAF\uDEB2-\uDEFF\uDF1D-\uDF26\uDF28-\uDF2F\uDF51-\uDFAF\uDFC5-\uDFDF\uDFF7-\uDFFF]|\uD804[\uDC47-\uDC65\uDC70-\uDC7E\uDCBB-\uDCCF\uDCE9-\uDCEF\uDCFA-\uDCFF\uDD35\uDD40-\uDD43\uDD48-\uDD4F\uDD74\uDD75\uDD77-\uDD7F\uDDC5-\uDDC8\uDDCD\uDDDB\uDDDD-\uDDFF\uDE12\uDE38-\uDE3D\uDE3F-\uDE7F\uDE87\uDE89\uDE8E\uDE9E\uDEA9-\uDEAF\uDEEB-\uDEEF\uDEFA-\uDEFF\uDF04\uDF0D\uDF0E\uDF11\uDF12\uDF29\uDF31\uDF34\uDF3A\uDF45\uDF46\uDF49\uDF4A\uDF4E\uDF4F\uDF51-\uDF56\uDF58-\uDF5C\uDF64\uDF65\uDF6D-\uDF6F\uDF75-\uDFFF]|\uD805[\uDC4B-\uDC4F\uDC5A-\uDC5D\uDC62-\uDC7F\uDCC6\uDCC8-\uDCCF\uDCDA-\uDD7F\uDDB6\uDDB7\uDDC1-\uDDD7\uDDDE-\uDDFF\uDE41-\uDE43\uDE45-\uDE4F\uDE5A-\uDE7F\uDEB9-\uDEBF\uDECA-\uDEFF\uDF1B\uDF1C\uDF2C-\uDF2F\uDF3A-\uDFFF]|\uD806[\uDC3B-\uDC9F\uDCEA-\uDCFE\uDD07\uDD08\uDD0A\uDD0B\uDD14\uDD17\uDD36\uDD39\uDD3A\uDD44-\uDD4F\uDD5A-\uDD9F\uDDA8\uDDA9\uDDD8\uDDD9\uDDE2\uDDE5-\uDDFF\uDE3F-\uDE46\uDE48-\uDE4F\uDE9A-\uDE9C\uDE9E-\uDEBF\uDEF9-\uDFFF]|\uD807[\uDC09\uDC37\uDC41-\uDC4F\uDC5A-\uDC71\uDC90\uDC91\uDCA8\uDCB7-\uDCFF\uDD07\uDD0A\uDD37-\uDD39\uDD3B\uDD3E\uDD48-\uDD4F\uDD5A-\uDD5F\uDD66\uDD69\uDD8F\uDD92\uDD99-\uDD9F\uDDAA-\uDEDF\uDEF7-\uDFAF\uDFB1-\uDFFF]|\uD808[\uDF9A-\uDFFF]|\uD809[\uDC6F-\uDC7F\uDD44-\uDFFF]|[\uD80A\uD80B\uD80E-\uD810\uD812-\uD819\uD824-\uD82B\uD82D\uD82E\uD830-\uD833\uD837\uD839\uD83D\uD83F\uD87B-\uD87D\uD87F\uD885-\uDB3F\uDB41-\uDBFF][\uDC00-\uDFFF]|\uD80D[\uDC2F-\uDFFF]|\uD811[\uDE47-\uDFFF]|\uD81A[\uDE39-\uDE3F\uDE5F\uDE6A-\uDECF\uDEEE\uDEEF\uDEF5-\uDEFF\uDF37-\uDF3F\uDF44-\uDF4F\uDF5A-\uDF62\uDF78-\uDF7C\uDF90-\uDFFF]|\uD81B[\uDC00-\uDE3F\uDE80-\uDEFF\uDF4B-\uDF4E\uDF88-\uDF8E\uDFA0-\uDFDF\uDFE2\uDFE5-\uDFEF\uDFF2-\uDFFF]|\uD821[\uDFF8-\uDFFF]|\uD823[\uDCD6-\uDCFF\uDD09-\uDFFF]|\uD82C[\uDD1F-\uDD4F\uDD53-\uDD63\uDD68-\uDD6F\uDEFC-\uDFFF]|\uD82F[\uDC6B-\uDC6F\uDC7D-\uDC7F\uDC89-\uDC8F\uDC9A-\uDC9C\uDC9F-\uDFFF]|\uD834[\uDC00-\uDD64\uDD6A-\uDD6C\uDD73-\uDD7A\uDD83\uDD84\uDD8C-\uDDA9\uDDAE-\uDE41\uDE45-\uDFFF]|\uD835[\uDC55\uDC9D\uDCA0\uDCA1\uDCA3\uDCA4\uDCA7\uDCA8\uDCAD\uDCBA\uDCBC\uDCC4\uDD06\uDD0B\uDD0C\uDD15\uDD1D\uDD3A\uDD3F\uDD45\uDD47-\uDD49\uDD51\uDEA6\uDEA7\uDEC1\uDEDB\uDEFB\uDF15\uDF35\uDF4F\uDF6F\uDF89\uDFA9\uDFC3\uDFCC\uDFCD]|\uD836[\uDC00-\uDDFF\uDE37-\uDE3A\uDE6D-\uDE74\uDE76-\uDE83\uDE85-\uDE9A\uDEA0\uDEB0-\uDFFF]|\uD838[\uDC07\uDC19\uDC1A\uDC22\uDC25\uDC2B-\uDCFF\uDD2D-\uDD2F\uDD3E\uDD3F\uDD4A-\uDD4D\uDD4F-\uDEBF\uDEFA-\uDFFF]|\uD83A[\uDCC5-\uDCCF\uDCD7-\uDCFF\uDD4C-\uDD4F\uDD5A-\uDFFF]|\uD83B[\uDC00-\uDDFF\uDE04\uDE20\uDE23\uDE25\uDE26\uDE28\uDE33\uDE38\uDE3A\uDE3C-\uDE41\uDE43-\uDE46\uDE48\uDE4A\uDE4C\uDE50\uDE53\uDE55\uDE56\uDE58\uDE5A\uDE5C\uDE5E\uDE60\uDE63\uDE65\uDE66\uDE6B\uDE73\uDE78\uDE7D\uDE7F\uDE8A\uDE9C-\uDEA0\uDEA4\uDEAA\uDEBC-\uDFFF]|\uD83C[\uDC00-\uDD2F\uDD4A-\uDD4F\uDD6A-\uDD6F\uDD8A-\uDFFF]|\uD83E[\uDC00-\uDFEF\uDFFA-\uDFFF]|\uD869[\uDEDE-\uDEFF]|\uD86D[\uDF35-\uDF3F]|\uD86E[\uDC1E\uDC1F]|\uD873[\uDEA2-\uDEAF]|\uD87A[\uDFE1-\uDFFF]|\uD87E[\uDE1E-\uDFFF]|\uD884[\uDF4B-\uDFFF]|\uDB40[\uDC00-\uDCFF\uDDF0-\uDFFF]/g,nTe=Object.hasOwnProperty
;class rTe{constructor(){this.occurrences,this.reset()}slug(e,t){const n=this
;let r=oTe(e,!0===t);const o=r
;for(;nTe.call(n.occurrences,r);)n.occurrences[o]++,r=o+"-"+n.occurrences[o]
;return n.occurrences[r]=0,r}reset(){this.occurrences=Object.create(null)}}
function oTe(e,t){
return"string"!=typeof e?"":(t||(e=e.toLowerCase()),e.replace(tTe,"").replace(/ /g,"-"))
}const aTe=(e,t)=>{const n=r=>{const o=`${oTe(e)}`
;if("text"===r.type)return t?.generateHeadingSlug?t?.generateHeadingSlug({
slug:r.slug}):r.slug?`${o}/description/${r.slug}`:`${o}/`
;if("tag"===r.type)return t?.generateTagSlug?`${o}/tag/${t.generateTagSlug(r.tag)}`:`${o}/tag/${oTe(r.tag.name??"")}`
;if("operation"===r.type){const e=r.parentTag?`${n({type:"tag",
tag:r.parentTag.tag,parentId:r.parentTag.id})}/`:`${o}/`
;return t?.generateOperationSlug?`${e}${t.generateOperationSlug({path:r.path,
operationId:r.operation.operationId,method:r.method.toUpperCase(),
summary:r.operation.summary})}`:`${e}${r.method.toUpperCase()}${r.path}`}
if("webhook"===r.type){const e=r.parentTag?`${n({type:"tag",
parentId:r.parentTag.id,tag:r.parentTag.tag})}/`:`${o}/`
;return t?.generateWebhookSlug?`${e}webhook/${t.generateWebhookSlug({
name:r.name,method:r.method?.toUpperCase()
})}`:`${e}webhook/${r.method?.toUpperCase()}/${oTe(r.name)}`}
if("model"===r.type){if(!r.name)return`${o}/models`;const e=r.parentTag?`${n({
type:"tag",parentId:r.parentTag.id,tag:r.parentTag.tag})}/`:`${o}/`
;return t?.generateModelSlug?`${e}model/${t.generateModelSlug({name:r.name
})}`:`${e}model/${oTe(r.name)}`}
return"example"===r.type?`${r.parentId}/example/${oTe(r.name)}`:"document"===r.type?o:(console.warn("[WARNING]: unhandled id generation for navigation item:",r),
"unknown-id")};return{hideModels:t?.hideModels??!1,
operationsSorter:t?.operationsSorter,tagsSorter:t?.tagsSorter,generateId:n}}
;const iTe=({generateId:e,parentId:t,info:n})=>{
if(!n.description?.trim())return[];const r=function(e){const t=new rTe
;return((e,t)=>e.map((e=>({...e,slug:t.slug(e.value)}))))(yH(e),t)
}(n.description),o=(e=>{const t=Math.min(...e.map((e=>e.depth)))
;return t>=1&&t<=6?t:1})(r),a=[];let i=null
;if(n.description&&!n.description.trim().startsWith("#")){const r={depth:1,
value:"Introduction",slug:"introduction"},o={id:e({type:"text",depth:r.depth,
slug:r.slug,parentId:t,info:n,value:r.value}),title:r.value,type:"text"}
;a.push(o)}for(const s of r){if(s.depth!==o&&s.depth!==o+1)continue;const r={
id:e({type:"text",depth:s.depth,slug:s.slug,parentId:t,info:n,value:s.value}),
title:s.value,type:"text"}
;s.depth===o?(r.children=[],a.push(r),i=r):i&&i.children?.push(r)}return a}
;function sTe(e){return Array.isArray(e)}function lTe(e){
return"bigint"==typeof e}function cTe(e){return"boolean"==typeof e}
function uTe(e){return e instanceof globalThis.Date}function dTe(e){
return"number"==typeof e}function pTe(e){return"object"==typeof e&&null!==e}
function hTe(e){return e instanceof globalThis.RegExp}function fTe(e){
return"string"==typeof e}function mTe(e){
return e instanceof globalThis.Uint8Array}function gTe(e){return void 0===e}
function vTe(e){return sTe(e)?function(e){return e.map((e=>vTe(e)))
}(e):uTe(e)?function(e){return new Date(e.getTime())}(e):mTe(e)?function(e){
return new Uint8Array(e)}(e):hTe(e)?function(e){
return new RegExp(e.source,e.flags)}(e):pTe(e)?function(e){const t={}
;for(const n of Object.getOwnPropertyNames(e))t[n]=vTe(e[n])
;for(const n of Object.getOwnPropertySymbols(e))t[n]=vTe(e[n]);return t}(e):e}
function bTe(e){return vTe(e)}function yTe(e,t){return bTe(void 0===t?e:{...t,
...e})}function OTe(e){return TTe(e)&&globalThis.Symbol.asyncIterator in e}
function wTe(e){return TTe(e)&&globalThis.Symbol.iterator in e}function xTe(e){
return e instanceof globalThis.Promise}function kTe(e){
return e instanceof Date&&globalThis.Number.isFinite(e.getTime())}
function STe(e){return e instanceof globalThis.Uint8Array}function _Te(e,t){
return t in e}function TTe(e){return null!==e&&"object"==typeof e}
function ETe(e){
return globalThis.Array.isArray(e)&&!globalThis.ArrayBuffer.isView(e)}
function ATe(e){return void 0===e}function CTe(e){return null===e}
function $Te(e){return"boolean"==typeof e}function PTe(e){
return"number"==typeof e}function DTe(e){return globalThis.Number.isInteger(e)}
function ITe(e){return"bigint"==typeof e}function MTe(e){
return"string"==typeof e}function NTe(e){return"function"==typeof e}
function RTe(e){return"symbol"==typeof e}var LTe;function BTe(e){
return sTe(e)?function(e){return globalThis.Object.freeze(e).map((e=>BTe(e)))
}(e):uTe(e)||mTe(e)||hTe(e)?e:pTe(e)?function(e){const t={}
;for(const n of Object.getOwnPropertyNames(e))t[n]=BTe(e[n])
;for(const n of Object.getOwnPropertySymbols(e))t[n]=BTe(e[n])
;return globalThis.Object.freeze(t)}(e):e}function jTe(e,t){const n=void 0!==t?{
...t,...e}:e;switch(LTe.InstanceMode){case"freeze":return BTe(n);case"clone":
return bTe(n);default:return n}}!function(e){function t(t){const n=TTe(t)
;return e.AllowArrayObject?n:n&&!ETe(t)}
e.InstanceMode="default",e.ExactOptionalPropertyTypes=!1,
e.AllowArrayObject=!1,e.AllowNaN=!1,
e.AllowNullVoid=!1,e.IsExactOptionalProperty=function(t,n){
return e.ExactOptionalPropertyTypes?n in t:void 0!==t[n]
},e.IsObjectLike=t,e.IsRecordLike=function(e){
return t(e)&&!(e instanceof Date)&&!(e instanceof Uint8Array)
},e.IsNumberLike=function(t){return e.AllowNaN?PTe(t):Number.isFinite(t)
},e.IsVoidLike=function(t){const n=ATe(t);return e.AllowNullVoid?n||null===t:n}
}(LTe||(LTe={}));class UTe extends Error{constructor(e){super(e)}}
const zTe=Symbol.for("TypeBox.Transform"),FTe=Symbol.for("TypeBox.Readonly"),ZTe=Symbol.for("TypeBox.Optional"),QTe=Symbol.for("TypeBox.Hint"),HTe=Symbol.for("TypeBox.Kind")
;function VTe(e){return pTe(e)&&"Readonly"===e[FTe]}function qTe(e){
return pTe(e)&&"Optional"===e[ZTe]}function WTe(e){return iEe(e,"Any")}
function XTe(e){return iEe(e,"Argument")}function GTe(e){return iEe(e,"Array")}
function YTe(e){return iEe(e,"AsyncIterator")}function KTe(e){
return iEe(e,"BigInt")}function JTe(e){return iEe(e,"Boolean")}function eEe(e){
return iEe(e,"Computed")}function tEe(e){return iEe(e,"Constructor")}
function nEe(e){return iEe(e,"Function")}function rEe(e){return iEe(e,"Integer")
}function oEe(e){return iEe(e,"Intersect")}function aEe(e){
return iEe(e,"Iterator")}function iEe(e,t){return pTe(e)&&HTe in e&&e[HTe]===t}
function sEe(e){return cTe(e)||dTe(e)||fTe(e)}function lEe(e){
return iEe(e,"Literal")}function cEe(e){return iEe(e,"MappedKey")}
function uEe(e){return iEe(e,"MappedResult")}function dEe(e){
return iEe(e,"Never")}function pEe(e){return iEe(e,"Null")}function hEe(e){
return iEe(e,"Number")}function fEe(e){return iEe(e,"Object")}function mEe(e){
return iEe(e,"Promise")}function gEe(e){return iEe(e,"Record")}function vEe(e){
return iEe(e,"Ref")}function bEe(e){return iEe(e,"RegExp")}function yEe(e){
return iEe(e,"String")}function OEe(e){return iEe(e,"Symbol")}function wEe(e){
return iEe(e,"TemplateLiteral")}function xEe(e){return pTe(e)&&zTe in e}
function kEe(e){return iEe(e,"Tuple")}function SEe(e){return iEe(e,"Undefined")}
function _Ee(e){return iEe(e,"Union")}function TEe(e){
return WTe(e)||XTe(e)||GTe(e)||JTe(e)||KTe(e)||YTe(e)||eEe(e)||tEe(e)||function(e){
return iEe(e,"Date")
}(e)||nEe(e)||rEe(e)||oEe(e)||aEe(e)||lEe(e)||cEe(e)||uEe(e)||dEe(e)||function(e){
return iEe(e,"Not")
}(e)||pEe(e)||hEe(e)||fEe(e)||mEe(e)||gEe(e)||vEe(e)||bEe(e)||yEe(e)||OEe(e)||wEe(e)||function(e){
return iEe(e,"This")}(e)||kEe(e)||SEe(e)||_Ee(e)||function(e){
return iEe(e,"Uint8Array")}(e)||function(e){return iEe(e,"Unknown")
}(e)||function(e){return iEe(e,"Unsafe")}(e)||function(e){return iEe(e,"Void")
}(e)||function(e){return pTe(e)&&HTe in e&&fTe(e[HTe])}(e)}
const EEe=["Argument","Any","Array","AsyncIterator","BigInt","Boolean","Computed","Constructor","Date","Enum","Function","Integer","Intersect","Iterator","Literal","MappedKey","MappedResult","Not","Null","Number","Object","Promise","Record","Ref","RegExp","String","Symbol","TemplateLiteral","This","Tuple","Undefined","Union","Uint8Array","Unknown","Void"]
;function AEe(e){try{return new RegExp(e),!0}catch{return!1}}function CEe(e){
if(!fTe(e))return!1;for(let t=0;t<e.length;t++){const n=e.charCodeAt(t)
;if(n>=7&&n<=13||27===n||127===n)return!1}return!0}function $Ee(e){
return IEe(e)||vAe(e)}function PEe(e){return gTe(e)||lTe(e)}function DEe(e){
return gTe(e)||dTe(e)}function IEe(e){return gTe(e)||cTe(e)}function MEe(e){
return gTe(e)||fTe(e)}function NEe(e){return gTe(e)||vAe(e)}function REe(e){
return pTe(e)&&"Optional"===e[ZTe]}function LEe(e){
return XEe(e,"Any")&&MEe(e.$id)}function BEe(e){
return XEe(e,"Array")&&"array"===e.type&&MEe(e.$id)&&vAe(e.items)&&DEe(e.minItems)&&DEe(e.maxItems)&&IEe(e.uniqueItems)&&NEe(e.contains)&&DEe(e.minContains)&&DEe(e.maxContains)
}function jEe(e){
return XEe(e,"AsyncIterator")&&"AsyncIterator"===e.type&&MEe(e.$id)&&vAe(e.items)
}function UEe(e){
return XEe(e,"BigInt")&&"bigint"===e.type&&MEe(e.$id)&&PEe(e.exclusiveMaximum)&&PEe(e.exclusiveMinimum)&&PEe(e.maximum)&&PEe(e.minimum)&&PEe(e.multipleOf)
}function zEe(e){return XEe(e,"Boolean")&&"boolean"===e.type&&MEe(e.$id)}
function FEe(e){
return XEe(e,"Constructor")&&"Constructor"===e.type&&MEe(e.$id)&&sTe(e.parameters)&&e.parameters.every((e=>vAe(e)))&&vAe(e.returns)
}function ZEe(e){
return XEe(e,"Date")&&"Date"===e.type&&MEe(e.$id)&&DEe(e.exclusiveMaximumTimestamp)&&DEe(e.exclusiveMinimumTimestamp)&&DEe(e.maximumTimestamp)&&DEe(e.minimumTimestamp)&&DEe(e.multipleOfTimestamp)
}function QEe(e){
return XEe(e,"Function")&&"Function"===e.type&&MEe(e.$id)&&sTe(e.parameters)&&e.parameters.every((e=>vAe(e)))&&vAe(e.returns)
}function HEe(e){
return XEe(e,"Integer")&&"integer"===e.type&&MEe(e.$id)&&DEe(e.exclusiveMaximum)&&DEe(e.exclusiveMinimum)&&DEe(e.maximum)&&DEe(e.minimum)&&DEe(e.multipleOf)
}function VEe(e){
return pTe(e)&&Object.entries(e).every((([e,t])=>CEe(e)&&vAe(t)))}
function qEe(e){
return XEe(e,"Intersect")&&(!fTe(e.type)||"object"===e.type)&&sTe(e.allOf)&&e.allOf.every((e=>vAe(e)&&!function(e){
return pTe(e)&&zTe in e
}(e)))&&MEe(e.type)&&(IEe(e.unevaluatedProperties)||NEe(e.unevaluatedProperties))&&MEe(e.$id)
}function WEe(e){
return XEe(e,"Iterator")&&"Iterator"===e.type&&MEe(e.$id)&&vAe(e.items)}
function XEe(e,t){return pTe(e)&&HTe in e&&e[HTe]===t}function GEe(e){
return JEe(e)&&fTe(e.const)}function YEe(e){return JEe(e)&&dTe(e.const)}
function KEe(e){return JEe(e)&&cTe(e.const)}function JEe(e){
return XEe(e,"Literal")&&MEe(e.$id)&&function(e){return cTe(e)||dTe(e)||fTe(e)
}(e.const)}function eAe(e){
return XEe(e,"Never")&&pTe(e.not)&&0===Object.getOwnPropertyNames(e.not).length}
function tAe(e){return XEe(e,"Not")&&vAe(e.not)}function nAe(e){
return XEe(e,"Null")&&"null"===e.type&&MEe(e.$id)}function rAe(e){
return XEe(e,"Number")&&"number"===e.type&&MEe(e.$id)&&DEe(e.exclusiveMaximum)&&DEe(e.exclusiveMinimum)&&DEe(e.maximum)&&DEe(e.minimum)&&DEe(e.multipleOf)
}function oAe(e){
return XEe(e,"Object")&&"object"===e.type&&MEe(e.$id)&&VEe(e.properties)&&$Ee(e.additionalProperties)&&DEe(e.minProperties)&&DEe(e.maxProperties)
}function aAe(e){
return XEe(e,"Promise")&&"Promise"===e.type&&MEe(e.$id)&&vAe(e.item)}
function iAe(e){
return XEe(e,"Record")&&"object"===e.type&&MEe(e.$id)&&$Ee(e.additionalProperties)&&pTe(e.patternProperties)&&(e=>{
const t=Object.getOwnPropertyNames(e.patternProperties)
;return 1===t.length&&AEe(t[0])&&pTe(e.patternProperties)&&vAe(e.patternProperties[t[0]])
})(e)}function sAe(e){
return XEe(e,"RegExp")&&MEe(e.$id)&&fTe(e.source)&&fTe(e.flags)&&DEe(e.maxLength)&&DEe(e.minLength)
}function lAe(e){
return XEe(e,"String")&&"string"===e.type&&MEe(e.$id)&&DEe(e.minLength)&&DEe(e.maxLength)&&function(e){
return gTe(e)||fTe(e)&&CEe(e)&&AEe(e)}(e.pattern)&&function(e){
return gTe(e)||fTe(e)&&CEe(e)}(e.format)}function cAe(e){
return XEe(e,"Symbol")&&"symbol"===e.type&&MEe(e.$id)}function uAe(e){
return XEe(e,"TemplateLiteral")&&"string"===e.type&&fTe(e.pattern)&&"^"===e.pattern[0]&&"$"===e.pattern[e.pattern.length-1]
}function dAe(e){
return XEe(e,"Tuple")&&"array"===e.type&&MEe(e.$id)&&dTe(e.minItems)&&dTe(e.maxItems)&&e.minItems===e.maxItems&&(gTe(e.items)&&gTe(e.additionalItems)&&0===e.minItems||sTe(e.items)&&e.items.every((e=>vAe(e))))
}function pAe(e){return XEe(e,"Undefined")&&"undefined"===e.type&&MEe(e.$id)}
function hAe(e){
return XEe(e,"Union")&&MEe(e.$id)&&pTe(e)&&sTe(e.anyOf)&&e.anyOf.every((e=>vAe(e)))
}function fAe(e){
return XEe(e,"Uint8Array")&&"Uint8Array"===e.type&&MEe(e.$id)&&DEe(e.minByteLength)&&DEe(e.maxByteLength)
}function mAe(e){return XEe(e,"Unknown")&&MEe(e.$id)}function gAe(e){
return XEe(e,"Void")&&"void"===e.type&&MEe(e.$id)}function vAe(e){
return pTe(e)&&(LEe(e)||function(e){return XEe(e,"Argument")&&dTe(e.index)
}(e)||BEe(e)||zEe(e)||UEe(e)||jEe(e)||function(e){
return XEe(e,"Computed")&&fTe(e.target)&&sTe(e.parameters)&&e.parameters.every((e=>vAe(e)))
}(e)||FEe(e)||ZEe(e)||QEe(e)||HEe(e)||qEe(e)||WEe(e)||JEe(e)||function(e){
return XEe(e,"MappedKey")&&sTe(e.keys)&&e.keys.every((e=>dTe(e)||fTe(e)))
}(e)||function(e){return XEe(e,"MappedResult")&&VEe(e.properties)
}(e)||eAe(e)||tAe(e)||nAe(e)||rAe(e)||oAe(e)||aAe(e)||iAe(e)||function(e){
return XEe(e,"Ref")&&MEe(e.$id)&&fTe(e.$ref)
}(e)||sAe(e)||lAe(e)||cAe(e)||uAe(e)||function(e){
return XEe(e,"This")&&MEe(e.$id)&&fTe(e.$ref)
}(e)||dAe(e)||pAe(e)||hAe(e)||fAe(e)||mAe(e)||function(e){return XEe(e,"Unsafe")
}(e)||gAe(e)||function(e){
return pTe(e)&&HTe in e&&fTe(e[HTe])&&!EEe.includes(e[HTe])}(e))}
const bAe="(true|false)",yAe="(0|[1-9][0-9]*)",OAe="(.*)",wAe=`^${yAe}$`,xAe=`^${OAe}$`,kAe="^(?!.*)$",SAe=new Map
;function _Ae(e){return SAe.has(e)}function TAe(e){return SAe.get(e)}
const EAe=new Map;function AAe(e){return EAe.has(e)}function CAe(e){
return EAe.get(e)}function $Ae(e){return jTe({[HTe]:"Any"},e)}function PAe(e,t){
return jTe({[HTe]:"Array",type:"array",items:e},t)}function DAe(e,t){
return jTe({[HTe]:"AsyncIterator",type:"AsyncIterator",items:e},t)}
function IAe(e,t,n){return jTe({[HTe]:"Computed",target:e,parameters:t},n)}
function MAe(e,t){return t.reduce(((e,t)=>function(e,t){const{[t]:n,...r}=e
;return r}(e,t)),e)}function NAe(e){return jTe({[HTe]:"Never",not:{}},e)}
function RAe(e){return jTe({[HTe]:"MappedResult",properties:e})}
function LAe(e,t,n){return jTe({[HTe]:"Constructor",type:"Constructor",
parameters:e,returns:t},n)}function BAe(e,t,n){return jTe({[HTe]:"Function",
type:"Function",parameters:e,returns:t},n)}function jAe(e,t){return jTe({
[HTe]:"Union",anyOf:e},t)}function UAe(e){
return e.map((e=>qTe(e)?MAe(e,[ZTe]):e))}function zAe(e,t){const n=function(e){
return e.some((e=>qTe(e)))}(e);return n?zCe(jAe(UAe(e),t)):jAe(UAe(e),t)}
function FAe(e,t){return 1===e.length?jTe(e[0],t):0===e.length?NAe(t):zAe(e,t)}
function ZAe(e,t){return 0===e.length?NAe(t):1===e.length?jTe(e[0],t):jAe(e,t)}
class QAe extends UTe{}function HAe(e){
return e.replace(/\\\$/g,"$").replace(/\\\*/g,"*").replace(/\\\^/g,"^").replace(/\\\|/g,"|").replace(/\\\(/g,"(").replace(/\\\)/g,")")
}function VAe(e,t,n){return e[t]===n&&92!==e.charCodeAt(t-1)}function qAe(e,t){
return VAe(e,t,"(")}function WAe(e,t){return VAe(e,t,")")}function XAe(e,t){
return VAe(e,t,"|")}function GAe(e){return function(e){
if(!qAe(e,0)||!WAe(e,e.length-1))return!1;let t=0
;for(let n=0;n<e.length;n++)if(qAe(e,n)&&(t+=1),
WAe(e,n)&&(t-=1),0===t&&n!==e.length-1)return!1;return!0}(e)?GAe(function(e){
return e.slice(1,e.length-1)}(e)):function(e){let t=0
;for(let n=0;n<e.length;n++)if(qAe(e,n)&&(t+=1),
WAe(e,n)&&(t-=1),XAe(e,n)&&0===t)return!0;return!1}(e)?function(e){
let[t,n]=[0,0];const r=[]
;for(let a=0;a<e.length;a++)if(qAe(e,a)&&(t+=1),WAe(e,a)&&(t-=1),
XAe(e,a)&&0===t){const t=e.slice(n,a);t.length>0&&r.push(GAe(t)),n=a+1}
const o=e.slice(n);return o.length>0&&r.push(GAe(o)),0===r.length?{type:"const",
const:""}:1===r.length?r[0]:{type:"or",expr:r}}(e):function(e){
for(let t=0;t<e.length;t++)if(qAe(e,t))return!0;return!1}(e)?function(e){
function t(e,t){
if(!qAe(e,t))throw new QAe("TemplateLiteralParser: Index must point to open parens")
;let n=0
;for(let r=t;r<e.length;r++)if(qAe(e,r)&&(n+=1),WAe(e,r)&&(n-=1),0===n)return[t,r]
;throw new QAe("TemplateLiteralParser: Unclosed group parens in expression")}
function n(e,t){for(let n=t;n<e.length;n++)if(qAe(e,n))return[t,n]
;return[t,e.length]}const r=[];for(let o=0;o<e.length;o++)if(qAe(e,o)){
const[n,a]=t(e,o),i=e.slice(n,a+1);r.push(GAe(i)),o=a}else{
const[t,a]=n(e,o),i=e.slice(t,a);i.length>0&&r.push(GAe(i)),o=a-1}
return 0===r.length?{type:"const",const:""}:1===r.length?r[0]:{type:"and",expr:r
}}(e):{type:"const",const:HAe(e)}}function YAe(e){
return GAe(e.slice(1,e.length-1))}class KAe extends UTe{}function JAe(e){
return!function(e){
return"or"===e.type&&2===e.expr.length&&"const"===e.expr[0].type&&"0"===e.expr[0].const&&"const"===e.expr[1].type&&"[1-9][0-9]*"===e.expr[1].const
}(e)&&!function(e){return"const"===e.type&&".*"===e.const}(e)&&(!!function(e){
return"or"===e.type&&2===e.expr.length&&"const"===e.expr[0].type&&"true"===e.expr[0].const&&"const"===e.expr[1].type&&"false"===e.expr[1].const
}(e)||("and"===e.type||"or"===e.type?e.expr.every((e=>JAe(e))):"const"===e.type||(()=>{
throw new KAe("Unknown expression type")})()))}function eCe(e){
return JAe(YAe(e.pattern))}class tCe extends UTe{}function*nCe(e){
if(1===e.length)return yield*e[0]
;for(const t of e[0])for(const n of nCe(e.slice(1)))yield`${t}${n}`}
function*rCe(e){return yield*nCe(e.expr.map((e=>[...oCe(e)])))}function*oCe(e){
return"and"===e.type?yield*rCe(e):"or"===e.type?yield*function*(e){
for(const t of e.expr)yield*oCe(t)}(e):"const"===e.type?yield*function*(e){
return yield e.const}(e):(()=>{throw new tCe("Unknown expression")})()}
function aCe(e){const t=YAe(e.pattern);return JAe(t)?[...oCe(t)]:[]}
function iCe(e,t){return jTe({[HTe]:"Literal",const:e,type:typeof e},t)}
function sCe(e){return jTe({[HTe]:"Boolean",type:"boolean"},e)}function lCe(e){
return jTe({[HTe]:"BigInt",type:"bigint"},e)}function cCe(e){return jTe({
[HTe]:"Number",type:"number"},e)}function uCe(e){return jTe({[HTe]:"String",
type:"string"},e)}function*dCe(e){const t=e.trim().replace(/"|'/g,"")
;return"boolean"===t?yield sCe():"number"===t?yield cCe():"bigint"===t?yield lCe():"string"===t?yield uCe():yield(()=>{
const e=t.split("|").map((e=>iCe(e.trim())))
;return 0===e.length?NAe():1===e.length?e[0]:FAe(e)})()}function*pCe(e){
if("{"!==e[1]){const t=iCe("$"),n=hCe(e.slice(1));return yield*[t,...n]}
for(let t=2;t<e.length;t++)if("}"===e[t]){
const n=dCe(e.slice(2,t)),r=hCe(e.slice(t+1));return yield*[...n,...r]}
yield iCe(e)}function*hCe(e){for(let t=0;t<e.length;t++)if("$"===e[t]){
const n=iCe(e.slice(0,t)),r=pCe(e.slice(t));return yield*[n,...r]}yield iCe(e)}
class fCe extends UTe{}function mCe(e,t){
return wEe(e)?e.pattern.slice(1,e.pattern.length-1):_Ee(e)?`(${e.anyOf.map((e=>mCe(e,t))).join("|")})`:hEe(e)||rEe(e)||KTe(e)?`${t}${yAe}`:yEe(e)?`${t}${OAe}`:lEe(e)?`${t}${n=e.const.toString(),
n.replace(/[.*+?^${}()|[\]\\]/g,"\\$&")}`:JTe(e)?`${t}${bAe}`:(()=>{
throw new fCe(`Unexpected Kind '${e[HTe]}'`)})();var n}function gCe(e){
return`^${e.map((e=>mCe(e,""))).join("")}$`}function vCe(e){
return FAe(aCe(e).map((e=>iCe(e))))}function bCe(e,t){
const n=fTe(e)?gCe([...hCe(e)]):gCe(e);return jTe({[HTe]:"TemplateLiteral",
type:"string",pattern:n},t)}function yCe(e){const t=[]
;for(const n of e)t.push(...OCe(n));return t}function OCe(e){
return[...new Set(wEe(e)?(n=e,
aCe(n).map((e=>e.toString()))):_Ee(e)?yCe(e.anyOf):lEe(e)?(t=e.const,
[t.toString()]):hEe(e)||rEe(e)?["[number]"]:[])];var t,n}function wCe(e,t,n){
return function(e,t,n){const r={}
;for(const o of Object.getOwnPropertyNames(t))r[o]=ACe(e,OCe(t[o]),n);return r
}(e,t.properties,n)}function xCe(e,t){return e.map((e=>_Ce(e,t)))}
function kCe(e,t){return HCe(function(e){return e.filter((e=>!dEe(e)))
}(xCe(e,t)))}function SCe(e,t){return FAe(function(e){
return e.some((e=>dEe(e)))?[]:e}(xCe(e,t)))}function _Ce(e,t){
return oEe(e)?kCe(e.allOf,t):_Ee(e)?SCe(e.anyOf,t):kEe(e)?(n=e.items??[],
(r=t)in n?n[r]:"[number]"===r?FAe(n):NAe()):GTe(e)?function(e,t){
return"[number]"===t?e:NAe()}(e.items,t):fEe(e)?function(e,t){
return t in e?e[t]:NAe()}(e.properties,t):NAe();var n,r}function TCe(e,t){
return t.map((t=>_Ce(e,t)))}function ECe(e,t){return FAe(TCe(e,t))}
function ACe(e,t,n){if(vEe(e)||vEe(t)){
const n="Index types using Ref parameters require both Type and Key to be of TSchema"
;if(!TEe(e)||!TEe(t))throw new UTe(n);return IAe("Index",[e,t])}
return uEe(t)?function(e,t,n){return RAe(wCe(e,t,n))
}(e,t,n):cEe(t)?function(e,t,n){const r=function(e,t,n){return function(e,t,n){
return t.reduce(((t,r)=>({...t,...CCe(e,r,n)})),{})}(e,t.keys,n)}(e,t,n)
;return RAe(r)}(e,t,n):jTe(TEe(t)?ECe(e,OCe(t)):ECe(e,t),n)}function CCe(e,t,n){
return{[t]:ACe(e,[t],bTe(n))}}function $Ce(e,t){return jTe({[HTe]:"Iterator",
type:"Iterator",items:e},t)}var PCe=function(e,t){const n=function(e){const t=[]
;for(let n in e)qTe(e[n])||t.push(n);return t}(e);return jTe(n.length>0?{
[HTe]:"Object",type:"object",properties:e,required:n}:{[HTe]:"Object",
type:"object",properties:e},t)};function DCe(e,t){return jTe({[HTe]:"Promise",
type:"Promise",item:e},t)}function ICe(e,t){return!1===t?function(e){
return jTe(MAe(e,[FTe]))}(e):function(e){return jTe({...e,[FTe]:"Readonly"})}(e)
}function MCe(e,t){const n=t??!0;return uEe(e)?function(e,t){
const n=function(e,t){return function(e,t){const n={}
;for(const r of globalThis.Object.getOwnPropertyNames(e))n[r]=MCe(e[r],t)
;return n}(e.properties,t)}(e,t);return RAe(n)}(e,n):ICe(e,n)}function NCe(e,t){
return jTe(e.length>0?{[HTe]:"Tuple",type:"array",items:e,additionalItems:!1,
minItems:e.length,maxItems:e.length}:{[HTe]:"Tuple",type:"array",
minItems:e.length,maxItems:e.length},t)}function RCe(e,t){
return e in t?jCe(e,t[e]):RAe(t)}function LCe(e,t){
return n=e,t.includes(n)?function(e){return{[e]:iCe(e)}}(e):function(e){
const t={};for(const n of e)t[n]=iCe(n);return t}(t);var n}function BCe(e,t){
return t.map((t=>jCe(e,t)))}function jCe(e,t){const n={...t}
;return qTe(t)?zCe(jCe(e,MAe(t,[ZTe]))):VTe(t)?MCe(jCe(e,MAe(t,[FTe]))):uEe(t)?RCe(e,t.properties):cEe(t)?function(e,t){
return RCe(e,LCe(e,t))
}(e,t.keys):tEe(t)?LAe(BCe(e,t.parameters),jCe(e,t.returns),n):nEe(t)?BAe(BCe(e,t.parameters),jCe(e,t.returns),n):YTe(t)?DAe(jCe(e,t.items),n):aEe(t)?$Ce(jCe(e,t.items),n):oEe(t)?VCe(BCe(e,t.allOf),n):_Ee(t)?ZAe(BCe(e,t.anyOf),n):kEe(t)?NCe(BCe(e,t.items??[]),n):fEe(t)?PCe(function(e,t){
const n={}
;for(const r of globalThis.Object.getOwnPropertyNames(t))n[r]=jCe(e,t[r])
;return n
}(e,t.properties),n):GTe(t)?PAe(jCe(e,t.items),n):mEe(t)?DCe(jCe(e,t.item),n):t}
function UCe(e,t){return!1===t?function(e){return jTe(MAe(e,[ZTe]))
}(e):function(e){return jTe({...e,[ZTe]:"Optional"})}(e)}function zCe(e,t){
const n=t??!0;return uEe(e)?function(e,t){const n=function(e,t){
return function(e,t){const n={}
;for(const r of globalThis.Object.getOwnPropertyNames(e))n[r]=zCe(e[r],t)
;return n}(e.properties,t)}(e,t);return RAe(n)}(e,n):UCe(e,n)}
function FCe(e,t={}){
const n=e.every((e=>fEe(e))),r=TEe(t.unevaluatedProperties)?{
unevaluatedProperties:t.unevaluatedProperties}:{}
;return jTe(!1===t.unevaluatedProperties||TEe(t.unevaluatedProperties)||n?{...r,
[HTe]:"Intersect",type:"object",allOf:e}:{...r,[HTe]:"Intersect",allOf:e},t)}
function ZCe(e){return e.map((e=>qTe(e)?MAe(e,[ZTe]):e))}function QCe(e,t){
return function(e){return e.every((e=>qTe(e)))
}(e)?zCe(FCe(ZCe(e),t)):FCe(ZCe(e),t)}function HCe(e,t={}){
if(1===e.length)return jTe(e[0],t);if(0===e.length)return NAe(t)
;if(e.some((e=>xEe(e))))throw new Error("Cannot intersect transform types")
;return QCe(e,t)}function VCe(e,t){if(1===e.length)return jTe(e[0],t)
;if(0===e.length)return NAe(t)
;if(e.some((e=>xEe(e))))throw new Error("Cannot intersect transform types")
;return FCe(e,t)}function qCe(...e){
const[t,n]="string"==typeof e[0]?[e[0],e[1]]:[e[0].$id,e[1]]
;if("string"!=typeof t)throw new UTe("Ref: $ref must be a string");return jTe({
[HTe]:"Ref",$ref:t},n)}function WCe(e){return e.map((e=>XCe(e)))}
function XCe(e,t){
return jTe(eEe(e)?(n=e.target,r=e.parameters,IAe("Awaited",[IAe(n,r)])):oEe(e)?VCe(WCe(e.allOf)):_Ee(e)?function(e){
return ZAe(WCe(e))}(e.anyOf):mEe(e)?function(e){return XCe(e)
}(e.item):vEe(e)?IAe("Awaited",[qCe(e.$ref)]):e,t);var n,r}function GCe(e){
const t=[];for(const n of e)t.push(YCe(n));return t}function YCe(e){
return oEe(e)?function(e){const t=[];for(const n of e)t.push(...n);return t
}(GCe(e.allOf)):_Ee(e)?function(e){const t=GCe(e);var n
;return 1===(n=t).length?n[0]:n.length>1?function(e,t){
return e.reduce(((e,t)=>function(e,t){return e.filter((e=>t.includes(e)))
}(e,t)),t)}(n.slice(1),n[0]):[]}(e.anyOf):kEe(e)?function(e){
return e.map(((e,t)=>t.toString()))
}(e.items??[]):GTe(e)?(e.items,["[number]"]):fEe(e)?(n=e.properties,
globalThis.Object.getOwnPropertyNames(n)):gEe(e)?(t=e.patternProperties,
KCe?globalThis.Object.getOwnPropertyNames(t).map((e=>"^"===e[0]&&"$"===e[e.length-1]?e.slice(1,e.length-1):e)):[]):[]
;var t,n}let KCe=!1;function JCe(e){KCe=!0;const t=YCe(e);KCe=!1
;return`^(${t.map((e=>`(${e})`)).join("|")})$`}function e$e(e,t){
const n=function(e){return e.map((e=>"[number]"===e?cCe():iCe(e)))}(YCe(e))
;return jTe(FAe(n),t)}function t$e(e,t){
return eEe(e)?(n=e.target,r=e.parameters,
IAe("KeyOf",[IAe(n,r)])):vEe(e)?IAe("KeyOf",[qCe(e.$ref)]):uEe(e)?function(e,t){
const n=function(e,t){return function(e,t){const n={}
;for(const r of globalThis.Object.getOwnPropertyNames(e))n[r]=t$e(e[r],bTe(t))
;return n}(e.properties,t)}(e,t);return RAe(n)}(e,t):e$e(e,t);var n,r}
function n$e(e){const t=[];for(const n of e)t.push(...YCe(n))
;return function(e){return[...new Set(e)]}(t)}function r$e(e,t){const n=[]
;for(const r of e)n.push(...TCe(r,[t]));return function(e){
return e.filter((e=>!dEe(e)))}(n)}function o$e(e){return jTe({[HTe]:"Date",
type:"Date"},e)}function a$e(e){return jTe({[HTe]:"Null",type:"null"},e)}
function i$e(e){return jTe({[HTe]:"Symbol",type:"symbol"},e)}function s$e(e){
return jTe({[HTe]:"Undefined",type:"undefined"},e)}function l$e(e){return jTe({
[HTe]:"Uint8Array",type:"Uint8Array"},e)}function c$e(e){return jTe({
[HTe]:"Unknown"},e)}function u$e(e,t){return!0===t?e:MCe(e)}function d$e(e,t){
return function(e){return pTe(e)&&!sTe(e)&&!mTe(e)&&Symbol.asyncIterator in e
}(e)||function(e){return pTe(e)&&!sTe(e)&&!mTe(e)&&Symbol.iterator in e
}(e)?u$e($Ae(),t):sTe(e)?MCe(NCe(e.map((e=>d$e(e,!1))))):mTe(e)?l$e():uTe(e)?o$e():pTe(e)?u$e(PCe(function(e){
const t={}
;for(const n of globalThis.Object.getOwnPropertyNames(e))t[n]=MCe(d$e(e[n],!1))
;return t}(e)),t):function(e){return"function"==typeof e
}(e)?u$e(BAe([],c$e()),t):gTe(e)?s$e():function(e){return null===e
}(e)?a$e():function(e){return"symbol"==typeof e
}(e)?i$e():lTe(e)?lCe():dTe(e)||cTe(e)||fTe(e)?iCe(e):PCe({})}
class p$e extends UTe{}var h$e,f$e;function m$e(e){
return e===h$e.False?e:h$e.True}function g$e(e){throw new p$e(e)}
function v$e(e){return eAe(e)||qEe(e)||hAe(e)||mAe(e)||LEe(e)}function b$e(e,t){
return eAe(t)?k$e():qEe(t)?x$e(e,t):hAe(t)?z$e(e,t):mAe(t)?F$e():LEe(t)?y$e():g$e("StructuralRight")
}function y$e(e,t){return h$e.True}function O$e(e,t){
return KEe(e)||zEe(e)?h$e.True:h$e.False}function w$e(e,t){
return JEe(e)&&dTe(e.const)||rAe(e)||HEe(e)?h$e.True:h$e.False}
function x$e(e,t){
return t.allOf.every((t=>Q$e(e,t)===h$e.True))?h$e.True:h$e.False}
function k$e(e,t){return h$e.False}function S$e(e){let[t,n]=[e,0]
;for(;tAe(t);)t=t.not,n+=1;return n%2==0?t:c$e()}function _$e(e,t){
return YEe(e)||rAe(e)||HEe(e)?h$e.True:h$e.False}function T$e(e,t){
return Object.getOwnPropertyNames(e.properties).length===t}function E$e(e){
return P$e(e)}function A$e(e){
return T$e(e,0)||T$e(e,1)&&"description"in e.properties&&hAe(e.properties.description)&&2===e.properties.description.anyOf.length&&(lAe(e.properties.description.anyOf[0])&&pAe(e.properties.description.anyOf[1])||lAe(e.properties.description.anyOf[1])&&pAe(e.properties.description.anyOf[0]))
}function C$e(e){return T$e(e,0)}function $$e(e){return T$e(e,0)}
function P$e(e){const t=cCe()
;return T$e(e,0)||T$e(e,1)&&"length"in e.properties&&m$e(Q$e(e.properties.length,t))===h$e.True
}function D$e(e,t){
return Q$e(e,t)===h$e.False||REe(e)&&!REe(t)?h$e.False:h$e.True}
function I$e(e,t){
return mAe(e)?h$e.False:LEe(e)?h$e.Union:eAe(e)||GEe(e)&&E$e(t)||YEe(e)&&C$e(t)||KEe(e)&&$$e(t)||cAe(e)&&A$e(t)||UEe(e)&&T$e(t,0)||lAe(e)&&E$e(t)||cAe(e)&&A$e(t)||rAe(e)&&C$e(t)||HEe(e)&&C$e(t)||zEe(e)&&$$e(t)||fAe(e)&&function(e){
return P$e(e)}(t)||ZEe(e)&&function(e){return T$e(e,0)}(t)||FEe(e)&&function(e){
return T$e(e,0)}(t)||QEe(e)&&function(e){const t=cCe()
;return T$e(e,0)||T$e(e,1)&&"length"in e.properties&&m$e(Q$e(e.properties.length,t))===h$e.True
}(t)?h$e.True:iAe(e)&&lAe(N$e(e))?"Record"===t[QTe]?h$e.True:h$e.False:iAe(e)&&rAe(N$e(e))&&T$e(t,0)?h$e.True:h$e.False
}function M$e(e,t){return v$e(t)?b$e(e,t):oAe(t)&&function(e){
const t=BAe([$Ae()],$Ae())
;return T$e(e,0)||T$e(e,1)&&"then"in e.properties&&m$e(Q$e(e.properties.then,t))===h$e.True
}(t)?h$e.True:aAe(t)?m$e(Q$e(e.item,t.item)):h$e.False}function N$e(e){
return wAe in e.patternProperties?cCe():xAe in e.patternProperties?uCe():g$e("Unknown record key pattern")
}function R$e(e){
return wAe in e.patternProperties?e.patternProperties[wAe]:xAe in e.patternProperties?e.patternProperties[xAe]:g$e("Unable to get record value schema")
}function L$e(e,t){const[n,r]=[N$e(t),R$e(t)]
;return GEe(e)&&rAe(n)&&m$e(Q$e(e,r))===h$e.True?h$e.True:fAe(e)&&rAe(n)||lAe(e)&&rAe(n)||BEe(e)&&rAe(n)?Q$e(e,r):oAe(e)?(()=>{
for(const t of Object.getOwnPropertyNames(e.properties))if(D$e(r,e.properties[t])===h$e.False)return h$e.False
;return h$e.True})():h$e.False}function B$e(e,t){
return JEe(e)&&fTe(e.const)||lAe(e)?h$e.True:h$e.False}function j$e(e,t){
return v$e(t)?b$e(e,t):oAe(t)&&P$e(t)||BEe(t)&&function(e,t){
return BEe(t)&&void 0!==e.items&&e.items.every((e=>Q$e(e,t.items)===h$e.True))
}(e,t)?h$e.True:dAe(t)?gTe(e.items)&&!gTe(t.items)||!gTe(e.items)&&gTe(t.items)?h$e.False:gTe(e.items)&&!gTe(t.items)||e.items.every(((e,n)=>Q$e(e,t.items[n])===h$e.True))?h$e.True:h$e.False:h$e.False
}function U$e(e,t){
return v$e(t)?b$e(e,t):oAe(t)?I$e(e,t):iAe(t)?L$e(e,t):gAe(t)?function(e,t){
return pAe(e)||pAe(e)?h$e.True:h$e.False}(e):pAe(t)?h$e.True:h$e.False}
function z$e(e,t){
return t.anyOf.some((t=>Q$e(e,t)===h$e.True))?h$e.True:h$e.False}
function F$e(e,t){return h$e.True}function Z$e(e,t){
return eAe(t)?k$e():qEe(t)?x$e(e,t):hAe(t)?z$e(e,t):LEe(t)?y$e():lAe(t)?B$e(e):rAe(t)?_$e(e):HEe(t)?w$e(e):zEe(t)?O$e(e):BEe(t)?function(e,t){
return mAe(e)?h$e.False:LEe(e)?h$e.Union:eAe(e)?h$e.True:h$e.False
}(e):dAe(t)?function(e,t){
return eAe(e)?h$e.True:mAe(e)?h$e.False:LEe(e)?h$e.Union:h$e.False
}(e):oAe(t)?I$e(e,t):mAe(t)?h$e.True:h$e.False}function Q$e(e,t){
return uAe(e)||uAe(t)?function(e,t){
return uAe(e)?Q$e(vCe(e),t):uAe(t)?Q$e(e,vCe(t)):g$e("Invalid fallthrough for TemplateLiteral")
}(e,t):sAe(e)||sAe(t)?function(e,t){return Q$e(sAe(e)?uCe():e,sAe(t)?uCe():t)
}(e,t):tAe(e)||tAe(t)?function(e,t){
return tAe(e)?Q$e(S$e(e),t):tAe(t)?Q$e(e,S$e(t)):g$e("Invalid fallthrough for Not")
}(e,t):LEe(e)?function(e,t){
return qEe(t)?x$e(e,t):hAe(t)&&t.anyOf.some((e=>LEe(e)||mAe(e)))?h$e.True:hAe(t)?h$e.Union:mAe(t)||LEe(t)?h$e.True:h$e.Union
}(e,t):BEe(e)?function(e,t){
return oAe(t)&&P$e(t)?h$e.True:v$e(t)?b$e(e,t):BEe(t)?m$e(Q$e(e.items,t.items)):h$e.False
}(e,t):UEe(e)?function(e,t){
return v$e(t)?b$e(e,t):oAe(t)?I$e(e,t):iAe(t)?L$e(e,t):UEe(t)?h$e.True:h$e.False
}(e,t):zEe(e)?function(e,t){
return v$e(t)?b$e(e,t):oAe(t)?I$e(e,t):iAe(t)?L$e(e,t):zEe(t)?h$e.True:h$e.False
}(e,t):jEe(e)?function(e,t){
return v$e(t)?b$e(e,t):jEe(t)?m$e(Q$e(e.items,t.items)):h$e.False
}(e,t):FEe(e)?function(e,t){
return v$e(t)?b$e(e,t):oAe(t)?I$e(e,t):FEe(t)?e.parameters.length>t.parameters.length?h$e.False:e.parameters.every(((e,n)=>m$e(Q$e(t.parameters[n],e))===h$e.True))?m$e(Q$e(e.returns,t.returns)):h$e.False:h$e.False
}(e,t):ZEe(e)?function(e,t){
return v$e(t)?b$e(e,t):oAe(t)?I$e(e,t):iAe(t)?L$e(e,t):ZEe(t)?h$e.True:h$e.False
}(e,t):QEe(e)?function(e,t){
return v$e(t)?b$e(e,t):oAe(t)?I$e(e,t):QEe(t)?e.parameters.length>t.parameters.length?h$e.False:e.parameters.every(((e,n)=>m$e(Q$e(t.parameters[n],e))===h$e.True))?m$e(Q$e(e.returns,t.returns)):h$e.False:h$e.False
}(e,t):HEe(e)?function(e,t){
return HEe(t)||rAe(t)?h$e.True:v$e(t)?b$e(e,t):oAe(t)?I$e(e,t):iAe(t)?L$e(e,t):h$e.False
}(e,t):qEe(e)?function(e,t){
return e.allOf.some((e=>Q$e(e,t)===h$e.True))?h$e.True:h$e.False
}(e,t):WEe(e)?function(e,t){
return v$e(t)?b$e(e,t):WEe(t)?m$e(Q$e(e.items,t.items)):h$e.False
}(e,t):JEe(e)?function(e,t){
return JEe(t)&&t.const===e.const?h$e.True:v$e(t)?b$e(e,t):oAe(t)?I$e(e,t):iAe(t)?L$e(e,t):lAe(t)?B$e(e):rAe(t)?_$e(e):HEe(t)?w$e(e):zEe(t)?O$e(e):h$e.False
}(e,t):eAe(e)?h$e.True:nAe(e)?function(e,t){
return v$e(t)?b$e(e,t):oAe(t)?I$e(e,t):iAe(t)?L$e(e,t):nAe(t)?h$e.True:h$e.False
}(e,t):rAe(e)?function(e,t){
return v$e(t)?b$e(e,t):oAe(t)?I$e(e,t):iAe(t)?L$e(e,t):HEe(t)||rAe(t)?h$e.True:h$e.False
}(e,t):oAe(e)?function(e,t){return v$e(t)?b$e(e,t):iAe(t)?L$e(e,t):oAe(t)?(()=>{
for(const n of Object.getOwnPropertyNames(t.properties)){
if(!(n in e.properties)&&!REe(t.properties[n]))return h$e.False
;if(REe(t.properties[n]))return h$e.True
;if(D$e(e.properties[n],t.properties[n])===h$e.False)return h$e.False}
return h$e.True})():h$e.False}(e,t):iAe(e)?function(e,t){
return v$e(t)?b$e(e,t):oAe(t)?I$e(e,t):iAe(t)?Q$e(R$e(e),R$e(t)):h$e.False
}(e,t):lAe(e)?function(e,t){
return v$e(t)?b$e(e,t):oAe(t)?I$e(e,t):iAe(t)?L$e(e,t):lAe(t)?h$e.True:h$e.False
}(e,t):cAe(e)?function(e,t){
return v$e(t)?b$e(e,t):oAe(t)?I$e(e,t):iAe(t)?L$e(e,t):cAe(t)?h$e.True:h$e.False
}(e,t):dAe(e)?j$e(e,t):aAe(e)?M$e(e,t):fAe(e)?function(e,t){
return v$e(t)?b$e(e,t):oAe(t)?I$e(e,t):iAe(t)?L$e(e,t):fAe(t)?h$e.True:h$e.False
}(e,t):pAe(e)?U$e(e,t):hAe(e)?function(e,t){
return e.anyOf.every((e=>Q$e(e,t)===h$e.True))?h$e.True:h$e.False
}(e,t):mAe(e)?Z$e(e,t):gAe(e)?function(e,t){
return qEe(t)?x$e(e,t):hAe(t)?z$e(e,t):mAe(t)?F$e():LEe(t)?y$e():oAe(t)?I$e(e,t):gAe(t)?h$e.True:h$e.False
}(e,t):g$e(`Unknown left type operand '${e[HTe]}'`)}function H$e(e,t){
return Q$e(e,t)}function V$e(e,t,n,r,o){return function(e,t,n,r,o){const a={}
;for(const i of globalThis.Object.getOwnPropertyNames(e))a[i]=q$e(e[i],t,n,r,bTe(o))
;return a}(e.properties,t,n,r,o)}function q$e(e,t,n,r,o){
return uEe(e)?function(e,t,n,r,o){return RAe(V$e(e,t,n,r,o))
}(e,t,n,r,o):cEe(e)?jTe(function(e,t,n,r,o){const a=function(e,t,n,r,o){
return function(e,t,n,r,o){return e.reduce(((e,a)=>({...e,...W$e(a,t,n,r,o)
})),{})}(e.keys,t,n,r,o)}(e,t,n,r,o);return RAe(a)
}(e,t,n,r,o)):jTe(function(e,t,n,r){const o=H$e(e,t)
;return o===h$e.Union?ZAe([n,r]):o===h$e.True?n:r}(e,t,n,r),o)}
function W$e(e,t,n,r,o){return{[e]:q$e(iCe(e),t,n,r,bTe(o))}}function X$e(e){
return"Intersect"===e[HTe]?function(e){return e.allOf.every((e=>X$e(e)))
}(e):"Union"===e[HTe]?function(e){return e.anyOf.some((e=>X$e(e)))
}(e):"Not"===e[HTe]?function(e){return!X$e(e.not)}(e):"Undefined"===e[HTe]}
function G$e(e,t,n={}){return wEe(e)?jTe(function(e,t){return G$e(vCe(e),t)
}(e,t),n):uEe(e)?jTe(function(e,t){const n=function(e,t){return function(e,t){
const n={}
;for(const r of globalThis.Object.getOwnPropertyNames(e))n[r]=G$e(e[r],t)
;return n}(e.properties,t)}(e,t);return RAe(n)
}(e,t),n):jTe(_Ee(e)?function(e,t){const n=e.filter((e=>H$e(e,t)===h$e.False))
;return 1===n.length?n[0]:ZAe(n)}(e.anyOf,t):H$e(e,t)!==h$e.False?NAe():e,n)}
function Y$e(e,t,n){return wEe(e)?jTe(function(e,t){return Y$e(vCe(e),t)
}(e,t),n):uEe(e)?jTe(function(e,t){const n=function(e,t){return function(e,t){
const n={}
;for(const r of globalThis.Object.getOwnPropertyNames(e))n[r]=Y$e(e[r],t)
;return n}(e.properties,t)}(e,t);return RAe(n)
}(e,t),n):jTe(_Ee(e)?function(e,t){const n=e.filter((e=>H$e(e,t)!==h$e.False))
;return 1===n.length?n[0]:ZAe(n)}(e.anyOf,t):H$e(e,t)!==h$e.False?e:NAe(),n)}
function K$e(e){return MCe(zCe(e))}function J$e(e,t,n){return jTe({
[HTe]:"Record",type:"object",patternProperties:{[e]:t}},n)}function ePe(e,t,n){
const r={};for(const o of e)r[o]=t;return PCe(r,{...n,[QTe]:"Record"})}
function tPe(e,t,n={}){return _Ee(e)?function(e,t,n){return ePe(OCe(ZAe(e)),t,n)
}(e.anyOf,t,n):wEe(e)?function(e,t,n){
return eCe(e)?ePe(OCe(e),t,n):J$e(e.pattern,t,n)}(e,t,n):lEe(e)?function(e,t,n){
return ePe([e.toString()],t,n)}(e.const,t,n):JTe(e)?function(e,t,n){return PCe({
true:t,false:t},n)}(0,t,n):rEe(e)?function(e,t,n){return J$e(wAe,t,n)
}(0,t,n):hEe(e)?function(e,t,n){return J$e(wAe,t,n)
}(0,t,n):bEe(e)?function(e,t,n){return J$e(e.source,t,n)
}(e,t,n):yEe(e)?function(e,t,n){return J$e(gTe(e.pattern)?xAe:e.pattern,t,n)
}(e,t,n):WTe(e)?function(e,t,n){return J$e(xAe,t,n)
}(0,t,n):dEe(e)?function(e,t,n){return J$e(kAe,t,n)}(0,t,n):NAe(n)}
function nPe(e){
return globalThis.Object.getOwnPropertyNames(e.patternProperties)[0]}
function rPe(e){return e.patternProperties[nPe(e)]}function oPe(e,t){
const n=function(e,t){
return globalThis.Object.getOwnPropertyNames(t).reduce(((n,r)=>({...n,
[r]:iPe(e,t[r])})),{})}(e,t.properties);return{...t,...PCe(n)}}
function aPe(e,t){const n=lPe(e,function(e){const t=nPe(e)
;return t===xAe?uCe():t===wAe?cCe():uCe({pattern:t})}(t)),r=tPe(n,lPe(e,rPe(t)))
;return{...t,...r}}function iPe(e,t){const n=VTe(t),r=qTe(t),o=lPe(e,t)
;return n&&r?K$e(o):n&&!r?MCe(o):!n&&r?zCe(o):o}function sPe(e,t){
return t.map((t=>lPe(e,t)))}function lPe(e,t){
return tEe(t)||nEe(t)?function(e,t){
return t.parameters=sPe(e,t.parameters),t.returns=lPe(e,t.returns),t
}(e,t):oEe(t)?function(e,t){return t.allOf=sPe(e,t.allOf),t
}(e,t):_Ee(t)?function(e,t){return t.anyOf=sPe(e,t.anyOf),t
}(e,t):kEe(t)?function(e,t){return gTe(t.items)||(t.items=sPe(e,t.items)),t
}(e,t):GTe(t)||YTe(t)||aEe(t)?function(e,t){return t.items=lPe(e,t.items),t
}(e,t):mEe(t)?function(e,t){return t.item=lPe(e,t.item),t
}(e,t):fEe(t)?oPe(e,t):gEe(t)?aPe(e,t):XTe(t)?function(e,t){
return t.index in e?e[t.index]:c$e()}(e,t):t}function cPe(e,t,n){return{
[e]:hPe(iCe(e),t,bTe(n))}}function uPe(e,t,n){return function(e,t,n){
return e.reduce(((e,r)=>({...e,...cPe(r,t,n)})),{})}(e.keys,t,n)}
function dPe(e,t){return"string"==typeof e?"Uncapitalize"===t?function(e){
const[t,n]=[e.slice(0,1),e.slice(1)];return[t.toLowerCase(),n].join("")
}(e):"Capitalize"===t?function(e){const[t,n]=[e.slice(0,1),e.slice(1)]
;return[t.toUpperCase(),n].join("")}(e):"Uppercase"===t?function(e){
return e.toUpperCase()}(e):"Lowercase"===t?function(e){return e.toLowerCase()
}(e):e:e.toString()}function pPe(e,t){return e.map((e=>hPe(e,t)))}
function hPe(e,t,n={}){return cEe(e)?function(e,t,n){return RAe(uPe(e,t,n))
}(e,t,n):wEe(e)?function(e,t,n){const r=YAe(e.pattern)
;return JAe(r)?bCe([ZAe(pPe([...oCe(r)].map((e=>iCe(e))),t))],n):{...e,
pattern:dPe(e.pattern,t)}
}(e,t,n):_Ee(e)?ZAe(pPe(e.anyOf,t),n):lEe(e)?iCe(dPe(e.const,t),n):jTe(e,n)}
function fPe(e,t,n){return function(e,t,n){const r={}
;for(const o of globalThis.Object.getOwnPropertyNames(e))r[o]=gPe(e[o],t,bTe(n))
;return r}(e.properties,t,n)}function mPe(e,t){return oEe(e)?VCe(function(e,t){
return e.map((e=>mPe(e,t)))}(e.allOf,t)):_Ee(e)?ZAe(function(e,t){
return e.map((e=>mPe(e,t)))}(e.anyOf,t)):fEe(e)?function(e,t){
const n=MAe(e,[zTe,"$id","required","properties"]),r=function(e,t){
return t.reduce(((e,t)=>function(e,t){const{[t]:n,...r}=e;return r}(e,t)),e)
}(e.properties,t);return PCe(r,n)}(e,t):PCe({})}function gPe(e,t,n){
const r=sTe(t)?function(e){
return ZAe(e.reduce(((e,t)=>sEe(t)?[...e,iCe(t)]:e),[]))
}(t):t,o=TEe(t)?OCe(t):t,a=vEe(e),i=vEe(t);return uEe(e)?function(e,t,n){
return RAe(fPe(e,t,n))}(e,o,n):cEe(t)?function(e,t,n){const r=function(e,t,n){
return function(e,t,n){return t.reduce(((t,r)=>({...t,...vPe(e,r,n)})),{})
}(e,t.keys,n)}(e,t,n);return RAe(r)
}(e,t,n):a&&i||!a&&i||a&&!i?IAe("Omit",[e,r],n):jTe({...mPe(e,o),...n})}
function vPe(e,t,n){return{[t]:gPe(e,[t],bTe(n))}}function bPe(e,t,n){
return function(e,t,n){const r={}
;for(const o of globalThis.Object.getOwnPropertyNames(e))r[o]=OPe(e[o],t,bTe(n))
;return r}(e.properties,t,n)}function yPe(e,t){return oEe(e)?VCe(function(e,t){
return e.map((e=>yPe(e,t)))}(e.allOf,t)):_Ee(e)?ZAe(function(e,t){
return e.map((e=>yPe(e,t)))}(e.anyOf,t)):fEe(e)?function(e,t){
const n=MAe(e,[zTe,"$id","required","properties"]),r=function(e,t){const n={}
;for(const r of t)r in e&&(n[r]=e[r]);return n}(e.properties,t);return PCe(r,n)
}(e,t):PCe({})}function OPe(e,t,n){const r=sTe(t)?function(e){
return ZAe(e.reduce(((e,t)=>sEe(t)?[...e,iCe(t)]:e),[]))
}(t):t,o=TEe(t)?OCe(t):t,a=vEe(e),i=vEe(t);return uEe(e)?function(e,t,n){
return RAe(bPe(e,t,n))}(e,o,n):cEe(t)?function(e,t,n){const r=function(e,t,n){
return function(e,t,n){return t.reduce(((t,r)=>({...t,...wPe(e,r,n)})),{})
}(e,t.keys,n)}(e,t,n);return RAe(r)
}(e,t,n):a&&i||!a&&i||a&&!i?IAe("Pick",[e,r],n):jTe({...yPe(e,o),...n})}
function wPe(e,t,n){return{[t]:OPe(e,[t],bTe(n))}}function xPe(e){
const t=MAe(e,[zTe,"$id","required","properties"]),n=function(e){const t={}
;for(const n of globalThis.Object.getOwnPropertyNames(e))t[n]=zCe(e[n]);return t
}(e.properties);return PCe(n,t)}function kPe(e){return e.map((e=>SPe(e)))}
function SPe(e){
return eEe(e)?(t=e.target,n=e.parameters,IAe("Partial",[IAe(t,n)])):vEe(e)?IAe("Partial",[qCe(e.$ref)]):oEe(e)?VCe(kPe(e.allOf)):_Ee(e)?ZAe(kPe(e.anyOf)):fEe(e)?xPe(e):KTe(e)||JTe(e)||rEe(e)||lEe(e)||pEe(e)||hEe(e)||yEe(e)||OEe(e)||SEe(e)?e:PCe({})
;var t,n}function _Pe(e,t){return uEe(e)?function(e,t){const n=function(e,t){
return function(e,t){const n={}
;for(const r of globalThis.Object.getOwnPropertyNames(e))n[r]=_Pe(e[r],bTe(t))
;return n}(e.properties,t)}(e,t);return RAe(n)}(e,t):jTe({...SPe(e),...t})}
function TPe(e){
const t=MAe(e,[zTe,"$id","required","properties"]),n=function(e){const t={}
;for(const n of globalThis.Object.getOwnPropertyNames(e))t[n]=MAe(e[n],[ZTe])
;return t}(e.properties);return PCe(n,t)}function EPe(e){
return e.map((e=>APe(e)))}function APe(e){
return eEe(e)?(t=e.target,n=e.parameters,
IAe("Required",[IAe(t,n)])):vEe(e)?IAe("Required",[qCe(e.$ref)]):oEe(e)?VCe(EPe(e.allOf)):_Ee(e)?ZAe(EPe(e.anyOf)):fEe(e)?TPe(e):KTe(e)||JTe(e)||rEe(e)||lEe(e)||pEe(e)||hEe(e)||yEe(e)||OEe(e)||SEe(e)?e:PCe({})
;var t,n}function CPe(e,t){return uEe(e)?function(e,t){const n=function(e,t){
return function(e,t){const n={}
;for(const r of globalThis.Object.getOwnPropertyNames(e))n[r]=CPe(e[r],t)
;return n}(e.properties,t)}(e,t);return RAe(n)}(e,t):jTe({...APe(e),...t})}
function $Pe(e,t){return t in e?vEe(e[t])?$Pe(e,e[t].$ref):IPe(e,e[t]):NAe()}
function PPe(e,t,n){const r=function(e,t){
return t.map((t=>vEe(t)?$Pe(e,t.$ref):IPe(e,t)))}(e,n)
;return"Awaited"===t?function(e){return XCe(e[0])}(r):"Index"===t?function(e){
return ACe(e[0],e[1])}(r):"KeyOf"===t?function(e){return t$e(e[0])
}(r):"Partial"===t?function(e){return _Pe(e[0])}(r):"Omit"===t?function(e){
return gPe(e[0],e[1])}(r):"Pick"===t?function(e){return OPe(e[0],e[1])
}(r):"Required"===t?function(e){return CPe(e[0])}(r):NAe()}function DPe(e,t){
return t.map((t=>IPe(e,t)))}function IPe(e,t){
return qTe(t)?jTe(IPe(e,MAe(t,[ZTe])),t):VTe(t)?jTe(IPe(e,MAe(t,[FTe])),t):xEe(t)?jTe(function(e,t){
return vEe(t)?{...$Pe(e,t.$ref),[zTe]:t[zTe]}:t
}(e,t),t):GTe(t)?jTe(function(e,t){return PAe(IPe(e,t))
}(e,t.items),t):YTe(t)?jTe(function(e,t){return DAe(IPe(e,t))
}(e,t.items),t):eEe(t)?jTe(PPe(e,t.target,t.parameters)):tEe(t)?jTe(function(e,t,n){
return LAe(DPe(e,t),IPe(e,n))
}(e,t.parameters,t.returns),t):nEe(t)?jTe(function(e,t,n){
return BAe(DPe(e,t),IPe(e,n))
}(e,t.parameters,t.returns),t):oEe(t)?jTe(function(e,t){return VCe(DPe(e,t))
}(e,t.allOf),t):aEe(t)?jTe(function(e,t){return $Ce(IPe(e,t))
}(e,t.items),t):fEe(t)?jTe(function(e,t){
return PCe(globalThis.Object.keys(t).reduce(((n,r)=>({...n,[r]:IPe(e,t[r])
})),{}))}(e,t.properties),t):gEe(t)?jTe(function(e,t){
const[n,r]=[IPe(e,rPe(t)),nPe(t)],o=yTe(t);return o.patternProperties[r]=n,o
}(e,t)):kEe(t)?jTe(function(e,t){return NCe(DPe(e,t))
}(e,t.items||[]),t):_Ee(t)?jTe(function(e,t){return ZAe(DPe(e,t))
}(e,t.anyOf),t):t}function MPe(e,t){return t in e?IPe(e,e[t]):NAe()}
(f$e=h$e||(h$e={}))[f$e.Union=0]="Union",
f$e[f$e.True=1]="True",f$e[f$e.False=2]="False";class NPe{constructor(e){
const t=(n=e,globalThis.Object.getOwnPropertyNames(n).reduce(((e,t)=>({...e,
[t]:MPe(n,t)})),{}));var n;const r=this.WithIdentifiers(t);this.$defs=r}
Import(e,t){const n={...this.$defs,[e]:jTe(this.$defs[e],t)};return jTe({
[HTe]:"Import",$defs:n,$ref:e})}WithIdentifiers(e){
return globalThis.Object.getOwnPropertyNames(e).reduce(((t,n)=>({...t,[n]:{
...e[n],$id:n}})),{})}}let RPe=0;class LPe{constructor(e){this.schema=e}
Decode(e){return new BPe(this.schema,e)}}class BPe{constructor(e,t){
this.schema=e,this.decode=t}EncodeTransform(e,t){const n={
Encode:n=>t[zTe].Encode(e(n)),Decode:e=>this.decode(t[zTe].Decode(e))};return{
...t,[zTe]:n}}EncodeSchema(e,t){const n={Decode:this.decode,Encode:e};return{
...t,[zTe]:n}}Encode(e){
return xEe(this.schema)?this.EncodeTransform(e,this.schema):this.EncodeSchema(e,this.schema)
}}const jPe=Object.freeze(Object.defineProperty({__proto__:null,Any:$Ae,
Argument:function(e){return jTe({[HTe]:"Argument",index:e})},Array:PAe,
AsyncIterator:DAe,Awaited:XCe,BigInt:lCe,Boolean:sCe,
Capitalize:function(e,t={}){return hPe(e,"Capitalize",t)},
Composite:function(e,t){const n=function(e,t){const n={}
;for(const r of t)n[r]=HCe(r$e(e,r));return n}(e,n$e(e));return PCe(n,t)},
Const:function(e,t){return jTe(d$e(e,!0),t)},Constructor:LAe,
ConstructorParameters:function(e,t){return tEe(e)?NCe(e.parameters,t):NAe(t)},
Date:o$e,Enum:function(e,t){if(gTe(e))throw new Error("Enum undefined or empty")
;const n=globalThis.Object.getOwnPropertyNames(e).filter((e=>isNaN(e))).map((t=>e[t]))
;return ZAe([...new Set(n)].map((e=>iCe(e))),{...t,[QTe]:"Enum"})},Exclude:G$e,
Extends:q$e,Extract:Y$e,Function:BAe,Index:ACe,InstanceType:function(e,t){
return tEe(e)?jTe(e.returns,t):NAe(t)},Instantiate:function(e,t){
return lPe(t,yTe(e))},Integer:function(e){return jTe({[HTe]:"Integer",
type:"integer"},e)},Intersect:VCe,Iterator:$Ce,KeyOf:t$e,Literal:iCe,
Lowercase:function(e,t={}){return hPe(e,"Lowercase",t)},Mapped:function(e,t,n){
const r=TEe(e)?OCe(e):e,o=function(e,t){const n={}
;for(const r of e)n[r]=jCe(r,t);return n}(r,t({[HTe]:"MappedKey",keys:r}))
;return PCe(o,n)},Module:function(e){return new NPe(e)},Never:NAe,
Not:function(e,t){return jTe({[HTe]:"Not",not:e},t)},Null:a$e,Number:cCe,
Object:PCe,Omit:gPe,Optional:zCe,Parameters:function(e,t){
return nEe(e)?NCe(e.parameters,t):NAe()},Partial:_Pe,Pick:OPe,Promise:DCe,
Readonly:MCe,ReadonlyOptional:K$e,Record:tPe,Recursive:function(e,t={}){
gTe(t.$id)&&(t.$id="T"+RPe++);const n=yTe(e({[HTe]:"This",$ref:`${t.$id}`}))
;return n.$id=t.$id,jTe({[QTe]:"Recursive",...n},t)},Ref:qCe,
RegExp:function(e,t){const n=fTe(e)?new globalThis.RegExp(e):e;return jTe({
[HTe]:"RegExp",type:"RegExp",source:n.source,flags:n.flags},t)},Required:CPe,
Rest:function(e){return function(e){
return oEe(e)?e.allOf:_Ee(e)?e.anyOf:kEe(e)?e.items??[]:[]}(e)},
ReturnType:function(e,t){return nEe(e)?jTe(e.returns,t):NAe(t)},String:uCe,
Symbol:i$e,TemplateLiteral:bCe,Transform:function(e){return new LPe(e)},
Tuple:NCe,Uint8Array:l$e,Uncapitalize:function(e,t={}){
return hPe(e,"Uncapitalize",t)},Undefined:s$e,Union:ZAe,Unknown:c$e,
Unsafe:function(e={}){return jTe({[HTe]:e[HTe]??"Unsafe"},e)},
Uppercase:function(e,t={}){return hPe(e,"Uppercase",t)},Void:function(e){
return jTe({[HTe]:"Void",type:"void"},e)}},Symbol.toStringTag,{value:"Module"
})),UPe=jPe.Object({name:jPe.String({
description:"The text that displays in the badge",minLength:1}),
position:jPe.Optional(jPe.Union([jPe.Literal("before"),jPe.Literal("after")],{
description:"The position of the badge in relation to the header",
default:"after"})),color:jPe.Optional(jPe.String({
description:"The color of the badge in various formats (keywords, RGB, RGBA, HSL, HSLA, Hexadecimal)",
pattern:"^(#([0-9A-Fa-f]{3}){1,2}|rgb\\(\\s*\\d+\\s*,\\s*\\d+\\s*,\\s*\\d+\\s*\\)|rgba\\(\\s*\\d+\\s*,\\s*\\d+\\s*,\\s*\\d+\\s*,\\s*[0-9.]*\\s*\\)|hsl\\(\\s*\\d+\\s*,\\s*\\d+%\\s*,\\s*\\d+%\\s*\\)|hsla\\(\\s*\\d+\\s*,\\s*\\d+%\\s*,\\s*\\d+%\\s*,\\s*[0-9.]*\\s*\\)|[a-zA-Z]+)$"
}))},{description:"Configuration for a single badge in the x-badges extension"
}),zPe=jPe.Object({"x-badges":jPe.Optional(jPe.Array(UPe))}),FPe=jPe.Object({
lang:jPe.Optional(jPe.String()),label:jPe.Optional(jPe.String()),
source:jPe.String()}),ZPe=jPe.Object({
"x-codeSamples":jPe.Optional(jPe.Array(FPe)),
"x-code-samples":jPe.Optional(jPe.Array(FPe)),
"x-custom-examples":jPe.Optional(jPe.Array(FPe))}),QPe=jPe.Object({
"x-scalar-selected-content-type":jPe.Optional(jPe.Record(jPe.String(),jPe.String()))
}),HPe="deprecated",VPe=jPe.Object({
"x-scalar-stability":jPe.Optional(jPe.Union([jPe.Literal("deprecated"),jPe.Literal("experimental"),jPe.Literal("stable")]))
}),qPe=({tagsMap:e,name:t,documentId:n,generateId:r})=>(e.get(t)||e.set(t,{
id:r({type:"tag",tag:{name:t},parentId:n}),parentId:n,entries:[],tag:{name:t}}),
e.get(t)),WPe=e=>e.deprecated||e["x-scalar-stability"]===HPe,XPe=({ref:e,operation:t,method:n,path:r,generateId:o,parentId:a,parentTag:i})=>{
const s=o({type:"operation",operation:t,parentTag:i,method:n,path:r,parentId:a
}),l=t.summary?.trim()?t.summary:r,c=WPe(t),u=(e=>{const t=new Set
;if(e.requestBody){const n=qke(e.requestBody)
;Object.values(n.content??{}).forEach((e=>{
Object.keys(e.examples??{}).forEach((e=>{t.add(e)}))}))}
return e.parameters&&e.parameters.forEach((e=>{const n=qke(e)??{}
;"content"in n&&n.content&&Object.values(n.content).forEach((e=>{
Object.keys(e.examples??{}).forEach((e=>{t.add(e)}))
})),"examples"in n&&n.examples&&Object.keys(n.examples??{}).forEach((e=>{
t.add(e)}))})),e.responses&&Object.values(e.responses).forEach((e=>{
const n=qke(e)??{}
;"content"in n&&n.content&&Object.values(n.content??{}).forEach((e=>{
Object.keys(e.examples??{}).forEach((e=>{t.add(e)}))}))})),Array.from(t)
})(t).map((e=>({type:"example",id:o({type:"example",parentId:s,name:e}),title:e,
name:e})));return{id:s,title:l,path:r,method:n,ref:e,type:"operation",
isDeprecated:c,children:u.length?u:void 0}
},GPe=({ref:e,name:t,generateId:n,parentTag:r,_schema:o,parentId:a})=>{
const i=n({name:t,type:"model",parentTag:r,parentId:a,schema:o}),s=qke(o)
;return{id:i,title:s&&"title"in s&&s.title||t,name:t,ref:e,type:"model"}
},YPe=({tag:e,generateId:t,children:n,isGroup:r=!1,parentId:o})=>{const a=t({
type:"tag",tag:e,parentId:o}),i=e["x-displayName"]??e.name??"Untitled Tag"
;e["x-scalar-order"]=n.map((e=>e.id));var s;return{id:a,title:i,name:e.name||i,
description:e.description,children:n,isGroup:r,isWebhooks:!1,type:"tag",
xKeys:(s=Q_e(e),
s?Object.fromEntries(Object.entries(s).filter((([e])=>e.startsWith("x-")))):{})}
},KPe=({_keys:e,tagsMap:t,options:{tagsSorter:n,operationsSorter:r,generateId:o},documentId:a,sortOrder:i})=>{
const s=e.flatMap((e=>{const{tag:n,entries:i}=qPe({tagsMap:t,name:e,
documentId:a,generateId:o});if(n["x-internal"]||n["x-scalar-ignore"])return[]
;const s=n["x-scalar-order"]
;return void 0===s&&("alpha"===r?i.sort(((e,t)=>"operation"===e.type&&"operation"===t.type?e.title.localeCompare(t.title):0)):"method"===r?i.sort(((e,t)=>"operation"===e.type&&"operation"===t.type?e.method.localeCompare(t.method):0)):"function"==typeof r&&i.sort(((e,t)=>{
if("operation"!==e.type&&"webhook"!==e.type||"operation"!==t.type&&"webhook"!==t.type)return 0
;const n="operation"===e.type?e.path:e.name,o="operation"===t.type?t.path:t.name
;return r({method:e.method,path:n,ref:e.ref,httpVerb:e.method},{method:t.method,
path:o,ref:t.ref,httpVerb:t.method})}))),YPe({tag:n,generateId:o,
children:s?Hke(i,s,"id"):i,parentId:a,isGroup:!1})}))
;return i?Hke(s,i,"id"):("alpha"===n?s.sort(((e,n)=>{const r=qPe({tagsMap:t,
name:e.title,documentId:a,generateId:o
}).tag["x-displayName"]||e.title||"Untitled Tag",i=qPe({tagsMap:t,name:n.title,
documentId:a,generateId:o}).tag["x-displayName"]||n.title||"Untitled Tag"
;return r.localeCompare(i)})):"function"==typeof n&&s.sort(((e,r)=>n(qPe({
tagsMap:t,name:e.name,documentId:a,generateId:o}).tag,qPe({tagsMap:t,
name:r.name,documentId:a,generateId:o}).tag))),s)
},JPe=({ref:e,method:t,name:n,title:r,generateId:o,parentTag:a,webhook:i,isDeprecated:s,parentId:l})=>({
id:o({type:"webhook",name:n,method:t,webhook:i,parentTag:a,parentId:l}),title:r,
name:n,ref:e,method:t,type:"webhook",isDeprecated:s}),eDe=(e,t,n)=>{
const{hideModels:r,tagsSorter:o,operationsSorter:a,generateId:i}=aTe(e,n),s=i({
type:"document",info:t.info,name:e
}),l=new Map(t.tags?.map((e=>[e.name??"Untitled Tag",{id:i({type:"tag",tag:e,
parentId:s}),parentId:s,tag:e,entries:[]}]))??[]),c=iTe({generateId:i,
parentId:s,info:t.info
}),{untaggedOperations:u}=(({document:e,tagsMap:t,generateId:n,documentId:r})=>{
const o=[];return Object.entries(e.paths??{}).forEach((([e,a])=>{
MH(a??{}).filter((e=>IH(e))).forEach((i=>{const s=a?.[i],l=qke(s);if(!l)return
;if(l["x-internal"]||l["x-scalar-ignore"]||!IH(i))return
;const c=`#/paths/${CSe(e)}/${i}`;l.tags?.length?l.tags.forEach((o=>{
const{tag:a,id:s}=qPe({tagsMap:t,name:o,documentId:r,generateId:n})
;t.get(o)?.entries.push(XPe({ref:c,operation:l,method:i,path:e,parentTag:{tag:a,
id:s},generateId:n,parentId:s}))})):o.push(XPe({ref:c,operation:l,method:i,
path:e,generateId:n,parentId:r}))}))})),{untaggedOperations:o}})({document:t,
tagsMap:l,generateId:i,documentId:s}),d=i({type:"webhook",name:"",parentId:s
}),p=(({document:e,tagsMap:t,generateId:n,untaggedWebhooksParentId:r,documentId:o})=>{
const a=[];return Object.entries(e.webhooks??{}).forEach((([e,i])=>{
MH(i??{}).filter((e=>IH(e))).forEach((s=>{const l=i?.[s],c=qke(l);if(!c)return
;if(c["x-internal"]||c["x-scalar-ignore"])return;const u=`#/webhooks/${e}/${s}`
;c.tags?.length?c.tags.forEach((r=>{const{tag:a,id:i}=qPe({tagsMap:t,name:r,
documentId:o,generateId:n});t.get(r)?.entries.push(JPe({ref:u,method:s,name:e,
title:c.summary??e,webhook:c,generateId:n,parentTag:{tag:a,id:i},parentId:i,
isDeprecated:WPe(c)}))})):a.push(JPe({ref:u,method:s,name:e,title:c.summary??e,
generateId:n,isDeprecated:WPe(c),webhook:c,parentId:r}))}))})),a})({document:t,
generateId:i,tagsMap:l,untaggedWebhooksParentId:d,documentId:s
}),h=(({document:e,tagsMap:t,documentId:n,options:{generateId:r,tagsSorter:o,operationsSorter:a}})=>{
if(e["x-tagGroups"])return e["x-tagGroups"].flatMap((e=>{const i=KPe({
_keys:e.tags,tagsMap:t,options:{tagsSorter:o,operationsSorter:a,generateId:r},
documentId:n,sortOrder:e["x-scalar-order"]})
;return e["x-scalar-order"]=i.map((e=>e.id)),i.length?YPe({tag:e,generateId:r,
children:i,parentId:n,isGroup:!0}):[]}));const i=Array.from(t.keys())
;return KPe({_keys:i,tagsMap:t,options:{generateId:r,tagsSorter:o,
operationsSorter:a},documentId:n,sortOrder:e["x-scalar-order"]})})({document:t,
tagsMap:l,documentId:s,options:{tagsSorter:o,operationsSorter:a,generateId:i}})
;if(c.push(...h),c.push(...u),p.length&&c.push({type:"tag",id:d,
title:"Webhooks",name:"Webhooks",children:p,isGroup:!1,isWebhooks:!0
}),!r&&t.components?.schemas){
const e=(({document:e,tagsMap:t,generateId:n,documentId:r})=>{
const o=e.components?.schemas??{},a=[];for(const i in o){const e=qke(o[i])
;if(e?.["x-internal"]||e?.["x-scalar-ignore"]||!Object.hasOwn(o,i))continue
;const s=`#/components/schemas/${i}`;e?.["x-tags"]?e["x-tags"].forEach((e=>{
const{tag:o,id:a}=qPe({tagsMap:t,name:e,documentId:r,generateId:n})
;t.get(e)?.entries.push(GPe({ref:s,name:i,generateId:n,parentTag:{tag:o,id:a},
parentId:r}))})):a.push(GPe({ref:s,name:i,generateId:n,_schema:qke(o[i]),
parentId:r}))}return a})({documentId:s,document:t,generateId:i,tagsMap:l})
;e.length&&c.push({type:"models",id:i({type:"model",parentId:s}),title:"Models",
name:"Models",children:e})}const f=t["x-scalar-order"]
;return f&&c.sort(((e,t)=>{const n=f.indexOf(e.id),r=f.indexOf(t.id)
;return(-1===n?Number.POSITIVE_INFINITY:n)-(-1===r?Number.POSITIVE_INFINITY:r)
})),t["x-scalar-order"]=Q_e(c.map((e=>e.id))),{id:s,type:"document",
title:t.info.title,name:e,children:c,icon:t["x-scalar-icon"]}
},tDe=e=>"example"===e.type,nDe=e=>e.store.workspace.documents[e.documentSlug??""],rDe=(e,t)=>{
const n=((e,t)=>"default"!==t||void 0!==e.workspace.documents[t]?t:e.workspace["x-scalar-active-document"]||Object.keys(e.workspace.documents)[0])(e,t.documentSlug),r={
store:e,documentSlug:n},o=((e,t)=>{const n=nDe(e)
;if(n)return"default"===t?Object.keys(n.paths??{})[0]:t
})(r,t.path),a=((e,t,n)=>{const r=nDe(e)
;if(r&&t)return"default"===n?Object.keys(r.paths?.[t]??{}).find(IH):IH(n)?n:void 0
})(r,o,t.method),i=nDe(r)?.["x-scalar-navigation"];if(!i)return{documentSlug:n,
path:o,method:a,example:"default"}
;const s=eTe(i).get(`${o}|${a}`)?.find((e=>"operation"===e.type)),l=((e,t,n)=>{
if(!nDe(e)||"operation"!==t?.type)return"default"
;const r=t.children?.filter(tDe)??[],o=r.find((e=>e.name===n))
;return o?o.name:"default"===n?r[0]?.name??"default":"default"})(r,s,t.example)
;return{documentSlug:n,path:o,method:a,example:l}},oDe="get",aDe=e=>{
if("string"!=typeof e)return console.warn(`Request method is not a string. Using ${oDe} as the default.`),
oDe;const t=e.trim().toLowerCase()
;return IH(t)?t:(console.warn(`${e||"Request method"} is not a valid request method. Using ${oDe} as the default.`),
oDe)},iDe=Qg({__name:"HttpMethod",props:{as:{},property:{},short:{type:Boolean},
method:{}},setup(e){
const t=e,n=Sy((()=>CH(String(t.method||"")))),r=Sy((()=>aDe(t.method)))
;return(t,o)=>(Ub(),Hb(bv(e.as??"span"),{class:"uppercase",style:Ah({
[e.property||"color"]:n.value.colorVar})},{
default:ig((()=>[kv(t.$slots,"default"),ey(" "+Uh(e.short?n.value.short:r.value),1)])),
_:3},8,["style"]))}
}),sDe=(e,t)=>"reference"===e?t:t.filter((e=>"document"===e.type||"operation"===e.type||"example"===e.type||"tag"===e.type)),lDe={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function cDe(e,t){return Ub(),Qb("svg",lDe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"m10.812 2.492-8.32 8.32a1.68 1.68 0 0 0 0 2.377l8.32 8.319a1.68 1.68 0 0 0 2.377 0l8.319-8.32a1.68 1.68 0 0 0 0-2.377l-8.32-8.319a1.68 1.68 0 0 0-2.377 0Z"
},null,-1)])])}const uDe={render:cDe},dDe=Object.freeze(Object.defineProperty({
__proto__:null,default:uDe,render:cDe},Symbol.toStringTag,{value:"Module"
})),pDe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function hDe(e,t){return Ub(),Qb("svg",pDe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M20.711 16.963V7.044a1.37 1.37 0 0 0-.759-1.229l-7.338-3.67a1.37 1.37 0 0 0-1.227 0l-7.34 3.662a1.37 1.37 0 0 0-.758 1.23v9.919a1.37 1.37 0 0 0 .759 1.229l7.34 3.67a1.38 1.38 0 0 0 1.229 0l7.34-3.663a1.37 1.37 0 0 0 .754-1.23Z"
},null,-1)])])}const fDe={render:hDe},mDe=Object.freeze(Object.defineProperty({
__proto__:null,default:fDe,render:hDe},Symbol.toStringTag,{value:"Module"
})),gDe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function vDe(e,t){return Ub(),Qb("svg",gDe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M2 12a10 10 0 1 0 20 0 10 10 0 0 0-20 0"},null,-1)])])}const bDe={render:vDe
},yDe=Object.freeze(Object.defineProperty({__proto__:null,default:bDe,render:vDe
},Symbol.toStringTag,{value:"Module"})),ODe={xmlns:"http://www.w3.org/2000/svg",
fill:"none",viewBox:"0 0 24 24"};function wDe(e,t){
return Ub(),Qb("svg",ODe,[...t[0]||(t[0]=[Gb("path",{stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",
d:"M19 3H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2V5a2 2 0 0 0-2-2"
},null,-1)])])}const xDe={render:wDe},kDe=Object.freeze(Object.defineProperty({
__proto__:null,default:xDe,render:wDe},Symbol.toStringTag,{value:"Module"
})),SDe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function _De(e,t){return Ub(),Qb("svg",SDe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M3.334 4.82v6.768a10.58 10.58 0 0 0 6.783 9.878l.926.356a2.67 2.67 0 0 0 1.914 0l.926-.356a10.58 10.58 0 0 0 6.783-9.878V4.821a1.32 1.32 0 0 0-.771-1.211A19.3 19.3 0 0 0 12 2a19.3 19.3 0 0 0-7.895 1.61 1.32 1.32 0 0 0-.771 1.21"
},null,-1)])])}const TDe={render:_De},EDe=Object.freeze(Object.defineProperty({
__proto__:null,default:TDe,render:_De},Symbol.toStringTag,{value:"Module"
})),ADe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function CDe(e,t){return Ub(),Qb("svg",ADe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M3 20h18M5 4h14a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2"
},null,-1)])])}const $De={render:CDe},PDe=Object.freeze(Object.defineProperty({
__proto__:null,default:$De,render:CDe},Symbol.toStringTag,{value:"Module"
})),DDe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function IDe(e,t){return Ub(),Qb("svg",DDe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M18 8V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v7a2 2 0 0 0 2 2h8m-5 4h5m6-7h2a2 2 0 0 1 2 2v6a2 2 0 0 1-2 2h-2a2 2 0 0 1-2-2v-6a2 2 0 0 1 2-2"
},null,-1)])])}const MDe={render:IDe},NDe=Object.freeze(Object.defineProperty({
__proto__:null,default:MDe,render:IDe},Symbol.toStringTag,{value:"Module"
})),RDe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function LDe(e,t){return Ub(),Qb("svg",RDe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M20.522 14.167V6.64a2.13 2.13 0 0 0-2.13-2.13H5.608a2.13 2.13 0 0 0-2.13 2.13v7.526m17.044 0H3.478m17.044 0 1.364 4.778a1.066 1.066 0 0 1-.959 1.545H3.073a1.065 1.065 0 0 1-.959-1.545l1.364-4.778m6.855 3.333h3.334"
},null,-1)])])}const BDe={render:LDe},jDe=Object.freeze(Object.defineProperty({
__proto__:null,default:BDe,render:LDe},Symbol.toStringTag,{value:"Module"
})),UDe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function zDe(e,t){return Ub(),Qb("svg",UDe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M8.333 2h7.334s2.666 0 2.666 2.667v14.666s0 2.667-2.666 2.667H8.333s-2.666 0-2.666-2.667V4.667S5.667 2 8.333 2"
},null,-1),Gb("path",{stroke:"currentColor","stroke-linecap":"round",
"stroke-linejoin":"round",
d:"M9.186 4.563h1.246s.889 0 .889.889V9.88s0 .889-.889.889H9.186s-.89 0-.89-.89V5.453s0-.89.89-.89"
},null,-1)])])}const FDe={render:zDe},ZDe=Object.freeze(Object.defineProperty({
__proto__:null,default:FDe,render:zDe},Symbol.toStringTag,{value:"Module"
})),QDe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function HDe(e,t){return Ub(),Qb("svg",QDe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M15.667 2H8.333a2.667 2.667 0 0 0-2.666 2.667v14.666A2.667 2.667 0 0 0 8.333 22h7.334a2.667 2.667 0 0 0 2.666-2.667V4.667A2.667 2.667 0 0 0 15.667 2"
},null,-1),Gb("path",{fill:"currentColor","fill-rule":"evenodd",
d:"M11 5a1 1 0 1 1 2 0 1 1 0 0 1-2 0","clip-rule":"evenodd"},null,-1)])])}
const VDe={render:HDe},qDe=Object.freeze(Object.defineProperty({__proto__:null,
default:VDe,render:HDe},Symbol.toStringTag,{value:"Module"})),WDe={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function XDe(e,t){return Ub(),Qb("svg",WDe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M15.667 2H8.333a2.667 2.667 0 0 0-2.666 2.667v14.666A2.667 2.667 0 0 0 8.333 22h7.334a2.667 2.667 0 0 0 2.666-2.667V4.667A2.667 2.667 0 0 0 15.667 2"
},null,-1),Gb("path",{fill:"currentColor","fill-rule":"evenodd",
d:"M8 5a1 1 0 1 1 2 0 1 1 0 0 1-2 0m3 2a1 1 0 1 1 2 0 1 1 0 0 1-2 0M8 9a1 1 0 1 1 2 0 1 1 0 0 1-2 0",
"clip-rule":"evenodd"},null,-1)])])}const GDe={render:XDe
},YDe=Object.freeze(Object.defineProperty({__proto__:null,default:GDe,render:XDe
},Symbol.toStringTag,{value:"Module"})),KDe={xmlns:"http://www.w3.org/2000/svg",
fill:"none",viewBox:"0 0 24 24"};function JDe(e,t){
return Ub(),Qb("svg",KDe,[...t[0]||(t[0]=[Gb("path",{stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",
d:"M7.198 2h9.603s1.74 0 1.74 1.74v16.52s0 1.74-1.74 1.74H7.198s-1.74 0-1.74-1.74V3.74S5.459 2 7.199 2Z"
},null,-1),Gb("path",{stroke:"currentColor","stroke-linecap":"round",
"stroke-linejoin":"round",
d:"M14.684 4.935H9.315a.94.94 0 0 1-.932-.8L8.067 2h7.865l-.315 2.133a.94.94 0 0 1-.933.802"
},null,-1)])])}const eIe={render:JDe},tIe=Object.freeze(Object.defineProperty({
__proto__:null,default:eIe,render:JDe},Symbol.toStringTag,{value:"Module"
})),nIe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function rIe(e,t){return Ub(),Qb("svg",nIe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M21 11V7a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h6m1.034-7.319a.499.499 0 0 1 .647-.647l9 3.5a.5.5 0 0 1-.033.943l-3.444 1.068a1 1 0 0 0-.66.66l-1.067 3.443a.5.5 0 0 1-.943.033z"
},null,-1)])])}const oIe={render:rIe},aIe=Object.freeze(Object.defineProperty({
__proto__:null,default:oIe,render:rIe},Symbol.toStringTag,{value:"Module"
})),iIe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function sIe(e,t){return Ub(),Qb("svg",iIe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M15.667 22H8.333a2.667 2.667 0 0 1-2.666-2.667V4.667A2.667 2.667 0 0 1 8.333 2h7.334a2.667 2.667 0 0 1 2.666 2.667v14.666A2.667 2.667 0 0 1 15.667 22"
},null,-1),Gb("path",{fill:"currentColor","fill-rule":"evenodd",
d:"M11 19a1 1 0 1 1 2 0 1 1 0 0 1-2 0","clip-rule":"evenodd"},null,-1)])])}
const lIe={render:sIe},cIe=Object.freeze(Object.defineProperty({__proto__:null,
default:lIe,render:sIe},Symbol.toStringTag,{value:"Module"})),uIe={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function dIe(e,t){return Ub(),Qb("svg",uIe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M10 7.5v2.813M14 7.5v2.813M14 7.5h2.5a1.125 1.125 0 0 1 1.125 1.125v5.062a1.125 1.125 0 0 1-1.125 1.125h-.543c-.373 0-.73.149-.994.412l-.864.864a1.4 1.4 0 0 1-.994.412h-2.21c-.373 0-.73-.148-.994-.412l-.864-.864a1.4 1.4 0 0 0-.994-.412H7.5a1.125 1.125 0 0 1-1.125-1.125V8.625A1.125 1.125 0 0 1 7.5 7.5zM4.2 3h15.6S21 3 21 4.2v15.6s0 1.2-1.2 1.2H4.2S3 21 3 19.8V4.2S3 3 4.2 3"
},null,-1)])])}const pIe={render:dIe},hIe=Object.freeze(Object.defineProperty({
__proto__:null,default:pIe,render:dIe},Symbol.toStringTag,{value:"Module"
})),fIe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function mIe(e,t){return Ub(),Qb("svg",fIe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M22 12c0 5.523-4.477 10-10 10m10-10c0-5.523-4.477-10-10-10m10 10H2m10 10C6.477 22 2 17.523 2 12m10 10a14.5 14.5 0 0 1 0-20m0 20a14.5 14.5 0 0 0 0-20M2 12C2 6.477 6.477 2 12 2"
},null,-1)])])}const gIe={render:mIe},vIe=Object.freeze(Object.defineProperty({
__proto__:null,default:gIe,render:mIe},Symbol.toStringTag,{value:"Module"
})),bIe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function yIe(e,t){return Ub(),Qb("svg",bIe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M2 8.82a15 15 0 0 1 20 0M5 12.859a10 10 0 0 1 14 0m-10.5 3.57a5 5 0 0 1 7 0"
},null,-1),Gb("path",{fill:"currentColor","fill-rule":"evenodd",
d:"M11 20a1 1 0 1 1 2 0 1 1 0 0 1-2 0","clip-rule":"evenodd"},null,-1)])])}
const OIe={render:yIe},wIe=Object.freeze(Object.defineProperty({__proto__:null,
default:OIe,render:yIe},Symbol.toStringTag,{value:"Module"})),xIe={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function kIe(e,t){return Ub(),Qb("svg",xIe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M14.7 10.2v3.6m2.556-6.147a3.6 3.6 0 0 0-5.094 0m7.632-2.547a7.2 7.2 0 0 0-10.179 0M4.8 13.8h14.4a1.8 1.8 0 0 1 1.8 1.8v3.6a1.8 1.8 0 0 1-1.8 1.8H4.8A1.8 1.8 0 0 1 3 19.2v-3.6a1.8 1.8 0 0 1 1.8-1.8"
},null,-1),Gb("path",{fill:"currentColor","fill-rule":"evenodd",
d:"M6 17.5a1 1 0 1 1 2 0 1 1 0 0 1-2 0m4 0a1 1 0 1 1 2 0 1 1 0 0 1-2 0",
"clip-rule":"evenodd"},null,-1)])])}const SIe={render:kIe
},_Ie=Object.freeze(Object.defineProperty({__proto__:null,default:SIe,render:kIe
},Symbol.toStringTag,{value:"Module"})),TIe={xmlns:"http://www.w3.org/2000/svg",
fill:"none",viewBox:"0 0 24 24"};function EIe(e,t){
return Ub(),Qb("svg",TIe,[...t[0]||(t[0]=[Gb("path",{stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",
d:"M8.5 2h7m-5.3 1v6.774a1.8 1.8 0 0 1-.19.807l-4.562 9.114A.9.9 0 0 0 6.258 21h11.484a.9.9 0 0 0 .81-1.305l-4.562-9.114a1.8 1.8 0 0 1-.19-.807V3M7.5 15.6h9"
},null,-1)])])}const AIe={render:EIe},CIe=Object.freeze(Object.defineProperty({
__proto__:null,default:AIe,render:EIe},Symbol.toStringTag,{value:"Module"
})),$Ie={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function PIe(e,t){return Ub(),Qb("svg",$Ie,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M4.802 13.8a.899.899 0 0 1-.702-1.467l8.908-9.178a.45.45 0 0 1 .774.414l-1.728 5.417A.9.9 0 0 0 12.9 10.2h6.298a.899.899 0 0 1 .702 1.467l-8.908 9.178a.45.45 0 0 1-.774-.414l1.728-5.417A.9.9 0 0 0 11.1 13.8z"
},null,-1)])])}const DIe={render:PIe},IIe=Object.freeze(Object.defineProperty({
__proto__:null,default:DIe,render:PIe},Symbol.toStringTag,{value:"Module"
})),MIe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function NIe(e,t){return Ub(),Qb("svg",MIe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M12 9.286a2.5 2.5 0 1 1 2.5 2.5m-2.5-2.5a2.5 2.5 0 1 0-2.5 2.5m2.5-2.5v.833m2.5 1.667a2.5 2.5 0 1 1-2.5 2.5m2.5-2.5h-.833m-4.167 0a2.5 2.5 0 1 0 2.5 2.5m-2.5-2.5h.833M12 10.119c-.92 0-1.667.746-1.667 1.667M12 10.119c.92 0 1.667.746 1.667 1.667M12 14.286v-.834m0 .834V20.5m-1.667-8.714c0 .92.746 1.666 1.667 1.666m1.667-1.666c0 .92-.746 1.666-1.667 1.666M4.2 3h15.6S21 3 21 4.2v15.6s0 1.2-1.2 1.2H4.2S3 21 3 19.8V4.2S3 3 4.2 3"
},null,-1)])])}const RIe={render:NIe},LIe=Object.freeze(Object.defineProperty({
__proto__:null,default:RIe,render:NIe},Symbol.toStringTag,{value:"Module"
})),BIe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function jIe(e,t){return Ub(),Qb("svg",BIe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"m10.812 2.492-8.32 8.32a1.68 1.68 0 0 0 0 2.377l8.32 8.319a1.68 1.68 0 0 0 2.377 0l8.319-8.32a1.68 1.68 0 0 0 0-2.377l-8.32-8.319a1.68 1.68 0 0 0-2.377 0ZM12 8v4"
},null,-1),Gb("path",{fill:"currentColor","fill-rule":"evenodd",
d:"M11 16a1 1 0 1 1 2 0 1 1 0 0 1-2 0","clip-rule":"evenodd"},null,-1)])])}
const UIe={render:jIe},zIe=Object.freeze(Object.defineProperty({__proto__:null,
default:UIe,render:jIe},Symbol.toStringTag,{value:"Module"})),FIe={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function ZIe(e,t){return Ub(),Qb("svg",FIe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M12 9.57v4.296m7.926 7.516H4.074c-.798 0-1.318-.84-.96-1.554L11.04 3.976a1.074 1.074 0 0 1 1.92 0l7.927 15.852a1.074 1.074 0 0 1-.96 1.554Z"
},null,-1),Gb("path",{fill:"currentColor","fill-rule":"evenodd",
d:"M11 18a1 1 0 1 1 2 0 1 1 0 0 1-2 0","clip-rule":"evenodd"},null,-1)])])}
const QIe={render:ZIe},HIe=Object.freeze(Object.defineProperty({__proto__:null,
default:QIe,render:ZIe},Symbol.toStringTag,{value:"Module"})),VIe={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function qIe(e,t){return Ub(),Qb("svg",VIe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M12 22c5.523 0 10-4.477 10-10S17.523 2 12 2 2 6.477 2 12s4.477 10 10 10"
},null,-1),Gb("path",{stroke:"currentColor","stroke-linecap":"round",
"stroke-linejoin":"round","stroke-miterlimit":"10",
d:"M12 17v-6 0a.5.5 0 0 0-.5-.5l-.5.001h-1M12 17h-2m2 0h2"},null,-1),Gb("path",{
fill:"currentColor","fill-rule":"evenodd",
d:"M10.75 7.5a1 1 0 1 1 2 0 1 1 0 0 1-2 0","clip-rule":"evenodd"},null,-1)])])}
const WIe={render:qIe},XIe=Object.freeze(Object.defineProperty({__proto__:null,
default:WIe,render:qIe},Symbol.toStringTag,{value:"Module"})),GIe={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function YIe(e,t){return Ub(),Qb("svg",GIe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M4.999 21.002H19M11.56 3.264a.5.5 0 0 1 .877 0l2.953 5.605a1 1 0 0 0 1.516.294L21.185 5.5a.5.5 0 0 1 .798.519l-2.835 10.248a1 1 0 0 1-.956.734H5.81a1 1 0 0 1-.957-.734L2.018 6.019a.5.5 0 0 1 .798-.52l4.277 3.665a1 1 0 0 0 1.516-.294l2.953-5.606Z"
},null,-1)])])}const KIe={render:YIe},JIe=Object.freeze(Object.defineProperty({
__proto__:null,default:KIe,render:YIe},Symbol.toStringTag,{value:"Module"
})),eMe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function tMe(e,t){return Ub(),Qb("svg",eMe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M13.527 3.525a1.8 1.8 0 0 0-1.273-.527H5.798a1.8 1.8 0 0 0-1.8 1.8v6.456c0 .478.19.936.527 1.273l7.836 7.836a2.184 2.184 0 0 0 3.078 0l5.924-5.924a2.184 2.184 0 0 0 0-3.078z"
},null,-1),Gb("path",{fill:"currentColor","fill-rule":"evenodd",
d:"M8 8a1 1 0 1 1 2 0 1 1 0 0 1-2 0","clip-rule":"evenodd"},null,-1)])])}
const nMe={render:tMe},rMe=Object.freeze(Object.defineProperty({__proto__:null,
default:nMe,render:tMe},Symbol.toStringTag,{value:"Module"})),oMe={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function aMe(e,t){return Ub(),Qb("svg",oMe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"m19 21-7-4-7 4V5a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2z"},null,-1)])])}const iMe={
render:aMe},sMe=Object.freeze(Object.defineProperty({__proto__:null,default:iMe,
render:aMe},Symbol.toStringTag,{value:"Module"})),lMe={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function cMe(e,t){return Ub(),Qb("svg",lMe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M11 14h1v4m4-16v4M3 10h18M8 2v4M5 4h14a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2"
},null,-1)])])}const uMe={render:cMe},dMe=Object.freeze(Object.defineProperty({
__proto__:null,default:uMe,render:cMe},Symbol.toStringTag,{value:"Module"
})),pMe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function hMe(e,t){return Ub(),Qb("svg",pMe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M17.333 5.01c1.39-.224 2.796-.34 4.205-.346.121 0 .238.044.329.125.085.084.133.2.133.32v14a.453.453 0 0 1-.444.444C14.186 19.66 12 21.997 12 21.997m0 0V7.091m0 14.906s-2.187-2.337-9.556-2.444A.453.453 0 0 1 2 19.109v-14c0-.12.048-.236.133-.32a.5.5 0 0 1 .33-.125C9.822 4.762 12 7.091 12 7.091m0 0a5.5 5.5 0 0 1 1.458-3.05 6.9 6.9 0 0 1 3.235-2.017.53.53 0 0 1 .436.053.41.41 0 0 1 .204.356V16.31a7.27 7.27 0 0 0-3.875 2.186A5.33 5.33 0 0 0 12 21.562"
},null,-1)])])}const fMe={render:hMe},mMe=Object.freeze(Object.defineProperty({
__proto__:null,default:fMe,render:hMe},Symbol.toStringTag,{value:"Module"
})),gMe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function vMe(e,t){return Ub(),Qb("svg",gMe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M11 3v8l3-3 3 3V3M5 3h14a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2"
},null,-1)])])}const bMe={render:vMe},yMe=Object.freeze(Object.defineProperty({
__proto__:null,default:bMe,render:vMe},Symbol.toStringTag,{value:"Module"
})),OMe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function wMe(e,t){return Ub(),Qb("svg",OMe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M15 3v4a2 2 0 0 0 2 2h4m-5-6H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2V8z"
},null,-1)])])}const xMe={render:wMe},kMe=Object.freeze(Object.defineProperty({
__proto__:null,default:xMe,render:wMe},Symbol.toStringTag,{value:"Module"
})),SMe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function _Me(e,t){return Ub(),Qb("svg",SMe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M13 6h6a2 2 0 0 1 2 2v11a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.93a2 2 0 0 1 1.67.9l.81 1.2a2 2 0 0 0 1.69.9"
},null,-1)])])}const TMe={render:_Me},EMe=Object.freeze(Object.defineProperty({
__proto__:null,default:TMe,render:_Me},Symbol.toStringTag,{value:"Module"
})),AMe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function CMe(e,t){return Ub(),Qb("svg",AMe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M16 4h2a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2h2m1-2h6a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H9a1 1 0 0 1-1-1V3a1 1 0 0 1 1-1"
},null,-1)])])}const $Me={render:CMe},PMe=Object.freeze(Object.defineProperty({
__proto__:null,default:$Me,render:CMe},Symbol.toStringTag,{value:"Module"
})),DMe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function IMe(e,t){return Ub(),Qb("svg",DMe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"m20.72 11.12-8.51 8.51a5.559 5.559 0 1 1-7.86-7.861l7.935-7.936a3.71 3.71 0 0 1 5.25 5.241L9.581 17.01a1.853 1.853 0 1 1-2.62-2.62l7.861-7.853"
},null,-1)])])}const MMe={render:IMe},NMe=Object.freeze(Object.defineProperty({
__proto__:null,default:MMe,render:IMe},Symbol.toStringTag,{value:"Module"
})),RMe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function LMe(e,t){return Ub(),Qb("svg",RMe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M10.2 16.8a3.6 3.6 0 1 1-7.2 0 3.6 3.6 0 0 1 7.2 0m0 0V5.7a2.1 2.1 0 0 0-4.125-.56L3.13 15.844m10.67.956a3.6 3.6 0 1 0 7.2 0 3.6 3.6 0 0 0-7.2 0m0 0V5.7a2.1 2.1 0 0 1 4.125-.56l2.945 10.7M10.2 9.6h3.6V12h-3.6z"
},null,-1)])])}const BMe={render:LMe},jMe=Object.freeze(Object.defineProperty({
__proto__:null,default:BMe,render:LMe},Symbol.toStringTag,{value:"Module"
})),UMe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function zMe(e,t){return Ub(),Qb("svg",UMe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M15 6V4m2 2.983 1.414-1.415M18 9h2m-3 2 1.2 1.2M4 20 15 9m-1.8-1.8L12 6"
},null,-1)])])}const FMe={render:zMe},ZMe=Object.freeze(Object.defineProperty({
__proto__:null,default:FMe,render:zMe},Symbol.toStringTag,{value:"Module"
})),QMe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function HMe(e,t){return Ub(),Qb("svg",QMe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M13.8 15.6v-1.8A1.8 1.8 0 0 0 12 12H4.8A1.8 1.8 0 0 1 3 10.2V7.5a1.8 1.8 0 0 1 1.8-1.8h1.8M19.2 3H8.4a1.8 1.8 0 0 0-1.8 1.8v1.8a1.8 1.8 0 0 0 1.8 1.8h10.8A1.8 1.8 0 0 0 21 6.6V4.8A1.8 1.8 0 0 0 19.2 3m-4.5 12.6h-1.8a.9.9 0 0 0-.9.9v3.6a.9.9 0 0 0 .9.9h1.8a.9.9 0 0 0 .9-.9v-3.6a.9.9 0 0 0-.9-.9"
},null,-1)])])}const VMe={render:HMe},qMe=Object.freeze(Object.defineProperty({
__proto__:null,default:VMe,render:HMe},Symbol.toStringTag,{value:"Module"
})),WMe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function XMe(e,t){return Ub(),Qb("svg",WMe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M16.494 3.913a2.56 2.56 0 0 1 1.855-.905 2.58 2.58 0 0 1 1.923.749 2.54 2.54 0 0 1 .741 1.915 2.53 2.53 0 0 1-.924 1.835l-12.13 12.13-4.943 1.348 1.348-4.942z"
},null,-1)])])}const GMe={render:XMe},YMe=Object.freeze(Object.defineProperty({
__proto__:null,default:GMe,render:XMe},Symbol.toStringTag,{value:"Module"
})),KMe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function JMe(e,t){return Ub(),Qb("svg",KMe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"m15.477 12.89 1.515 8.526a.5.5 0 0 1-.81.47l-3.58-2.687a1 1 0 0 0-1.197 0l-3.586 2.686a.5.5 0 0 1-.81-.469l1.514-8.526M18 8A6 6 0 1 1 6 8a6 6 0 0 1 12 0"
},null,-1)])])}const eNe={render:JMe},tNe=Object.freeze(Object.defineProperty({
__proto__:null,default:eNe,render:JMe},Symbol.toStringTag,{value:"Module"
})),nNe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function rNe(e,t){return Ub(),Qb("svg",nNe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M4.8 14.7s.9-.9 3.6-.9 4.5 1.8 7.2 1.8 3.6-.9 3.6-.9V3.9s-.9.9-3.6.9S11.1 3 8.4 3s-3.6.9-3.6.9zm0 0V21"
},null,-1)])])}const oNe={render:rNe},aNe=Object.freeze(Object.defineProperty({
__proto__:null,default:oNe,render:rNe},Symbol.toStringTag,{value:"Module"
})),iNe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function sNe(e,t){return Ub(),Qb("svg",iNe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M19 14c1.49-1.46 3-3.21 3-5.5A5.5 5.5 0 0 0 16.5 3c-1.76 0-3 .5-4.5 2-1.5-1.5-2.74-2-4.5-2A5.5 5.5 0 0 0 2 8.5c0 2.3 1.5 4.05 3 5.5l7 7z"
},null,-1)])])}const lNe={render:sNe},cNe=Object.freeze(Object.defineProperty({
__proto__:null,default:lNe,render:sNe},Symbol.toStringTag,{value:"Module"
})),uNe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function dNe(e,t){return Ub(),Qb("svg",uNe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M11.525 2.295a.53.53 0 0 1 .95 0l2.31 4.679a2.12 2.12 0 0 0 1.595 1.16l5.166.756a.53.53 0 0 1 .294.904l-3.736 3.638a2.12 2.12 0 0 0-.611 1.878l.882 5.14a.53.53 0 0 1-.771.56l-4.618-2.428a2.12 2.12 0 0 0-1.973 0L6.396 21.01a.53.53 0 0 1-.77-.56l.881-5.139a2.12 2.12 0 0 0-.611-1.879L2.16 9.795a.53.53 0 0 1 .294-.906l5.165-.755a2.12 2.12 0 0 0 1.597-1.16z"
},null,-1)])])}const pNe={render:dNe},hNe=Object.freeze(Object.defineProperty({
__proto__:null,default:pNe,render:dNe},Symbol.toStringTag,{value:"Module"
})),fNe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function mNe(e,t){return Ub(),Qb("svg",fNe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M4 3v4M2 5h4m14 12v2m-1-1h2m-6.937-2.5a2 2 0 0 1 1.437-1.437l6.135-1.582a.5.5 0 0 0 0-.962L15.5 9.936A2 2 0 0 1 14.063 8.5l-1.582-6.135a.5.5 0 0 0-.963 0L9.937 8.5A2 2 0 0 1 8.5 9.937l-6.135 1.581a.5.5 0 0 0 0 .964L8.5 14.063A2 2 0 0 1 9.937 15.5l1.582 6.135a.5.5 0 0 0 .963 0z"
},null,-1)])])}const gNe={render:mNe},vNe=Object.freeze(Object.defineProperty({
__proto__:null,default:gNe,render:mNe},Symbol.toStringTag,{value:"Module"
})),bNe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function yNe(e,t){return Ub(),Qb("svg",bNe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M7 11v4a2 2 0 0 0 2 2h4"},null,-1),Gb("circle",{cx:"7",cy:"7",r:"3.25",
stroke:"currentColor"},null,-1),Gb("circle",{cx:"17",cy:"17",r:"3.25",
stroke:"currentColor"},null,-1)])])}const ONe={render:yNe
},wNe=Object.freeze(Object.defineProperty({__proto__:null,default:ONe,render:yNe
},Symbol.toStringTag,{value:"Module"})),xNe={xmlns:"http://www.w3.org/2000/svg",
fill:"none",viewBox:"0 0 24 24"};function kNe(e,t){
return Ub(),Qb("svg",xNe,[...t[0]||(t[0]=[Gb("path",{stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",
d:"M15 21v-6a1 1 0 0 0-1-1h-4a1 1 0 0 0-1 1v6M3 10a2 2 0 0 1 .709-1.528l7-5.999a2 2 0 0 1 2.582 0l7 5.999A2 2 0 0 1 21 10v9a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2z"
},null,-1)])])}const SNe={render:kNe},_Ne=Object.freeze(Object.defineProperty({
__proto__:null,default:SNe,render:kNe},Symbol.toStringTag,{value:"Module"
})),TNe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function ENe(e,t){return Ub(),Qb("svg",TNe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M13.414 17.657 12 19.07A5 5 0 0 1 4.929 12l1.414-1.414m4.243-4.243L12 4.93A5 5 0 0 1 19.071 12l-1.414 1.414m-8.485 1.414 5.656-5.656"
},null,-1)])])}const ANe={render:ENe},CNe=Object.freeze(Object.defineProperty({
__proto__:null,default:ANe,render:ENe},Symbol.toStringTag,{value:"Module"
})),$Ne={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function PNe(e,t){return Ub(),Qb("svg",$Ne,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M12 2v2m0 16v2M4.93 4.93l1.41 1.41m11.32 11.32 1.41 1.41M2 12h2m16 0h2M6.34 17.66l-1.41 1.41M19.07 4.93l-1.41 1.41M16 12a4 4 0 1 1-8 0 4 4 0 0 1 8 0"
},null,-1)])])}const DNe={render:PNe},INe=Object.freeze(Object.defineProperty({
__proto__:null,default:DNe,render:PNe},Symbol.toStringTag,{value:"Module"
})),MNe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function NNe(e,t){return Ub(),Qb("svg",MNe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M5.778 10h12.444c.982 0 1.778.895 1.778 2v8c0 1.105-.796 2-1.778 2H5.778C4.796 22 4 21.105 4 20v-8c0-1.105.796-2 1.778-2M7 10V7a5 5 0 1 1 10 0v3"
},null,-1),Gb("path",{fill:"currentColor","fill-rule":"evenodd",
d:"M11 16a1 1 0 1 1 2 0 1 1 0 0 1-2 0","clip-rule":"evenodd"},null,-1)])])}
const RNe={render:NNe},LNe=Object.freeze(Object.defineProperty({__proto__:null,
default:RNe,render:NNe},Symbol.toStringTag,{value:"Module"})),BNe={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function jNe(e,t){return Ub(),Qb("svg",BNe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M5.778 10h12.444c.982 0 1.778.895 1.778 2v8c0 1.105-.796 2-1.778 2H5.778C4.796 22 4 21.105 4 20v-8c0-1.105.796-2 1.778-2M7 10V7a5 5 0 1 1 10 0v3"
},null,-1),Gb("path",{fill:"currentColor","fill-rule":"evenodd",
d:"M11 16a1 1 0 1 1 2 0 1 1 0 0 1-2 0","clip-rule":"evenodd"},null,-1)])])}
const UNe={render:jNe},zNe=Object.freeze(Object.defineProperty({__proto__:null,
default:UNe,render:jNe},Symbol.toStringTag,{value:"Module"})),FNe={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function ZNe(e,t){return Ub(),Qb("svg",FNe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M7.5 21a5.5 5.5 0 1 0 0-11 5.5 5.5 0 0 0 0 11m3.9-9.4L19 4m-3.5 3.5 3 3M22 7l-3-3"
},null,-1)])])}const QNe={render:ZNe},HNe=Object.freeze(Object.defineProperty({
__proto__:null,default:QNe,render:ZNe},Symbol.toStringTag,{value:"Module"
})),VNe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function qNe(e,t){return Ub(),Qb("svg",VNe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M11 19a8 8 0 1 0 0-16 8 8 0 0 0 0 16m10 2-4.35-4.35"},null,-1)])])}
const WNe={render:qNe},XNe=Object.freeze(Object.defineProperty({__proto__:null,
default:WNe,render:qNe},Symbol.toStringTag,{value:"Module"})),GNe={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function YNe(e,t){return Ub(),Qb("svg",GNe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M2 11.78v.44a2 2 0 0 0 2 2h.18a2 2 0 0 1 1.73 1l.25.43a2 2 0 0 1 0 2l-.08.15a2 2 0 0 0 .73 2.73l.38.22a2 2 0 0 0 2.73-.73l.1-.15a2 2 0 0 1 1.72-1h.51a2 2 0 0 1 1.74 1l.09.15a2 2 0 0 0 2.73.73l.38-.22a2 2 0 0 0 .73-2.73l-.08-.15a2 2 0 0 1 0-2l.25-.43a2 2 0 0 1 1.73-1H20a2 2 0 0 0 2-2v-.44a2 2 0 0 0-2-2h-.18a2 2 0 0 1-1.73-1l-.25-.43a2 2 0 0 1 0-2l.08-.15a2 2 0 0 0-.73-2.73l-.39-.22a2 2 0 0 0-2.73.73l-.08.15a2 2 0 0 1-1.74 1h-.5a2 2 0 0 1-1.74-1l-.09-.15a2 2 0 0 0-2.73-.73l-.38.22a2 2 0 0 0-.73 2.73l.08.15a2 2 0 0 1 0 2l-.25.43a2 2 0 0 1-1.73 1H4a2 2 0 0 0-2 2"
},null,-1),Gb("path",{stroke:"currentColor","stroke-linecap":"round",
"stroke-linejoin":"round",d:"M15 12a3 3 0 1 0-6 0 3 3 0 0 0 6 0"},null,-1)])])}
const KNe={render:YNe},JNe=Object.freeze(Object.defineProperty({__proto__:null,
default:KNe,render:YNe},Symbol.toStringTag,{value:"Module"})),eRe={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function tRe(e,t){return Ub(),Qb("svg",eRe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M16 9a5 5 0 0 1 0 6m3.364 3.364a9 9 0 0 0 0-12.728M11 4.702a.706.706 0 0 0-1.203-.498L6.413 7.587A1.4 1.4 0 0 1 5.416 8H3a1 1 0 0 0-1 1v6a1 1 0 0 0 1 1h2.416a1.4 1.4 0 0 1 .997.413l3.383 3.384A.705.705 0 0 0 11 19.298z"
},null,-1)])])}const nRe={render:tRe},rRe=Object.freeze(Object.defineProperty({
__proto__:null,default:nRe,render:tRe},Symbol.toStringTag,{value:"Module"
})),oRe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function aRe(e,t){return Ub(),Qb("svg",oRe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M11.566 18.582v2.778s3.367-.611 4.445-2.222c.58-.87.599-2.196.465-3.334m-10.698-3.01H3s.611-3.367 2.222-4.445c.87-.58 2.196-.6 3.334-.465m-.82 8.883-1.571-1.571-.625-.625a20.2 20.2 0 0 1 1.837-4.667 10.76 10.76 0 0 1 5.199-4.825c2.26-1.003 4.914-1.314 7.712-.903.486 3.46.349 9.4-5.665 12.92a20.6 20.6 0 0 1-4.73 1.828l-.586-.585zm0 0L6.165 18.34"
},null,-1)])])}const iRe={render:aRe},sRe=Object.freeze(Object.defineProperty({
__proto__:null,default:iRe,render:aRe},Symbol.toStringTag,{value:"Module"
})),lRe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function cRe(e,t){return Ub(),Qb("svg",lRe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"m9 15 3-3m5 1a6 6 0 0 0-6-6m10 6A10 10 0 0 0 11 3m-7 7a7.31 7.31 0 0 0 10 10z"
},null,-1)])])}const uRe={render:cRe},dRe=Object.freeze(Object.defineProperty({
__proto__:null,default:uRe,render:cRe},Symbol.toStringTag,{value:"Module"
})),pRe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function hRe(e,t){return Ub(),Qb("svg",pRe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M4 3v4M2 5h4m14 12v2m-1-1h2m-10.582-5.578L5.368 13.5a.763.763 0 0 1-.906-.574l-.439-1.757a.875.875 0 0 1 .565-1.034l11.036-3.629m-2.35 5.307 3.541-.755m-1.546 8.317L12.73 14.3M7.225 9.268l.91 3.642m.596 6.465 2.537-5.075m4.397-7.233a1.635 1.635 0 0 1 1.19-1.982l.89-.222a.817.817 0 0 1 .99.594l1.239 4.953a.82.82 0 0 1-.594.99l-.891.223a1.634 1.634 0 0 1-1.982-1.189zm-2.03 5.77a1.635 1.635 0 1 1-3.27 0 1.635 1.635 0 0 1 3.27 0"
},null,-1)])])}const fRe={render:hRe},mRe=Object.freeze(Object.defineProperty({
__proto__:null,default:fRe,render:hRe},Symbol.toStringTag,{value:"Module"
})),gRe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function vRe(e,t){return Ub(),Qb("svg",gRe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"m7.59 13.51 6.83 3.98m-.01-10.98-6.82 3.98M20 5a3 3 0 1 1-6 0 3 3 0 0 1 6 0M8 12a3 3 0 1 1-6 0 3 3 0 0 1 6 0m12 7a3 3 0 1 1-6 0 3 3 0 0 1 6 0"
},null,-1)])])}const bRe={render:vRe},yRe=Object.freeze(Object.defineProperty({
__proto__:null,default:bRe,render:vRe},Symbol.toStringTag,{value:"Module"
})),ORe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function wRe(e,t){return Ub(),Qb("svg",ORe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M18 12h-1.488a1.2 1.2 0 0 0-1.158.876l-1.41 5.016a.15.15 0 0 1-.288 0L10.344 6.108a.15.15 0 0 0-.288 0l-1.41 5.016A1.2 1.2 0 0 1 7.494 12H6"
},null,-1),Gb("path",{stroke:"currentColor","stroke-linecap":"round",
"stroke-linejoin":"round",
d:"M19 3H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2V5a2 2 0 0 0-2-2"
},null,-1)])])}const xRe={render:wRe},kRe=Object.freeze(Object.defineProperty({
__proto__:null,default:xRe,render:wRe},Symbol.toStringTag,{value:"Module"
})),SRe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function _Re(e,t){return Ub(),Qb("svg",SRe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M12 6v6l4 2M2 12a10 10 0 1 0 20 0 10 10 0 0 0-20 0"},null,-1)])])}const TRe={
render:_Re},ERe=Object.freeze(Object.defineProperty({__proto__:null,default:TRe,
render:_Re},Symbol.toStringTag,{value:"Module"})),ARe={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function CRe(e,t){return Ub(),Qb("svg",ARe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M17.263 5.71v.181c0 .558-.222 1.094-.617 1.489l-3.157 3.158a2.105 2.105 0 0 1-2.978 0L7.353 7.38a2.1 2.1 0 0 1-.616-1.489v-.18m10.526 0V3.605A2.105 2.105 0 0 0 15.158 1.5H8.842a2.105 2.105 0 0 0-2.105 2.105v2.106m10.526 0H6.737m0 15.789h10.526m-10.526 0 3.948-3.158a2.105 2.105 0 0 1 2.63 0l3.948 3.158m-10.526 0v-4.391c0-.559.222-1.094.616-1.489l3.158-3.158a2.105 2.105 0 0 1 2.978 0l3.157 3.158c.395.395.617.93.617 1.489V21.5"
},null,-1)])])}const $Re={render:CRe},PRe=Object.freeze(Object.defineProperty({
__proto__:null,default:$Re,render:CRe},Symbol.toStringTag,{value:"Module"
})),DRe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function IRe(e,t){return Ub(),Qb("svg",DRe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M16 21v-2a4 4 0 0 0-4-4H6a4 4 0 0 0-4 4v2m20 0v-2a4 4 0 0 0-3-3.87m-3-12a4 4 0 0 1 0 7.75M13 7a4 4 0 1 1-8 0 4 4 0 0 1 8 0"
},null,-1)])])}const MRe={render:IRe},NRe=Object.freeze(Object.defineProperty({
__proto__:null,default:MRe,render:IRe},Symbol.toStringTag,{value:"Module"
})),RRe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function LRe(e,t){return Ub(),Qb("svg",RRe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M12 2a7.071 7.071 0 1 0 10 10M12 2a10 10 0 0 0-7.071 17.071M12 2a10 10 0 0 0-7.071 17.071M22 12a10 10 0 0 1-17.071 7.071M22 12a10 10 0 0 1-17.071 7.071"
},null,-1)])])}const BRe={render:LRe},jRe=Object.freeze(Object.defineProperty({
__proto__:null,default:BRe,render:LRe},Symbol.toStringTag,{value:"Module"
})),URe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function zRe(e,t){return Ub(),Qb("svg",URe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M21 15a2 2 0 0 1-2 2H7l-4 4V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2z"},null,-1)])])}
const FRe={render:zRe},ZRe=Object.freeze(Object.defineProperty({__proto__:null,
default:FRe,render:zRe},Symbol.toStringTag,{value:"Module"})),QRe={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function HRe(e,t){return Ub(),Qb("svg",QRe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M11.023 12.976a1.8 1.8 0 0 0-.603-.397L3.284 9.718a.45.45 0 0 1 .021-.843l17.098-5.85a.446.446 0 0 1 .572.572l-5.85 17.098a.45.45 0 0 1-.843.021l-2.861-7.138a1.8 1.8 0 0 0-.398-.601Zm0 0 9.845-9.843"
},null,-1)])])}const VRe={render:HRe},qRe=Object.freeze(Object.defineProperty({
__proto__:null,default:VRe,render:HRe},Symbol.toStringTag,{value:"Module"
})),WRe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function XRe(e,t){return Ub(),Qb("svg",WRe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"m22 7-8.97 5.7a1.94 1.94 0 0 1-2.06 0L2 7m2-3h16a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2"
},null,-1)])])}const GRe={render:XRe},YRe=Object.freeze(Object.defineProperty({
__proto__:null,default:GRe,render:XRe},Symbol.toStringTag,{value:"Module"
})),KRe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function JRe(e,t){return Ub(),Qb("svg",KRe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M9 12h5M9 8h5m-9 9V5a2 2 0 0 1 2-2h13m0 0a2 2 0 0 0-2 2v14a2 2 0 0 1-2 2m4-18a2 2 0 0 1 2 2v2a1 1 0 0 1-1 1h-3m-2 13H4a2 2 0 0 1-2-2v-1a1 1 0 0 1 1-1h10a1 1 0 0 1 1 1v1a2 2 0 0 0 2 2"
},null,-1)])])}const eLe={render:JRe},tLe=Object.freeze(Object.defineProperty({
__proto__:null,default:eLe,render:JRe},Symbol.toStringTag,{value:"Module"
})),nLe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function rLe(e,t){return Ub(),Qb("svg",nLe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M12 2v20m5-17H9.5a3.5 3.5 0 1 0 0 7h5a3.5 3.5 0 1 1 0 7H6"},null,-1)])])}
const oLe={render:rLe},aLe=Object.freeze(Object.defineProperty({__proto__:null,
default:oLe,render:rLe},Symbol.toStringTag,{value:"Module"})),iLe={
xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function sLe(e,t){return Ub(),Qb("svg",iLe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"m22 7-8.5 8.5-5-5L2 17M22 7h-6m6 0v6"},null,-1)])])}const lLe={render:sLe
},cLe=Object.freeze(Object.defineProperty({__proto__:null,default:lLe,render:sLe
},Symbol.toStringTag,{value:"Module"})),uLe={xmlns:"http://www.w3.org/2000/svg",
fill:"none",viewBox:"0 0 24 24"};function dLe(e,t){
return Ub(),Qb("svg",uLe,[...t[0]||(t[0]=[Gb("path",{stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",
d:"M8 17v-7m4 7v-4m4 4V8M5 21h14a2 2 0 0 0 2-2V5a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2"
},null,-1)])])}const pLe={render:dLe},hLe=Object.freeze(Object.defineProperty({
__proto__:null,default:pLe,render:dLe},Symbol.toStringTag,{value:"Module"
})),fLe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function mLe(e,t){return Ub(),Qb("svg",fLe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M3.011 20.99c1.124-.887 2.04-1.775 3.506-1.977 1.268 0 2.49.481 3.416 1.348a3.595 3.595 0 0 0 5.561-2.115 3.146 3.146 0 0 0 3.317-4.599 3.148 3.148 0 0 0 1.234-5.241 3.145 3.145 0 1 0-4.45-4.45 3.147 3.147 0 0 0-5.24 1.234 3.146 3.146 0 0 0-4.6 3.317 3.596 3.596 0 0 0-2.11 5.533c.714 1.035 1.532 2.197 1.344 3.444-.247 1.477-1.066 2.366-1.978 3.506m0 0L16.494 7.507"
},null,-1)])])}const gLe={render:mLe},vLe=Object.freeze(Object.defineProperty({
__proto__:null,default:gLe,render:mLe},Symbol.toStringTag,{value:"Module"
})),bLe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function yLe(e,t){return Ub(),Qb("svg",bLe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M21.038 16.44v2.71a1.81 1.81 0 0 1-1.97 1.807 17.9 17.9 0 0 1-7.794-2.773 17.6 17.6 0 0 1-5.42-5.42 17.9 17.9 0 0 1-2.773-7.83 1.806 1.806 0 0 1 1.798-1.97h2.71a1.806 1.806 0 0 1 1.806 1.554 11.6 11.6 0 0 0 .632 2.538 1.8 1.8 0 0 1-.406 1.906l-1.147 1.147a14.45 14.45 0 0 0 5.42 5.42l1.146-1.148a1.81 1.81 0 0 1 1.906-.406c.82.305 1.671.518 2.538.632a1.807 1.807 0 0 1 1.554 1.833"
},null,-1)])])}const OLe={render:yLe},wLe=Object.freeze(Object.defineProperty({
__proto__:null,default:OLe,render:yLe},Symbol.toStringTag,{value:"Module"
})),xLe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function kLe(e,t){return Ub(),Qb("svg",xLe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"m8.21 2.5 1.782 1.781m4.016 0L15.79 2.5M9.158 7.36v-.947a2.845 2.845 0 1 1 5.684 0v.947M12 19.553c-3.126 0-5.684-2.558-5.684-5.685v-2.842a3.79 3.79 0 0 1 3.79-3.79h3.789a3.79 3.79 0 0 1 3.79 3.79v2.842c0 3.127-2.559 5.685-5.685 5.685m0 0v-8.527M6.818 9.132c-1.829-.19-3.344-1.8-3.344-3.79m2.842 7.58h-3.79m.948 7.578c0-1.99 1.61-3.695 3.6-3.79M20.498 5.342c0 1.99-1.516 3.6-3.316 3.79m4.292 3.79h-3.79m-.758 3.788c1.99.095 3.6 1.8 3.6 3.79"
},null,-1)])])}const SLe={render:kLe},_Le=Object.freeze(Object.defineProperty({
__proto__:null,default:SLe,render:kLe},Symbol.toStringTag,{value:"Module"
})),TLe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function ELe(e,t){return Ub(),Qb("svg",TLe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M17.662 18.661a4.33 4.33 0 1 0-2.455-7.891 6.662 6.662 0 1 0-6.537 7.89h8.993Z"
},null,-1)])])}const ALe={render:ELe},CLe=Object.freeze(Object.defineProperty({
__proto__:null,default:ALe,render:ELe},Symbol.toStringTag,{value:"Module"
})),$Le={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function PLe(e,t){return Ub(),Qb("svg",$Le,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M20 12a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v4a2 2 0 0 0 2 2m16 0H4m16 0a2 2 0 0 1 2 2v4a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-4a2 2 0 0 1 2-2"
},null,-1),Gb("path",{fill:"currentColor",
d:"M18 9a1 1 0 1 0 0-2 1 1 0 0 0 0 2m0 8a1 1 0 1 0 0-2 1 1 0 0 0 0 2"
},null,-1),Gb("path",{stroke:"currentColor","stroke-linecap":"round",
"stroke-linejoin":"round",d:"M6 8h4m-4 8h4"},null,-1)])])}const DLe={render:PLe
},ILe=Object.freeze(Object.defineProperty({__proto__:null,default:DLe,render:PLe
},Symbol.toStringTag,{value:"Module"})),MLe={xmlns:"http://www.w3.org/2000/svg",
fill:"none",viewBox:"0 0 24 24"};function NLe(e,t){
return Ub(),Qb("svg",MLe,[...t[0]||(t[0]=[Gb("path",{stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",
d:"M3 6.601c0 .955.948 1.87 2.636 2.546S9.613 10.2 12 10.2s4.676-.38 6.364-1.054C20.052 8.47 21 7.556 21 6.6m-18 0c0-.955.948-1.87 2.636-2.546C7.324 3.38 9.613 3.001 12 3.001s4.676.38 6.364 1.054C20.052 4.731 21 5.646 21 6.601m-18 0v5.4m18-5.4v5.4M3 12c0 1.987 4.03 3.6 9 3.6s9-1.612 9-3.6M3 12v5.4c0 1.987 4.03 3.6 9 3.6s9-1.613 9-3.6V12"
},null,-1)])])}const RLe={render:NLe},LLe=Object.freeze(Object.defineProperty({
__proto__:null,default:RLe,render:NLe},Symbol.toStringTag,{value:"Module"
})),BLe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function jLe(e,t){return Ub(),Qb("svg",BLe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M9 3H4a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1h5a1 1 0 0 0 1-1V4a1 1 0 0 0-1-1m11 0h-5a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1h5a1 1 0 0 0 1-1V4a1 1 0 0 0-1-1m0 11h-5a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1h5a1 1 0 0 0 1-1v-5a1 1 0 0 0-1-1M9 14H4a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1h5a1 1 0 0 0 1-1v-5a1 1 0 0 0-1-1"
},null,-1)])])}const ULe={render:jLe},zLe=Object.freeze(Object.defineProperty({
__proto__:null,default:ULe,render:jLe},Symbol.toStringTag,{value:"Module"
})),FLe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function ZLe(e,t){return Ub(),Qb("svg",FLe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M20 14h-5a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1h5a1 1 0 0 0 1-1v-5a1 1 0 0 0-1-1M9 14H4a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1h5a1 1 0 0 0 1-1v-5a1 1 0 0 0-1-1m5-11H9a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1h5a1 1 0 0 0 1-1V4a1 1 0 0 0-1-1"
},null,-1)])])}const QLe={render:ZLe},HLe=Object.freeze(Object.defineProperty({
__proto__:null,default:QLe,render:ZLe},Symbol.toStringTag,{value:"Module"
})),VLe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function qLe(e,t){return Ub(),Qb("svg",VLe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"m3.3 7 8.7 5m0 0 8.7-5M12 12v10m9-14a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l7-4A2 2 0 0 0 21 16z"
},null,-1)])])}const WLe={render:qLe},XLe=Object.freeze(Object.defineProperty({
__proto__:null,default:WLe,render:qLe},Symbol.toStringTag,{value:"Module"
})),GLe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function YLe(e,t){return Ub(),Qb("svg",GLe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"m7 14 2.5-2.5L7 9m5 7.5h5M5 4h14c1.105 0 2 .796 2 1.778v12.444c0 .982-.895 1.778-2 1.778H5c-1.105 0-2-.796-2-1.778V5.778C3 4.796 3.895 4 5 4"
},null,-1)])])}const KLe={render:YLe},JLe=Object.freeze(Object.defineProperty({
__proto__:null,default:KLe,render:YLe},Symbol.toStringTag,{value:"Module"
})),eBe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function tBe(e,t){return Ub(),Qb("svg",eBe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
"stroke-width":"1.347",
d:"M2.02 3.015h1.796l2.39 11.156a1.8 1.8 0 0 0 1.796 1.42h8.784a1.796 1.796 0 0 0 1.752-1.411l1.482-6.674H4.777"
},null,-1),Gb("path",{fill:"currentColor","fill-rule":"evenodd",
d:"M7 20a1 1 0 1 1 2 0 1 1 0 0 1-2 0m9 0a1 1 0 1 1 2 0 1 1 0 0 1-2 0",
"clip-rule":"evenodd"},null,-1)])])}const nBe={render:tBe
},rBe=Object.freeze(Object.defineProperty({__proto__:null,default:nBe,render:tBe
},Symbol.toStringTag,{value:"Module"})),oBe={xmlns:"http://www.w3.org/2000/svg",
fill:"none",viewBox:"0 0 24 24"};function aBe(e,t){
return Ub(),Qb("svg",oBe,[...t[0]||(t[0]=[Gb("path",{stroke:"currentColor",
"stroke-linecap":"round","stroke-linejoin":"round",
d:"M12 8v13m0-13c-.362-1.49-.985-2.765-1.787-3.657C9.41 3.451 8.465 2.983 7.5 3a2.5 2.5 0 1 0 0 5M12 8c.362-1.49.985-2.765 1.787-3.657.803-.892 1.748-1.36 2.713-1.343a2.5 2.5 0 0 1 0 5m2.5 4v7a2 2 0 0 1-2 2H7a2 2 0 0 1-2-2v-7M4 8h16a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H4a1 1 0 0 1-1-1V9a1 1 0 0 1 1-1"
},null,-1)])])}const iBe={render:aBe},sBe=Object.freeze(Object.defineProperty({
__proto__:null,default:iBe,render:aBe},Symbol.toStringTag,{value:"Module"
})),lBe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function cBe(e,t){return Ub(),Qb("svg",lBe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M3 9h18M3 9v10a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2V9M3 9l2.45-4.9A2 2 0 0 1 7.24 3h9.52a2 2 0 0 1 1.8 1.1L21 9m-9-6v6"
},null,-1)])])}const uBe={render:cBe},dBe=Object.freeze(Object.defineProperty({
__proto__:null,default:uBe,render:cBe},Symbol.toStringTag,{value:"Module"
})),pBe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function hBe(e,t){return Ub(),Qb("svg",pBe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M4.929 19.071a10 10 0 0 0 14.142 0m0-14.142a10 10 0 0 0-14.142 0M4 15.5v-7l2.8 7v-7m5.6 7H11a1.4 1.4 0 0 1-1.4-1.4V9.9A1.4 1.4 0 0 1 11 8.5h1.4m-2.8 4.2h2.8m2.8-4.2v1.883a8.4 8.4 0 0 0 .601 3.119L16.6 15.5l1.4-4.9 1.4 4.9.8-1.998a8.4 8.4 0 0 0 .6-3.12V8.5"
},null,-1)])])}const fBe={render:hBe},mBe=Object.freeze(Object.defineProperty({
__proto__:null,default:fBe,render:hBe},Symbol.toStringTag,{value:"Module"
})),gBe={xmlns:"http://www.w3.org/2000/svg",fill:"none",viewBox:"0 0 24 24"}
;function vBe(e,t){return Ub(),Qb("svg",gBe,[...t[0]||(t[0]=[Gb("path",{
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
d:"M7 20.5 8 14h1.08a1.48 1.48 0 0 0 1.18-.58 1.44 1.44 0 0 0 .27-1.28l-.75-3A1.49 1.49 0 0 0 8.33 8H3m16-3h-3.753a1.49 1.49 0 0 0-1.45 1.14l-.75 3a1.44 1.44 0 0 0 .28 1.28 1.48 1.48 0 0 0 1.18.58h1.58l.78 4.75a1.5 1.5 0 0 0 1.46 1.25h2M2 12a10 10 0 1 0 20 0 10 10 0 0 0-20 0"
},null,-1)])])}const bBe={render:vBe},yBe=Object.freeze(Object.defineProperty({
__proto__:null,default:bBe,render:vBe},Symbol.toStringTag,{value:"Module"}))
;const OBe=function(e){const t=Object.entries(e).map((([e,t])=>{
const n=e.replace("./icons/","").replace(".svg","");return{icon:{src:n,
title:n.replaceAll("-"," "),tags:[]},rawData:t}
})),n=t.map((e=>e.icon)),r=Object.fromEntries(t.map((e=>[e.icon.src,e.rawData])))
;return{iconDefinitionList:n,iconDataMap:r}}(Object.assign({
"./icons/basic-shape-diamond.svg":dDe,"./icons/basic-shape-hexagon.svg":mDe,
"./icons/basic-shape-primary-circle-ellipse-round.svg":yDe,
"./icons/basic-shape-primary-square-rectangle.svg":kDe,
"./icons/basic-shape-shield.svg":EDe,
"./icons/computer-device-desktop-monitor.svg":PDe,
"./icons/computer-device-desktop.svg":NDe,
"./icons/computer-device-laptop.svg":jDe,
"./icons/computer-device-mobile-phone-android-samsung-back.svg":ZDe,
"./icons/computer-device-mobile-phone-android-samsung.svg":qDe,
"./icons/computer-device-mobile-phone-iphone-x-back.svg":YDe,
"./icons/computer-device-mobile-phone-iphone-x.svg":tIe,
"./icons/computer-device-mobile-tablet-touch.svg":aIe,
"./icons/computer-device-mobile-tablet.svg":cIe,
"./icons/computer-device-network-ethernet-cat6.svg":hIe,
"./icons/computer-device-network-lan-www.svg":vIe,
"./icons/computer-device-network-wifi-connection.svg":wIe,
"./icons/computer-device-network-wifi-router.svg":_Ie,
"./icons/ecology-science-erlenmeyer-flask.svg":CIe,
"./icons/image-flash-lightning.svg":IIe,"./icons/image-picture-flower.svg":LIe,
"./icons/interface-alert-exclamation-diamond.svg":zIe,
"./icons/interface-alert-exclamation-triangle-warning.svg":HIe,
"./icons/interface-alert-information-circle.svg":XIe,
"./icons/interface-award-crown.svg":JIe,
"./icons/interface-bookmark-tag.svg":rMe,"./icons/interface-bookmark.svg":sMe,
"./icons/interface-calendar-date-one.svg":dMe,
"./icons/interface-content-book-open-pages.svg":mMe,
"./icons/interface-content-book-page.svg":yMe,
"./icons/interface-content-file.svg":kMe,
"./icons/interface-content-folder.svg":EMe,
"./icons/interface-copy-clipboard.svg":PMe,
"./icons/interface-edit-attachment.svg":NMe,
"./icons/interface-edit-binocular.svg":jMe,
"./icons/interface-edit-magic-wand.svg":ZMe,
"./icons/interface-edit-tool-paint-roller.svg":qMe,
"./icons/interface-edit-tool-pencil.svg":YMe,
"./icons/interface-favorite-award.svg":tNe,
"./icons/interface-favorite-flag.svg":aNe,
"./icons/interface-favorite-heart.svg":cNe,
"./icons/interface-favorite-star.svg":hNe,
"./icons/interface-favorite-stars-sparkles.svg":vNe,
"./icons/interface-hierarchy-flowchart.svg":wNe,
"./icons/interface-home-house.svg":_Ne,"./icons/interface-hyperlink.svg":CNe,
"./icons/interface-lighting-brightness.svg":INe,
"./icons/interface-lock-closed.svg":LNe,
"./icons/interface-lock-open-unlock.svg":zNe,
"./icons/interface-login-key.svg":HNe,"./icons/interface-search.svg":XNe,
"./icons/interface-setting-cog.svg":JNe,
"./icons/interface-share-megaphone-bullhorn.svg":rRe,
"./icons/interface-share-rocket.svg":sRe,
"./icons/interface-share-satellite.svg":dRe,
"./icons/interface-share-space-ship.svg":mRe,"./icons/interface-share.svg":yRe,
"./icons/interface-signal-square.svg":kRe,
"./icons/interface-time-clock-circle.svg":ERe,
"./icons/interface-time-hour-glass.svg":PRe,
"./icons/interface-users-multiple.svg":NRe,
"./icons/interface-weather-moon.svg":jRe,
"./icons/mail-chat-bubble-square.svg":ZRe,
"./icons/mail-send-email-paper-airplane.svg":qRe,
"./icons/mail-send-envelope.svg":YRe,"./icons/money-cashier-receipt.svg":tLe,
"./icons/money-currency-dollar-pay.svg":aLe,
"./icons/money-graph-arrow-increase.svg":cLe,
"./icons/money-graph-bar-chart-increase.svg":hLe,
"./icons/nature-ecology-leaf.svg":vLe,"./icons/phone-telephone.svg":wLe,
"./icons/programming-bug.svg":_Le,"./icons/programming-cloud.svg":CLe,
"./icons/programming-computer-database-server.svg":ILe,
"./icons/programming-computer-database.svg":LLe,
"./icons/programming-module-four-layout.svg":zLe,
"./icons/programming-module-three.svg":HLe,"./icons/programming-module.svg":XLe,
"./icons/programming-script-code.svg":JLe,"./icons/shopping-cart.svg":rBe,
"./icons/shopping-gift-present.svg":sBe,
"./icons/shopping-shipping-box-parcel-package.svg":dBe,
"./icons/tag-new-circle.svg":mBe,"./icons/travel-map-earth-globe.svg":yBe
})),wBe=OBe.iconDataMap,xBe=Qg({__name:"LibraryIcon",props:{src:{}},setup(e){
const t=e,n=Sy((()=>(e=>wBe[e])(t.src)))
;return(e,t)=>n.value?(Ub(),Hb(bv(n.value),{key:0})):ny("",!0)}}),kBe=(e,t)=>{
const n=e.__vccOpts||e;for(const[r,o]of t)n[r]=o;return n},SBe={
class:"bg-b-2 absolute top-[1lh] right-0.75 flex -translate-y-1/2 rounded p-0.25 opacity-0 peer-hover/button:opacity-100 peer-focus-visible/button:opacity-100 focus-within:opacity-100 hover:opacity-100 has-[&[aria-expanded=true]]:opacity-100"
};const _Be=kBe({},[["render",function(e,t){
return Ub(),Qb("div",SBe,[kv(e.$slots,"default")])
}]]),TBe=e=>"children"in e&&Array.isArray(e.children)&&e.children.length>0,EBe=(e,t,n)=>TBe(t)?"client"===e||"reference"===e&&("operation"!==t.type&&"webhook"!==t.type):!("client"!==e||!n)&&("document"===t.type||"tag"===t.type),ABe=jS({
base:"relative after:absolute after:inset-x-0 after:block after:bg-blue after:opacity-15 after:pointer-events-none after:rounded",
variants:{position:{before:"after:-top-0.5 after:h-0.75",
after:"after:-bottom-0.5 after:h-0.75",into:"after:inset-0"}}
}),CBe=bm(null),$Be=bm(null);function PBe(e){
const{ceiling:t=.8,floor:n=.2,isDraggable:r=!0,isDroppable:o=!0,parentIds:a=[],id:i,onDragStart:s,onDragEnd:l}=e,c=Sy((()=>a.at(-1)??null)),u=((e,t)=>{
let n=!1;return(...r)=>{n||(e(...r),n=!0,setTimeout((()=>n=!1),t))}})((e=>{
if(!CBe.value||CBe.value.id===i||a.includes(CBe.value?.id??""))return
;const r=$Be.value?.offset,s=e.target.offsetHeight,l=n*s,u=t*s;let d=null
;e.offsetY<=0&&r&&"after"!==r?d=r:e.offsetY<=l?d="before":e.offsetY>=u?d="after":e.offsetY>l&&e.offsetY<u&&(d="into"),
(e=>"function"==typeof o?o(CBe.value,{id:i,parentId:c.value,offset:e
}):km(o))(d)&&($Be.value={id:i,parentId:c.value,offset:d})}),25),d=Sy((()=>{
const e=i===$Be.value?.id?$Be.value.offset:void 0;return e?ABe({position:e}):""
}));return{draggableAttrs:Sy((()=>({class:d.value||void 0,
draggable:!!km(r)||void 0}))),draggableEvents:{dragend:()=>{
if(!$Be.value||!CBe.value)return;const e={...CBe.value},t={...$Be.value}
;CBe.value=null,
$Be.value=null,document.querySelectorAll("[data-dragging]").forEach((e=>e.removeAttribute("data-dragging"))),
e.id!==t.id&&l?.(e,t)},dragover:e=>{e.preventDefault(),e.stopPropagation(),u(e)
},dragstart:e=>{e.stopPropagation(),(e=>{
if(!(km(r)&&e.dataTransfer&&e.target instanceof HTMLElement))return
;e.target.setAttribute("data-dragging","true"),e.dataTransfer.dropEffect="move",
e.dataTransfer.effectAllowed="move";const t={id:i,parentId:c.value};CBe.value=t,
s?.(t)})(e)}},draggingItem:CBe,hoveredItem:$Be}}const DBe=Qg({
__name:"SidebarHttpBadge",props:{method:{},active:{type:Boolean},webhook:{
type:Boolean}},setup:e=>(t,n)=>(Ub(),Hb(iDe,{
class:Ih(["sidebar-heading-type",`sidebar-heading-type--${e.method.toLowerCase()}`,{
"sidebar-heading-type-active":e.active}]),method:e.method,
property:"--method-color",short:""},{default:ig((()=>[n[0]||(n[0]=Gb("span",{
class:"sr-only"
},"HTTP Method: ",-1)),kv(t.$slots,"default",{},(()=>[e.webhook?(Ub(),
Hb(xm(T$),{key:0,style:Ah({color:xm(CH)(e.method).colorVar}),weight:"bold"
},null,8,["style"])):ny("",!0)]),!0)])),_:3},8,["class","method"]))
}),IBe=kBe(DBe,[["__scopeId","data-v-1857170e"]]),MBe=Qg({
__name:"SidebarItemLabel",props:{item:{},operationTitleSource:{}},
setup:e=>(t,n)=>"model"===e.item.type?(Ub(),Hb(xm(Zoe),{key:0,preset:"property",
text:e.item.title},null,8,["text"])):(Ub(),Hb(xm(Zoe),{key:1,
text:"path"===e.operationTitleSource&&"path"in e.item?e.item.path:e.item.title
},null,8,["text"]))}),NBe={key:0,class:"line-through"},RBe={key:0,
class:"line-through"},LBe=Qg({__name:"SidebarItem",props:{item:{},layout:{},
isSelected:{type:Function},isExpanded:{type:Function},options:{},isDraggable:{},
isDroppable:{type:Function}},emits:["selectItem","onDragEnd"],setup(e,{emit:t}){
const n=t,r=$v(),o=e=>("isDeprecated"in e&&e.isDeprecated)??!1,a=(e,t)=>{
n("onDragEnd",e,t)},{draggableAttrs:i,draggableEvents:s}=PBe({id:e.item.id,
isDraggable:e.isDraggable,isDroppable:e.isDroppable,onDragEnd:a});return(t,l)=>{
const c=gv("SidebarItem",!0)
;return xm(TBe)(e.item)&&(e=>"isGroup"in e&&e.isGroup)(e.item)?(Ub(),
Hb(xm(Ooe),iy({key:0},xm(i),_v(xm(s))),{
items:ig((()=>[(Ub(!0),Qb(Mb,null,wv(xm(sDe)(e.layout,e.item.children),(o=>(Ub(),
Hb(c,{key:o.id,isDraggable:e.isDraggable,isDroppable:e.isDroppable,
isExpanded:e.isExpanded,isSelected:e.isSelected,item:o,layout:e.layout,
options:e.options,onOnDragEnd:a,onSelectItem:l[0]||(l[0]=e=>n("selectItem",e))
},xv({_:2},[r.decorator?{name:"decorator",
fn:ig((e=>[kv(t.$slots,"decorator",iy({ref_for:!0},e))])),key:"0"
}:void 0,r.empty?{name:"empty",fn:ig((e=>[kv(t.$slots,"empty",iy({ref_for:!0
},e))])),key:"1"}:void 0,r.icon?{name:"icon",fn:ig((e=>[kv(t.$slots,"icon",iy({
ref_for:!0},e))])),key:"2"
}:void 0]),1032,["isDraggable","isDroppable","isExpanded","isSelected","item","layout","options"])))),128))])),
default:ig((()=>[ey(Uh(e.item.title)+" ",1)])),_:3
},16)):xm(EBe)(e.layout,e.item,void 0!==r.empty)?(Ub(),Hb(xm(doe),iy({key:1,
active:e.isSelected(e.item.id),class:"relative",controlled:"",
open:e.isExpanded(e.item.id)},xm(i),_v(xm(s)),{
onClick:l[2]||(l[2]=()=>n("selectItem",e.item.id))}),xv({items:ig((()=>[(Ub(!0),
Qb(Mb,null,wv(xm(sDe)(e.layout,e.item.children??[]),(o=>(Ub(),Hb(c,{key:o.id,
isDraggable:e.isDraggable,isDroppable:e.isDroppable,isExpanded:e.isExpanded,
isSelected:e.isSelected,item:o,layout:e.layout,options:e.options,parentIds:[],
onOnDragEnd:a,onSelectItem:l[1]||(l[1]=e=>n("selectItem",e))},xv({_:2
},[r.decorator?{name:"decorator",fn:ig((e=>[kv(t.$slots,"decorator",iy({
ref_for:!0},e))])),key:"0"}:void 0,r.empty?{name:"empty",
fn:ig((e=>[kv(t.$slots,"empty",iy({ref_for:!0},e))])),key:"1"}:void 0,r.icon?{
name:"icon",fn:ig((e=>[kv(t.$slots,"icon",iy({ref_for:!0},e))])),key:"2"
}:void 0]),1032,["isDraggable","isDroppable","isExpanded","isSelected","item","layout","options"])))),128)),r.empty&&0===(e.item.children?.length??0)?kv(t.$slots,"empty",{
key:0,item:e.item}):ny("",!0)])),
default:ig((()=>[o(e.item)?(Ub(),Qb("span",NBe,[Yb(MBe,{item:e.item,
operationTitleSource:e.options?.operationTitleSource
},null,8,["item","operationTitleSource"])])):(Ub(),Hb(MBe,{key:1,item:e.item,
operationTitleSource:e.options?.operationTitleSource
},null,8,["item","operationTitleSource"]))])),_:2},["document"===e.item.type?{
name:"icon",fn:ig((({open:n})=>[kv(t.$slots,"icon",{item:e.item,open:n
},(()=>[Yb(xm(xBe),{class:"text-c-3 block group-hover/group-button:hidden",
src:"icon"in e.item&&e.item.icon||"interface-content-folder"
},null,8,["src"]),Yb(xm(ooe),{
class:"text-c-3 hidden group-hover/group-button:flex",open:n
},null,8,["open"])]))])),key:"0"}:void 0,"method"in e.item?{name:"aside",
fn:ig((()=>["method"in e.item?(Ub(),Hb(IBe,{key:0,
active:e.isSelected(e.item.id),class:Ih(["ml-2 h-4 self-start",{
"group-hover/button:opacity-0 group-focus-visible/button:opacity-0 group-has-[~*_[aria-expanded=true]]/button:opacity-0 group-has-[~*:focus-within]/button:opacity-0 group-has-[~*:hover]/button:opacity-0":r.decorator
}]),method:e.item.method,webhook:"webhook"===e.item.type
},null,8,["active","class","method","webhook"])):ny("",!0)])),key:"1"
}:void 0,r.decorator?{name:"after",fn:ig((()=>[Yb(_Be,null,{
default:ig((()=>[kv(t.$slots,"decorator",{item:e.item})])),_:3})])),key:"2"
}:void 0]),1040,["active","open"])):(Ub(),Hb(xm(poe),iy({key:2,is:"button"
},xm(i),{class:"relative",selected:e.isSelected(e.item.id)},_v(xm(s)),{
onClick:l[3]||(l[3]=()=>n("selectItem",e.item.id))}),xv({
default:ig((()=>[o(e.item)?(Ub(),Qb("span",RBe,[Yb(MBe,{item:e.item,
operationTitleSource:e.options?.operationTitleSource
},null,8,["item","operationTitleSource"])])):(Ub(),Hb(MBe,{key:1,item:e.item,
operationTitleSource:e.options?.operationTitleSource
},null,8,["item","operationTitleSource"]))])),_:2},[r.icon?{name:"icon",
fn:ig((()=>[kv(t.$slots,"icon",{item:e.item,open:!0})])),key:"0"
}:void 0,"method"in e.item?{name:"aside",
fn:ig((()=>["method"in e.item?(Ub(),Hb(IBe,{key:0,
active:e.isSelected(e.item.id),class:Ih(["ml-2 h-4 self-start",{
"group-hover/button:opacity-0 group-focus-visible/button:opacity-0 group-has-[~*_[aria-expanded=true]]/button:opacity-0 group-has-[~*:focus-within]/button:opacity-0 group-has-[~*:hover]/button:opacity-0":r.decorator
}]),method:e.item.method,webhook:"webhook"===e.item.type
},null,8,["active","class","method","webhook"])):ny("",!0)])),key:"1"
}:void 0,r.decorator?{name:"after",fn:ig((()=>[Yb(_Be,null,{
default:ig((()=>[kv(t.$slots,"decorator",{item:e.item})])),_:3})])),key:"2"
}:void 0]),1040,["selected"]))}}}),BBe=Qg({__name:"ScalarSidebar",props:{
layout:{},items:{},isSelected:{type:Function},isExpanded:{type:Function},
options:{},indent:{default:20},isDraggable:{},isDroppable:{type:Function}},
emits:["reorder","selectItem"],setup(e,{emit:t}){const n=t,r=$v(),o=(e,t)=>{
n("reorder",e,t)};return(t,a)=>(Ub(),Hb(xm(Wre),{class:"flex min-h-0 flex-col",
style:Ah({"--scalar-sidebar-indent":e.indent+"px"})},{
default:ig((()=>[kv(t.$slots,"header"),kv(t.$slots,"default",{},(()=>[Yb(xm(foe),{
class:"custom-scroll pt-0"},{
default:ig((()=>[kv(t.$slots,"before"),(Ub(!0),Qb(Mb,null,wv(xm(sDe)(e.layout,e.items),(i=>(Ub(),
Hb(LBe,{key:i.id,isDraggable:e.isDraggable??"client"===e.layout,
isDroppable:e.isDroppable,isExpanded:e.isExpanded,isSelected:e.isSelected,
item:i,layout:e.layout,options:e.options,onOnDragEnd:o,
onSelectItem:a[0]||(a[0]=e=>n("selectItem",e))},xv({_:2},[r.decorator?{
name:"decorator",fn:ig((e=>[kv(t.$slots,"decorator",iy({ref_for:!0},e))])),
key:"0"}:void 0,r.empty?{name:"empty",fn:ig((e=>[kv(t.$slots,"empty",iy({
ref_for:!0},e))])),key:"1"}:void 0,r.icon?{name:"icon",
fn:ig((e=>[kv(t.$slots,"icon",iy({ref_for:!0},e))])),key:"2"
}:void 0]),1032,["isDraggable","isDroppable","isExpanded","isSelected","item","layout","options"])))),128))])),
_:3}),a[1]||(a[1]=Gb("div",{class:"flex-1"
},null,-1))])),kv(t.$slots,"footer")])),_:3},8,["style"]))}
}),jBe=({items:e,nestedKey:t="children",filter:n=()=>!0,getId:r=e=>e.id})=>{
const o=new Map,a=e=>{
n(e)&&o.set(r(e),e),t in e&&Array.isArray(e[t])&&e[t]?.forEach((t=>a({...t,
parent:e})))};return e.forEach(a),o},UBe=(e,t)=>{const n=Sy((()=>jBe({
items:km(e),nestedKey:t?.key??"children"}))),r=bm({}),o=bm({}),a=bm(null)
;return{items:Sy((()=>km(e))),index:n,selectedItems:r,expandedItems:o,
selectedItem:a,setSelected:e=>{const o=e=>{
e&&(r.value[e.id]=!0,"parent"in e&&e.parent&&o(e.parent))}
;t?.hooks?.onBeforeSelect&&t.hooks.onBeforeSelect(e),
r.value={},a.value=e,null!==e&&o(n.value.get(e)),
t?.hooks?.onAfterSelect&&t.hooks.onAfterSelect(e)},setExpanded:(e,r)=>{
const a=e=>{e&&(o.value[e.id]=!0,"parent"in e&&e.parent&&a(e.parent))}
;t?.hooks?.onBeforeExpand&&t.hooks.onBeforeExpand(e),
!1===r?o.value[e]=!1:a(n.value.get(e)),
t?.hooks?.onAfterExpand&&t.hooks.onAfterExpand(e)},isExpanded:e=>o.value[e]??!1,
isSelected:e=>r.value[e]??!1,getEntryById:e=>n.value.get(e),reset:()=>{
r.value={},o.value={}}}},zBe=(e,t)=>{if(t.type===e)return t
;if("children"in t)for(const n of t.children??[]){const t=zBe(e,n);if(t)return t
}return null
},FBe=({document:e,path:t,method:n,example:r})=>JSON.stringify([e,t,n,r].filter(xH))
;var ZBe=["input:not([inert])","select:not([inert])","textarea:not([inert])","a[href]:not([inert])","button:not([inert])","[tabindex]:not(slot):not([inert])","audio[controls]:not([inert])","video[controls]:not([inert])",'[contenteditable]:not([contenteditable="false"]):not([inert])',"details>summary:first-of-type:not([inert])","details:not([inert])"],QBe=ZBe.join(","),HBe="undefined"==typeof Element,VBe=HBe?function(){}:Element.prototype.matches||Element.prototype.msMatchesSelector||Element.prototype.webkitMatchesSelector,qBe=!HBe&&Element.prototype.getRootNode?function(e){
var t;return null==e||null===(t=e.getRootNode)||void 0===t?void 0:t.call(e)
}:function(e){return null==e?void 0:e.ownerDocument},WBe=function e(t,n){var r
;void 0===n&&(n=!0)
;var o=null==t||null===(r=t.getAttribute)||void 0===r?void 0:r.call(t,"inert")
;return""===o||"true"===o||n&&t&&e(t.parentNode)},XBe=function(e,t,n){
if(WBe(e))return[];var r=Array.prototype.slice.apply(e.querySelectorAll(QBe))
;return t&&VBe.call(e,QBe)&&r.unshift(e),r=r.filter(n)},GBe=function e(t,n,r){
for(var o=[],a=Array.from(t);a.length;){var i=a.shift()
;if(!WBe(i,!1))if("SLOT"===i.tagName){
var s=i.assignedElements(),l=e(s.length?s:i.children,!0,r)
;r.flatten?o.push.apply(o,l):o.push({scopeParent:i,candidates:l})}else{
VBe.call(i,QBe)&&r.filter(i)&&(n||!t.includes(i))&&o.push(i)
;var c=i.shadowRoot||"function"==typeof r.getShadowRoot&&r.getShadowRoot(i),u=!WBe(c,!1)&&(!r.shadowRootFilter||r.shadowRootFilter(i))
;if(c&&u){var d=e(!0===c?i.children:c.children,!0,r)
;r.flatten?o.push.apply(o,d):o.push({scopeParent:i,candidates:d})
}else a.unshift.apply(a,i.children)}}return o},YBe=function(e){
return!isNaN(parseInt(e.getAttribute("tabindex"),10))},KBe=function(e){
if(!e)throw new Error("No node provided")
;return e.tabIndex<0&&(/^(AUDIO|VIDEO|DETAILS)$/.test(e.tagName)||function(e){
var t,n=null==e||null===(t=e.getAttribute)||void 0===t?void 0:t.call(e,"contenteditable")
;return""===n||"true"===n}(e))&&!YBe(e)?0:e.tabIndex},JBe=function(e,t){
return e.tabIndex===t.tabIndex?e.documentOrder-t.documentOrder:e.tabIndex-t.tabIndex
},eje=function(e){return"INPUT"===e.tagName},tje=function(e){return function(e){
return eje(e)&&"radio"===e.type}(e)&&!function(e){if(!e.name)return!0
;var t,n=e.form||qBe(e),r=function(e){
return n.querySelectorAll('input[type="radio"][name="'+e+'"]')}
;if("undefined"!=typeof window&&void 0!==window.CSS&&"function"==typeof window.CSS.escape)t=r(window.CSS.escape(e.name));else try{
t=r(e.name)}catch(a){
return console.error("Looks like you have a radio button with a name attribute containing invalid CSS selector characters and need the CSS.escape polyfill: %s",a.message),
!1}var o=function(e,t){
for(var n=0;n<e.length;n++)if(e[n].checked&&e[n].form===t)return e[n]}(t,e.form)
;return!o||o===e}(e)},nje=function(e){
var t=e.getBoundingClientRect(),n=t.width,r=t.height;return 0===n&&0===r
},rje=function(e,t){var n=t.displayCheck,r=t.getShadowRoot
;if("hidden"===getComputedStyle(e).visibility)return!0
;var o=VBe.call(e,"details>summary:first-of-type")?e.parentElement:e
;if(VBe.call(o,"details:not([open]) *"))return!0
;if(n&&"full"!==n&&"legacy-full"!==n){if("non-zero-area"===n)return nje(e)}else{
if("function"==typeof r){for(var a=e;e;){var i=e.parentElement,s=qBe(e)
;if(i&&!i.shadowRoot&&!0===r(i))return nje(e)
;e=e.assignedSlot?e.assignedSlot:i||s===e.ownerDocument?i:s.host}e=a}
if(function(e){
var t,n,r,o,a=e&&qBe(e),i=null===(t=a)||void 0===t?void 0:t.host,s=!1
;if(a&&a!==e)for(s=!!(null!==(n=i)&&void 0!==n&&null!==(r=n.ownerDocument)&&void 0!==r&&r.contains(i)||null!=e&&null!==(o=e.ownerDocument)&&void 0!==o&&o.contains(e));!s&&i;){
var l,c,u
;s=!(null===(c=i=null===(l=a=qBe(i))||void 0===l?void 0:l.host)||void 0===c||null===(u=c.ownerDocument)||void 0===u||!u.contains(i))
}return s}(e))return!e.getClientRects().length;if("legacy-full"!==n)return!0}
return!1},oje=function(e,t){return!(t.disabled||WBe(t)||function(e){
return eje(e)&&"hidden"===e.type}(t)||rje(t,e)||function(e){
return"DETAILS"===e.tagName&&Array.prototype.slice.apply(e.children).some((function(e){
return"SUMMARY"===e.tagName}))}(t)||function(e){
if(/^(INPUT|BUTTON|SELECT|TEXTAREA)$/.test(e.tagName))for(var t=e.parentElement;t;){
if("FIELDSET"===t.tagName&&t.disabled){for(var n=0;n<t.children.length;n++){
var r=t.children.item(n)
;if("LEGEND"===r.tagName)return!!VBe.call(t,"fieldset[disabled] *")||!r.contains(e)
}return!0}t=t.parentElement}return!1}(t))},aje=function(e,t){
return!(tje(t)||KBe(t)<0||!oje(e,t))},ije=function(e){
var t=parseInt(e.getAttribute("tabindex"),10);return!!(isNaN(t)||t>=0)
},sje=function e(t){var n=[],r=[];return t.forEach((function(t,o){
var a=!!t.scopeParent,i=a?t.scopeParent:t,s=function(e,t){var n=KBe(e)
;return n<0&&t&&!YBe(e)?0:n}(i,a),l=a?e(t.candidates):i
;0===s?a?n.push.apply(n,l):n.push(i):r.push({documentOrder:o,tabIndex:s,item:t,
isScope:a,content:l})})),r.sort(JBe).reduce((function(e,t){
return t.isScope?e.push.apply(e,t.content):e.push(t.content),e}),[]).concat(n)
},lje=function(e,t){if(t=t||{},!e)throw new Error("No node provided")
;return!1!==VBe.call(e,QBe)&&aje(t,e)
},cje=ZBe.concat("iframe").join(","),uje=function(e,t){
if(t=t||{},!e)throw new Error("No node provided")
;return!1!==VBe.call(e,cje)&&oje(t,e)};function dje(e,t){
(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n]
;return r}function pje(e,t,n){return(t=function(e){var t=function(e,t){
if("object"!=typeof e||!e)return e;var n=e[Symbol.toPrimitive];if(void 0!==n){
var r=n.call(e,t);if("object"!=typeof r)return r
;throw new TypeError("@@toPrimitive must return a primitive value.")}
return("string"===t?String:Number)(e)}(e,"string")
;return"symbol"==typeof t?t:t+""}(t))in e?Object.defineProperty(e,t,{value:n,
enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function hje(e,t){
var n=Object.keys(e);if(Object.getOwnPropertySymbols){
var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter((function(t){
return Object.getOwnPropertyDescriptor(e,t).enumerable}))),n.push.apply(n,r)}
return n}function fje(e){for(var t=1;t<arguments.length;t++){
var n=null!=arguments[t]?arguments[t]:{}
;t%2?hje(Object(n),!0).forEach((function(t){pje(e,t,n[t])
})):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):hje(Object(n)).forEach((function(t){
Object.defineProperty(e,t,Object.getOwnPropertyDescriptor(n,t))}))}return e}
function mje(e){return function(e){if(Array.isArray(e))return dje(e)
}(e)||function(e){
if("undefined"!=typeof Symbol&&null!=e[Symbol.iterator]||null!=e["@@iterator"])return Array.from(e)
}(e)||function(e,t){if(e){if("string"==typeof e)return dje(e,t)
;var n={}.toString.call(e).slice(8,-1)
;return"Object"===n&&e.constructor&&(n=e.constructor.name),
"Map"===n||"Set"===n?Array.from(e):"Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?dje(e,t):void 0
}}(e)||function(){
throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")
}()}var gje=function(e,t){if(e.length>0){var n=e[e.length-1];n!==t&&n.pause()}
var r=e.indexOf(t);-1===r||e.splice(r,1),e.push(t)},vje=function(e,t){
var n=e.indexOf(t);-1!==n&&e.splice(n,1),e.length>0&&e[e.length-1].unpause()
},bje=function(e){
return"Tab"===(null==e?void 0:e.key)||9===(null==e?void 0:e.keyCode)
},yje=function(e){return bje(e)&&!e.shiftKey},Oje=function(e){
return bje(e)&&e.shiftKey},wje=function(e){return setTimeout(e,0)
},xje=function(e){
for(var t=arguments.length,n=new Array(t>1?t-1:0),r=1;r<t;r++)n[r-1]=arguments[r]
;return"function"==typeof e?e.apply(void 0,n):e},kje=function(e){
return e.target.shadowRoot&&"function"==typeof e.composedPath?e.composedPath()[0]:e.target
},Sje=[],_je=function(e,t){
var n,r=(null==t?void 0:t.document)||document,o=(null==t?void 0:t.trapStack)||Sje,a=fje({
returnFocusOnDeactivate:!0,escapeDeactivates:!0,delayInitialFocus:!0,
isKeyForward:yje,isKeyBackward:Oje},t),i={containers:[],containerGroups:[],
tabbableGroups:[],nodeFocusedBeforeActivation:null,mostRecentlyFocusedNode:null,
active:!1,paused:!1,delayInitialFocusTimer:void 0,recentNavEvent:void 0
},s=function(e,t,n){return e&&void 0!==e[t]?e[t]:a[n||t]},l=function(e,t){
var n="function"==typeof(null==t?void 0:t.composedPath)?t.composedPath():void 0
;return i.containerGroups.findIndex((function(t){
var r=t.container,o=t.tabbableNodes
;return r.contains(e)||(null==n?void 0:n.includes(r))||o.find((function(t){
return t===e}))}))},c=function(e){
var t=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},n=t.hasFallback,o=void 0!==n&&n,i=t.params,s=void 0===i?[]:i,l=a[e]
;if("function"==typeof l&&(l=l.apply(void 0,mje(s))),!0===l&&(l=void 0),!l){
if(void 0===l||!1===l)return l
;throw new Error("`".concat(e,"` was specified but was not a node, or did not return a node"))
}var c=l;if("string"==typeof l){try{c=r.querySelector(l)}catch(u){
throw new Error("`".concat(e,'` appears to be an invalid selector; error="').concat(u.message,'"'))
}
if(!c&&!o)throw new Error("`".concat(e,"` as selector refers to no known node"))
}return c},u=function(){var e=c("initialFocus",{hasFallback:!0})
;if(!1===e)return!1
;if(void 0===e||e&&!uje(e,a.tabbableOptions))if(l(r.activeElement)>=0)e=r.activeElement;else{
var t=i.tabbableGroups[0];e=t&&t.firstTabbableNode||c("fallbackFocus")
}else null===e&&(e=c("fallbackFocus"))
;if(!e)throw new Error("Your focus-trap needs to have at least one focusable element")
;return e},d=function(){if(i.containerGroups=i.containers.map((function(e){
var t=function(e,t){var n
;return n=(t=t||{}).getShadowRoot?GBe([e],t.includeContainer,{
filter:aje.bind(null,t),flatten:!1,getShadowRoot:t.getShadowRoot,
shadowRootFilter:ije}):XBe(e,t.includeContainer,aje.bind(null,t)),sje(n)
}(e,a.tabbableOptions),n=function(e,t){
return(t=t||{}).getShadowRoot?GBe([e],t.includeContainer,{
filter:oje.bind(null,t),flatten:!0,getShadowRoot:t.getShadowRoot
}):XBe(e,t.includeContainer,oje.bind(null,t))
}(e,a.tabbableOptions),r=t.length>0?t[0]:void 0,o=t.length>0?t[t.length-1]:void 0,i=n.find((function(e){
return lje(e)})),s=n.slice().reverse().find((function(e){return lje(e)
})),l=!!t.find((function(e){return KBe(e)>0}));return{container:e,
tabbableNodes:t,focusableNodes:n,posTabIndexesFound:l,firstTabbableNode:r,
lastTabbableNode:o,firstDomTabbableNode:i,lastDomTabbableNode:s,
nextTabbableNode:function(e){
var r=!(arguments.length>1&&void 0!==arguments[1])||arguments[1],o=t.indexOf(e)
;return o<0?r?n.slice(n.indexOf(e)+1).find((function(e){return lje(e)
})):n.slice(0,n.indexOf(e)).reverse().find((function(e){return lje(e)
})):t[o+(r?1:-1)]}}})),i.tabbableGroups=i.containerGroups.filter((function(e){
return e.tabbableNodes.length>0
})),i.tabbableGroups.length<=0&&!c("fallbackFocus"))throw new Error("Your focus-trap must have at least one container with at least one tabbable node in it at all times")
;if(i.containerGroups.find((function(e){return e.posTabIndexesFound
}))&&i.containerGroups.length>1)throw new Error("At least one node with a positive tabindex was found in one of your focus-trap's multiple containers. Positive tabindexes are only supported in single-container focus-traps.")
},p=function(e){var t=e.activeElement
;if(t)return t.shadowRoot&&null!==t.shadowRoot.activeElement?p(t.shadowRoot):t
},h=function(e){!1!==e&&e!==p(document)&&(e&&e.focus?(e.focus({
preventScroll:!!a.preventScroll}),i.mostRecentlyFocusedNode=e,function(e){
return e.tagName&&"input"===e.tagName.toLowerCase()&&"function"==typeof e.select
}(e)&&e.select()):h(u()))},f=function(e){var t=c("setReturnFocus",{params:[e]})
;return t||!1!==t&&e},m=function(e){
var t=e.target,n=e.event,r=e.isBackward,o=void 0!==r&&r;t=t||kje(n),d()
;var s=null;if(i.tabbableGroups.length>0){
var u=l(t,n),p=u>=0?i.containerGroups[u]:void 0
;if(u<0)s=o?i.tabbableGroups[i.tabbableGroups.length-1].lastTabbableNode:i.tabbableGroups[0].firstTabbableNode;else if(o){
var h=i.tabbableGroups.findIndex((function(e){var n=e.firstTabbableNode
;return t===n}))
;if(h<0&&(p.container===t||uje(t,a.tabbableOptions)&&!lje(t,a.tabbableOptions)&&!p.nextTabbableNode(t,!1))&&(h=u),
h>=0){var f=0===h?i.tabbableGroups.length-1:h-1,m=i.tabbableGroups[f]
;s=KBe(t)>=0?m.lastTabbableNode:m.lastDomTabbableNode
}else bje(n)||(s=p.nextTabbableNode(t,!1))}else{
var g=i.tabbableGroups.findIndex((function(e){var n=e.lastTabbableNode
;return t===n}))
;if(g<0&&(p.container===t||uje(t,a.tabbableOptions)&&!lje(t,a.tabbableOptions)&&!p.nextTabbableNode(t))&&(g=u),
g>=0){var v=g===i.tabbableGroups.length-1?0:g+1,b=i.tabbableGroups[v]
;s=KBe(t)>=0?b.firstTabbableNode:b.firstDomTabbableNode
}else bje(n)||(s=p.nextTabbableNode(t))}}else s=c("fallbackFocus");return s
},g=function(e){var t=kje(e)
;l(t,e)>=0||(xje(a.clickOutsideDeactivates,e)?n.deactivate({
returnFocus:a.returnFocusOnDeactivate
}):xje(a.allowOutsideClick,e)||e.preventDefault())},v=function(e){
var t=kje(e),n=l(t,e)>=0
;if(n||t instanceof Document)n&&(i.mostRecentlyFocusedNode=t);else{var r
;e.stopImmediatePropagation();var o=!0
;if(i.mostRecentlyFocusedNode)if(KBe(i.mostRecentlyFocusedNode)>0){
var s=l(i.mostRecentlyFocusedNode),c=i.containerGroups[s].tabbableNodes
;if(c.length>0){var d=c.findIndex((function(e){
return e===i.mostRecentlyFocusedNode}))
;d>=0&&(a.isKeyForward(i.recentNavEvent)?d+1<c.length&&(r=c[d+1],
o=!1):d-1>=0&&(r=c[d-1],o=!1))}}else i.containerGroups.some((function(e){
return e.tabbableNodes.some((function(e){return KBe(e)>0}))}))||(o=!1);else o=!1
;o&&(r=m({target:i.mostRecentlyFocusedNode,
isBackward:a.isKeyBackward(i.recentNavEvent)
})),h(r||(i.mostRecentlyFocusedNode||u()))}i.recentNavEvent=void 0
},b=function(e){(a.isKeyForward(e)||a.isKeyBackward(e))&&function(e){
var t=arguments.length>1&&void 0!==arguments[1]&&arguments[1];i.recentNavEvent=e
;var n=m({event:e,isBackward:t});n&&(bje(e)&&e.preventDefault(),h(n))
}(e,a.isKeyBackward(e))},y=function(e){(function(e){
return"Escape"===(null==e?void 0:e.key)||"Esc"===(null==e?void 0:e.key)||27===(null==e?void 0:e.keyCode)
})(e)&&!1!==xje(a.escapeDeactivates,e)&&(e.preventDefault(),n.deactivate())
},O=function(e){var t=kje(e)
;l(t,e)>=0||xje(a.clickOutsideDeactivates,e)||xje(a.allowOutsideClick,e)||(e.preventDefault(),
e.stopImmediatePropagation())},w=function(){
if(i.active)return gje(o,n),i.delayInitialFocusTimer=a.delayInitialFocus?wje((function(){
h(u())
})):h(u()),r.addEventListener("focusin",v,!0),r.addEventListener("mousedown",g,{
capture:!0,passive:!1}),r.addEventListener("touchstart",g,{capture:!0,passive:!1
}),r.addEventListener("click",O,{capture:!0,passive:!1
}),r.addEventListener("keydown",b,{capture:!0,passive:!1
}),r.addEventListener("keydown",y),n},x=function(){
if(i.active)return r.removeEventListener("focusin",v,!0),
r.removeEventListener("mousedown",g,!0),
r.removeEventListener("touchstart",g,!0),
r.removeEventListener("click",O,!0),r.removeEventListener("keydown",b,!0),
r.removeEventListener("keydown",y),n
},k="undefined"!=typeof window&&"MutationObserver"in window?new MutationObserver((function(e){
e.some((function(e){return Array.from(e.removedNodes).some((function(e){
return e===i.mostRecentlyFocusedNode}))}))&&h(u())})):void 0,S=function(){
k&&(k.disconnect(),i.active&&!i.paused&&i.containers.map((function(e){
k.observe(e,{subtree:!0,childList:!0})})))};return(n={get active(){
return i.active},get paused(){return i.paused},activate:function(e){
if(i.active)return this
;var t=s(e,"onActivate"),n=s(e,"onPostActivate"),o=s(e,"checkCanFocusTrap")
;o||d(),
i.active=!0,i.paused=!1,i.nodeFocusedBeforeActivation=r.activeElement,null==t||t()
;var a=function(){o&&d(),w(),S(),null==n||n()}
;return o?(o(i.containers.concat()).then(a,a),this):(a(),this)},
deactivate:function(e){if(!i.active)return this;var t=fje({
onDeactivate:a.onDeactivate,onPostDeactivate:a.onPostDeactivate,
checkCanReturnFocus:a.checkCanReturnFocus},e)
;clearTimeout(i.delayInitialFocusTimer),
i.delayInitialFocusTimer=void 0,x(),i.active=!1,i.paused=!1,S(),vje(o,n)
;var r=s(t,"onDeactivate"),l=s(t,"onPostDeactivate"),c=s(t,"checkCanReturnFocus"),u=s(t,"returnFocus","returnFocusOnDeactivate")
;null==r||r();var d=function(){wje((function(){
u&&h(f(i.nodeFocusedBeforeActivation)),null==l||l()}))}
;return u&&c?(c(f(i.nodeFocusedBeforeActivation)).then(d,d),this):(d(),this)},
pause:function(e){if(i.paused||!i.active)return this
;var t=s(e,"onPause"),n=s(e,"onPostPause")
;return i.paused=!0,null==t||t(),x(),S(),null==n||n(),this},unpause:function(e){
if(!i.paused||!i.active)return this
;var t=s(e,"onUnpause"),n=s(e,"onPostUnpause")
;return i.paused=!1,null==t||t(),d(),w(),S(),null==n||n(),this},
updateContainerElements:function(e){var t=[].concat(e).filter(Boolean)
;return i.containers=t.map((function(e){
return"string"==typeof e?r.querySelector(e):e})),i.active&&d(),S(),this}
}).updateContainerElements(e),n}
;const Tje=e=>Object.entries(e),Eje=(e,t,n=!1,r=new Set)=>{
for(const a in t)if(a in e){
const i=e[a],s=t[a],l=n&&(Array.isArray(i)||Array.isArray(s))
;if("object"!=typeof i||null===i||"object"!=typeof s||null===s||l)try{e[a]=s
}catch(o){console.warn(`Issue setting ${a} on object`),console.warn(o)}else{
const e=sSe(i),t=sSe(s);if(r.has(e)||r.has(t))continue
;r.add(e),r.add(t),Eje(i,s,n,r)}}else e[a]=t[a];return e};let Aje=function(e){
switch(e.errorType){case Kje.ArrayContains:
return"Expected array to contain at least one matching value"
;case Kje.ArrayMaxContains:
return`Expected array to contain no more than ${e.schema.maxContains} matching values`
;case Kje.ArrayMinContains:
return`Expected array to contain at least ${e.schema.minContains} matching values`
;case Kje.ArrayMaxItems:
return`Expected array length to be less or equal to ${e.schema.maxItems}`
;case Kje.ArrayMinItems:
return`Expected array length to be greater or equal to ${e.schema.minItems}`
;case Kje.ArrayUniqueItems:return"Expected array elements to be unique"
;case Kje.Array:return"Expected array";case Kje.AsyncIterator:
return"Expected AsyncIterator";case Kje.BigIntExclusiveMaximum:
return`Expected bigint to be less than ${e.schema.exclusiveMaximum}`
;case Kje.BigIntExclusiveMinimum:
return`Expected bigint to be greater than ${e.schema.exclusiveMinimum}`
;case Kje.BigIntMaximum:
return`Expected bigint to be less or equal to ${e.schema.maximum}`
;case Kje.BigIntMinimum:
return`Expected bigint to be greater or equal to ${e.schema.minimum}`
;case Kje.BigIntMultipleOf:
return`Expected bigint to be a multiple of ${e.schema.multipleOf}`
;case Kje.BigInt:return"Expected bigint";case Kje.Boolean:
return"Expected boolean";case Kje.DateExclusiveMinimumTimestamp:
return`Expected Date timestamp to be greater than ${e.schema.exclusiveMinimumTimestamp}`
;case Kje.DateExclusiveMaximumTimestamp:
return`Expected Date timestamp to be less than ${e.schema.exclusiveMaximumTimestamp}`
;case Kje.DateMinimumTimestamp:
return`Expected Date timestamp to be greater or equal to ${e.schema.minimumTimestamp}`
;case Kje.DateMaximumTimestamp:
return`Expected Date timestamp to be less or equal to ${e.schema.maximumTimestamp}`
;case Kje.DateMultipleOfTimestamp:
return`Expected Date timestamp to be a multiple of ${e.schema.multipleOfTimestamp}`
;case Kje.Date:return"Expected Date";case Kje.Function:return"Expected function"
;case Kje.IntegerExclusiveMaximum:
return`Expected integer to be less than ${e.schema.exclusiveMaximum}`
;case Kje.IntegerExclusiveMinimum:
return`Expected integer to be greater than ${e.schema.exclusiveMinimum}`
;case Kje.IntegerMaximum:
return`Expected integer to be less or equal to ${e.schema.maximum}`
;case Kje.IntegerMinimum:
return`Expected integer to be greater or equal to ${e.schema.minimum}`
;case Kje.IntegerMultipleOf:
return`Expected integer to be a multiple of ${e.schema.multipleOf}`
;case Kje.Integer:return"Expected integer"
;case Kje.IntersectUnevaluatedProperties:return"Unexpected property"
;case Kje.Intersect:return"Expected all values to match";case Kje.Iterator:
return"Expected Iterator";case Kje.Literal:
return`Expected ${"string"==typeof e.schema.const?`'${e.schema.const}'`:e.schema.const}`
;case Kje.Never:return"Never";case Kje.Not:return"Value should not match"
;case Kje.Null:return"Expected null";case Kje.NumberExclusiveMaximum:
return`Expected number to be less than ${e.schema.exclusiveMaximum}`
;case Kje.NumberExclusiveMinimum:
return`Expected number to be greater than ${e.schema.exclusiveMinimum}`
;case Kje.NumberMaximum:
return`Expected number to be less or equal to ${e.schema.maximum}`
;case Kje.NumberMinimum:
return`Expected number to be greater or equal to ${e.schema.minimum}`
;case Kje.NumberMultipleOf:
return`Expected number to be a multiple of ${e.schema.multipleOf}`
;case Kje.Number:return"Expected number";case Kje.Object:return"Expected object"
;case Kje.ObjectAdditionalProperties:return"Unexpected property"
;case Kje.ObjectMaxProperties:
return`Expected object to have no more than ${e.schema.maxProperties} properties`
;case Kje.ObjectMinProperties:
return`Expected object to have at least ${e.schema.minProperties} properties`
;case Kje.ObjectRequiredProperty:return"Expected required property"
;case Kje.Promise:return"Expected Promise";case Kje.RegExp:
return"Expected string to match regular expression"
;case Kje.StringFormatUnknown:return`Unknown format '${e.schema.format}'`
;case Kje.StringFormat:
return`Expected string to match '${e.schema.format}' format`
;case Kje.StringMaxLength:
return`Expected string length less or equal to ${e.schema.maxLength}`
;case Kje.StringMinLength:
return`Expected string length greater or equal to ${e.schema.minLength}`
;case Kje.StringPattern:return`Expected string to match '${e.schema.pattern}'`
;case Kje.String:return"Expected string";case Kje.Symbol:return"Expected symbol"
;case Kje.TupleLength:
return`Expected tuple to have ${e.schema.maxItems||0} elements`;case Kje.Tuple:
return"Expected tuple";case Kje.Uint8ArrayMaxByteLength:
return`Expected byte length less or equal to ${e.schema.maxByteLength}`
;case Kje.Uint8ArrayMinByteLength:
return`Expected byte length greater or equal to ${e.schema.minByteLength}`
;case Kje.Uint8Array:return"Expected Uint8Array";case Kje.Undefined:
return"Expected undefined";case Kje.Union:return"Expected union value"
;case Kje.Void:return"Expected void";case Kje.Kind:
return`Expected kind '${e.schema[HTe]}'`;default:return"Unknown error type"}}
;class Cje extends UTe{constructor(e){
super(`Unable to dereference schema with $id '${e.$ref}'`),this.schema=e}}
function $je(e,t){return!MTe(e.$id)||t.some((t=>t.$id===e.$id))||t.push(e),t}
function Pje(e,t){return"This"===e[HTe]||"Ref"===e[HTe]?function(e,t){
const n=t.find((t=>t.$id===e.$ref));if(void 0===n)throw new Cje(e)
;return Pje(n,t)}(e,t):e}class Dje extends UTe{constructor(e){
super("Unable to hash value"),this.value=e}}var Ije,Mje
;(Mje=Ije||(Ije={}))[Mje.Undefined=0]="Undefined",
Mje[Mje.Null=1]="Null",Mje[Mje.Boolean=2]="Boolean",
Mje[Mje.Number=3]="Number",Mje[Mje.String=4]="String",
Mje[Mje.Object=5]="Object",
Mje[Mje.Array=6]="Array",Mje[Mje.Date=7]="Date",Mje[Mje.Uint8Array=8]="Uint8Array",
Mje[Mje.Symbol=9]="Symbol",Mje[Mje.BigInt=10]="BigInt"
;let Nje=BigInt("14695981039346656037")
;const[Rje,Lje]=[BigInt("1099511628211"),BigInt("18446744073709551616")],Bje=Array.from({
length:256
}).map(((e,t)=>BigInt(t))),jje=new Float64Array(1),Uje=new DataView(jje.buffer),zje=new Uint8Array(jje.buffer)
;function*Fje(e){const t=0===e?1:Math.ceil(Math.floor(Math.log2(e)+1)/8)
;for(let n=0;n<t;n++)yield e>>8*(t-1-n)&255}function Zje(e){
if(ETe(e))return function(e){Qje(Ije.Array);for(const t of e)Zje(t)}(e)
;if($Te(e))return function(e){Qje(Ije.Boolean),Qje(e?1:0)}(e)
;if(ITe(e))return function(e){Qje(Ije.BigInt),Uje.setBigInt64(0,e)
;for(const t of zje)Qje(t)}(e);if(kTe(e))return function(e){
Qje(Ije.Date),Zje(e.getTime())}(e);if(!CTe(e)){if(PTe(e))return function(e){
Qje(Ije.Number),Uje.setFloat64(0,e);for(const t of zje)Qje(t)}(e)
;if(TTe(e))return function(e){Qje(Ije.Object)
;for(const t of globalThis.Object.getOwnPropertyNames(e).sort())Zje(t),Zje(e[t])
}(e);if(MTe(e))return function(e){Qje(Ije.String)
;for(let t=0;t<e.length;t++)for(const n of Fje(e.charCodeAt(t)))Qje(n)}(e)
;if(RTe(e))return function(e){Qje(Ije.Symbol),Zje(e.description)}(e)
;if(STe(e))return function(e){Qje(Ije.Uint8Array)
;for(let t=0;t<e.length;t++)Qje(e[t])}(e);if(ATe(e))return Qje(Ije.Undefined)
;throw new Dje(e)}Qje(Ije.Null)}function Qje(e){Nje^=Bje[e],Nje=Nje*Rje%Lje}
function Hje(e){return Nje=BigInt("14695981039346656037"),Zje(e),Nje}
class Vje extends UTe{constructor(e){super("Unknown type"),this.schema=e}}
function qje(e,t,n){const r=e.get(t)
;return(!r||!r.has(n))&&(r?(r.add(n),!0):void e.set(t,new WeakSet([n])))}
function Wje(e){return"Any"===e[HTe]||"Unknown"===e[HTe]}function Xje(e){
return void 0!==e}function Gje(e,t,n,r){const o=Xje(e.$id)?$je(e,t):t,a=e
;switch(a[HTe]){case"Any":case"Argument":case"Unknown":return!0;case"Array":
return function(e,t,n,r){if(!ETe(n))return!1
;if(Xje(e.minItems)&&!(n.length>=e.minItems))return!1
;if(Xje(e.maxItems)&&!(n.length<=e.maxItems))return!1
;if(!1===qje(r,n,e))return!0;if(!n.every((n=>Gje(e.items,t,n,r))))return!1
;if(!0===e.uniqueItems&&!function(){const e=new Set;for(const t of n){
const n=Hje(t);if(e.has(n))return!1;e.add(n)}return!0}())return!1
;if(!(Xje(e.contains)||PTe(e.minContains)||PTe(e.maxContains)))return!0
;const o=Xje(e.contains)?e.contains:NAe(),a=n.reduce(((e,n)=>Gje(o,t,n,r)?e+1:e),0)
;return!(0===a||PTe(e.minContains)&&a<e.minContains||PTe(e.maxContains)&&a>e.maxContains)
}(a,o,n,r);case"AsyncIterator":return function(e,t,n){return OTe(n)}(0,0,n)
;case"BigInt":return function(e,t,n){
return!(!ITe(n)||Xje(e.exclusiveMaximum)&&!(n<e.exclusiveMaximum)||Xje(e.exclusiveMinimum)&&!(n>e.exclusiveMinimum)||Xje(e.maximum)&&!(n<=e.maximum)||Xje(e.minimum)&&!(n>=e.minimum)||Xje(e.multipleOf)&&n%e.multipleOf!==BigInt(0))
}(a,0,n);case"Boolean":return function(e,t,n){return $Te(n)}(0,0,n)
;case"Constructor":return function(e,t,n,r){
return Gje(e.returns,t,n.prototype,r)}(a,o,n,r);case"Date":
return function(e,t,n){
return!(!kTe(n)||Xje(e.exclusiveMaximumTimestamp)&&!(n.getTime()<e.exclusiveMaximumTimestamp)||Xje(e.exclusiveMinimumTimestamp)&&!(n.getTime()>e.exclusiveMinimumTimestamp)||Xje(e.maximumTimestamp)&&!(n.getTime()<=e.maximumTimestamp)||Xje(e.minimumTimestamp)&&!(n.getTime()>=e.minimumTimestamp)||Xje(e.multipleOfTimestamp)&&n.getTime()%e.multipleOfTimestamp!=0)
}(a,0,n);case"Function":return function(e,t,n){return NTe(n)}(0,0,n)
;case"Import":return function(e,t,n,r){const o=globalThis.Object.values(e.$defs)
;return Gje(e.$defs[e.$ref],[...t,...o],n,r)}(a,o,n,r);case"Integer":
return function(e,t,n){
return!(!DTe(n)||Xje(e.exclusiveMaximum)&&!(n<e.exclusiveMaximum)||Xje(e.exclusiveMinimum)&&!(n>e.exclusiveMinimum)||Xje(e.maximum)&&!(n<=e.maximum)||Xje(e.minimum)&&!(n>=e.minimum)||Xje(e.multipleOf)&&n%e.multipleOf!=0)
}(a,0,n);case"Intersect":return function(e,t,n,r){
const o=e.allOf.every((e=>Gje(e,t,n,r)));if(!1===e.unevaluatedProperties){
const t=new RegExp(JCe(e)),r=Object.getOwnPropertyNames(n).every((e=>t.test(e)))
;return o&&r}if(TEe(e.unevaluatedProperties)){
const a=new RegExp(JCe(e)),i=Object.getOwnPropertyNames(n).every((o=>a.test(o)||Gje(e.unevaluatedProperties,t,n[o],r)))
;return o&&i}return o}(a,o,n,r);case"Iterator":return function(e,t,n){
return wTe(n)}(0,0,n);case"Literal":return function(e,t,n){return n===e.const
}(a,0,n);case"Never":return!1;case"Not":return function(e,t,n,r){
return!Gje(e.not,t,n,r)}(a,o,n,r);case"Null":return function(e,t,n){
return CTe(n)}(0,0,n);case"Number":return function(e,t,n){
return!(!LTe.IsNumberLike(n)||Xje(e.exclusiveMaximum)&&!(n<e.exclusiveMaximum)||Xje(e.exclusiveMinimum)&&!(n>e.exclusiveMinimum)||Xje(e.minimum)&&!(n>=e.minimum)||Xje(e.maximum)&&!(n<=e.maximum)||Xje(e.multipleOf)&&n%e.multipleOf!=0)
}(a,0,n);case"Object":return function(e,t,n,r){if(!LTe.IsObjectLike(n))return!1
;if(Xje(e.minProperties)&&!(Object.getOwnPropertyNames(n).length>=e.minProperties))return!1
;if(Xje(e.maxProperties)&&!(Object.getOwnPropertyNames(n).length<=e.maxProperties))return!1
;if(!1===qje(r,n,e))return!0;const o=Object.getOwnPropertyNames(e.properties)
;for(const a of o){const o=e.properties[a]
;if(e.required&&e.required.includes(a)){if(!Gje(o,t,n[a],r))return!1
;if((X$e(o)||Wje(o))&&!(a in n))return!1
}else if(LTe.IsExactOptionalProperty(n,a)&&!Gje(o,t,n[a],r))return!1}
if(!1===e.additionalProperties){const t=Object.getOwnPropertyNames(n)
;return!(!e.required||e.required.length!==o.length||t.length!==o.length)||t.every((e=>o.includes(e)))
}
if("object"==typeof e.additionalProperties)return Object.getOwnPropertyNames(n).every((a=>o.includes(a)||Gje(e.additionalProperties,t,n[a],r)))
;return!0}(a,o,n,r);case"Promise":return function(e,t,n){return xTe(n)}(0,0,n)
;case"Record":return function(e,t,n,r){if(!LTe.IsRecordLike(n))return!1
;if(Xje(e.minProperties)&&!(Object.getOwnPropertyNames(n).length>=e.minProperties))return!1
;if(Xje(e.maxProperties)&&!(Object.getOwnPropertyNames(n).length<=e.maxProperties))return!1
;const[o,a]=Object.entries(e.patternProperties)[0],i=new RegExp(o),s=Object.entries(n).every((([e,n])=>!i.test(e)||Gje(a,t,n,r))),l="object"!=typeof e.additionalProperties||Object.entries(n).every((([n,o])=>!!i.test(n)||Gje(e.additionalProperties,t,o,r))),c=!1!==e.additionalProperties||Object.getOwnPropertyNames(n).every((e=>i.test(e)))
;return s&&l&&c}(a,o,n,r);case"Ref":case"This":return function(e,t,n,r){
return Gje(Pje(e,t),t,n,r)}(a,o,n,r);case"RegExp":return function(e,t,n){
const r=new RegExp(e.source,e.flags)
;return(!Xje(e.minLength)||n.length>=e.minLength)&&(!Xje(e.maxLength)||n.length<=e.maxLength)&&r.test(n)
}(a,0,n);case"String":return function(e,t,n){if(!MTe(n))return!1
;if(Xje(e.minLength)&&!(n.length>=e.minLength))return!1
;if(Xje(e.maxLength)&&!(n.length<=e.maxLength))return!1
;if(Xje(e.pattern)&&!new RegExp(e.pattern).test(n))return!1
;if(Xje(e.format))return!!_Ae(e.format)&&TAe(e.format)(n);return!0}(a,0,n)
;case"Symbol":return function(e,t,n){return RTe(n)}(0,0,n)
;case"TemplateLiteral":return function(e,t,n){
return MTe(n)&&new RegExp(e.pattern).test(n)}(a,0,n);case"Tuple":
return function(e,t,n,r){if(!ETe(n))return!1
;if(void 0===e.items&&0!==n.length)return!1;if(n.length!==e.maxItems)return!1
;if(!e.items)return!0
;for(let o=0;o<e.items.length;o++)if(!Gje(e.items[o],t,n[o],r))return!1;return!0
}(a,o,n,r);case"Undefined":return function(e,t,n){return ATe(n)}(0,0,n)
;case"Union":return function(e,t,n,r){return e.anyOf.some((e=>Gje(e,t,n,r)))
}(a,o,n,r);case"Uint8Array":return function(e,t,n){
return!!STe(n)&&(!Xje(e.maxByteLength)||n.length<=e.maxByteLength)&&(!Xje(e.minByteLength)||n.length>=e.minByteLength)
}(a,0,n);case"Void":return function(e,t,n){return LTe.IsVoidLike(n)}(0,0,n)
;default:if(!AAe(a[HTe]))throw new Vje(a);return function(e,t,n){
return!!AAe(e[HTe])&&CAe(e[HTe])(e,n)}(a,0,n)}}function Yje(...e){
return 2===e.length||3===e.length&&e[2]instanceof WeakMap?Gje(e[0],[],e[1],e[2]??new WeakMap):Gje(e[0],e[1],e[2],e[3]??new WeakMap)
}var Kje,Jje
;(Jje=Kje||(Kje={}))[Jje.ArrayContains=0]="ArrayContains",Jje[Jje.ArrayMaxContains=1]="ArrayMaxContains",
Jje[Jje.ArrayMaxItems=2]="ArrayMaxItems",
Jje[Jje.ArrayMinContains=3]="ArrayMinContains",
Jje[Jje.ArrayMinItems=4]="ArrayMinItems",
Jje[Jje.ArrayUniqueItems=5]="ArrayUniqueItems",
Jje[Jje.Array=6]="Array",Jje[Jje.AsyncIterator=7]="AsyncIterator",
Jje[Jje.BigIntExclusiveMaximum=8]="BigIntExclusiveMaximum",
Jje[Jje.BigIntExclusiveMinimum=9]="BigIntExclusiveMinimum",
Jje[Jje.BigIntMaximum=10]="BigIntMaximum",
Jje[Jje.BigIntMinimum=11]="BigIntMinimum",
Jje[Jje.BigIntMultipleOf=12]="BigIntMultipleOf",
Jje[Jje.BigInt=13]="BigInt",Jje[Jje.Boolean=14]="Boolean",
Jje[Jje.DateExclusiveMaximumTimestamp=15]="DateExclusiveMaximumTimestamp",
Jje[Jje.DateExclusiveMinimumTimestamp=16]="DateExclusiveMinimumTimestamp",
Jje[Jje.DateMaximumTimestamp=17]="DateMaximumTimestamp",
Jje[Jje.DateMinimumTimestamp=18]="DateMinimumTimestamp",
Jje[Jje.DateMultipleOfTimestamp=19]="DateMultipleOfTimestamp",
Jje[Jje.Date=20]="Date",
Jje[Jje.Function=21]="Function",Jje[Jje.IntegerExclusiveMaximum=22]="IntegerExclusiveMaximum",
Jje[Jje.IntegerExclusiveMinimum=23]="IntegerExclusiveMinimum",
Jje[Jje.IntegerMaximum=24]="IntegerMaximum",
Jje[Jje.IntegerMinimum=25]="IntegerMinimum",
Jje[Jje.IntegerMultipleOf=26]="IntegerMultipleOf",Jje[Jje.Integer=27]="Integer",
Jje[Jje.IntersectUnevaluatedProperties=28]="IntersectUnevaluatedProperties",
Jje[Jje.Intersect=29]="Intersect",
Jje[Jje.Iterator=30]="Iterator",Jje[Jje.Kind=31]="Kind",
Jje[Jje.Literal=32]="Literal",
Jje[Jje.Never=33]="Never",Jje[Jje.Not=34]="Not",Jje[Jje.Null=35]="Null",
Jje[Jje.NumberExclusiveMaximum=36]="NumberExclusiveMaximum",
Jje[Jje.NumberExclusiveMinimum=37]="NumberExclusiveMinimum",
Jje[Jje.NumberMaximum=38]="NumberMaximum",
Jje[Jje.NumberMinimum=39]="NumberMinimum",
Jje[Jje.NumberMultipleOf=40]="NumberMultipleOf",
Jje[Jje.Number=41]="Number",Jje[Jje.ObjectAdditionalProperties=42]="ObjectAdditionalProperties",
Jje[Jje.ObjectMaxProperties=43]="ObjectMaxProperties",
Jje[Jje.ObjectMinProperties=44]="ObjectMinProperties",
Jje[Jje.ObjectRequiredProperty=45]="ObjectRequiredProperty",
Jje[Jje.Object=46]="Object",
Jje[Jje.Promise=47]="Promise",Jje[Jje.RegExp=48]="RegExp",
Jje[Jje.StringFormatUnknown=49]="StringFormatUnknown",
Jje[Jje.StringFormat=50]="StringFormat",
Jje[Jje.StringMaxLength=51]="StringMaxLength",
Jje[Jje.StringMinLength=52]="StringMinLength",
Jje[Jje.StringPattern=53]="StringPattern",
Jje[Jje.String=54]="String",Jje[Jje.Symbol=55]="Symbol",
Jje[Jje.TupleLength=56]="TupleLength",
Jje[Jje.Tuple=57]="Tuple",Jje[Jje.Uint8ArrayMaxByteLength=58]="Uint8ArrayMaxByteLength",
Jje[Jje.Uint8ArrayMinByteLength=59]="Uint8ArrayMinByteLength",
Jje[Jje.Uint8Array=60]="Uint8Array",
Jje[Jje.Undefined=61]="Undefined",Jje[Jje.Union=62]="Union",
Jje[Jje.Void=63]="Void";class eUe extends UTe{constructor(e){
super("Unknown type"),this.schema=e}}function tUe(e){
return e.replace(/~/g,"~0").replace(/\//g,"~1")}function nUe(e){
return void 0!==e}class rUe{constructor(e){this.iterator=e}[Symbol.iterator](){
return this.iterator}First(){const e=this.iterator.next()
;return e.done?void 0:e.value}}function oUe(e,t,n,r,o=[]){return{type:e,
schema:t,path:n,value:r,message:Aje({errorType:e,path:n,schema:t,value:r,
errors:o}),errors:o}}function*aUe(e,t,n,r){const o=nUe(e.$id)?[...t,e]:t,a=e
;switch(a[HTe]){case"Any":case"Argument":case"Unknown":
return yield*function*(e,t,n,r){}();case"Array":return yield*function*(e,t,n,r){
if(!ETe(r))return yield oUe(Kje.Array,e,n,r)
;!nUe(e.minItems)||r.length>=e.minItems||(yield oUe(Kje.ArrayMinItems,e,n,r)),
!nUe(e.maxItems)||r.length<=e.maxItems||(yield oUe(Kje.ArrayMaxItems,e,n,r))
;for(let i=0;i<r.length;i++)yield*aUe(e.items,t,`${n}/${i}`,r[i])
;if(!0!==e.uniqueItems||function(){const e=new Set;for(const t of r){
const n=Hje(t);if(e.has(n))return!1;e.add(n)}return!0
}()||(yield oUe(Kje.ArrayUniqueItems,e,n,r)),
!(nUe(e.contains)||nUe(e.minContains)||nUe(e.maxContains)))return
;const o=nUe(e.contains)?e.contains:NAe(),a=r.reduce(((e,r,a)=>!0===aUe(o,t,`${n}${a}`,r).next().done?e+1:e),0)
;0===a&&(yield oUe(Kje.ArrayContains,e,n,r)),
PTe(e.minContains)&&a<e.minContains&&(yield oUe(Kje.ArrayMinContains,e,n,r)),
PTe(e.maxContains)&&a>e.maxContains&&(yield oUe(Kje.ArrayMaxContains,e,n,r))
}(a,o,n,r);case"AsyncIterator":return yield*function*(e,t,n,r){
OTe(r)||(yield oUe(Kje.AsyncIterator,e,n,r))}(a,0,n,r);case"BigInt":
return yield*function*(e,t,n,r){if(!ITe(r))return yield oUe(Kje.BigInt,e,n,r)
;!nUe(e.exclusiveMaximum)||r<e.exclusiveMaximum||(yield oUe(Kje.BigIntExclusiveMaximum,e,n,r)),
!nUe(e.exclusiveMinimum)||r>e.exclusiveMinimum||(yield oUe(Kje.BigIntExclusiveMinimum,e,n,r)),
!nUe(e.maximum)||r<=e.maximum||(yield oUe(Kje.BigIntMaximum,e,n,r)),
!nUe(e.minimum)||r>=e.minimum||(yield oUe(Kje.BigIntMinimum,e,n,r)),
nUe(e.multipleOf)&&r%e.multipleOf!==BigInt(0)&&(yield oUe(Kje.BigIntMultipleOf,e,n,r))
}(a,0,n,r);case"Boolean":return yield*function*(e,t,n,r){
$Te(r)||(yield oUe(Kje.Boolean,e,n,r))}(a,0,n,r);case"Constructor":
return yield*function*(e,t,n,r){yield*aUe(e.returns,t,n,r.prototype)}(a,o,n,r)
;case"Date":return yield*function*(e,t,n,r){
if(!kTe(r))return yield oUe(Kje.Date,e,n,r)
;!nUe(e.exclusiveMaximumTimestamp)||r.getTime()<e.exclusiveMaximumTimestamp||(yield oUe(Kje.DateExclusiveMaximumTimestamp,e,n,r)),
!nUe(e.exclusiveMinimumTimestamp)||r.getTime()>e.exclusiveMinimumTimestamp||(yield oUe(Kje.DateExclusiveMinimumTimestamp,e,n,r)),
!nUe(e.maximumTimestamp)||r.getTime()<=e.maximumTimestamp||(yield oUe(Kje.DateMaximumTimestamp,e,n,r)),
!nUe(e.minimumTimestamp)||r.getTime()>=e.minimumTimestamp||(yield oUe(Kje.DateMinimumTimestamp,e,n,r)),
nUe(e.multipleOfTimestamp)&&r.getTime()%e.multipleOfTimestamp!=0&&(yield oUe(Kje.DateMultipleOfTimestamp,e,n,r))
}(a,0,n,r);case"Function":return yield*function*(e,t,n,r){
NTe(r)||(yield oUe(Kje.Function,e,n,r))}(a,0,n,r);case"Import":
return yield*function*(e,t,n,r){
const o=globalThis.Object.values(e.$defs),a=e.$defs[e.$ref]
;yield*aUe(a,[...t,...o],n,r)}(a,o,n,r);case"Integer":
return yield*function*(e,t,n,r){if(!DTe(r))return yield oUe(Kje.Integer,e,n,r)
;!nUe(e.exclusiveMaximum)||r<e.exclusiveMaximum||(yield oUe(Kje.IntegerExclusiveMaximum,e,n,r)),
!nUe(e.exclusiveMinimum)||r>e.exclusiveMinimum||(yield oUe(Kje.IntegerExclusiveMinimum,e,n,r)),
!nUe(e.maximum)||r<=e.maximum||(yield oUe(Kje.IntegerMaximum,e,n,r)),
!nUe(e.minimum)||r>=e.minimum||(yield oUe(Kje.IntegerMinimum,e,n,r)),
nUe(e.multipleOf)&&r%e.multipleOf!=0&&(yield oUe(Kje.IntegerMultipleOf,e,n,r))
}(a,0,n,r);case"Intersect":return yield*function*(e,t,n,r){let o=!1
;for(const a of e.allOf)for(const e of aUe(a,t,n,r))o=!0,yield e
;if(o)return yield oUe(Kje.Intersect,e,n,r);if(!1===e.unevaluatedProperties){
const t=new RegExp(JCe(e))
;for(const o of Object.getOwnPropertyNames(r))t.test(o)||(yield oUe(Kje.IntersectUnevaluatedProperties,e,`${n}/${o}`,r))
}if("object"==typeof e.unevaluatedProperties){const o=new RegExp(JCe(e))
;for(const a of Object.getOwnPropertyNames(r))if(!o.test(a)){
const o=aUe(e.unevaluatedProperties,t,`${n}/${a}`,r[a]).next()
;o.done||(yield o.value)}}}(a,o,n,r);case"Iterator":
return yield*function*(e,t,n,r){wTe(r)||(yield oUe(Kje.Iterator,e,n,r))
}(a,0,n,r);case"Literal":return yield*function*(e,t,n,r){
r!==e.const&&(yield oUe(Kje.Literal,e,n,r))}(a,0,n,r);case"Never":
return yield*function*(e,t,n,r){yield oUe(Kje.Never,e,n,r)}(a,0,n,r);case"Not":
return yield*function*(e,t,n,r){
!0===aUe(e.not,t,n,r).next().done&&(yield oUe(Kje.Not,e,n,r))}(a,o,n,r)
;case"Null":return yield*function*(e,t,n,r){CTe(r)||(yield oUe(Kje.Null,e,n,r))
}(a,0,n,r);case"Number":return yield*function*(e,t,n,r){
if(!LTe.IsNumberLike(r))return yield oUe(Kje.Number,e,n,r)
;!nUe(e.exclusiveMaximum)||r<e.exclusiveMaximum||(yield oUe(Kje.NumberExclusiveMaximum,e,n,r)),
!nUe(e.exclusiveMinimum)||r>e.exclusiveMinimum||(yield oUe(Kje.NumberExclusiveMinimum,e,n,r)),
!nUe(e.maximum)||r<=e.maximum||(yield oUe(Kje.NumberMaximum,e,n,r)),
!nUe(e.minimum)||r>=e.minimum||(yield oUe(Kje.NumberMinimum,e,n,r)),
nUe(e.multipleOf)&&r%e.multipleOf!=0&&(yield oUe(Kje.NumberMultipleOf,e,n,r))
}(a,0,n,r);case"Object":return yield*function*(e,t,n,r){
if(!LTe.IsObjectLike(r))return yield oUe(Kje.Object,e,n,r)
;!nUe(e.minProperties)||Object.getOwnPropertyNames(r).length>=e.minProperties||(yield oUe(Kje.ObjectMinProperties,e,n,r)),
!nUe(e.maxProperties)||Object.getOwnPropertyNames(r).length<=e.maxProperties||(yield oUe(Kje.ObjectMaxProperties,e,n,r))
;const o=Array.isArray(e.required)?e.required:[],a=Object.getOwnPropertyNames(e.properties),i=Object.getOwnPropertyNames(r)
;for(const s of o)i.includes(s)||(yield oUe(Kje.ObjectRequiredProperty,e.properties[s],`${n}/${tUe(s)}`,void 0))
;if(!1===e.additionalProperties)for(const s of i)a.includes(s)||(yield oUe(Kje.ObjectAdditionalProperties,e,`${n}/${tUe(s)}`,r[s]))
;if("object"==typeof e.additionalProperties)for(const s of i)a.includes(s)||(yield*aUe(e.additionalProperties,t,`${n}/${tUe(s)}`,r[s]))
;for(const s of a){const o=e.properties[s]
;e.required&&e.required.includes(s)?(yield*aUe(o,t,`${n}/${tUe(s)}`,r[s]),
X$e(e)&&!(s in r)&&(yield oUe(Kje.ObjectRequiredProperty,o,`${n}/${tUe(s)}`,void 0))):LTe.IsExactOptionalProperty(r,s)&&(yield*aUe(o,t,`${n}/${tUe(s)}`,r[s]))
}}(a,o,n,r);case"Promise":return yield*function*(e,t,n,r){
xTe(r)||(yield oUe(Kje.Promise,e,n,r))}(a,0,n,r);case"Record":
return yield*function*(e,t,n,r){
if(!LTe.IsRecordLike(r))return yield oUe(Kje.Object,e,n,r)
;!nUe(e.minProperties)||Object.getOwnPropertyNames(r).length>=e.minProperties||(yield oUe(Kje.ObjectMinProperties,e,n,r)),
!nUe(e.maxProperties)||Object.getOwnPropertyNames(r).length<=e.maxProperties||(yield oUe(Kje.ObjectMaxProperties,e,n,r))
;const[o,a]=Object.entries(e.patternProperties)[0],i=new RegExp(o)
;for(const[s,l]of Object.entries(r))i.test(s)&&(yield*aUe(a,t,`${n}/${tUe(s)}`,l))
;if("object"==typeof e.additionalProperties)for(const[s,l]of Object.entries(r))i.test(s)||(yield*aUe(e.additionalProperties,t,`${n}/${tUe(s)}`,l))
;if(!1===e.additionalProperties)for(const[s,l]of Object.entries(r))if(!i.test(s))return yield oUe(Kje.ObjectAdditionalProperties,e,`${n}/${tUe(s)}`,l)
}(a,o,n,r);case"Ref":case"This":return yield*function*(e,t,n,r){
yield*aUe(Pje(e,t),t,n,r)}(a,o,n,r);case"RegExp":
return yield*function*(e,t,n,r){
return MTe(r)?(!nUe(e.minLength)||r.length>=e.minLength||(yield oUe(Kje.StringMinLength,e,n,r)),
!nUe(e.maxLength)||r.length<=e.maxLength||(yield oUe(Kje.StringMaxLength,e,n,r)),
new RegExp(e.source,e.flags).test(r)?void 0:yield oUe(Kje.RegExp,e,n,r)):yield oUe(Kje.String,e,n,r)
}(a,0,n,r);case"String":return yield*function*(e,t,n,r){
if(!MTe(r))return yield oUe(Kje.String,e,n,r)
;!nUe(e.minLength)||r.length>=e.minLength||(yield oUe(Kje.StringMinLength,e,n,r)),
!nUe(e.maxLength)||r.length<=e.maxLength||(yield oUe(Kje.StringMaxLength,e,n,r)),
MTe(e.pattern)&&(new RegExp(e.pattern).test(r)||(yield oUe(Kje.StringPattern,e,n,r)))
;MTe(e.format)&&(_Ae(e.format)?TAe(e.format)(r)||(yield oUe(Kje.StringFormat,e,n,r)):yield oUe(Kje.StringFormatUnknown,e,n,r))
}(a,0,n,r);case"Symbol":return yield*function*(e,t,n,r){
RTe(r)||(yield oUe(Kje.Symbol,e,n,r))}(a,0,n,r);case"TemplateLiteral":
return yield*function*(e,t,n,r){if(!MTe(r))return yield oUe(Kje.String,e,n,r)
;new RegExp(e.pattern).test(r)||(yield oUe(Kje.StringPattern,e,n,r))}(a,0,n,r)
;case"Tuple":return yield*function*(e,t,n,r){
if(!ETe(r))return yield oUe(Kje.Tuple,e,n,r)
;if(void 0===e.items&&0!==r.length)return yield oUe(Kje.TupleLength,e,n,r)
;if(r.length!==e.maxItems)return yield oUe(Kje.TupleLength,e,n,r)
;if(e.items)for(let o=0;o<e.items.length;o++)yield*aUe(e.items[o],t,`${n}/${o}`,r[o])
}(a,o,n,r);case"Undefined":return yield*function*(e,t,n,r){
ATe(r)||(yield oUe(Kje.Undefined,e,n,r))}(a,0,n,r);case"Union":
return yield*function*(e,t,n,r){if(Yje(e,t,r))return
;const o=e.anyOf.map((e=>new rUe(aUe(e,t,n,r))));yield oUe(Kje.Union,e,n,r,o)
}(a,o,n,r);case"Uint8Array":return yield*function*(e,t,n,r){
if(!STe(r))return yield oUe(Kje.Uint8Array,e,n,r)
;!nUe(e.maxByteLength)||r.length<=e.maxByteLength||(yield oUe(Kje.Uint8ArrayMaxByteLength,e,n,r)),
!nUe(e.minByteLength)||r.length>=e.minByteLength||(yield oUe(Kje.Uint8ArrayMinByteLength,e,n,r))
}(a,0,n,r);case"Void":return yield*function*(e,t,n,r){
LTe.IsVoidLike(r)||(yield oUe(Kje.Void,e,n,r))}(a,0,n,r);default:
if(!AAe(a[HTe]))throw new eUe(e);return yield*function*(e,t,n,r){
CAe(e[HTe])(e,r)||(yield oUe(Kje.Kind,e,n,r))}(a,0,n,r)}}
function iUe(e,t=new WeakMap){if(ETe(e))return function(e,t){
if(t.has(e))return t.get(e);const n=[];t.set(e,n)
;for(let r=0;r<e.length;r++)n.push(iUe(e[r],t));return n}(e,t)
;if(kTe(e))return function(e){return new Date(e.toISOString())}(e)
;if(function(e){return globalThis.ArrayBuffer.isView(e)}(e))return function(e){
return e.slice()}(e);if(function(e){return e instanceof globalThis.Map
}(e))return function(e){return new Map(iUe([...e.entries()]))}(e)
;if(function(e){return e instanceof globalThis.Set}(e))return function(e){
return new Set(iUe([...e.entries()]))}(e);if(TTe(e))return function(e,t){
if(t.has(e))return t.get(e);const n={};t.set(e,n)
;for(const r of Object.getOwnPropertyNames(e))n[r]=iUe(e[r],t)
;for(const r of Object.getOwnPropertySymbols(e))n[r]=iUe(e[r],t);return n}(e,t)
;if(function(e){return ITe(e)||$Te(e)||CTe(e)||PTe(e)||MTe(e)||RTe(e)||ATe(e)
}(e))return e;throw new Error("ValueClone: Unable to clone value")}
class sUe extends UTe{constructor(e,t){super(t),this.schema=e}}function lUe(e){
return NTe(e)?e():iUe(e)}function cUe(e,t){const n=$je(e,t),r=e;switch(r[HTe]){
case"Any":case"Record":case"Unknown":return function(e,t){
return _Te(e,"default")?lUe(e.default):{}}(r);case"Argument":return{}
;case"Array":return function(e,t){if(!0!==e.uniqueItems||_Te(e,"default")){
if("contains"in e&&!_Te(e,"default"))throw new sUe(e,"Array with the contains constraint requires a default value")
;return"default"in e?lUe(e.default):void 0!==e.minItems?Array.from({
length:e.minItems}).map((n=>cUe(e.items,t))):[]}
throw new sUe(e,"Array with the uniqueItems constraint requires a default value")
}(r,n);case"AsyncIterator":return function(e,t){
return _Te(e,"default")?lUe(e.default):async function*(){}()}(r);case"BigInt":
return function(e,t){return _Te(e,"default")?lUe(e.default):BigInt(0)}(r)
;case"Boolean":return function(e,t){return!!_Te(e,"default")&&lUe(e.default)}(r)
;case"Constructor":return function(e,t){
if(_Te(e,"default"))return lUe(e.default);{const n=cUe(e.returns,t)
;return"object"!=typeof n||Array.isArray(n)?class{}:class{constructor(){
for(const[e,t]of Object.entries(n))this[e]=t}}}}(r,n);case"Date":
return function(e,t){
return _Te(e,"default")?lUe(e.default):void 0!==e.minimumTimestamp?new Date(e.minimumTimestamp):new Date
}(r);case"Function":return function(e,t){
return _Te(e,"default")?lUe(e.default):()=>cUe(e.returns,t)}(r,n);case"Import":
return function(e,t){const n=globalThis.Object.values(e.$defs)
;return cUe(e.$defs[e.$ref],[...t,...n])}(r,n);case"Integer":case"Number":
return function(e,t){
return _Te(e,"default")?lUe(e.default):void 0!==e.minimum?e.minimum:0}(r)
;case"Intersect":return function(e,t){if(_Te(e,"default"))return lUe(e.default)
;{const n=e.allOf.reduce(((e,n)=>{const r=cUe(n,t);return"object"==typeof r?{
...e,...r}:r}),{})
;if(!Yje(e,t,n))throw new sUe(e,"Intersect produced invalid value. Consider using a default value.")
;return n}}(r,n);case"Iterator":return function(e,t){
return _Te(e,"default")?lUe(e.default):function*(){}()}(r);case"Literal":
return function(e,t){return _Te(e,"default")?lUe(e.default):e.const}(r)
;case"Never":return function(e,t){if(_Te(e,"default"))return lUe(e.default)
;throw new sUe(e,"Never types cannot be created. Consider using a default value.")
}(r);case"Not":return function(e,t){if(_Te(e,"default"))return lUe(e.default)
;throw new sUe(e,"Not types must have a default value")}(r);case"Null":
return function(e,t){return _Te(e,"default")?lUe(e.default):null}(r)
;case"Object":return function(e,t){if(_Te(e,"default"))return lUe(e.default);{
const n=new Set(e.required),r={}
;for(const[o,a]of Object.entries(e.properties))n.has(o)&&(r[o]=cUe(a,t))
;return r}}(r,n);case"Promise":return function(e,t){
return _Te(e,"default")?lUe(e.default):Promise.resolve(cUe(e.item,t))}(r,n)
;case"Ref":return function(e,t){
return _Te(e,"default")?lUe(e.default):cUe(Pje(e,t),t)}(r,n);case"RegExp":
return function(e,t){if(_Te(e,"default"))return lUe(e.default)
;throw new sUe(e,"RegExp types cannot be created. Consider using a default value.")
}(r);case"String":return function(e,t){if(void 0!==e.pattern){
if(_Te(e,"default"))return lUe(e.default)
;throw new sUe(e,"String types with patterns must specify a default value")}
if(void 0!==e.format){if(_Te(e,"default"))return lUe(e.default)
;throw new sUe(e,"String types with formats must specify a default value")}
return _Te(e,"default")?lUe(e.default):void 0!==e.minLength?Array.from({
length:e.minLength}).map((()=>" ")).join(""):""}(r);case"Symbol":
return function(e,t){
return _Te(e,"default")?lUe(e.default):"value"in e?Symbol.for(e.value):Symbol()
}(r);case"TemplateLiteral":return function(e,t){
if(_Te(e,"default"))return lUe(e.default)
;if(!eCe(e))throw new sUe(e,"Can only create template literals that produce a finite variants. Consider using a default value.")
;return aCe(e)[0]}(r);case"This":return function(e,t){
if(dUe++>uUe)throw new sUe(e,"Cannot create recursive type as it appears possibly infinite. Consider using a default.")
;return _Te(e,"default")?lUe(e.default):cUe(Pje(e,t),t)}(r,n);case"Tuple":
return function(e,t){
return _Te(e,"default")?lUe(e.default):void 0===e.items?[]:Array.from({
length:e.minItems}).map(((n,r)=>cUe(e.items[r],t)))}(r,n);case"Undefined":
case"Void":return function(e,t){return _Te(e,"default")?lUe(e.default):void 0
}(r);case"Union":return function(e,t){if(_Te(e,"default"))return lUe(e.default)
;if(0===e.anyOf.length)throw new Error("ValueCreate.Union: Cannot create Union with zero variants")
;return cUe(e.anyOf[0],t)}(r,n);case"Uint8Array":return function(e,t){
return _Te(e,"default")?lUe(e.default):void 0!==e.minByteLength?new Uint8Array(e.minByteLength):new Uint8Array(0)
}(r);default:if(!AAe(r[HTe]))throw new sUe(r,"Unknown type")
;return function(e,t){if(_Te(e,"default"))return lUe(e.default)
;throw new Error("User defined types must specify a default value")}(r)}}
const uUe=512;let dUe=0;function pUe(...e){
return dUe=0,2===e.length?cUe(e[0],e[1]):cUe(e[0],[])}class hUe extends UTe{
constructor(e,t){super(t),this.schema=e}}function fUe(e,t,n){
if("Object"!==e[HTe]||"object"!=typeof n||CTe(n)){if("Union"===e[HTe]){
const r=e.anyOf.map((e=>Pje(e,t))).map((e=>fUe(e,t,n)));return Math.max(...r)}
return Yje(e,t,n)?1:0}{const r=e,o=Object.getOwnPropertyNames(n)
;return Object.entries(r.properties).reduce(((e,[r,a])=>e+(("Literal"===a[HTe]&&a.const===n[r]?100:0)+(Yje(a,t,n[r])?10:0)+(o.includes(r)?1:0))),0)
}}function mUe(e,t,n,r){
if("default"in e)return"function"==typeof n?e.default:iUe(e.default);{
const o=function(e,t,n){const r=e.anyOf.map((e=>Pje(e,t)));let[o,a]=[r[0],0]
;for(const i of r){const e=fUe(i,t,n);e>a&&(o=i,a=e)}return o}(e,t,n)
;return yUe(o,t,n,r)}}function gUe(e,t){
return TTe(e)&&!TTe(t)||!TTe(e)&&TTe(t)?e:TTe(e)&&TTe(t)?globalThis.Object.getOwnPropertyNames(e).reduce(((n,r)=>{
const o=r in t?gUe(e[r],t[r]):e[r];return{...n,[r]:o}}),{}):t}
function vUe(e,t,n){if(Yje(e,t,n))return n;const r=pUe(e,t),o=gUe(r,n)
;return Yje(e,t,o)?o:r}function bUe(e,t,n,r){const o=MTe(e.$id)?$je(e,t):t,a=e
;switch(e[HTe]){case"Array":return function(e,t,n,r){if(Yje(e,t,n))return iUe(n)
;const o=ETe(n)?n:pUe(e,t),a=PTe(e.minItems)&&o.length<e.minItems?[...o,...Array.from({
length:e.minItems-o.length
},(()=>null))]:o,i=(PTe(e.maxItems)&&a.length>e.maxItems?a.slice(0,e.maxItems):a).map((n=>bUe(e.items,t,n,r)))
;if(!0!==e.uniqueItems)return i;const s=[...new Set(i)]
;if(!Yje(e,t,s))throw new hUe(e,"Array cast produced invalid data due to uniqueItems constraint")
;return s}(a,o,n,r);case"Constructor":return function(e,t,n,r){
if(Yje(e,t,n))return pUe(e,t)
;const o=new Set(e.returns.required||[]),a=function(){}
;for(const[i,s]of Object.entries(e.returns.properties))(o.has(i)||void 0!==n.prototype[i])&&(a.prototype[i]=bUe(s,t,n.prototype[i],r))
;return a}(a,o,n,r);case"Import":return function(e,t,n,r){
const o=globalThis.Object.values(e.$defs)
;return bUe(e.$defs[e.$ref],[...t,...o],n,r)}(a,o,n,r);case"Intersect":
return vUe(a,o,n);case"Never":return function(e,t,n){
throw new hUe(e,"Never types cannot be cast")}(a);case"Object":
return function(e,t,n,r){if(r.has(n))return r.get(n);if(Yje(e,t,n))return n
;if(null===n||"object"!=typeof n)return pUe(e,t)
;const o=new Set(e.required||[]),a={};r.set(n,a)
;for(const[i,s]of Object.entries(e.properties))(o.has(i)||void 0!==n[i])&&(a[i]=bUe(s,t,n[i],r))
;if("object"==typeof e.additionalProperties){
const o=Object.getOwnPropertyNames(e.properties)
;for(const i of Object.getOwnPropertyNames(n))o.includes(i)||(a[i]=bUe(e.additionalProperties,t,n[i],r))
}return a}(a,o,n,r);case"Record":return function(e,t,n,r){
if(Yje(e,t,n))return iUe(n)
;if(null===n||"object"!=typeof n||Array.isArray(n)||n instanceof Date)return pUe(e,t)
;const o=Object.getOwnPropertyNames(e.patternProperties)[0],a=e.patternProperties[o],i={}
;for(const[s,l]of Object.entries(n))i[s]=bUe(a,t,l,r);return i}(a,o,n,r)
;case"Ref":case"This":return function(e,t,n,r){return bUe(Pje(e,t),t,n,r)
}(a,o,n,r);case"Tuple":return function(e,t,n,r){
return Yje(e,t,n)?iUe(n):ETe(n)?void 0===e.items?[]:e.items.map(((e,o)=>bUe(e,t,n[o],r))):pUe(e,t)
}(a,o,n,r);case"Union":return function(e,t,n,r){
return Yje(e,t,n)?iUe(n):mUe(e,t,n,r)}(a,o,n,r);case"Date":case"Symbol":
case"Uint8Array":return function(e,t,n){return Yje(e,t,n)?iUe(n):pUe(e,t)
}(e,t,n);default:return function(e,t,n){return Yje(e,t,n)?n:pUe(e,t)}(a,o,n)}}
function yUe(...e){
return 2===e.length||3===e.length&&e[2]instanceof WeakMap?bUe(e[0],[],e[1],e[2]??new WeakMap):bUe(e[0],e[1],e[2],e[3]??new WeakMap)
}const OUe=(e,t)=>yUe(e,t),wUe=(...e)=>jPe.Composite(e),xUe={
navigation:"x-scalar-navigation"},kUe={activeDocument:"x-scalar-active-document"
},SUe=jPe.Object({name:jPe.String(),value:jPe.Union([jPe.Object({
description:jPe.Optional(jPe.String()),default:jPe.String({default:""})
}),jPe.String()])}),_Ue=jPe.Object({description:jPe.Optional(jPe.String()),
color:jPe.String({default:"#FFFFFF"}),variables:jPe.Array(SUe)
}),TUe=jPe.Object({
"x-scalar-environments":jPe.Optional(jPe.Record(jPe.String(),_Ue))
}),EUe=jPe.Object({"x-scalar-icon":jPe.Optional(jPe.String())}),AUe=jPe.Object({
"x-scalar-is-dirty":jPe.Optional(jPe.Boolean())}),CUe=jPe.Object({
"x-scalar-set-operation-security":jPe.Optional(jPe.Boolean({default:!1}))
}),$Ue=jPe.Object({name:jPe.String(),value:jPe.String(),
domain:jPe.Optional(jPe.String()),path:jPe.Optional(jPe.String()),
isDisabled:jPe.Optional(jPe.Boolean())}),PUe=jPe.Object({
"x-scalar-cookies":jPe.Optional(jPe.Array($Ue))}),DUe=jPe.Object({
"x-scalar-order":jPe.Optional(jPe.Array(jPe.String()))
}),IUe="ComponentsObject",MUe="SecurityRequirementObject",NUe="TagObject",RUe="CallbackObject",LUe="PathsObject",BUe="PathItemObject",jUe="OperationObject",UUe="SchemaObject",zUe="EncodingObject",FUe="HeaderObject",ZUe="MediaTypeObject",QUe="ServerObject",HUe="ExternalDocumentationObject",VUe="InfoObject",qUe="ContactObject",WUe="LicenseObject",XUe="ResponseObject",GUe="ResponsesObject",YUe="ParameterObject",KUe="ExampleObject",JUe="RequestBodyObject",eze="SecuritySchemeObject",tze="SecuritySchemes",nze="LinkObject",rze="XMLObject",oze="DiscriminatorObject",aze="OAuthFlowsObject",ize="ServerVariableObject",sze="TraversedDescriptionObject",lze="TraversedOperationObject",cze="TraversedSchemaObject",uze="TraversedWebhookObject",dze="TraversedTagObject",pze="TraversedEntryObject",hze="TraversedDocumentObject",fze="XScalarSelectedSecurity",mze=jPe.Ref(IUe),gze=jPe.Ref(MUe),vze=jPe.Ref(NUe),bze=jPe.Ref(RUe),yze=jPe.Ref(BUe),Oze=jPe.Ref(LUe),wze=jPe.Ref(jUe),xze=jPe.Ref(UUe),kze=jPe.Ref(zUe),Sze=jPe.Ref(FUe),_ze=jPe.Ref(ZUe),Tze=jPe.Ref(QUe),Eze=jPe.Ref(HUe),Aze=jPe.Ref(VUe),Cze=jPe.Ref(qUe),$ze=jPe.Ref(WUe),Pze=jPe.Ref(XUe),Dze=jPe.Ref(GUe),Ize=jPe.Ref(YUe),Mze=jPe.Ref(KUe),Nze=jPe.Ref(JUe),Rze=jPe.Ref(eze),Lze=jPe.Ref(nze),Bze=jPe.Ref(rze),jze=jPe.Ref(oze),Uze=jPe.Ref(aze),zze=jPe.Ref(ize),Fze=jPe.Ref(pze),Zze=jPe.Ref(hze),Qze=jPe.Object({
"x-scalar-selected-security":jPe.Optional(jPe.Object({
selectedIndex:jPe.Integer(),selectedSchemes:jPe.Array(gze)}))}),Hze=jPe.Object({
"x-scalar-selected-server":jPe.Optional(jPe.String())}),Vze=wUe(jPe.Object({
name:jPe.String(),tags:jPe.Array(jPe.String())}),DUe),qze=jPe.Object({
"x-tagGroups":jPe.Optional(jPe.Array(Vze))}),Wze=jPe.Object({id:jPe.String(),
title:jPe.String()}),Xze=wUe(Wze,jPe.Object({type:jPe.Literal("document"),
name:jPe.String(),children:jPe.Optional(jPe.Array(Fze)),
icon:jPe.Optional(jPe.String())})),Gze=wUe(Wze,jPe.Object({
type:jPe.Literal("text"),children:jPe.Optional(jPe.Array(Fze))
})),Yze=wUe(Wze,jPe.Object({type:jPe.Literal("example"),name:jPe.String()
})),Kze=wUe(Wze,jPe.Object({type:jPe.Literal("operation"),ref:jPe.String(),
method:jPe.Union(PH.map((e=>jPe.Literal(e)))),path:jPe.String(),
isDeprecated:jPe.Optional(jPe.Boolean()),children:jPe.Optional(jPe.Array(Fze))
})),Jze=wUe(Wze,jPe.Object({type:jPe.Literal("model"),ref:jPe.String(),
name:jPe.String()})),eFe=wUe(Wze,jPe.Object({type:jPe.Literal("webhook"),
ref:jPe.String(),method:jPe.Union(PH.map((e=>jPe.Literal(e)))),
name:jPe.String(),isDeprecated:jPe.Optional(jPe.Boolean())
})),tFe=wUe(Wze,jPe.Object({type:jPe.Literal("tag"),name:jPe.String(),
description:jPe.Optional(jPe.String()),children:jPe.Optional(jPe.Array(Fze)),
isGroup:jPe.Boolean(),isWebhooks:jPe.Optional(jPe.Boolean()),
xKeys:jPe.Optional(jPe.Record(jPe.String(),jPe.Unknown()))
})),nFe=wUe(Wze,jPe.Object({type:jPe.Literal("models"),name:jPe.String(),
children:jPe.Optional(jPe.Array(Fze))
})),rFe=jPe.Union([Gze,Kze,Jze,tFe,eFe,Yze,Xze,nFe]),oFe=jPe.Object({
$status:jPe.Optional(jPe.Union([jPe.Literal("loading"),jPe.Literal("error")])),
$global:jPe.Optional(jPe.Boolean())}),aFe=wUe(jPe.Object({$ref:jPe.String(),
summary:jPe.Optional(jPe.String()),description:jPe.Optional(jPe.String())
}),oFe),iFe=e=>wUe(aFe,jPe.Object({"$ref-value":e
})),sFe=jPe.Record(jPe.String(),jPe.Union([yze,iFe(yze)])),lFe=jPe.Record(jPe.String(),jPe.Union([Rze,iFe(Rze)])),cFe=jPe.Object({
schemas:jPe.Optional(jPe.Record(jPe.String(),jPe.Union([xze,iFe(xze)]))),
responses:jPe.Optional(jPe.Record(jPe.String(),jPe.Union([Pze,iFe(Pze)]))),
parameters:jPe.Optional(jPe.Record(jPe.String(),jPe.Union([Ize,iFe(Ize)]))),
examples:jPe.Optional(jPe.Record(jPe.String(),jPe.Union([Mze,iFe(Mze)]))),
requestBodies:jPe.Optional(jPe.Record(jPe.String(),jPe.Union([Nze,iFe(Nze)]))),
headers:jPe.Optional(jPe.Record(jPe.String(),jPe.Union([Sze,iFe(Sze)]))),
securitySchemes:jPe.Optional(lFe),
links:jPe.Optional(jPe.Record(jPe.String(),jPe.Union([Lze,iFe(Lze)]))),
callbacks:jPe.Optional(jPe.Record(jPe.String(),jPe.Union([bze,iFe(bze)]))),
pathItems:jPe.Optional(jPe.Record(jPe.String(),yze))}),uFe=jPe.Object({
name:jPe.Optional(jPe.String()),url:jPe.Optional(jPe.String()),
email:jPe.Optional(jPe.String())}),dFe=jPe.Object({propertyName:jPe.String(),
mapping:jPe.Optional(jPe.Record(jPe.String(),jPe.String()))}),pFe=jPe.Object({
contentType:jPe.Optional(jPe.String()),
headers:jPe.Optional(jPe.Record(jPe.String(),jPe.Union([Sze,iFe(Sze)])))
}),hFe=jPe.Object({"x-disabled":jPe.Optional(jPe.Boolean())
}),fFe=wUe(jPe.Object({summary:jPe.Optional(jPe.String()),
description:jPe.Optional(jPe.String()),value:jPe.Optional(jPe.Any()),
externalValue:jPe.Optional(jPe.String())}),hFe),mFe=jPe.Object({
url:jPe.String(),description:jPe.Optional(jPe.String())}),gFe=jPe.Object({
description:jPe.Optional(jPe.String()),required:jPe.Optional(jPe.Boolean()),
deprecated:jPe.Optional(jPe.Boolean())}),vFe=wUe(gFe,jPe.Object({
style:jPe.Optional(jPe.String()),explode:jPe.Optional(jPe.Boolean()),
schema:jPe.Optional(jPe.Union([xze,iFe(xze)])),example:jPe.Optional(jPe.Any()),
examples:jPe.Optional(jPe.Record(jPe.String(),jPe.Union([Mze,iFe(Mze)])))
})),bFe=jPe.Union([vFe,wUe(gFe,jPe.Object({
content:jPe.Optional(jPe.Record(jPe.String(),_ze))}))]),yFe=jPe.Object({
"x-scalar-sdk-installation":jPe.Optional(jPe.Array(jPe.Object({
lang:jPe.String(),source:jPe.Optional(jPe.String()),
description:jPe.Optional(jPe.String())})))}),OFe=wUe(jPe.Object({
title:jPe.String(),version:jPe.String(),summary:jPe.Optional(jPe.String()),
description:jPe.Optional(jPe.String()),
termsOfService:jPe.Optional(jPe.String()),contact:jPe.Optional(Cze),
license:jPe.Optional($ze)}),yFe),wFe=jPe.Object({
name:jPe.Optional(jPe.String()),identifier:jPe.Optional(jPe.String()),
url:jPe.Optional(jPe.String())}),xFe=jPe.Object({
operationRef:jPe.Optional(jPe.String()),operationId:jPe.Optional(jPe.String()),
parameters:jPe.Optional(jPe.Record(jPe.String(),jPe.Any())),
requestBody:jPe.Optional(jPe.Any()),description:jPe.Optional(jPe.String()),
server:jPe.Optional(Tze)}),kFe=jPe.Object({
schema:jPe.Optional(jPe.Union([xze,iFe(xze)])),example:jPe.Optional(jPe.Any()),
examples:jPe.Optional(jPe.Record(jPe.String(),jPe.Union([Mze,iFe(Mze)]))),
encoding:jPe.Optional(jPe.Record(jPe.String(),kze))}),SFe=jPe.Object({
"x-scalar-credentials-location":jPe.Optional(jPe.Union([jPe.Literal("header"),jPe.Literal("body")]))
}),_Fe=jPe.Object({
"x-scalar-security-body":jPe.Optional(jPe.Record(jPe.String(),jPe.String()))
}),TFe=jPe.Object({
"x-scalar-security-query":jPe.Optional(jPe.Record(jPe.String(),jPe.String()))
}),EFe=jPe.Object({"x-scalar-secret-token":jPe.String()}),AFe=jPe.Object({
"x-scalar-secret-username":jPe.String(),"x-scalar-secret-password":jPe.String()
}),CFe=jPe.Object({"x-scalar-secret-client-secret":jPe.String()
}),$Fe=jPe.Object({"x-scalar-secret-client-id":jPe.String()}),PFe=jPe.Object({
"x-scalar-secret-redirect-uri":jPe.String()}),DFe=jPe.Object({
"x-tokenName":jPe.Optional(jPe.String())}),IFe=jPe.Object({
"x-usePkce":jPe.Union([jPe.Literal("SHA-256"),jPe.Literal("plain"),jPe.Literal("no")],{
default:"no"})}),MFe=wUe(jPe.Object({refreshUrl:jPe.String(),
scopes:jPe.Record(jPe.String(),jPe.String())
}),$Fe,EFe,TFe,_Fe,DFe),NFe=wUe(MFe,jPe.Object({authorizationUrl:jPe.String()
}),PFe),RFe=wUe(MFe,jPe.Object({tokenUrl:jPe.String()
}),AFe,CFe,SFe),LFe=wUe(MFe,jPe.Object({tokenUrl:jPe.String()
}),CFe,SFe),BFe=wUe(MFe,jPe.Object({authorizationUrl:jPe.String(),
tokenUrl:jPe.String()}),CFe,PFe,IFe,SFe),jFe=jPe.Object({
implicit:jPe.Optional(NFe),password:jPe.Optional(RFe),
clientCredentials:jPe.Optional(LFe),authorizationCode:jPe.Optional(BFe)
}),UFe=jPe.Object({"x-internal":jPe.Optional(jPe.Boolean())}),zFe=jPe.Object({
"x-scalar-ignore":jPe.Optional(jPe.Boolean())
}),FFe=jPe.Record(jPe.String(),jPe.Boolean()),ZFe=jPe.Record(jPe.String(),FFe),QFe=jPe.Object({
"x-scalar-disable-parameters":jPe.Optional(jPe.Object({
"global-cookies":jPe.Optional(ZFe),"global-headers":jPe.Optional(ZFe),
"default-headers":jPe.Optional(ZFe)}))}),HFe=jPe.Object({name:jPe.String(),
value:jPe.String()}),VFe=jPe.Object({url:jPe.String(),method:jPe.String(),
httpVersion:jPe.String(),headers:jPe.Array(HFe),cookies:jPe.Array(HFe),
headersSize:jPe.Number(),queryString:jPe.Array(HFe),bodySize:jPe.Number(),
postData:jPe.Optional(jPe.Union([jPe.Object({mimeType:jPe.String(),
text:jPe.String()}),jPe.Object({mimeType:jPe.String(),
params:jPe.Array(jPe.Object({name:jPe.String(),value:jPe.Optional(jPe.String())
}))})]))}),qFe=jPe.Object({status:jPe.Number(),statusText:jPe.String(),
headers:jPe.Array(HFe),cookies:jPe.Array(HFe),httpVersion:jPe.String(),
redirectURL:jPe.String(),headersSize:jPe.Number(),bodySize:jPe.Number(),
content:jPe.Object({size:jPe.Number(),mimeType:jPe.String(),
encoding:jPe.Optional(jPe.String()),text:jPe.Optional(jPe.String())})
}),WFe=jPe.Object({time:jPe.Number(),timestamp:jPe.Number(),request:VFe,
response:qFe,meta:jPe.Object({example:jPe.String()}),
requestMetadata:jPe.Object({variables:jPe.Record(jPe.String(),jPe.String())})
}),XFe=jPe.Object({"x-scalar-history":jPe.Optional(jPe.Array(WFe))
}),GFe=wUe(jPe.Object({tags:jPe.Optional(jPe.Array(jPe.String())),
summary:jPe.Optional(jPe.String()),description:jPe.Optional(jPe.String()),
externalDocs:jPe.Optional(Eze),operationId:jPe.Optional(jPe.String()),
parameters:jPe.Optional(jPe.Array(jPe.Union([Ize,iFe(Ize)]))),
requestBody:jPe.Optional(jPe.Union([Nze,iFe(Nze)])),responses:jPe.Optional(Dze),
deprecated:jPe.Optional(jPe.Boolean()),security:jPe.Optional(jPe.Array(gze)),
servers:jPe.Optional(jPe.Array(Tze)),
callbacks:jPe.Optional(jPe.Record(jPe.String(),jPe.Union([bze,iFe(bze)])))
}),Qze,zPe,UFe,zFe,ZPe,VPe,QFe,XFe),YFe=jPe.Object({
"x-global":jPe.Optional(jPe.Boolean())}),KFe=wUe(jPe.Object({name:jPe.String(),
in:jPe.Union([jPe.Literal("query"),jPe.Literal("header"),jPe.Literal("path"),jPe.Literal("cookie")]),
description:jPe.Optional(jPe.String()),required:jPe.Optional(jPe.Boolean()),
deprecated:jPe.Optional(jPe.Boolean()),
allowEmptyValue:jPe.Optional(jPe.Boolean())
}),YFe,UFe,zFe),JFe=wUe(KFe,jPe.Object({style:jPe.Optional(jPe.String()),
explode:jPe.Optional(jPe.Boolean()),
schema:jPe.Optional(jPe.Union([xze,iFe(xze)])),example:jPe.Optional(jPe.Any()),
examples:jPe.Optional(jPe.Record(jPe.String(),jPe.Union([Mze,iFe(Mze)])))
})),eZe=wUe(KFe,jPe.Object({content:jPe.Optional(jPe.Record(jPe.String(),_ze))
})),tZe=jPe.Union([JFe,eZe]),nZe=jPe.Object({$ref:jPe.Optional(jPe.String()),
summary:jPe.Optional(jPe.String()),description:jPe.Optional(jPe.String()),
get:jPe.Optional(jPe.Union([wze,iFe(wze)])),
put:jPe.Optional(jPe.Union([wze,iFe(wze)])),
post:jPe.Optional(jPe.Union([wze,iFe(wze)])),
delete:jPe.Optional(jPe.Union([wze,iFe(wze)])),
patch:jPe.Optional(jPe.Union([wze,iFe(wze)])),
connect:jPe.Optional(jPe.Union([wze,iFe(wze)])),
options:jPe.Optional(jPe.Union([wze,iFe(wze)])),
head:jPe.Optional(jPe.Union([wze,iFe(wze)])),
trace:jPe.Optional(jPe.Union([wze,iFe(wze)])),
servers:jPe.Optional(jPe.Array(Tze)),
parameters:jPe.Optional(jPe.Array(jPe.Union([Ize,iFe(Ize)])))
}),rZe=jPe.Record(jPe.String(),yze),oZe=wUe(jPe.Object({
description:jPe.Optional(jPe.String()),content:jPe.Record(jPe.String(),_ze),
required:jPe.Optional(jPe.Boolean())}),QPe),aZe=jPe.Object({
description:jPe.String(),
headers:jPe.Optional(jPe.Record(jPe.String(),jPe.Union([Sze,iFe(Sze)]))),
content:jPe.Optional(jPe.Record(jPe.String(),_ze)),
links:jPe.Optional(jPe.Record(jPe.String(),jPe.Union([Lze,iFe(Lze)])))
}),iZe=jPe.Record(jPe.String(),jPe.Union([Pze,iFe(Pze)])),sZe=jPe.Object({
"x-tags":jPe.Optional(jPe.Array(jPe.String()))}),lZe=jPe.Object({
"x-additionalPropertiesName":jPe.Optional(jPe.String())}),cZe=jPe.Object({
"x-enumDescriptions":jPe.Optional(jPe.Union([jPe.Record(jPe.String(),jPe.String()),jPe.Array(jPe.String())])),
"x-enum-descriptions":jPe.Optional(jPe.Union([jPe.Record(jPe.String(),jPe.String()),jPe.Array(jPe.String())]))
}),uZe=jPe.Object({"x-enum-varnames":jPe.Optional(jPe.Array(jPe.String())),
"x-enumNames":jPe.Optional(jPe.Array(jPe.String()))}),dZe=jPe.Object({
"x-examples":jPe.Optional(jPe.Record(jPe.String(),jPe.Unknown()))
}),pZe=jPe.Object({"x-variable":jPe.Optional(jPe.String())
}),hZe=jPe.Union([xze,iFe(xze)]),fZe=jPe.Object({
type:jPe.Union([jPe.Literal("null"),jPe.Literal("boolean"),jPe.Array(jPe.Union([jPe.Literal("null"),jPe.Literal("boolean"),jPe.Literal("string"),jPe.Literal("number"),jPe.Literal("integer"),jPe.Literal("object"),jPe.Literal("array")]))])
}),mZe=wUe(zFe,UFe,pZe,dZe,cZe,uZe,lZe,sZe),gZe=jPe.Object({
name:jPe.Optional(jPe.String()),title:jPe.Optional(jPe.String()),
description:jPe.Optional(jPe.String()),default:jPe.Optional(jPe.Unknown()),
enum:jPe.Optional(jPe.Array(jPe.Unknown())),const:jPe.Optional(jPe.Unknown()),
contentMediaType:jPe.Optional(jPe.String()),
contentEncoding:jPe.Optional(jPe.String()),contentSchema:jPe.Optional(hZe),
deprecated:jPe.Optional(jPe.Boolean()),discriminator:jPe.Optional(jze),
readOnly:jPe.Optional(jPe.Boolean()),writeOnly:jPe.Optional(jPe.Boolean()),
xml:jPe.Optional(Bze),externalDocs:jPe.Optional(Eze),
example:jPe.Optional(jPe.Unknown()),
examples:jPe.Optional(jPe.Array(jPe.Unknown())),
allOf:jPe.Optional(jPe.Array(hZe)),oneOf:jPe.Optional(jPe.Array(hZe)),
anyOf:jPe.Optional(jPe.Array(hZe)),not:jPe.Optional(hZe)}),vZe=jPe.Object({
type:jPe.Union([jPe.Literal("number"),jPe.Literal("integer")]),
format:jPe.Optional(jPe.String()),multipleOf:jPe.Optional(jPe.Number()),
maximum:jPe.Optional(jPe.Number()),exclusiveMaximum:jPe.Optional(jPe.Number({
minimum:0})),minimum:jPe.Optional(jPe.Number()),
exclusiveMinimum:jPe.Optional(jPe.Number({minimum:0}))}),bZe=jPe.Object({
type:jPe.Literal("string"),format:jPe.Optional(jPe.String()),
maxLength:jPe.Optional(jPe.Integer({minimum:0})),
minLength:jPe.Optional(jPe.Integer({minimum:0})),
pattern:jPe.Optional(jPe.String())}),yZe=jPe.Object({type:jPe.Literal("array"),
maxItems:jPe.Optional(jPe.Integer({minimum:0})),
minItems:jPe.Optional(jPe.Integer({minimum:0})),
uniqueItems:jPe.Optional(jPe.Boolean()),items:jPe.Optional(hZe),
prefixItems:jPe.Optional(jPe.Array(hZe))}),OZe=jPe.Object({
type:jPe.Literal("object"),maxProperties:jPe.Optional(jPe.Integer({minimum:0})),
minProperties:jPe.Optional(jPe.Integer({minimum:0})),
required:jPe.Optional(jPe.Array(jPe.String())),
properties:jPe.Optional(jPe.Record(jPe.String(),hZe)),
additionalProperties:jPe.Optional(jPe.Union([jPe.Boolean(),hZe])),
patternProperties:jPe.Optional(jPe.Record(jPe.String(),hZe))
}),wZe=jPe.Union([wUe(jPe.Object({__scalar_:jPe.String()
}),gZe,mZe),wUe(fZe,gZe,mZe),wUe(vZe,gZe,mZe),wUe(bZe,gZe,mZe),wUe(OZe,gZe,mZe),wUe(yZe,gZe,mZe)]),xZe=jPe.Partial(jPe.Record(jPe.String(),jPe.Array(jPe.String()))),kZe=jPe.Object({
"x-default-scopes":jPe.Optional(jPe.Array(jPe.String()))}),SZe=jPe.Object({
description:jPe.Optional(jPe.String())}),_Ze=wUe(SZe,EFe,jPe.Object({
type:jPe.Literal("apiKey"),name:jPe.String(),
in:jPe.Union([jPe.Literal("query"),jPe.Literal("header"),jPe.Literal("cookie")])
})),TZe=wUe(SZe,EFe,AFe,jPe.Object({type:jPe.Literal("http"),
scheme:jPe.Union([jPe.Literal("basic"),jPe.Literal("bearer")]),
bearerFormat:jPe.Optional(jPe.String())})),EZe=wUe(SZe,jPe.Object({
type:jPe.Literal("oauth2"),flows:Uze}),kZe),AZe=wUe(SZe,jPe.Object({
type:jPe.Literal("openIdConnect"),openIdConnectUrl:jPe.String()
})),CZe=jPe.Union([_Ze,TZe,EZe,AZe]),$Ze=jPe.Object({url:jPe.String(),
description:jPe.Optional(jPe.String()),
variables:jPe.Optional(jPe.Record(jPe.String(),zze))}),PZe=jPe.Object({
enum:jPe.Optional(jPe.Array(jPe.String())),default:jPe.Optional(jPe.String()),
description:jPe.Optional(jPe.String())}),DZe=jPe.Object({
"x-displayName":jPe.Optional(jPe.String())}),IZe=wUe(jPe.Object({
name:jPe.String(),description:jPe.Optional(jPe.String()),
externalDocs:jPe.Optional(Eze)}),DZe,UFe,zFe,DUe),MZe=jPe.Object({
name:jPe.Optional(jPe.String()),namespace:jPe.Optional(jPe.String()),
prefix:jPe.Optional(jPe.String()),attribute:jPe.Optional(jPe.Boolean()),
wrapped:jPe.Optional(jPe.Boolean())}),NZe=wUe(jPe.Partial(jPe.Object({
"x-scalar-client-config-active-environment":jPe.String(),
"x-original-oas-version":jPe.String(),
"x-scalar-original-source-url":jPe.String(),[xUe.navigation]:Zze
})),qze,TUe,Qze,Hze,CUe,EUe,DUe,PUe,jPe.Object({
"x-scalar-original-document-hash":jPe.String()}),AUe),RZe=wUe(jPe.Object({
openapi:jPe.String(),info:Aze,jsonSchemaDialect:jPe.Optional(jPe.String()),
servers:jPe.Optional(jPe.Array(Tze)),paths:jPe.Optional(Oze),
webhooks:jPe.Optional(jPe.Record(jPe.String(),yze)),
components:jPe.Optional(mze),security:jPe.Optional(jPe.Array(gze)),
tags:jPe.Optional(jPe.Array(vze)),externalDocs:jPe.Optional(Eze)
}),NZe),LZe=jPe.Module({[IUe]:cFe,[MUe]:xZe,[NUe]:IZe,[RUe]:sFe,[BUe]:nZe,
[LUe]:rZe,[jUe]:GFe,[UUe]:wZe,[zUe]:pFe,[ZUe]:kFe,[FUe]:bFe,[QUe]:$Ze,[HUe]:mFe,
[VUe]:OFe,[qUe]:uFe,[WUe]:wFe,[XUe]:aZe,[GUe]:iZe,[YUe]:tZe,[KUe]:fFe,[JUe]:oZe,
[tze]:lFe,[eze]:CZe,[nze]:xFe,[rze]:MZe,[oze]:dFe,[aze]:jFe,[ize]:PZe,
OpenApiDocument:RZe,[sze]:Gze,[lze]:Kze,[cze]:Jze,[uze]:eFe,[dze]:tFe,[pze]:rFe,
[hze]:Xze,[fze]:Qze}),BZe=LZe.Import("OpenApiDocument")
;LZe.Import("ComponentsObject"),
LZe.Import("SecurityRequirementObject"),LZe.Import("TagObject"),
LZe.Import("CallbackObject"),
LZe.Import("PathItemObject"),LZe.Import("PathsObject"),
LZe.Import("OperationObject"),
LZe.Import("SchemaObject"),LZe.Import("EncodingObject"),
LZe.Import("MediaTypeObject"),LZe.Import("HeaderObject")
;const jZe=LZe.Import("ServerObject");LZe.Import("ExternalDocumentationObject"),
LZe.Import("InfoObject"),
LZe.Import("ContactObject"),LZe.Import("LicenseObject"),
LZe.Import("ResponseObject"),
LZe.Import("ResponsesObject"),LZe.Import("ParameterObject"),
LZe.Import("ExampleObject"),LZe.Import("RequestBodyObject")
;const UZe=LZe.Import("SecuritySchemes"),zZe=LZe.Import("SecuritySchemeObject")
;LZe.Import("LinkObject"),
LZe.Import("XMLObject"),LZe.Import("DiscriminatorObject"),
LZe.Import("OAuthFlowsObject"),
LZe.Import("ServerVariableObject"),LZe.Import("TraversedDescriptionObject"),
LZe.Import("TraversedEntryObject"),
LZe.Import("TraversedTagObject"),LZe.Import("TraversedOperationObject"),
LZe.Import("TraversedSchemaObject"),LZe.Import("TraversedWebhookObject")
;const FZe=LZe.Import("XScalarSelectedSecurity"),ZZe={
clientSecret:"x-scalar-secret-client-secret",
password:"x-scalar-secret-password",token:"x-scalar-secret-token",
username:"x-scalar-secret-username",value:"x-scalar-secret-token",
"x-scalar-client-id":"x-scalar-secret-client-id",
"x-scalar-redirect-uri":"x-scalar-secret-redirect-uri"},QZe=e=>{const t={...e}
;for(const[n,r]of Tje(ZZe))e[n]&&(t[r]||=e[n]);return t},HZe=e=>{
if("oauth2"===e.type){
const t=new Set,n=Tje(e.flows??{}).reduce(((e,[n,r])=>(e[n]=r&&QZe(r),
r?.selectedScopes?.forEach((e=>t.add(e))),
e)),{}),r=t.size>0&&!e["x-default-scopes"]?.length?{
"x-default-scopes":Array.from(t)}:{};return OUe(zZe,{...e,flows:n,...r})}
return OUe(zZe,QZe(e))},VZe=e=>{const t=new WeakSet,n=e=>{
if(null==e||"object"!=typeof e)return e;const r=sSe(e)
;if(t.has(r))return"[circular]"
;if(t.add(r),"object"==typeof e&&null!==e&&"$ref"in e){
const o=e["$ref-value"],a=n(o);return t.delete(r),a}if(Array.isArray(e)){
const o=e.map((e=>n(e)));return t.delete(r),o}
if(e instanceof File||e instanceof Date)return t.delete(r),e
;if("object"==typeof e&&null!==e){const o={}
;for(const[t,r]of Object.entries(e))o[t]=n(r);return t.delete(r),o}
return t.delete(r),e};return n(e)},qZe=(e={},t={})=>{
const n=VZe(e),r=Eje(n,t)??{}
;return Object.fromEntries(Tje(r).map((([e,t])=>[e,HZe(t)])))}
;async function WZe({defaultValue:e,validation:t,transformation:n,maxRetries:r=5}){
const o=n?.(e)??e;return await t(o)?o:XZe({value:[o,1],validation:t,
maxRetries:r,transformation:n})}
async function XZe({value:e,validation:t,maxRetries:n,attempts:r=0,transformation:o}){
if(r>=n)return;const a=e.join(" "),i=o?.(a)??a;return await t(i)?i:XZe({
value:[e[0],e[1]+1],validation:t,maxRetries:n,transformation:o,attempts:r+1})}
const GZe=(e,{id:t,name:n,scopes:r,newScopePayload:o,meta:a})=>{if(!e)return
;const i="document"===a.type?e:qke(e.paths?.[a.path]?.[a.method]);if(!i)return
;const s=i["x-scalar-selected-security"]?.selectedSchemes;if(!s)return
;const l=s.find((e=>JSON.stringify(Object.keys(e))===JSON.stringify(t)))
;if(void 0!==(c=l)&&Object.keys(c).length>0){var c;if(o){
const t=qke(e.components?.securitySchemes?.[n]),a=t?.flows?.[o?.flowType]
;if(!a)return
;return a.scopes||={},a.scopes[o.name]=o.description,void(l[n]=[...r,o.name])}
l[n]=r}},YZe=({document:e})=>({
updateSelectedSecuritySchemes:t=>(async(e,{selectedRequirements:t,newSchemes:n,meta:r})=>{
if(!e)return;const o=(await Promise.all(n.map((async t=>{const n=await WZe({
defaultValue:t.name,validation:t=>!e.components?.securitySchemes?.[t],
maxRetries:100})
;if(n)return e.components||(e.components={}),e.components.securitySchemes||(e.components.securitySchemes={}),
e.components.securitySchemes[n]=t.scheme,{[n]:[]}
})))).filter(Boolean),a="document"===r.type?e:qke(e.paths?.[r.path]?.[r.method]),i=[...t,...o]
;if(!a)return
;a["x-scalar-selected-security"]||(a["x-scalar-selected-security"]={
selectedIndex:-1,selectedSchemes:[]})
;const s=a["x-scalar-selected-security"].selectedIndex
;a["x-scalar-selected-security"].selectedSchemes=i,
i.length>0&&s<0&&(a["x-scalar-selected-security"].selectedIndex=0),
s>=i.length&&(a["x-scalar-selected-security"].selectedIndex=i.length-1)})(e,t),
updateSecurityScheme:t=>((e,{payload:t,name:n})=>{
const r=qke(e?.components?.securitySchemes?.[n])
;if(r)return r.type===t.type&&Eje(r,t),r
;console.error(`Security scheme ${n} not found`)})(e,t),
updateSelectedAuthTab:t=>((e,{index:t,meta:n})=>{if(!e)return
;const r="document"===n.type?e:qke(e.paths?.[n.path]?.[n.method])
;r&&(r["x-scalar-selected-security"]||(r["x-scalar-selected-security"]={
selectedIndex:0,selectedSchemes:[]
}),r["x-scalar-selected-security"].selectedIndex=t)})(e,t),
updateSelectedScopes:t=>GZe(e,t),deleteSecurityScheme:t=>((e,{names:t})=>{
if(!e)return;const n=qke(e.components?.securitySchemes);if(!n)return
;t.forEach((e=>{delete n[e]}))
;const r=e=>e.filter((e=>!t.some((t=>Object.keys(e).includes(t)))))
;if(e["x-scalar-selected-security"]){const t=e["x-scalar-selected-security"]
;t.selectedSchemes=r(t.selectedSchemes)}
e.security&&(e.security=r(e.security)),Object.values(e.paths??{}).forEach((e=>{
Object.values(e).forEach((e=>{if("object"!=typeof e)return;const t=qke(e)
;"security"in t&&t.security&&(t.security=r(t.security)),
"x-scalar-selected-security"in t&&t["x-scalar-selected-security"]&&(t["x-scalar-selected-security"].selectedSchemes=r(t["x-scalar-selected-security"].selectedSchemes))
}))}))})(e,t)}),KZe=({collection:e})=>({
upsertCookie:t=>((e,{payload:t,index:n})=>{if(!e)return
;if(e["x-scalar-cookies"]||(e["x-scalar-cookies"]=[]),void 0!==n){
if(n<0||n>=e["x-scalar-cookies"].length)return;const r=OUe($Ue,{
...e["x-scalar-cookies"][n],...t});return e["x-scalar-cookies"][n]=r,r}
const r=OUe($Ue,t);return e["x-scalar-cookies"].push(r),r})(e,t),
deleteCookie:t=>((e,{index:t})=>!(!e||!e["x-scalar-cookies"]||t<0||t>=e["x-scalar-cookies"].length||(e["x-scalar-cookies"].splice(t,1),
0)))(e,t)}),JZe=({document:e,store:t})=>({toggleSecurity:()=>(e=>{
e&&(e["x-scalar-set-operation-security"]=!e["x-scalar-set-operation-security"])
})(e),updateDocumentInfo:t=>((e,t)=>{e&&Eje(e.info,t)})(e,t),
updateWatchMode:t=>((e,t)=>{e&&(e["x-scalar-watch-mode"]=t)})(e,t),
updateDocumentIcon:t=>((e,t)=>{
e&&e["x-scalar-navigation"]&&(e["x-scalar-icon"]=t,
e["x-scalar-navigation"].icon=t)})(e,t),createEmptyDocument:e=>(async(e,t)=>{
e&&(e.workspace.documents[t.name]?t.callback?.(!1):(await e.addDocument({
name:t.name,document:{openapi:"3.1.0",info:{title:t.name,version:"1.0.0"},
paths:{"/":{get:{}}},"x-scalar-icon":t.icon}}),t.callback?.(!0)))})(t,e),
deleteDocument:e=>((e,t)=>{e&&e.deleteDocument(t.name)})(t,e)
}),eQe=({workspace:e,collection:t})=>({
upsertEnvironment:n=>((e,t,{environmentName:n,payload:r,oldEnvironmentName:o})=>{
if(!t||!e)return;t["x-scalar-environments"]||(t["x-scalar-environments"]={})
;const a=!t["x-scalar-environments"][o??n],i=OUe(_Ue,{
...t["x-scalar-environments"][o??n],...r})
;return t["x-scalar-environments"][n]=i,
o&&o!==n&&(delete t["x-scalar-environments"][o],
e["x-scalar-active-environment"]===o&&(e["x-scalar-active-environment"]=n)),
a&&(e["x-scalar-active-environment"]=n),i})(e,t,n),
deleteEnvironment:n=>((e,t,{environmentName:n})=>{
t&&e&&delete t["x-scalar-environments"]?.[n]})(e,t,n),
upsertEnvironmentVariable:e=>((e,{environmentName:t,variable:n,index:r})=>{
if(!e?.["x-scalar-environments"]?.[t])return void console.error("Environment not found",t)
;const o=OUe(SUe,n);if(void 0!==r){
if(""===o.name)return void e["x-scalar-environments"][t].variables.splice(r,1)
;e["x-scalar-environments"][t].variables[r]=o
}else e["x-scalar-environments"][t].variables.push(o);return o})(t,e),
deleteEnvironmentVariable:e=>((e,{environmentName:t,index:n})=>{
e?.["x-scalar-environments"]?.[t]?e["x-scalar-environments"]?.[t]?.variables?.splice(n,1):console.error("Environment not found",t)
})(t,e)}),tQe=(e,t)=>{if(!e)return null;const n=e.workspace.documents[t]
;return n||null
},nQe=new Set(["__proto__","prototype","constructor"]),rQe=(e,t)=>{
if(nQe.has(e)){throw new Error(`Prototype pollution key detected: "${e}"`)}
},oQe=async e=>{const t=await async function(e){
if("function"!=typeof e.formData)return null;if(e.bodyUsed)return null
;const t=e.headers.get("content-type")??""
;if(!t.includes("multipart/form-data")&&!t.includes("application/x-www-form-urlencoded"))return null
;try{return await e.formData()}catch{return null}}(e.clone())
;if(t)return Array.from(t.entries()).reduce(((e,[t,n])=>{if(n instanceof File){
const r=`@${n.name}`;return e.params.push({name:t,value:r}),e.size+=r.length,e}
return e.params.push({name:t,value:n}),e.size+=n.length,e}),{params:[],size:0})
;if(e.headers.get("content-type")?.includes("application/octet-stream"))return{
text:"",size:-1};const n=await e.arrayBuffer();return{size:n.byteLength,
text:(new TextDecoder).decode(n)}}
;const aQe=e=>Array.from(e.headers.entries()).reduce(((e,[t,n])=>{
if("cookie"===t.toLowerCase()){const t=iQe(n);e.cookies.push(...t.cookies)
}else e.headers.push({name:t,value:n}),e.headersSize+=t.length+2+n.length+2
;return e}),{headers:[],headersSize:0,cookies:[]
}),iQe=e=>e.split(";").reduce(((e,t)=>{const n=t.trim(),r=n.indexOf("=")
;if(-1===r)return e;const o=n.substring(0,r).trim(),a=n.substring(r+1).trim()
;return e.cookies.push({name:o,value:a}),e.size+=o.length+2+a.length+2,e}),{
cookies:[],size:0}),sQe=e=>Array.from(e.headers.entries()).reduce(((e,[t,n])=>{
if(e.headers.push({name:t,value:n
}),e.headersSize+=t.length+2+n.length+2,"set-cookie"===t.toLowerCase()){
const t=uQe(n);t&&e.cookies.push(t)}return e}),{headers:[],headersSize:0,
cookies:[]}),lQe=async e=>{const t=e.headers.get("content-type")
;if(!t||!cQe(t))return{text:"",size:-1,encoding:void 0};try{
const t=await e.arrayBuffer(),n=t.byteLength;return{
text:new TextDecoder("utf-8").decode(t),size:n,encoding:void 0}}catch{return{
text:"",size:-1,encoding:void 0}}},cQe=e=>{const t=e.toLowerCase()
;return!!t.startsWith("text/")||(!(!t.includes("application/json")&&!t.includes("+json"))||(!!(t.includes("application/xml")||t.includes("text/xml")||t.includes("+xml"))||(!(!t.includes("application/javascript")&&!t.includes("application/x-javascript"))||!(!t.includes("application/x-www-form-urlencoded")&&!t.includes("application/graphql")))))
},uQe=e=>{const t=e.split(";");if(0===t.length||!t[0])return null
;const n=t[0].trim(),r=n.indexOf("=");if(-1===r)return null;return{
name:n.substring(0,r).trim(),value:n.substring(r+1).trim()}
},dQe=e=>"type"in e&&("array"===e.type||Array.isArray(e.type)&&e.type.includes("array")),pQe=e=>"type"in e&&("string"===e.type||Array.isArray(e.type)&&e.type.includes("string")),hQe=e=>"type"in e&&("number"===e.type||"integer"===e.type||Array.isArray(e.type)&&e.type.includes("number")||Array.isArray(e.type)&&e.type.includes("integer")),fQe=e=>"content"in e&&void 0!==e.content,mQe=({harRequest:e,exampleKey:t,baseOperation:n={},pathVariables:r={}})=>{
if(n.parameters||(n.parameters=[]),((e,t,n)=>{e.forEach((e=>{const r=qke(e)
;fQe(r)||(gQe(qke(e),n,!0),"path"===r.in&&(r.examples||={},r.examples[n]={
value:t[r.name]??"","x-disabled":!1}))}))
})(n.parameters,r,t),e.queryString&&e.queryString.length>0)for(const o of e.queryString){
const e=vQe(n.parameters,o.name,"query")
;e&&!fQe(e)&&(e.examples||={},e.examples[t]={value:o.value,"x-disabled":!1})}
if(e.headers&&e.headers.length>0)for(const o of e.headers){
const e=vQe(n.parameters,o.name,"header")
;e&&!fQe(e)&&(e.examples||={},e.examples[t]={value:o.value,"x-disabled":!1})}
if(e.cookies&&e.cookies.length>0)for(const o of e.cookies){
const e=vQe(n.parameters,o.name,"cookie")
;e&&!fQe(e)&&(e.examples||={},e.examples[t]={value:o.value,"x-disabled":!1})}
if(e.postData){const{mimeType:r,text:o,params:a}=e.postData
;n.requestBody||(n.requestBody={content:{}});const i=qke(n.requestBody)
;i.content[r]||(i.content[r]={schema:{type:"object"}});const s=i.content[r]
;if(!s)return n;let l;if(s.examples||={},a&&a.length>0){l=[]
;for(const e of a)l.push({name:e.name,value:e.value,"x-disabled":!1})}else l=o
;s.examples[t]={value:l,"x-disabled":!1
},i["x-scalar-selected-content-type"]||={},
i["x-scalar-selected-content-type"][t]=r}return n},gQe=(e,t,n)=>{
fQe(e)||e.examples?.[t]&&(qke(e.examples[t])["x-disabled"]=n)},vQe=(e,t,n)=>{
for(const o of e){const e=qke(o);if(fQe(e))continue;if(e.in!==n)continue
;if("header"===n?e.name.toLowerCase()===t.toLowerCase():e.name===t)return e}
const r={name:t,in:n,schema:{type:"string"}};return e.push(r),r},bQe=(e,t)=>{
const n={};for(const r of t){const t=e.indexOf(`{${r}}`);-1!==t&&(n[r]=t)}
return n},yQe=({store:e,operation:t,generateId:n,method:r,path:o,entries:a})=>{
a?.forEach((a=>{
if(!(e=>"document"===e.type||"tag"===e.type||"operation"===e.type)(a.parent))return
;const i=(({store:e,entry:t})=>{const n=J_e("document",t);if(!n)return null
;const r=e.workspace.documents[n.name]
;return r?"document"===t.type?r:"tag"===t.type?r.tags?.find((e=>e.name===t.name))??null:"operation"===t.type?qke(r.paths?.[t.path]?.[t.method])??null:null:null
})({store:e,entry:a.parent});if(!i||!("x-scalar-order"in i))return
;const s=i["x-scalar-order"],l=s?.indexOf(a.id)
;if(!Array.isArray(s)||"number"!=typeof l||l<0)return
;const c="tag"===a.parent.type&&"name"in i?{tag:i,id:a.parent.id}:void 0
;s[l]=n({type:"operation",path:o,method:r,operation:t,parentId:a.parent.id,
parentTag:c})}))},OQe=(e,t,{meta:n,payload:{method:r,path:o},callback:a})=>{
const i=n.method!==r,s=n.path!==o;if(!i&&!s)return void a("no-change")
;const l=i?r:n.method,c=s?o:n.path
;if(e?.paths?.[c]?.[l])return void a("conflict")
;const u=e?.["x-scalar-navigation"]
;if(!u||!t)return void console.error("Document or workspace not found",{
document:e});const d=qke(e.paths?.[n.path]?.[n.method])
;if(!d)return void console.error("Operation not found",{meta:n,document:e})
;if(s){const e=RH(n.path,{includePath:!0,includeEnv:!1
}).filter((e=>void 0!==e)),t=RH(c,{includePath:!0,includeEnv:!1
}).filter((e=>void 0!==e));if(e.length>0||t.length>0){const e=d.parameters??[]
;d.parameters=((e,t,n)=>{const r=RH(t,{includePath:!0,includeEnv:!1
}).filter((e=>void 0!==e)),o=RH(e,{includePath:!0,includeEnv:!1
}).filter((e=>void 0!==e)),a=bQe(t,r),i=bQe(e,o),s=[],l=[];for(const p of n){
const e=qke(p);"path"===e?.in?s.push(e):l.push(p)}const c=new Map
;for(const p of s)p.name&&c.set(p.name,p);const u=new Set,d=[]
;for(const p of o){if(c.has(p)){d.push(c.get(p)),u.add(p);continue}
const e=i[p],t=r.find((t=>a[t]===e&&!u.has(t)));if(t&&c.has(t)){const e=c.get(t)
;e.name=p,d.push(e),u.add(t)}else d.push({name:p,in:"path"})}
return Q_e([...d,...l],{depth:1})})(c,n.path,e)}}
const{generateId:p}=aTe(u.name),h=eTe(u).get(`${n.path}|${n.method}`);h&&yQe({
store:t,operation:d,generateId:p,method:l,path:c,entries:h
}),e.paths||(e.paths={}),
e.paths[c]||(e.paths[c]={}),rQe(c),rQe(n.path),rQe(l),e.paths[c][l]=Q_e(d)
;const f=e.paths[n.path]
;f&&IH(n.method)&&(delete f[n.method],0===Object.keys(f).length&&delete e.paths[n.path]),
delete d["x-scalar-history"],a("success")},wQe=(e,t,n)=>{
const r=qke(e?.paths?.[n.path]?.[n.method]);if(!r)return null
;let o=qke(r.requestBody);o||(r.requestBody={content:{}
},o=qke(r.requestBody)),o.content[t]||={},
o.content[t].examples||={},o.content[t].examples[n.exampleKey]||={}
;return qke(o.content[t].examples?.[n.exampleKey])??null
},xQe=async(e,{payload:t,meta:n})=>{if(!e||!t)return
;const r=qke(e.paths?.[n.path]?.[n.method]);if(!r)return
;const o=(r.parameters??[]).reduce(((e,t)=>{const r=qke(t)
;return fQe(r)||"path"===r.in&&(e[r.name]=qke(r.examples?.[n.exampleKey])?.value??""),
e
}),{}),a=await(async({request:e,includeBody:t=!0,httpVersion:n="HTTP/1.1",bodySizeLimit:r=1048576})=>{
const o=new URL(e.url),a=Array.from(o.searchParams.entries()).map((([e,t])=>({
name:e,value:t
}))),{headers:i,headersSize:s,cookies:l}=aQe(e),c=e.headers.get("content-type")?.split(";")[0]?.trim()??"text/plain",u=await(async()=>{
if(t&&e.body){const t=await oQe(e.clone());if(t.size<=r)return t}return{text:"",
size:-1}})();return{method:e.method,url:e.url,httpVersion:n,headers:i,cookies:l,
queryString:a,headersSize:s,bodySize:u.size,postData:"params"in u?{mimeType:c,
params:u.params}:{mimeType:c,text:u.text}}})({request:t.request
}),i=await(async({response:e,includeBody:t=!0,httpVersion:n="HTTP/1.1",bodySizeLimit:r=1048576})=>{
const{headers:o,headersSize:a,cookies:i}=sQe(e),s=e.headers.get("location")||"",l=e.headers.get("content-type")??"text/plain",c=await(async()=>{
if(t&&e.body){const t=await lQe(e.clone());if(t.size<=r)return t}return{text:"",
size:-1,encoding:void 0}})();return{status:e.status,statusText:e.statusText,
httpVersion:n,headers:o,cookies:i,content:{size:c.size,mimeType:l,text:c.text,
encoding:c.encoding},redirectURL:s,headersSize:a,bodySize:c.size}})({
response:t.response})
;r["x-scalar-history"]||=[],r["x-scalar-history"].length>=5&&(r["x-scalar-history"]=Q_e(r["x-scalar-history"].filter(((e,t)=>0!==t)),{
depth:1})),r["x-scalar-history"].push({response:i,request:a,meta:{
example:n.exampleKey},time:t.duration,timestamp:t.timestamp,requestMetadata:{
variables:o}})},kQe=({document:e,store:t})=>({createOperation:e=>((e,t)=>{
const n=e?.workspace.documents[t.documentName]
;if(!n)return void t.callback?.(!1)
;const{path:r,method:o,operation:a}=t,i=r.startsWith("/")?r:`/${r}`
;n.paths||(n.paths={}),n.paths[i]||(n.paths[i]={}),rQe(i),rQe(o),n.paths[i][o]=a
;const{servers:s}=a,l=Q_e(s?.[0])
;for(const c of s??[])n.servers?.some((e=>e.url===c.url))||(n.servers||(n.servers=[]),
n.servers.push(Q_e(c)))
;return l&&(n["x-scalar-selected-server"]=l.url),t.callback?.(!0),i})(t,e),
updateOperationSummary:t=>((e,{meta:t,payload:{summary:n}})=>{if(!e)return
;const r=qke(e.paths?.[t.path]?.[t.method]);r&&(r.summary=n)})(e,t),
updateOperationPathMethod:n=>OQe(e,t,n),
deleteOperation:e=>((e,{meta:t,documentName:n})=>{
const r=e?.workspace.documents[n]
;r&&(rQe(t.path),rQe(t.method),delete r.paths?.[t.path]?.[t.method],
0===Object.keys(r.paths?.[t.path]??{}).length&&delete r.paths?.[t.path])})(t,e),
deleteOperationExample:e=>((e,{meta:{path:t,method:n,exampleKey:r},documentName:o})=>{
const a=e?.workspace.documents[o];if(!a)return;const i=qke(a.paths?.[t]?.[n])
;if(!i)return;i.parameters?.forEach((e=>{const t=qke(e)
;"content"in t&&t.content&&Object.values(t.content).forEach((e=>{
delete e.examples?.[r]})),"examples"in t&&t.examples&&delete t.examples?.[r]}))
;const s=qke(i.requestBody);s&&Object.values(s.content??{}).forEach((e=>{
delete e.examples?.[r]}))})(t,e),
updateOperationExtraParameters:t=>((e,{type:t,meta:n,payload:r,in:o})=>{
if(!e)return;const a=qke(e.paths?.[n.path]?.[n.method]);if(!a)return
;a["x-scalar-disable-parameters"]||(a["x-scalar-disable-parameters"]={})
;const i={global:{cookie:"global-cookies"},default:{header:"default-headers"}
}[t]?.[o]
;i&&(a["x-scalar-disable-parameters"][i]||(a["x-scalar-disable-parameters"][i]={}),
a["x-scalar-disable-parameters"][i][n.exampleKey]={
...a["x-scalar-disable-parameters"][i][n.exampleKey]??{},
[n.name]:r.isDisabled??!1})})(e,t),
upsertOperationParameter:t=>((e,{meta:t,type:n,payload:r,originalParameter:o})=>{
if(o){if(o.name=r.name,fQe(o))return
;o.examples||(o.examples={}),o.examples[t.exampleKey]||={}
;const e=qke(o.examples[t.exampleKey])
;return e.value=r.value,void(e["x-disabled"]=r.isDisabled)}
const a=qke(e?.paths?.[t.path]?.[t.method])
;a?(a.parameters||=[],a.parameters.push({name:r.name,in:n,required:"path"===n,
examples:{[t.exampleKey]:{value:r.value,"x-disabled":!1}}
})):console.error("Operation not found",{meta:t,document:e})})(e,t),
deleteOperationParameter:t=>((e,{meta:t,originalParameter:n})=>{
const r=qke(e?.paths?.[t.path]?.[t.method]),o=r?.parameters?.findIndex((e=>qke(e)===n))??-1
;if(r&&o>=0)return void(r.parameters=Q_e(r.parameters?.filter(((e,t)=>t!==o)),{
depth:1}))
;const a=qke(e?.paths?.[t.path]),i=a?.parameters?.findIndex((e=>qke(e)===n))??-1
;a&&i>=0&&(a.parameters=Q_e(a.parameters?.filter(((e,t)=>t!==i)),{depth:1}))
})(e,t),deleteAllOperationParameters:t=>((e,{meta:t,type:n})=>{if(!e)return
;const r=qke(e.paths?.[t.path]?.[t.method])
;r&&(r.parameters=r.parameters?.filter((e=>qke(e).in!==n))??[])})(e,t),
updateOperationRequestBodyContentType:t=>((e,{meta:t,payload:n})=>{if(!e)return
;const r=qke(e.paths?.[t.path]?.[t.method]);if(!r)return
;let o=qke(r.requestBody);o||(r.requestBody={content:{}
},o=qke(r.requestBody)),o["x-scalar-selected-content-type"]||(o["x-scalar-selected-content-type"]={}),
o["x-scalar-selected-content-type"][t.exampleKey]=n.contentType})(e,t),
updateOperationRequestBodyExample:t=>((e,{meta:t,payload:n,contentType:r})=>{
const o=wQe(e,r,t);o?o.value=n:console.error("Example not found",t.exampleKey)
})(e,t),
updateOperationRequestBodyFormValue:t=>((e,{meta:t,payload:n,contentType:r})=>{
const o=wQe(e,r,t);o?o.value=Q_e(n,{depth:3
}):console.error("Example not found",t.exampleKey)})(e,t),
addResponseToHistory:t=>xQe(e,t),
reloadOperationHistory:t=>((e,{meta:t,index:n,callback:r})=>{
if(!e)return void console.error("Document not found",t.path,t.method)
;const o=qke(e.paths?.[t.path]?.[t.method])
;if(!o)return void console.error("Operation not found",t.path,t.method)
;const a=o["x-scalar-history"]?.[n];a?(mQe({harRequest:a.request,
exampleKey:"draft",baseOperation:o,pathVariables:a.requestMetadata.variables
}),r("success")):console.error("History item not found",n)})(e,t)}),SQe=(e,t)=>{
const n={};for(const r of t){const t=e.indexOf(`{${r}}`);-1!==t&&(n[r]=t)}
return n},_Qe=(e,{index:t,server:n})=>{const r=e?.servers?.[t]
;if(!r)return void console.error("Server not found at index:",t)
;const o=r.url,a=OUe(jZe,{...r,...n});if(o&&o!==a.url){const t=a.variables??{}
;a.variables=((e,t,n)=>{const r=RH(t,{includePath:!0,includeEnv:!1
}).filter((e=>void 0!==e)),o=RH(e,{includePath:!0,includeEnv:!1
}).filter((e=>void 0!==e)),a=SQe(t,r),i=SQe(e,o),s=new Set,l={}
;for(const c of o){if(n[c]){l[c]=n[c],s.add(c);continue}
const e=i[c],t=r.find((t=>a[t]===e&&!s.has(t)))
;t&&n[t]?(l[c]=n[t],s.add(t)):l[c]={default:""}}return l
})(a.url,o,t),e["x-scalar-selected-server"]===o&&(e["x-scalar-selected-server"]=a.url)
}return e.servers?e.servers[t]=a:e.servers=[a],a},TQe=({document:e})=>({
addServer:()=>(e=>{if(!e)return;const t=OUe(jZe,{})
;return e.servers||(e.servers=[]),e.servers.push(t),t})(e),
updateServer:t=>_Qe(e,t),deleteServer:t=>((e,{index:t})=>{if(!e?.servers)return
;const n=e.servers[t]?.url
;e.servers.splice(t,1),e["x-scalar-selected-server"]===n&&(e["x-scalar-selected-server"]=e.servers[0]?.url??void 0)
})(e,t),updateServerVariables:t=>((e,{index:t,key:n,value:r})=>{
const o=e?.servers?.[t]?.variables?.[n]
;if(!o)return void console.error("Variable not found",n,t);o.default=r
;const a=e?.servers?.[t]?.url;if(a)return o;console.error("URL not found",t)
})(e,t),updateSelectedServer:t=>((e,{url:t})=>{if(e){
if(""===t)return e["x-scalar-selected-server"]="",""
;if(e.servers?.some((e=>e.url===t)))return e["x-scalar-selected-server"]=e["x-scalar-selected-server"]===t?"":t,
e["x-scalar-selected-server"]}})(e,t)
}),EQe=e=>null!==e&&void 0!==e["x-scalar-tabs"],AQe=e=>Q_e(e["x-scalar-tabs"],{
depth:1}),CQe=e=>e["x-scalar-active-tab"]??0,$Qe=({workspace:e})=>({
updateTabs:t=>((e,t)=>{
e&&(t["x-scalar-tabs"]&&(e["x-scalar-tabs"]=t["x-scalar-tabs"]),
void 0!==t["x-scalar-active-tab"]&&(e["x-scalar-active-tab"]=t["x-scalar-active-tab"]))
})(e,t),addTab:t=>((e,t)=>{if(!EQe(e))return!1;const n=AQe(e),r=n[CQe(e)]
;if(!r)return!1;const o=[...n,{...r}]
;return e["x-scalar-tabs"]=o,e["x-scalar-active-tab"]=o.length-1,!0})(e),
closeTab:t=>((e,t)=>{if(!EQe(e))return!1
;const n="event"in t?t.event.code.startsWith("Digit")?Number.parseInt(t.event.key,10)-1:Number.NaN:t.index,r=AQe(e).filter(((e,t)=>t!==n))
;return!(r.length<=0||(e["x-scalar-tabs"]=r,
n>=r.length&&(e["x-scalar-active-tab"]=r.length-1),0))})(e,t),
closeOtherTabs:t=>((e,t)=>{if(!EQe(e))return!1;const n=AQe(e)
;return!(n.length<=1||(e["x-scalar-tabs"]=n.filter(((e,n)=>n===t.index)),
e["x-scalar-active-tab"]=0,0))})(e,t),navigatePreviousTab:t=>((e,t)=>{
if(!EQe(e))return!1;const n=CQe(e)
;return!(n<=0||(e["x-scalar-active-tab"]=n-1,0))})(e),
navigateNextTab:t=>((e,t)=>{if(!EQe(e))return!1;const n=AQe(e),r=CQe(e)
;return!(r>=n.length-1||(e["x-scalar-active-tab"]=r+1,0))})(e),
focusTab:t=>((e,t)=>{if(!EQe(e))return!1
;const n=AQe(e),r="event"in t?t.event.code.startsWith("Digit")?Number.parseInt(t.event.key,10)-1:Number.NaN:t.index
;return!(Number.isNaN(r)||r<0||r>=n.length||(e["x-scalar-active-tab"]=r,0))
})(e,t),focusLastTab:t=>((e,t)=>{if(!EQe(e))return!1;const n=AQe(e)
;return!(n.length<=1||(e["x-scalar-active-tab"]=n.length-1,0))})(e)
}),PQe=({store:e})=>({createTag:t=>((e,t)=>{
const n=e?.workspace.documents[t.documentName]
;n?(n.tags||(n.tags=[]),n.tags.push({name:t.name
})):console.error("Document not found",{payload:t,store:e})})(e,t),
deleteTag:t=>((e,t)=>{const n=e?.workspace.documents[t.documentName]
;n&&(Object.values(n.paths??{}).forEach((e=>{Object.values(e).forEach((e=>{
if("object"!=typeof e||Array.isArray(e))return;const n=qke(e)
;"tags"in n&&(n.tags=Q_e(n.tags?.filter((e=>e!==t.name)),{depth:2}))}))
})),Object.values(n.webhooks??{}).forEach((e=>{Object.values(e).forEach((e=>{
if("object"!=typeof e||Array.isArray(e))return;const n=qke(e)
;n.tags=Q_e(n.tags?.filter((e=>e!==t.name)),{depth:2})}))
})),n.tags=Q_e(n.tags?.filter((e=>e.name!==t.name)),{depth:2}))})(e,t)
}),DQe=({workspace:e})=>({updateActiveProxy:t=>((e,t)=>{
e&&(e["x-scalar-active-proxy"]=t??void 0)})(e,t),updateColorMode:t=>((e,t)=>{
e&&(e["x-scalar-color-mode"]=t)})(e,t),updateTheme:t=>((e,t)=>{
e&&(e["x-scalar-theme"]=t)})(e,t),updateSelectedClient:t=>((e,t)=>{
e&&(e["x-scalar-default-client"]=t)})(e,t)});function IQe(e){const t=t=>({
auth:YZe({document:t}),cookie:KZe({collection:t}),document:JZe({document:t,
store:e}),operation:kQe({document:t,store:e}),server:TQe({document:t}),tag:PQe({
store:e}),environment:eQe({workspace:e?.workspace??null,collection:t})});return{
workspace:()=>({cookie:KZe({collection:e?.workspace??null}),tabs:$Qe({
workspace:e?.workspace??null}),workspace:DQe({workspace:e?.workspace??null}),
environment:eQe({workspace:e?.workspace??null,collection:e?.workspace??null})}),
active:()=>t(e?.workspace.activeDocument??null),doc:n=>t(tQe(e,n))}}
const MQe=(e,t,n)=>async r=>{const o=await(n[e]?.onBeforeExecute?.(r))??r
;return await t(o),await(n[e]?.onAfterExecute?.(o)),o}
;function NQe({eventBus:e,isSidebarOpen:t,sidebarState:n,modalState:r,store:o}){
(function({eventBus:e,store:t,hooks:n}){
const r=Sy((()=>IQe(t.value))),o=({collectionType:e})=>"document"===e?r.value.active():r.value.workspace()
;e.on("workspace:update:active-proxy",(e=>MQe("workspace:update:active-proxy",r.value.workspace().workspace.updateActiveProxy,n)(e))),
e.on("workspace:update:color-mode",(e=>MQe("workspace:update:color-mode",r.value.workspace().workspace.updateColorMode,n)(e))),
e.on("workspace:update:theme",(e=>MQe("workspace:update:theme",r.value.workspace().workspace.updateTheme,n)(e))),
e.on("workspace:update:selected-client",(e=>MQe("workspace:update:selected-client",r.value.workspace().workspace.updateSelectedClient,n)(e))),
e.on("document:update:icon",(e=>MQe("document:update:icon",r.value.active().document.updateDocumentIcon,n)(e))),
e.on("document:update:info",(e=>MQe("document:update:info",r.value.active().document.updateDocumentInfo,n)(e))),
e.on("document:toggle:security",(e=>MQe("document:toggle:security",r.value.active().document.toggleSecurity,n)(e))),
e.on("document:update:watch-mode",(e=>MQe("document:update:watch-mode",r.value.active().document.updateWatchMode,n)(e))),
e.on("document:create:empty-document",(e=>MQe("document:create:empty-document",r.value.active().document.createEmptyDocument,n)(e))),
e.on("document:delete:document",(e=>MQe("document:delete:document",r.value.active().document.deleteDocument,n)(e))),
e.on("environment:upsert:environment",(e=>MQe("environment:upsert:environment",o(e).environment.upsertEnvironment,n)(e))),
e.on("environment:delete:environment",(e=>MQe("environment:delete:environment",o(e).environment.deleteEnvironment,n)(e))),
e.on("environment:upsert:environment-variable",(e=>MQe("environment:upsert:environment-variable",o(e).environment.upsertEnvironmentVariable,n)(e))),
e.on("environment:delete:environment-variable",(e=>MQe("environment:delete:environment-variable",o(e).environment.deleteEnvironmentVariable,n)(e))),
e.on("cookie:upsert:cookie",(async e=>{
await MQe("cookie:upsert:cookie",o(e).cookie.upsertCookie,n)(e)
})),e.on("cookie:delete:cookie",(async e=>{
await MQe("cookie:delete:cookie",o(e).cookie.deleteCookie,n)(e)
})),e.on("auth:delete:security-scheme",(e=>MQe("auth:delete:security-scheme",r.value.active().auth.deleteSecurityScheme,n)(e))),
e.on("auth:update:active-index",(e=>MQe("auth:update:active-index",r.value.active().auth.updateSelectedAuthTab,n)(e))),
e.on("auth:update:security-scheme",(e=>MQe("auth:update:security-scheme",r.value.active().auth.updateSecurityScheme,n)(e))),
e.on("auth:update:selected-scopes",(e=>MQe("auth:update:selected-scopes",r.value.active().auth.updateSelectedScopes,n)(e))),
e.on("auth:update:selected-security-schemes",(e=>MQe("auth:update:selected-security-schemes",r.value.active().auth.updateSelectedSecuritySchemes,n)(e))),
e.on("server:add:server",(e=>MQe("server:add:server",r.value.active().server.addServer,n)(e))),
e.on("server:update:server",(e=>MQe("server:update:server",r.value.active().server.updateServer,n)(e))),
e.on("server:delete:server",(e=>MQe("server:delete:server",r.value.active().server.deleteServer,n)(e))),
e.on("server:update:variables",(e=>MQe("server:update:variables",r.value.active().server.updateServerVariables,n)(e))),
e.on("server:update:selected",(e=>MQe("server:update:selected",r.value.active().server.updateSelectedServer,n)(e))),
e.on("operation:create:operation",(e=>MQe("operation:create:operation",r.value.active().operation.createOperation,n)(e))),
e.on("operation:update:pathMethod",(e=>MQe("operation:update:pathMethod",r.value.active().operation.updateOperationPathMethod,n)(e))),
e.on("operation:update:summary",(e=>MQe("operation:update:summary",r.value.active().operation.updateOperationSummary,n)(e))),
e.on("operation:delete:operation",(e=>MQe("operation:delete:operation",r.value.active().operation.deleteOperation,n)(e))),
e.on("operation:delete:example",(e=>MQe("operation:delete:example",r.value.active().operation.deleteOperationExample,n)(e))),
e.on("operation:upsert:parameter",(e=>MQe("operation:upsert:parameter",r.value.active().operation.upsertOperationParameter,n)(e))),
e.on("operation:update:extra-parameters",(e=>MQe("operation:update:extra-parameters",r.value.active().operation.updateOperationExtraParameters,n)(e))),
e.on("operation:delete:parameter",(e=>MQe("operation:delete:parameter",r.value.active().operation.deleteOperationParameter,n)(e))),
e.on("operation:delete-all:parameters",(e=>MQe("operation:delete-all:parameters",r.value.active().operation.deleteAllOperationParameters,n)(e))),
e.on("operation:update:requestBody:contentType",(e=>MQe("operation:update:requestBody:contentType",r.value.active().operation.updateOperationRequestBodyContentType,n)(e))),
e.on("operation:update:requestBody:value",(e=>MQe("operation:update:requestBody:value",r.value.active().operation.updateOperationRequestBodyExample,n)(e))),
e.on("operation:update:requestBody:formValue",(e=>MQe("operation:update:requestBody:formValue",r.value.active().operation.updateOperationRequestBodyFormValue,n)(e))),
e.on("operation:reload:history",(e=>MQe("operation:reload:history",r.value.active().operation.reloadOperationHistory,n)(e))),
e.on("tag:create:tag",(e=>MQe("tag:create:tag",r.value.active().tag.createTag,n)(e))),
e.on("tag:delete:tag",(e=>MQe("tag:delete:tag",r.value.active().tag.deleteTag,n)(e))),
e.on("tabs:add:tab",(e=>MQe("tabs:add:tab",r.value.workspace().tabs.addTab,n)(e))),
e.on("tabs:close:tab",(e=>MQe("tabs:close:tab",r.value.workspace().tabs.closeTab,n)(e))),
e.on("tabs:close:other-tabs",(e=>MQe("tabs:close:other-tabs",r.value.workspace().tabs.closeOtherTabs,n)(e))),
e.on("tabs:focus:tab",(e=>MQe("tabs:focus:tab",r.value.workspace().tabs.focusTab,n)(e))),
e.on("tabs:focus:tab-last",(e=>MQe("tabs:focus:tab-last",r.value.workspace().tabs.focusLastTab,n)(e))),
e.on("tabs:navigate:previous",(e=>MQe("tabs:navigate:previous",r.value.workspace().tabs.navigatePreviousTab,n)(e))),
e.on("tabs:navigate:next",(e=>MQe("tabs:navigate:next",r.value.workspace().tabs.navigateNextTab,n)(e))),
e.on("tabs:update:tabs",(e=>MQe("tabs:update:tabs",r.value.workspace().tabs.updateTabs,n)(e))),
e.on("hooks:on:request:complete",(e=>MQe("hooks:on:request:complete",r.value.active().operation.addResponseToHistory,n)(e)))
})({eventBus:e,store:bm(o),hooks:{}
}),e.on("scroll-to:nav-item",(({id:e})=>n.handleSelectItem(e))),
e.on("ui:toggle:sidebar",(()=>t.value=!t.value)),
e.on("ui:close:client-modal",(()=>r.hide())),e.on("ui:open:client-modal",(e=>{
e?("id"in e&&e.id?n.handleSelectItem(e.id):"method"in e&&"path"in e&&n.handleSelectItem(n.getEntryByLocation({
document:o.workspace.activeDocument?.["x-scalar-navigation"]?.id??"",
path:e.path,method:e.method,example:e.exampleName})?.id??""),r.show()):r.show()
}))}const RQe={c:["libcurl"],clojure:["clj_http"],
csharp:["httpclient","restsharp"],dart:["http"],fsharp:["httpclient"],
go:["native"],http:["http1.1"],java:["asynchttp","nethttp","okhttp","unirest"],
js:["axios","fetch","jquery","ofetch","xhr"],kotlin:["okhttp"],
node:["axios","fetch","ofetch","undici"],objc:["nsurlsession"],ocaml:["cohttp"],
php:["curl","guzzle"],powershell:["restmethod","webrequest"],
python:["python3","requests","httpx_sync","httpx_async"],r:["httr"],
ruby:["native"],rust:["reqwest"],shell:["curl","httpie","wget"],
swift:["nsurlsession"]
},LQe=Tje(RQe).flatMap((([e,t])=>t.map((t=>`${e}/${t}`)))),BQe=e=>{
if(!0===e)return[];if(!e||Array.isArray(e)&&0===e.length)return LQe
;const t=new Set(LQe);if(Array.isArray(e))for(const n of e){const e=RQe[n]
;if(e)for(const r of e)t.delete(`${n}/${r}`);else if(n.includes("/"))t.delete(n);else for(const r of MH(RQe))t.delete(`${r}/${n}`)
}else if("object"==typeof e)for(const[n,r]of Object.entries(e))if(!0===r){
const e=RQe[n];if(e)for(const r of e)t.delete(`${n}/${r}`)
}else if(Array.isArray(r))for(const e of r)t.delete(e),t.delete(`${n}/${e}`)
;return Array.from(t)},jQe=(e=[],t=[])=>{const n=t.flatMap((e=>{const t=qke(e)
;return t?`${t.in}:${t.name}`:[]})),r=new Set(n);return[...e.filter((e=>{
const t=qke(e);return!!t&&!r.has(`${t.in}:${t.name}`)})),...t]
},UQe=(e,t)=>typeof e?.["x-scalar-selected-server"]>"u"&&t?.length?t[0]:t?.find((({url:t})=>t===e?.["x-scalar-selected-server"]))??null
;function zQe(e,t={}){if(!e?.length){const e=HQe(t);return e?[e]:[]}
if(!Array.isArray(e))return[];const n=e.map((e=>function(e,t){
return e.url?.startsWith("/")&&(e.url=function(e,t){
const{baseServerUrl:n,documentUrl:r}=t;if(n)return ZH(n,e);if(r){const t=FQe(r)
;if(t)return ZH(t,e)}const o=ZQe();return o?ZH(o,e):e}(e.url,t)),e}(e,t)))
;if(0===n.length){const e=HQe(t);return e?[e]:[]}return n}function FQe(e){try{
const t=new URL(e),n=t.port?`:${t.port}`:""
;return`${t.protocol}//${t.hostname}${n}`}catch{return}}function ZQe(){
if(!(typeof window>"u"||"string"!=typeof window?.location?.origin))return window.location.origin
}function QQe(e){return{url:e}}function HQe(e){if(e.documentUrl){
const t=function(e){const t=FQe(e);if(t)return QQe(t)}(e.documentUrl)
;if(t)return t}return function(){const e=ZQe();if(e)return QQe(e)}()}
const VQe=Qg({__name:"ViewLayout",setup(e){const{cx:t}=zS()
;return(e,n)=>(Ub(),Qb("div",Mh(Kb(xm(t)("flex flex-col min-h-0 flex-1 *:border-t first:*:border-t-0 md:*:border-t-0 xl:overflow-hidden md:flex-row leading-3"))),[kv(e.$slots,"default")],16))
}}),qQe={
class:"custom-scroll flex flex-col pr-0 *:border-t *:first:border-t-0 xl:flex-row *:xl:border-t-0 *:xl:border-l *:first:xl:border-l-0"
};const WQe=sae({},[["render",function(e,t){
return Ub(),Qb("div",qQe,[kv(e.$slots,"default")])
}]]),XQe=()=>typeof window<"u"&&"electron"in window,GQe=e=>e.variables.reduce(((e,t)=>(e[t.name]="string"==typeof t.value?t.value:t.value.default,
e)),{}),YQe=(e,t)=>{
const n=(r=e?.variables??{},Object.entries(r)).reduce(((e,[t,n])=>(n.default&&(e[t]=n.default),
e)),{});var r;return LH(e?.url??"",{...t,...n})
},KQe=({environment:e,server:t,path:n,pathVariables:r,urlParams:o})=>{
const a=GQe(e),i=YQe(t,a),s=LH(n,{...a,...r});return QH(i,s,o)
},JQe="2.20.2",eHe=(e,t,n)=>({name:e,defaultValue:t,
isOverridden:n.has(e.toLowerCase())
}),tHe=({method:e,operation:t,exampleKey:n,hideDisabledHeaders:r=!1})=>{
const o=new Set(t.parameters?.filter((e=>"header"===qke(e).in)).map((e=>qke(e).name.toLowerCase()))??[]),a=t["x-scalar-disable-parameters"]?.["default-headers"]?.[n]??{},i=[],s=qke(t.requestBody)
;if(EH(e)){
const e=s?.["x-scalar-selected-content-type"]?.[n]??Object.keys(s?.content??{})[0]??"application/json"
;i.push(eHe("Content-Type",e,o))}
return i.push(eHe("Accept","*/*",o)),XQe()&&JQe&&i.push(eHe("User-Agent",`Scalar/${JQe}`,o)),
r?i.filter((e=>!0!==a[e.name.toLowerCase()])):i},nHe=(e,t,n)=>{
if("content"in e){
const r=e.content?.[n??Object.keys(e.content)[0]??""],o=r?.examples??{},a=t||Object.keys(o)[0]||"",i=VZe(o[a])
;return typeof i<"u"?i:!t&&r?.example?{value:VZe(r.example)}:void 0}
if("examples"in e||"example"in e){
const n=qke(e.examples)??{},r=t||Object.keys(n)[0]||"",o=VZe(n?.[r])
;if(typeof o<"u")return o;if(!t&&e.example)return{value:VZe(e.example)}}
const r=VZe(e);if("schema"in r&&r.schema){
if("default"in r.schema&&typeof r.schema.default<"u")return{
value:r.schema.default}
;if("enum"in r.schema&&typeof r.schema.enum?.[0]<"u")return{
value:r.schema.enum[0]}
;if("examples"in r.schema&&typeof r.schema.examples?.[0]<"u")return{
value:r.schema.examples[0]}
;if("example"in r.schema&&typeof r.schema.example<"u")return{
value:r.schema.example}}
},rHe=(new Date).toISOString(),oHe=rHe.split("T")[0],aHe=rHe.split("T")[1].split(".")[0],iHe={
"date-time":rHe,date:oHe,email:"hello@example.com",hostname:"example.com",
"idn-email":"jane.doe@example.com","idn-hostname":"example.com",
ipv4:"127.0.0.1",ipv6:"51d4:7fab:bfbf:b7d7:b2cb:d4b4:3dad:d998",
"iri-reference":"/entitiy/1",iri:"https://example.com/entity/123",
"json-pointer":"/nested/objects",password:"super-secret",regex:"/[a-z]/",
"relative-json-pointer":"1/nested/objects",time:aHe,"uri-reference":"../folder",
"uri-template":"https://example.com/{id}",uri:"https://example.com",
uuid:"123e4567-e89b-12d3-a456-426614174000",
"object-id":"6592008029c8c3e4dc76256c"
},sHe=(e,t=!1,n="")=>"type"in e&&"string"===e.type&&"format"in e&&"binary"===e.format?"@filename":t&&"format"in e&&e.format?iHe[e.format]??n:n,lHe=new WeakMap,cHe=new WeakMap,uHe=(e,t,n)=>{
if("object"!=typeof t||null===t)return t
;const r=sSe(fSe(e)),o=lHe.get(r)??new Map;return o&&o.set(n,t),lHe.set(r,o),t
},dHe=(e,t,n,r)=>{
if(e.deprecated||"write"===r?.mode&&e.readOnly||"read"===r?.mode&&e.writeOnly)return!0
;if(!0!==r?.omitEmptyAndOptionalProperties||"type"in e&&("object"===e.type||"array"===e.type)||(e=>!!(e.allOf||e.oneOf||e.anyOf))(e)||"examples"in e&&Array.isArray(e.examples)&&e.examples.length>0||"example"in e&&void 0!==e.example||"default"in e&&void 0!==e.default||"const"in e&&void 0!==e.const||"enum"in e&&Array.isArray(e.enum)&&e.enum.length>0)return!1
;const o=n??e.title??"",a=(e=>{if(!e)return;const t=cHe.get(e);if(t)return t
;if("required"in e){const t=e.required;if(Array.isArray(t)&&t.length>0){
const n=new Set(t);return cHe.set(e,n),n}}})(t);return!(a&&a.has(o))
},pHe=(e,t)=>Array.isArray(e)&&Array.isArray(t)?[...e,...t]:e&&"object"==typeof e&&t&&"object"==typeof t?{
...e,...t
}:t,hHe=(e,t,{level:n=0,parentSchema:r,name:o,seen:a=new WeakSet}={})=>{
const i=qke(e);if(!xH(i))return;const s=sSe(fSe(i));if(a.has(s))return;a.add(s)
;const l=(e=>JSON.stringify({emptyString:e?.emptyString,xml:e?.xml,mode:e?.mode,
variables:e?.variables,
omitEmptyAndOptionalProperties:e?.omitEmptyAndOptionalProperties
}))(t),c=lHe.get(s)?.get(l);if(typeof c<"u")return a.delete(s),c
;if(n>10)return a.delete(s),"[Max Depth Exceeded]";const u=!!t?.emptyString
;if(dHe(i,r,o,t))return void a.delete(s);if("x-variable"in i&&i["x-variable"]){
const e=t?.variables?.[i["x-variable"]]
;if(void 0!==e)return!("type"in i)||"number"!==i.type&&"integer"!==i.type?(a.delete(s),
uHe(i,e,l)):(a.delete(s),uHe(i,Number(e),l))}
if(Array.isArray(i.examples)&&i.examples.length>0)return a.delete(s),
uHe(i,i.examples[0],l)
;if(void 0!==i.example)return a.delete(s),uHe(i,i.example,l)
;if(void 0!==i.default)return a.delete(s),uHe(i,i.default,l)
;if(void 0!==i.const)return a.delete(s),uHe(i,i.const,l)
;if(Array.isArray(i.enum)&&i.enum.length>0)return a.delete(s),uHe(i,i.enum[0],l)
;if("properties"in i||"type"in i&&"object"===i.type){const e=((e,t,n,r,o)=>{
const a={};if("properties"in e&&e.properties){
const o=Object.keys(e.properties),i=n>3?Math.min(10,o.length):o.length
;for(let s=0;s<i;s++){const i=o[s],l=qke(e.properties[i]);if(!l)continue
;const c=t?.xml&&"xml"in l?l.xml?.name:void 0,u=hHe(l,t,{level:n+1,
parentSchema:e,name:i,seen:r});typeof u<"u"&&(a[c??i]=u)}
n>3&&o.length>10&&(a["..."]="[Additional Properties Truncated]")}
if("patternProperties"in e&&e.patternProperties)for(const i of Object.keys(e.patternProperties)){
const o=qke(e.patternProperties[i]);o&&(a[i]=hHe(o,t,{level:n+1,parentSchema:e,
name:i,seen:r}))}if("additionalProperties"in e&&e.additionalProperties){
const o=qke(e.additionalProperties),i=!0===e.additionalProperties||"object"==typeof e.additionalProperties&&0===Object.keys(e.additionalProperties).length
;a["object"==typeof o&&"x-additionalPropertiesName"in o&&"string"==typeof o["x-additionalPropertiesName"]&&o["x-additionalPropertiesName"].trim().length>0?o["x-additionalPropertiesName"].trim():"additionalProperty"]=i?"anything":"object"==typeof o?hHe(o,t,{
level:n+1,seen:r}):"anything"}
if(e.oneOf?.[0])Object.assign(a,hHe(qke(e.oneOf[0]),t,{level:n+1,seen:r
}));else if(e.anyOf?.[0])Object.assign(a,hHe(qke(e.anyOf[0]),t,{level:n+1,seen:r
}));else if(Array.isArray(e.allOf)&&e.allOf.length>0){let o=a
;for(const a of e.allOf){const i=hHe(qke(a),t,{level:n+1,parentSchema:e,seen:r})
;o=pHe(o,i)}o&&"object"==typeof o&&Object.assign(a,o)}
if(t?.xml&&"xml"in e&&e.xml?.name&&0===n){const t={}
;return t[e.xml.name]=a,uHe(e,t,o)}return uHe(e,a,o)})(i,t,n,a,l)
;return a.delete(s),e}if("type"in i&&"array"===i.type||"items"in i){
const e=((e,t,n,r,o)=>{
const a="items"in e?qke(e.items):void 0,i=a&&"object"==typeof a&&"xml"in a?a.xml?.name:void 0,s=!!(t?.xml&&"xml"in e&&e.xml?.wrapped&&i)
;if(void 0!==e.example)return uHe(e,s?{[i]:e.example}:e.example,o)
;if(a&&"object"==typeof a){if(Array.isArray(a.allOf)&&a.allOf.length>0){
const l=a.allOf.filter(xH),c=qke(l[0])
;if(c&&"object"==typeof c&&"type"in c&&"object"===c.type){const a=hHe({
type:"object",allOf:l},t,{level:n+1,parentSchema:e,seen:r});return uHe(e,s?[{
[i]:a}]:[a],o)}const u=l.map((o=>hHe(qke(o),t,{level:n+1,parentSchema:e,seen:r
}))).filter(xH);return uHe(e,s?u.map((e=>({[i]:e}))):u,o)}
const l=a.anyOf||a.oneOf;if(l&&l.length>0){const a=l[0],c=hHe(qke(a),t,{
level:n+1,parentSchema:e,seen:r});return uHe(e,s?[{[i]:c}]:[c],o)}}
const l=a&&"object"==typeof a&&("type"in a&&"object"===a.type||"properties"in a),c=a&&"object"==typeof a&&("type"in a&&"array"===a.type||"items"in a)
;if(a&&"object"==typeof a&&("type"in a&&a.type||l||c)){const l=hHe(a,t,{
level:n+1,seen:r});return uHe(e,s?[{[i]:l}]:[l],o)}return uHe(e,[],o)
})(i,t,n,a,l);return a.delete(s),e}const d=((e,t,n)=>{
if("type"in e&&e.type&&!Array.isArray(e.type))switch(e.type){case"string":
return sHe(e,t,n??"");case"boolean":return!0;case"integer":case"number":
return"minimum"in e&&"number"==typeof e.minimum?e.minimum:1;case"array":return[]
;default:return}})(i,u,t?.emptyString)
;if(void 0!==d)return a.delete(s),uHe(i,d,l);const p=i.oneOf||i.anyOf
;if(Array.isArray(p)&&p.length>0){for(const e of p){const r=qke(e)
;if(r&&(!("type"in r)||"null"!==r.type))return a.delete(s),uHe(i,hHe(r,t,{
level:n+1,seen:a}),l)}return a.delete(s),uHe(i,null,l)}
if(Array.isArray(i.allOf)&&i.allOf.length>0){let e;const r=i.allOf
;for(const o of r){const r=hHe(o,t,{level:n+1,parentSchema:i,seen:a})
;void 0===e?e=r:e&&"object"==typeof e&&r&&"object"==typeof r?e=pHe(e,r):void 0!==r&&(e=r)
}return a.delete(s),uHe(i,e??null,l)}const h=((e,t,n)=>{
if("type"in e&&Array.isArray(e.type)){if(e.type.includes("null"))return null
;const r=e.type[0];if(r)switch(r){case"string":return sHe(e,t,n??"")
;case"boolean":return!0;case"integer":case"number":
return"minimum"in e&&"number"==typeof e.minimum?e.minimum:1;case"null":
return null;default:return}}})(i,u,t?.emptyString)
;return void 0!==h?(a.delete(s),uHe(i,h,l)):(a.delete(s),uHe(i,null,l))
},fHe=(e,t,n)=>{const r=e.content?.[t],o=nHe(e,n,t);if(o)return o
;const a=qke(r?.schema);if(!a)return null;const i=hHe(a,{mode:"write"})
;return i?{value:i}:null};zc({uid:jX.brand(),name:cl().default(""),
value:cl().default(""),domain:cl().optional(),path:cl().optional()})
;const mHe=({cookie:e,url:t,disabledGlobalCookies:n})=>{
if(e.isDisabled||!0===n[e.name.toLowerCase()]||!e.name)return!1
;const r=new URL(t,"https://example.com");return!(e.domain&&!((e,t)=>{
if(!e||!t)return!0;try{
const n=e.startsWith("http")?e:`http://${e}`,r=new URL(n).hostname,o=!t,a=t===r,i=t.startsWith(".")&&t===`.${r}`,s=t.startsWith(".")&&r?.endsWith(t)
;return o||a||s||i}catch{return!1}
})(t,e.domain)||e.path&&!r.pathname.startsWith(e.path))},gHe=(e,t)=>{
const n=t?.["x-disabled"];return"boolean"==typeof n?n:!e.required&&"path"!==e.in
},vHe=(e,t)=>"string"==typeof e?e:t.includes("json")||"object"==typeof e&&null!==e&&!Array.isArray(e)?JSON.stringify(e):String(e),bHe=(e,t)=>{
if(Array.isArray(e))return e.join(",");if("object"==typeof e&&null!==e){
const n=Object.entries(e)
;return t?n.map((([e,t])=>`${e}=${t}`)).join(","):n.map((([e,t])=>`${e},${t}`)).join(",")
}return e},yHe=(e,t)=>Array.isArray(e)&&t?e.map((e=>({key:"",value:e
}))):Array.isArray(e)?e.join(","):"object"==typeof e&&null!==e&&t?Object.entries(e).map((([e,t])=>({
key:e,value:t
}))):"object"==typeof e&&null!==e?Object.entries(e).map((([e,t])=>`${e},${t}`)).join(","):e,OHe=(e,t)=>{
if(Array.isArray(e)&&t)return e.map((e=>({key:"",value:e})))
;if(Array.isArray(e))return e.map((e=>null===e?"null":String(e))).join(",")
;if("object"==typeof e&&null!==e&&t)return Object.entries(e).map((([e,t])=>({
key:e,value:t})));if("object"==typeof e&&null!==e){const t=e=>{const n=[]
;for(const[r,o]of Object.entries(e))"object"!=typeof o||null===o||Array.isArray(o)?n.push(r,null===o?"null":String(o)):n.push(r,...t(o))
;return n};return t(e).join(",")}return e
},wHe=e=>Array.isArray(e)?e.join(" "):"object"==typeof e&&null!==e?Object.entries(e).map((([e,t])=>`${e} ${t}`)).join(" "):String(e),xHe=e=>Array.isArray(e)?e.join("|"):"object"==typeof e&&null!==e?Object.entries(e).flat().join("|"):String(e),kHe=(e,t)=>{
const n=[],r=(e,t)=>{for(const[o,a]of Object.entries(e)){const e=`${t}[${o}]`
;"object"!=typeof a||null===a||Array.isArray(a)?n.push({key:e,value:String(a)
}):r(a,e)}};return"object"==typeof t&&null!==t&&!Array.isArray(t)&&r(t,e),n
},SHe=(e,t)=>"explode"in e&&void 0!==e.explode?e.explode:t,_He=(e,t,n,r)=>{
const o=!("explode"in e)||void 0===e.explode||e.explode,a="style"in e&&e.style?e.style:"form"
;if("content"in e&&e.content){
const o=Object.keys(e.content)[0]??"application/json",a=vHe(n,o)
;return void r.set(t,a)}if("deepObject"===a&&o){const e=kHe(t,n)
;for(const t of e)r.append(t.key,t.value);return}if("spaceDelimited"===a){
const e=wHe(n),o=r.get(t);return void r.set(t,o?`${o} ${e}`:e)}
if("pipeDelimited"===a){const e=xHe(n),o=r.get(t)
;return void r.set(t,o?`${o}|${e}`:e)}const i=yHe(n,o)
;if(Array.isArray(i))for(const s of i){const e=s.key||t
;r.append(e,String(s.value))}else r.append(t,String(i))},THe=(e,t,n,r)=>{
const o=OHe(t,n);if(Array.isArray(o))for(const a of o){const t=a.key||e
;r.push(OUe($Ue,{name:t,value:String(a.value),path:"/"}))}else r.push(OUe($Ue,{
name:e,value:String(o),path:"/"}))},EHe="function"==typeof Buffer
;"function"==typeof TextDecoder&&new TextDecoder
;const AHe="function"==typeof TextEncoder?new TextEncoder:void 0,CHe=Array.prototype.slice.call("ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=")
;(e=>{let t={};e.forEach(((e,n)=>t[e]=n))})(CHe)
;const $He=String.fromCharCode.bind(String)
;"function"==typeof Uint8Array.from&&Uint8Array.from.bind(Uint8Array)
;const PHe=e=>e.replace(/=/g,"").replace(/[+\/]/g,(e=>"+"==e?"-":"_")),DHe="function"==typeof btoa?e=>btoa(e):EHe?e=>Buffer.from(e,"binary").toString("base64"):e=>{
let t,n,r,o,a="";const i=e.length%3;for(let s=0;s<e.length;){
if((n=e.charCodeAt(s++))>255||(r=e.charCodeAt(s++))>255||(o=e.charCodeAt(s++))>255)throw new TypeError("invalid character found")
;t=n<<16|r<<8|o,a+=CHe[t>>18&63]+CHe[t>>12&63]+CHe[t>>6&63]+CHe[63&t]}
return i?a.slice(0,i-3)+"===".substring(i):a
},IHe=EHe?e=>Buffer.from(e).toString("base64"):e=>{let t=[]
;for(let n=0,r=e.length;n<r;n+=4096)t.push($He.apply(null,e.subarray(n,n+4096)))
;return DHe(t.join(""))},MHe=(e,t=!1)=>t?PHe(IHe(e)):IHe(e),NHe=e=>{
if(e.length<2)return(t=e.charCodeAt(0))<128?e:t<2048?$He(192|t>>>6)+$He(128|63&t):$He(224|t>>>12&15)+$He(128|t>>>6&63)+$He(128|63&t)
;var t=65536+1024*(e.charCodeAt(0)-55296)+(e.charCodeAt(1)-56320)
;return $He(240|t>>>18&7)+$He(128|t>>>12&63)+$He(128|t>>>6&63)+$He(128|63&t)
},RHe=/[\uD800-\uDBFF][\uDC00-\uDFFFF]|[^\x00-\x7F]/g,LHe=EHe?e=>Buffer.from(e,"utf8").toString("base64"):AHe?e=>IHe(AHe.encode(e)):e=>DHe(e.replace(RHe,NHe)),BHe=(e,t=!1)=>t?PHe(LHe(e)):LHe(e),jHe=(e,t)=>t.flatMap((t=>MH(t).flatMap((t=>qke(e?.[t])||[]))))??[],UHe=({environment:e,exampleKey:t="default",globalCookies:n,method:r,operation:o,path:a,proxyUrl:i,server:s,selectedSecuritySchemes:l})=>{
try{const c=qke(o.requestBody),u=GQe(e),d=((e=[],t={},n="default")=>{const r={
cookies:[],headers:{},pathVariables:{},urlParams:new URLSearchParams}
;if(0===e.length)return r;for(const o of e){const e=qke(o),a=nHe(e,n,void 0)
;if(!a||gHe(e,a))continue
;const i="string"==typeof a.value?BH(a.value,t):a.value,s=BH(e.name,t)
;switch(e.in){case"header":{
if("content-type"===s.toLowerCase()&&"multipart/form-data"===i)break
;const t=bHe(i,SHe(e,!1));if(!xH(t))break;const n=String(t)
;r.headers[s]?r.headers[s]=`${r.headers[s]},${n}`:r.headers[s]=n;break}
case"path":{const t=bHe(i,SHe(e,!1))
;r.pathVariables[s]=encodeURIComponent(String(t));break}case"query":
_He(e,s,i,r.urlParams);break;case"cookie":THe(s,i,SHe(e,!0),r.cookies)}}return r
})(o.parameters??[],u,t),p=((e,t={},n="")=>{
const r={},o=[],a=new URLSearchParams;return e.forEach((e=>{
if("apiKey"===e.type){const i=BH(e.name,t),s=BH(e["x-scalar-secret-token"],t)||n
;"header"===e.in&&(r[i]=s),
"query"===e.in&&a.append(i,s),"cookie"===e.in&&o.push(OUe($Ue,{name:i,value:s,
path:"/"}))}if("http"===e.type)if("basic"===e.scheme){
const n=`${BH(e["x-scalar-secret-username"],t)}:${BH(e["x-scalar-secret-password"],t)}`
;r.Authorization=`Basic ${":"===n?"username:password":BHe(n)}`}else{
const o=BH(e["x-scalar-secret-token"],t);r.Authorization=`Bearer ${o||n}`}
if("oauth2"===e.type){
const o=Object.values(e.flows),a=BH(o.filter(xH).find((e=>e["x-scalar-secret-token"]))?.["x-scalar-secret-token"]??"",t)
;r.Authorization=`Bearer ${a||n}`}})),{headers:r,cookies:o,urlParams:a}
})(l,u),h=tHe({method:r,operation:o,exampleKey:t,hideDisabledHeaders:!0
}).filter((e=>!e.isOverridden)).reduce(((e,t)=>(e[t.name]=t.defaultValue,
e)),{}),f=new Headers({...h,...d.headers,...p.headers
}),m=new URLSearchParams([...d.urlParams,...p.urlParams]),g=EH(r)?((e,t={},n="default")=>{
if(!e)return null
;const r=e?.["x-scalar-selected-content-type"]?.[n]??Object.keys(e?.content??{})[0]??"application/json",o=fHe(e,r,n)
;if(!o)return null
;if(("multipart/form-data"===r||"application/x-www-form-urlencoded"===r)&&Array.isArray(o.value)){
const e=o.value.filter((e=>!e.isDisabled)),n="multipart/form-data"===r?new FormData:new URLSearchParams
;return e.forEach((({name:e,value:r})=>{if(!e)return;const o=BH(e,t)
;if(r instanceof File&&n instanceof FormData){const e=Q_e(r)
;n.append(o,e,e.name)}else"string"==typeof r&&n.append(o,BH(r,t))})),n}
return"object"==typeof o.value?BH(JSON.stringify(o.value),t):"string"==typeof o.value?BH(o.value,t):o.value
})(c,u,t):null
;g&&(g instanceof FormData||g instanceof URLSearchParams)&&f.delete("Content-Type")
;const v=KQe({environment:e,server:s,path:a,pathVariables:d.pathVariables,
urlParams:m});if(!v)throw C_e;const b=qH(i,v),y=VH(i,v),O=f.get("User-Agent")
;XQe()&&O&&f.set("X-Scalar-User-Agent",O)
;const w=(({paramCookies:e,globalCookies:t,env:n,originalCookieHeader:r,url:o,useCustomCookieHeader:a,disabledGlobalCookies:i})=>{
const s=t.filter((e=>mHe({cookie:e,url:o,disabledGlobalCookies:i
}))).map((e=>OUe($Ue,{...e,name:BH(e.name,n),value:BH(e.value,n)}))),l=((e,t)=>{
const n=e.map((e=>`${e.name}=${e.value}`)).join("; ")
;return t&&n?`${t}; ${n}`:t||n||""})([...s,...e],r??void 0)
;return l?a?(console.warn("We're using a `X-Scalar-Cookie` custom header to the request. The proxy will forward this as a `Cookie` header. We do this to avoid the browser omitting the `Cookie` header for cross-origin requests for security reasons."),
{name:"X-Scalar-Cookie",value:l
}):(console.warn("We're trying to add a Cookie header, but browsers often omit them for cross-origin requests for various security reasons. If it's not working, that's probably why. Here are the requirements for it to work:\n\n        - The browser URL must be on the same domain as the server URL.\n        - The connection must be made over HTTPS.\n        "),
{name:"Cookie",value:l}):null})({paramCookies:[...d.cookies,...p.cookies],
globalCookies:n,env:u,originalCookieHeader:f.get("Cookie"),url:v,
useCustomCookieHeader:XQe()||b,
disabledGlobalCookies:o["x-scalar-disable-parameters"]?.["global-cookies"]?.[t]??{}
});w&&f.set(w.name,w.value);const x=new AbortController;return[null,{
controller:x,isUsingProxy:b,request:new Request(y,{method:r.toUpperCase(),
headers:f,signal:x.signal,body:g})}]}catch(Ck){return[$_e(Ck,x_e),null]}
},zHe=e=>{const t=new Headers;if(e.headers.forEach((({name:e,value:n})=>{
t.append(e,n)})),e.cookies?.length){
const n=e.cookies.map((({name:e,value:t})=>`${e}=${t}`)).join("; ")
;t.append("Cookie",n)}return t},FHe=e=>{if(!e)return null
;const{params:t,text:n,mimeType:r}=e;if(t?.length){
const e=r?.includes("multipart/form-data")?new FormData:new URLSearchParams
;return t.forEach((({name:t,value:n})=>{e.append(t,n||"")})),e}
return n?(new TextEncoder).encode(n):null
},ZHe=e=>"getSetCookie"in e&&"function"==typeof e.getSetCookie?e.getSetCookie():[],QHe=e=>{
const t=new Headers;return e.headers.forEach((({name:e,value:n})=>{t.append(e,n)
})),t},HHe=e=>{if(!e.content.text)return{body:null,data:"",size:0}
;const{text:t,encoding:n}=e.content;if(n)return{body:null,data:t,size:t.length}
;const r=(new TextEncoder).encode(t).buffer;return{body:r,data:t,
size:r.byteLength}
},VHe=e=>e.split("-").map((e=>e.charAt(0).toUpperCase()+e.toLowerCase().slice(1))).join("-"),qHe=async(e,t,n)=>{
let r=e;for(const o of n){const e=o.hooks?.[t];e&&(r=await e(r)??r)}return r}
;var WHe,XHe,GHe,YHe,KHe,JHe,eVe,tVe,nVe,rVe={};function oVe(){
return WHe||(WHe=1,
rVe.removeLeadingAndTrailingHTTPWhitespace=e=>e.replace(/^[ \t\n\r]+/u,"").replace(/[ \t\n\r]+$/u,""),
rVe.removeTrailingHTTPWhitespace=e=>e.replace(/[ \t\n\r]+$/u,""),
rVe.isHTTPWhitespaceChar=e=>" "===e||"\t"===e||"\n"===e||"\r"===e,
rVe.solelyContainsHTTPTokenCodePoints=e=>/^[-!#$%&'*+.^_`|~A-Za-z0-9]*$/u.test(e),
rVe.soleyContainsHTTPQuotedStringTokenCodePoints=e=>/^[\t\u0020-\u007E\u0080-\u00FF]*$/u.test(e),
rVe.asciiLowercase=e=>e.replace(/[A-Z]/gu,(e=>e.toLowerCase())),
rVe.collectAnHTTPQuotedString=(e,t)=>{let n="";for(t++;;){
for(;t<e.length&&'"'!==e[t]&&"\\"!==e[t];)n+=e[t],++t;if(t>=e.length)break
;const r=e[t];if(++t,"\\"!==r)break;if(t>=e.length){n+="\\";break}n+=e[t],++t}
return[n,t]}),rVe}const aVe=jR(function(){if(nVe)return tVe;nVe=1
;const e=function(){if(GHe)return XHe;GHe=1
;const{asciiLowercase:e,solelyContainsHTTPTokenCodePoints:t,soleyContainsHTTPQuotedStringTokenCodePoints:n}=oVe()
;return XHe=class{constructor(e){this._map=e}get size(){return this._map.size}
get(t){return t=e(String(t)),this._map.get(t)}has(t){
return t=e(String(t)),this._map.has(t)}set(r,o){
if(r=e(String(r)),o=String(o),!t(r))throw new Error(`Invalid MIME type parameter name "${r}": only HTTP token code points are valid.`)
;if(!n(o))throw new Error(`Invalid MIME type parameter value "${o}": only HTTP quoted-string token code points are valid.`)
;return this._map.set(r,o)}clear(){this._map.clear()}delete(t){
return t=e(String(t)),this._map.delete(t)}forEach(e,t){this._map.forEach(e,t)}
keys(){return this._map.keys()}values(){return this._map.values()}entries(){
return this._map.entries()}[Symbol.iterator](){
return this._map[Symbol.iterator]()}}}(),t=function(){if(KHe)return YHe;KHe=1
;const{removeLeadingAndTrailingHTTPWhitespace:e,removeTrailingHTTPWhitespace:t,isHTTPWhitespaceChar:n,solelyContainsHTTPTokenCodePoints:r,soleyContainsHTTPQuotedStringTokenCodePoints:o,asciiLowercase:a,collectAnHTTPQuotedString:i}=oVe()
;return YHe=s=>{s=e(s);let l=0,c="";for(;l<s.length&&"/"!==s[l];)c+=s[l],++l
;if(0===c.length||!r(c))return null;if(l>=s.length)return null;++l;let u=""
;for(;l<s.length&&";"!==s[l];)u+=s[l],++l
;if(u=t(u),0===u.length||!r(u))return null;const d={type:a(c),subtype:a(u),
parameters:new Map};for(;l<s.length;){for(++l;n(s[l]);)++l;let e=""
;for(;l<s.length&&";"!==s[l]&&"="!==s[l];)e+=s[l],++l;if(e=a(e),l<s.length){
if(";"===s[l])continue;++l}let c=null
;if('"'===s[l])for([c,l]=i(s,l);l<s.length&&";"!==s[l];)++l;else{
for(c="";l<s.length&&";"!==s[l];)c+=s[l],++l;if(c=t(c),""===c)continue}
e.length>0&&r(e)&&o(c)&&!d.parameters.has(e)&&d.parameters.set(e,c)}return d}
}(),n=function(){if(eVe)return JHe;eVe=1
;const{solelyContainsHTTPTokenCodePoints:e}=oVe();return JHe=t=>{
let n=`${t.type}/${t.subtype}`;if(0===t.parameters.size)return n
;for(let[r,o]of t.parameters)n+=";",
n+=r,n+="=",e(o)&&0!==o.length||(o=o.replace(/(["\\])/gu,"\\$1"),
o=`"${o}"`),n+=o;return n}
}(),{asciiLowercase:r,solelyContainsHTTPTokenCodePoints:o}=oVe()
;return tVe=class{constructor(n){n=String(n);const r=t(n)
;if(null===r)throw new Error(`Could not parse MIME type string "${n}"`)
;this._type=r.type,this._subtype=r.subtype,this._parameters=new e(r.parameters)}
static parse(e){try{return new this(e)}catch(Bw){return null}}get essence(){
return`${this.type}/${this.subtype}`}get type(){return this._type}set type(e){
if(0===(e=r(String(e))).length)throw new Error("Invalid type: must be a non-empty string")
;if(!o(e))throw new Error(`Invalid type ${e}: must contain only HTTP token code points`)
;this._type=e}get subtype(){return this._subtype}set subtype(e){
if(0===(e=r(String(e))).length)throw new Error("Invalid subtype: must be a non-empty string")
;if(!o(e))throw new Error(`Invalid subtype ${e}: must contain only HTTP token code points`)
;this._subtype=e}get parameters(){return this._parameters}toString(){
return n(this)}isJavaScript({prohibitParameters:e=!1}={}){switch(this._type){
case"text":switch(this._subtype){case"ecmascript":case"javascript":
case"javascript1.0":case"javascript1.1":case"javascript1.2":case"javascript1.3":
case"javascript1.4":case"javascript1.5":case"jscript":case"livescript":
case"x-ecmascript":case"x-javascript":return!e||0===this._parameters.size
;default:return!1}case"application":switch(this._subtype){case"ecmascript":
case"javascript":case"x-ecmascript":case"x-javascript":
return!e||0===this._parameters.size;default:return!1}default:return!1}}isXML(){
return"xml"===this._subtype&&("text"===this._type||"application"===this._type)||this._subtype.endsWith("+xml")
}isHTML(){return"html"===this._subtype&&"text"===this._type}}}()),iVe={
"application/epub+zip":{extension:".epub"},"application/gzip":{extension:".gz"},
"application/java-archive":{extension:".jar"},"application/javascript":{
extension:".js",raw:!0},"application/json":{extension:".json",raw:!0,
language:"json"},"application/ld+json":{extension:".jsonld",raw:!0,
language:"json"},"application/problem+json":{extension:".json",raw:!0,
language:"json"},"application/vnd.api+json":{extension:".json",raw:!0,
language:"json"},"application/dns-json":{extension:".json",raw:!0,
language:"json"},"application/msword":{extension:".doc"},
"application/octet-stream":{extension:".bin"},"application/ogg":{
extension:".ogx"},"application/pdf":{extension:".pdf",preview:"object"},
"application/rtf":{extension:".rtf",raw:!0},"application/vnd.amazon.ebook":{
extension:".azw"},"application/vnd.apple.installer+xml":{extension:".mpkg",
raw:!0,language:"xml"},"application/vnd.mozilla.xul+xml":{extension:".xul",
raw:!0,language:"xml"},"application/vnd.ms-excel":{extension:".xls"},
"application/vnd.ms-fontobject":{extension:".eot"},
"application/vnd.ms-powerpoint":{extension:".ppt"},
"application/vnd.oasis.opendocument.presentation":{extension:".odp"},
"application/vnd.oasis.opendocument.spreadsheet":{extension:".ods"},
"application/vnd.oasis.opendocument.text":{extension:".odt"},
"application/vnd.openxmlformats-officedocument.presentationml.presentation":{
extension:".pptx"},
"application/vnd.openxmlformats-officedocument.spreadsheetml.sheet":{
extension:".xlsx"},
"application/vnd.openxmlformats-officedocument.wordprocessingml.document":{
extension:".docx"},"application/vnd.rar":{extension:".rar"},
"application/vnd.visio":{extension:".vsd"},"application/x-7z-compressed":{
extension:".7z"},"application/x-abiword":{extension:".abw"},
"application/x-bzip":{extension:".bz"},"application/x-bzip2":{extension:".bz2"},
"application/x-cdf":{extension:".cda"},"application/x-csh":{extension:".csh"},
"application/x-freearc":{extension:".arc"},"application/x-httpd-php":{
extension:".php",raw:!0},"application/x-sh":{extension:".sh",raw:!0},
"application/x-tar":{extension:".tar"},"application/xhtml+xml":{
extension:".xhtml",raw:!0,language:"html"},"application/xml":{extension:".xml",
raw:!0,language:"xml"},"application/yaml":{extension:".yaml",raw:!0,
language:"yaml"},"application/zip":{extension:".zip"},"audio/aac":{
extension:".aac"},"audio/midi":{extension:".midi"},"audio/mpeg":{
extension:".mp3",preview:"audio"},"audio/ogg":{extension:".oga"},"audio/wav":{
extension:".wav"},"audio/webm":{extension:".weba"},"font/otf":{extension:".otf"
},"font/ttf":{extension:".ttf"},"font/woff":{extension:".woff"},"font/woff2":{
extension:".woff2"},"image/apng":{extension:".apng",preview:"image",alpha:!0},
"image/avif":{extension:".avif",preview:"image"},"image/bmp":{extension:".bmp",
preview:"image"},"image/gif":{extension:".gif",preview:"image",alpha:!0},
"image/jpeg":{extension:".jpg",preview:"image"},"image/png":{extension:".png",
preview:"image",alpha:!0},"image/svg+xml":{extension:".svg",raw:!0,
language:"xml",preview:"image",alpha:!0},"image/tiff":{extension:".tiff"},
"image/vnd.microsoft.icon":{extension:".ico",preview:"image"},"image/webp":{
extension:".webp",preview:"image",alpha:!0},"text/calendar":{extension:".ics",
raw:!0},"text/css":{extension:".css",raw:!0,language:"css"},"text/csv":{
extension:".csv",raw:!0},"text/html":{extension:".html",raw:!0,language:"html",
preview:"object"},"text/javascript":{extension:".js",raw:!0},"text/plain":{
extension:".txt",raw:!0},"text/xml":{extension:".xml",raw:!0,language:"xml"},
"text/yaml":{extension:".yaml",raw:!0,language:"yaml"},"video/3gpp":{
extension:".3gp"},"audio/3gpp":{extension:".3gp"},"video/3gpp2":{
extension:".3g2"},"audio/3gpp2":{extension:".3g2"},"video/mp2t":{extension:".ts"
},"video/mp4":{extension:".mp4",preview:"video"},"video/mpeg":{extension:".mpeg"
},"video/ogg":{extension:".ogv"},"video/webm":{extension:".webm",preview:"video"
},"video/x-msvideo":{extension:".avi"}};function sVe(e){const t=iVe[e]
;return t||(e.endsWith("+json")?{extension:".json",raw:!0,language:"json"
}:void 0)}Object.entries(iVe).filter((([,e])=>e?.raw)).map((([e])=>e))
;const lVe=(e,t)=>{const n=new aVe(t);return function(e){return!!sVe(e)?.raw
}(n.essence)?new TextDecoder(n.parameters.get("charset")).decode(e):new Blob([e],{
type:n.essence})
},cVe=[204,205,304],uVe=async({isUsingProxy:e,operation:t,request:n,plugins:r})=>{
try{const{request:o}=await qHe({request:n
},"beforeRequest",r),a=Date.now(),i=await fetch(o.clone()),s=Date.now(),l=s-a,c=i.headers.get("content-type"),u=((e,t=!1)=>{
const n=Object.fromEntries(e)
;t&&["Access-Control-Allow-Credentials","Access-Control-Allow-Headers","Access-Control-Allow-Methods","Access-Control-Allow-Origin","Access-Control-Expose-Headers"].map((e=>e.toLowerCase())).forEach((e=>delete n[e]))
;const r=Object.keys(n).find((e=>"x-scalar-modified-headers"===e.toLowerCase())),o=r?n[r]?.toString().split(", ")?.map((e=>e.toLowerCase()))??[]:[]
;return Object.keys(n).forEach((e=>{o.includes(e.toLowerCase())&&delete n[e]})),
r&&delete n[r],Object.keys(n).forEach((e=>{const t=/^x-scalar-original-/i
;if(t.test(e)){const r=e.replace(t,"");n[e]&&(n[r]=n[e],delete n[e])}
})),Object.keys(n).forEach((e=>{const t=VHe(e)
;e!==t&&n[e]&&(n[t]=n[e],delete n[e])
})),Object.fromEntries(Object.entries(n).sort((([e],[t])=>e.localeCompare(t))))
})(i.headers,e),d=new URL(i.url),p=d.pathname+d.search,h=i.statusText||$H[i.status]?.name||"",f=o.method,m=cVe.includes(i.status)
;return c?.startsWith("text/event-stream")&&i.body?dVe({response:i,
modifiedRequest:o,operation:t,plugins:r,endTime:s,duration:l,responseHeaders:u,
statusText:h,method:f,fullPath:p}):pVe({response:i,modifiedRequest:o,
operation:t,plugins:r,endTime:s,duration:l,responseHeaders:u,statusText:h,
method:f,fullPath:p,contentType:c,shouldSkipBody:m})}catch(bk){
return[$_e(bk,A_e),null]}
},dVe=async({response:e,modifiedRequest:t,operation:n,plugins:r,endTime:o,duration:a,responseHeaders:i,statusText:s,method:l,fullPath:c})=>{
const u=new Response(null,{status:e.status,statusText:s,headers:e.headers})
;await qHe({response:u,request:t,operation:n},"responseReceived",r)
;const d=ZHe(u.headers);return[null,{timestamp:o,request:t,response:{...u,
headers:i,cookieHeaderKeys:d,reader:e.body.getReader(),duration:a,method:l,
path:c},originalResponse:u.clone()}]
},pVe=async({response:e,modifiedRequest:t,operation:n,plugins:r,endTime:o,duration:a,responseHeaders:i,statusText:s,method:l,fullPath:c,contentType:u,shouldSkipBody:d})=>{
const p=await e.clone().arrayBuffer(),h=lVe(p,u??"text/plain;charset=UTF-8"),f=new Response(d?null:p,{
status:e.status,statusText:s,headers:e.headers});await qHe({response:f,
request:t,operation:n},"responseReceived",r);const m=ZHe(f.headers)
;return[null,{timestamp:o,request:t,response:{...f,headers:i,cookieHeaderKeys:m,
data:h,size:p.byteLength,duration:a,method:l,status:e.status,path:c},
originalResponse:e.clone()}]},hVe=()=>{
const e=bm(100),t=bm(0),n=bm(!1),r=bm(),o=()=>{
n.value?e.value-=(e.value-15)/60:e.value-=t.value/20,
e.value<=0&&(clearInterval(r.value),r.value=void 0,e.value=100,n.value=!1)}
;return{startLoading:()=>{
r.value?n.value=!0:(n.value=!0,r.value=setInterval(o,20))},stopLoading:()=>{
t.value=e.value,n.value=!1},percentage:e}},fVe={100:{color:"text-yellow"},200:{
color:"text-green"},202:{color:"text-green"},300:{color:"text-blue"},304:{
color:"text-blue"},400:{color:"text-red"},401:{color:"text-orange"},422:{
color:"text-yellow"},423:{color:"text-purple"},505:{color:"text-orange"}
},mVe=e=>fVe[e]||{color:"text-grey"},gVe={class:"min-w-0"},vVe={
class:"text-c-1 min-w-0 truncate"},bVe=Qg({__name:"AddressBarHistory",props:{
target:{},history:{}},emits:["select:history:item"],setup(e,{emit:t}){const n=t
;return(t,r)=>(Ub(),Hb(xm(fk),{as:"div"},{default:ig((({open:t})=>[Yb(xm(FK),{
offset:0,resize:"",target:e.target},xv({default:ig((()=>[e.history.length?(Ub(),
Hb(xm(mk),{key:0,
class:"address-bar-history-button z-context-plus text-c-3 focus:text-c-1 relative mr-1 rounded-lg p-1.5"
},{default:ig((()=>[Yb(xm(Gne),{icon:"History",size:"sm",thickness:"2.25"
}),r[0]||(r[0]=Gb("span",{class:"sr-only"},"Request History",-1))])),_:1
})):ny("",!0)])),_:2},[t?{name:"floating",fn:ig((({width:t})=>[Yb(xm(gk),{
class:"custom-scroll grid max-h-[inherit] grid-cols-[44px_1fr_repeat(3,auto)] items-center border-t p-0.75",
static:"",style:Ah({width:t})},{
default:ig((()=>[(Ub(!0),Qb(Mb,null,wv(e.history,((e,t)=>(Ub(),Hb(xm(vk),{key:t,
as:"button",
class:"font-code ui-active:*:bg-b-2 text-c-2 contents text-sm font-medium *:flex *:h-8 *:cursor-pointer *:items-center *:rounded-none *:px-1.5 *:first:rounded-l *:last:rounded-r",
value:t,onClick:e=>n("select:history:item",{index:t})},{
default:ig((()=>[Yb(xm(rke),{class:"text-[11px]",method:e.method
},null,8,["method"]),Gb("div",gVe,[Gb("div",vVe,Uh(e.path),1)]),Gb("div",null,Uh(xm(oke)(e.duration)),1),Gb("div",{
class:Ih([xm(mVe)(e.status).color])
},Uh(e.status),3),Gb("div",null,Uh(xm($H)[e.status]?.name),1)])),_:2
},1032,["value","onClick"])))),128))])),_:1},8,["style"]),Yb(xm(ZK),{
class:"-top-(--scalar-address-bar-height) rounded-lg"})])),key:"0"
}:void 0]),1032,["target"])])),_:1}))}
}),yVe=sae(bVe,[["__scopeId","data-v-b45f1e9d"]]),OVe=["aria-expanded"],wVe={
class:"overflow-hidden text-ellipsis whitespace-nowrap"},xVe=["id"],kVe={key:0
},SVe={class:"description text-c-3 px-3 py-1.5"},_Ve=Qg({
__name:"ServerDropdownItem",props:{server:{},serverOption:{}},
emits:["update:variable","update:selectedServer"],setup(e,{emit:t}){
const n=t,r=Hg(),o=Sy((()=>e.serverOption.id===e.server?.url)),a=Sy((()=>o.value&&Object.keys(e.server?.variables??{}).length>0))
;return(t,i)=>(Ub(),Qb("div",{
class:Ih(["group/item flex min-h-fit flex-col rounded border",{
"border-transparent":!o.value}])},[Gb("button",iy(a.value?{"aria-controls":xm(r)
}:{},{"aria-expanded":a.value,
class:["flex min-h-8 cursor-pointer items-center gap-1.5 rounded px-1.5",o.value?"text-c-1 bg-b-2":"hover:bg-b-2"],
type:"button",onClick:i[0]||(i[0]=e=>n("update:selectedServer"))}),[Yb(xm(KG),{
selected:o.value
},null,8,["selected"]),Gb("span",wVe,Uh(e.serverOption.label),1)],16,OVe),a.value?(Ub(),
Qb("div",{key:0,id:xm(r),
class:"bg-b-2 divide divide-y rounded-b border-t *:pl-4",
onClick:i[2]||(i[2]=BO((()=>{}),["stop"]))},[Yb(G_e,{
variables:e.server?.variables,
"onUpdate:variable":i[1]||(i[1]=(e,t)=>n("update:variable",e,t))
},null,8,["variables"]),e.server?.description?(Ub(),
Qb("div",kVe,[Gb("div",SVe,[Yb(xm(mre),{value:e.server.description
},null,8,["value"])])])):ny("",!0)],8,xVe)):ny("",!0)],2))}
}),TVe=sae(_Ve,[["__scopeId","data-v-1b7a32a4"]]),EVe=["onClick"],AVe={
class:"flex items-center justify-center"},CVe=Qg({__name:"ServerDropdown",
props:{servers:{},server:{},target:{},layout:{}},
emits:["update:selectedServer","update:variable","update:servers"],
setup(e,{emit:t}){const n=t,r=Sy((()=>e.servers.map((e=>({id:e.url,
label:e.url??"Unknown server"
}))))),o=Sy((()=>e.server?.url?.endsWith("/")?e.server.url.slice(0,-1):e.server?.url||""))
;return(t,a)=>(Ub(),Hb(xm(Rre),{class:"max-h-[inherit] p-0 text-base",focus:"",
offset:0,placement:"bottom-start",resize:"",target:e.target,
teleport:`#${e.target}`},{popover:ig((({close:t})=>[Gb("div",{
class:"custom-scroll flex max-h-[inherit] flex-col gap-1 border-t p-1",onClick:t
},[(Ub(!0),Qb(Mb,null,wv(r.value,((t,r)=>(Ub(),Hb(TVe,{key:t.id,server:e.server,
serverOption:t,type:"request",
"onUpdate:selectedServer":e=>n("update:selectedServer",{url:t.id}),
"onUpdate:variable":(e,t)=>n("update:variable",{index:r,key:e,value:t})
},null,8,["server","serverOption","onUpdate:selectedServer","onUpdate:variable"])))),128)),"modal"!==e.layout?(Ub(),
Qb("button",{key:0,
class:"text-xxs hover:bg-b-2 flex cursor-pointer items-center gap-1.5 rounded p-1.75",
type:"button",onClick:a[0]||(a[0]=e=>n("update:servers"))
},[Gb("div",AVe,[Yb(xm(GA),{class:"size-4"
})]),a[3]||(a[3]=Gb("span",null,"Update Servers",-1))])):ny("",!0)],8,EVe)])),
backdrop:ig((()=>[Yb(xm(ZK),{
class:"-top-(--scalar-address-bar-height) rounded-lg"})])),
default:ig((()=>[Yb(xm(WS),{
class:"z-context-plus hover:bg-b-2 font-code text-c-2 ml-0.75 h-auto gap-0.75 rounded border px-1.5 text-base whitespace-nowrap",
variant:"ghost"},{default:ig((()=>[e.server?(Ub(),Qb(Mb,{key:0
},[a[1]||(a[1]=Gb("span",{class:"sr-only"
},"Server:",-1)),ey(" "+Uh(o.value),1)],64)):(Ub(),Qb(Mb,{key:1
},[a[2]||(a[2]=Gb("span",{class:"sr-only"},"Add Server",-1)),Yb(xm(uC),{
class:"size-3"})],64))])),_:1})])),_:1},8,["target","teleport"]))}}),$Ve={
class:"group-[.alert]:outline-orange group-[.error]:outline-red w-full pr-10 -outline-offset-1 has-[:focus-visible]:rounded-[4px] has-[:focus-visible]:outline"
},PVe={class:"text-c-1 whitespace-nowrap"},DVe={
class:"text-c-1 overflow-hidden text-ellipsis"},IVe={
class:"overflow-hidden text-ellipsis"},MVe={
class:"flex h-4 w-4 items-center justify-center"},NVe=Qg({
__name:"DataTableInputSelect",props:{modelValue:{
type:[String,Number,Boolean,Array,Object]},value:{},default:{
type:[String,Number,Boolean,Array,Object]},canAddCustomValue:{type:Boolean,
default:!0},type:{}},emits:["update:modelValue"],setup(e,{emit:t}){
const n=e,r=t,o=Sy((()=>n.value??[])),a=bm(!1),i=bm(""),s=bm(null);mg(i,(e=>{
r("update:modelValue",e)}));const l=e=>{r("update:modelValue",e),a.value=!1
},c=()=>{i.value.trim()&&l(i.value)},u=()=>{
i.value.trim()||r("update:modelValue",""),a.value=!1
},d=e=>n.modelValue.toString()===e;mg(a,(e=>{e&&Xm((()=>{s.value?.focus()}))}))
;const p=Sy((()=>void 0!==n.modelValue?n.modelValue:n.default)),h=Sy((()=>o.value.map((e=>{
const t=e.toString();return{id:t,label:t,value:t}})))),f=Sy((()=>{
const e=new Set(n.modelValue.toString().split(","))
;return h.value.filter((t=>e.has(t.id)))})),m=e=>{const t=e.map((e=>e.value))
;r("update:modelValue",t.join(","))}
;return(t,n)=>(Ub(),Qb("div",$Ve,["array"===e.type?(Ub(),Hb(xm(VK),{key:0,
modelValue:f.value,options:h.value,"onUpdate:modelValue":m},{
default:ig((()=>[Yb(xm(WS),{
class:"custom-scroll h-full justify-start gap-1.5 px-2 py-1.5 pr-6 font-normal outline-none",
fullWidth:"",variant:"ghost"},{
default:ig((()=>[Gb("span",PVe,Uh(f.value.length>0?f.value.map((e=>e.label)).join(", "):"Select a value"),1),Yb(xm(Gne),{
class:"min-w-4",icon:"ChevronDown",size:"md"})])),_:1})])),_:1
},8,["modelValue","options"])):a.value?sg((Ub(),Qb("input",{key:1,
ref_key:"inputRef",ref:s,"onUpdate:modelValue":n[0]||(n[0]=e=>i.value=e),
class:"text-c-1 w-full min-w-0 border-none px-2 py-1.5 outline-none",
placeholder:"Value",type:"text",onBlur:u,onKeyup:UO(c,["enter"])
},null,544)),[[TO,i.value]]):(Ub(),Hb(xm(f2),{key:2,resize:"",value:p.value},{
items:ig((()=>[(Ub(!0),Qb(Mb,null,wv(o.value,(e=>(Ub(),Hb(xm(Hoe),{key:e,
class:"group/item flex items-center gap-1.5 overflow-hidden text-ellipsis whitespace-nowrap",
value:e,onClick:t=>l(e)},{default:ig((()=>[Gb("div",{
class:Ih(["flex h-4 w-4 items-center justify-center rounded-full p-[3px]",d(e)?"bg-c-accent text-b-1":"shadow-border text-transparent"])
},[Yb(xm(Gne),{class:"size-2.5",icon:"Checkmark",thickness:"3"
})],2),Gb("span",IVe,Uh(e),1)])),_:2
},1032,["value","onClick"])))),128)),e.canAddCustomValue?(Ub(),Qb(Mb,{key:0
},[o.value.length?(Ub(),Hb(xm(Cre),{key:0})):ny("",!0),Yb(xm(Hoe),{
class:"flex items-center gap-1.5",onClick:n[1]||(n[1]=e=>a.value=!0)},{
default:ig((()=>[Gb("div",MVe,[Yb(xm(Gne),{icon:"Add",size:"sm"
})]),n[2]||(n[2]=Gb("span",null,"Add value",-1))])),_:1})],64)):ny("",!0)])),
default:ig((()=>[Yb(xm(WS),{
class:"size-full justify-start gap-1.5 overflow-auto px-2 py-1.5 font-normal whitespace-nowrap outline-none",
variant:"ghost"},{
default:ig((()=>[Gb("span",DVe,Uh(p.value??"Select a value"),1),Yb(xm(Gne),{
icon:"ChevronDown",size:"md"})])),_:1})])),_:1},8,["value"]))]))}}),RVe={key:0,
class:"gap-1/2 flex flex-col"},LVe=["onClick"],BVe={
class:"flex items-center gap-2 whitespace-nowrap"},jVe={
class:"w-20 overflow-hidden text-right text-ellipsis whitespace-nowrap"
},UVe=Qg({__name:"EnvironmentVariablesDropdown",props:{query:{},environment:{},
dropdownPosition:{}},emits:["select","redirect"],setup(e,{expose:t,emit:n}){
const r=n,o=bm(!0),a=bm(null),i=bm(0),s=()=>{r("redirect"),o.value=!1
},l=Sy((()=>e.environment.variables.map((e=>({key:e.name,
value:"string"==typeof e.value?e.value:e.value.default}))))),c=new Qxe(l.value,{
keys:["key","value"]}),u=Sy((()=>{
if(!e.query)return l.value.slice(-4).filter((({key:e,value:t})=>""!==e||""!==t))
;const t=c.search(e.query,{limit:10})
;return t.length>0?t.map((e=>e.item)).filter((({key:e,value:t})=>""!==e||""!==t)):[]
})),d=e=>{r("select",e)};t({handleArrowKey:e=>{
const t="up"===e?-1:1,n=u.value.length;0!==n&&(i.value=(i.value+t+n)%n)},
handleSelect:()=>{if(i.value>=0){const e=u.value[i.value];e&&d(e.key)}}
}),iv((()=>{i.value=0}));const p=Sy((()=>({
left:(e.dropdownPosition?.left??0)+"px",top:(e.dropdownPosition?.top??0)+5+"px"
})));return t2(a,(()=>{o.value=!1}),{ignore:[a]
}),(t,n)=>o.value?(Ub(),Hb(xm(zK),{key:0,class:"scalar-client"},{
default:ig((()=>[Gb("div",{ref_key:"dropdownRef",ref:a,
class:"custom-scroll fixed top-0 left-0 flex max-h-[60svh] w-56 flex-col rounded border p-0.75",
style:Ah(p.value)
},[u.value.length?(Ub(),Qb("ul",RVe,[(Ub(!0),Qb(Mb,null,wv(u.value,((t,n)=>(Ub(),
Qb("li",{key:t.key,
class:Ih(["font-code text-xxs hover:bg-b-2 flex h-8 cursor-pointer items-center justify-between gap-1.5 rounded p-1.5 transition-colors duration-150",{
"bg-b-2":n===i.value}]),onClick:e=>d(t.key)},[Gb("div",BVe,[Gb("span",{
class:"h-2.25 w-2.25 min-w-2.25 rounded-full",style:Ah({
backgroundColor:e.environment.color})
},null,4),ey(" "+Uh(t.key),1)]),Gb("span",jVe,Uh(t.value),1)],10,LVe)))),128))])):(Ub(),
Hb(xm(WS),{key:1,
class:"font-code text-xxs bg-b-inherit hover:bg-b-2 flex h-8 w-full justify-start gap-2 px-1.5 transition-colors duration-150",
variant:"outlined",onClick:s},{default:ig((()=>[Yb(xm(uC),{class:"size-3"
}),n[0]||(n[0]=ey(" Add Variable ",-1))])),_:1})),n[1]||(n[1]=Gb("div",{
class:"bg-b-1 brightness-lifted absolute inset-0 -z-1 rounded shadow-lg"
},null,-1))],4)])),_:1})):ny("",!0)}});let zVe=class e extends hle{
constructor(e,t){
super(),this.variableName=e,this.pillColor=t?.color||"var(--scalar-color-1)"
;const n=t?.variables?.find((t=>t.name===e)),r=n?"string"==typeof n.value?n.value:n.value?.default:void 0
;this.variableInfo={value:r||"No value",hasValue:!!r}}app;pillColor;variableInfo
;toDOM(){const e=document.createElement("span")
;e.className="cm-pill",e.textContent=this.variableName,
e.style.setProperty("--tw-bg-base",this.pillColor),
e.style.opacity=this.variableInfo.hasValue?"1":"0.5";const t=Qg({render:()=>{
const e=_y("div",{class:"flex items-center gap-1 whitespace-nowrap"
},[_y("span",this.variableName)]);return _y(Uoe,{
content:this.variableInfo.value,delay:0,placement:"bottom",offset:6},{
default:()=>e})}});return this.app=HO(t),this.app.mount(e),e}destroy(){
this.app&&(this.app.unmount(),this.app=null)}eq(t){
return t instanceof e&&t.variableName===this.variableName&&t.pillColor===this.pillColor&&t.variableInfo.value===this.variableInfo.value&&t.variableInfo.hasValue===this.variableInfo.hasValue
}ignoreEvent(){return!1}};const FVe=e=>dce.fromClass(class{decorations
;lastEnvironment;constructor(t){
this.lastEnvironment=e.environment,this.decorations=this.buildDecorations(t)}
update(t){
if(e.environment!==this.lastEnvironment)return this.lastEnvironment=e.environment,
void(this.decorations=this.buildDecorations(t.view))
;(t.docChanged||t.viewportChanged)&&(this.decorations=this.buildDecorations(t.view))
}buildDecorations(t){const n=new Qie;for(const{from:r,to:o}of t.visibleRanges){
const a=t.state.doc.sliceString(r,o),i=new RegExp(NH.VARIABLES.source,NH.VARIABLES.flags)
;let s;for(;null!==(s=i.exec(a));){const o=r+s.index,a=o+s[0].length,i=s[1]??""
;t.state.doc.sliceString(o,a).includes("\n")||n.add(o,a,mle.widget({
widget:new zVe(i,e.environment),side:1}))}}return n.finish()}},{
decorations:e=>e.decorations}),ZVe=cde.domEventHandlers({keydown(e,t){
if("Backspace"!==e.key)return!1;const{state:n}=t,{from:r,to:o}=n.selection.main
;return 0===r&&o===n.doc.length?(t.dispatch({changes:{from:0,to:n.doc.length},
selection:{anchor:0}
}),e.preventDefault(),!0):r===o&&r>=2&&"}}"===n.doc.sliceString(r-2,r)&&(t.dispatch({
changes:{from:r-2,to:r},selection:{anchor:r-2}}),e.preventDefault(),!0)}}),QVe={
class:"whitespace-nowrap"},HVe=["id"],VVe={key:0,
class:"z-context text-c-2 absolute right-1.5 bottom-1 hidden font-sans group-has-[:focus-visible]/input:block",
role:"alert"},qVe={key:5,class:"centered-y text-orange absolute right-7 text-xs"
},WVe={key:6,
class:"centered-y absolute right-0 flex h-full items-center p-1.5 group-has-[.cm-focused]:z-1"
},XVe={key:7,
class:"required centered-y text-xxs text-c-3 group-[.error]:text-red bg-b-1 pointer-events-none absolute right-0 mr-0.5 pt-px pr-2 opacity-100 shadow-[-8px_0_4px_var(--scalar-background-1)] transition-opacity duration-150 group-[.alert]:bg-transparent group-[.alert]:shadow-none group-[.error]:bg-transparent group-[.error]:shadow-none peer-has-[.cm-focused]:opacity-0"
},GVe=Qg({inheritAttrs:!1,__name:"CodeInput",props:{modelValue:{},
environment:{},type:{},disabled:{type:Boolean,default:!1},error:{type:Boolean,
default:!1},layout:{default:"desktop"},enum:{},examples:{},default:{},nullable:{
type:Boolean,default:!1},placeholder:{},required:{type:Boolean},colorPicker:{
type:Boolean,default:!1},lineNumbers:{type:Boolean,default:!1},lint:{
type:Boolean,default:!1},lineWrapping:{type:Boolean,default:!1},language:{},
extensions:{default:()=>[]},disableTabIndent:{type:Boolean,default:!1},
disableEnter:{type:Boolean,default:!1},disableCloseBrackets:{type:Boolean,
default:!1},emitOnBlur:{type:Boolean,default:!0},withVariables:{type:Boolean,
default:!0},importCurl:{type:Boolean,default:!1},alwaysEmitChange:{type:Boolean,
default:!1},handleFieldChange:{type:Function},handleFieldSubmit:{type:Function},
linethrough:{type:Boolean}},
emits:["update:modelValue","submit","blur","curl","redirectToEnvironment"],
setup(e,{expose:t,emit:n}){
const r=n,o=Pv(),a=o.id||`id-${BX()}`,i=bm(!1),s=Sy((()=>!e.enum?.length&&("boolean"===e.type||Array.isArray(e.type)&&e.type.includes("boolean")))),l=Sy((()=>e.nullable?["true","false","null"]:["true","false"])),c=Sy((()=>Array.isArray(e.type)?e.type.find((e=>"null"!==e))??"string":e.type)),u=t=>{
if(!e.alwaysEmitChange&&t===b(e.modelValue))return
;if("string"==typeof t&&e.importCurl&&t.trim().toLowerCase().startsWith("curl"))return r("curl",t),
void(O.value&&O.value.dispatch({changes:{from:0,to:O.value.state.doc.length,
insert:b(e.modelValue)}}));const n=y(t)
;e.handleFieldChange?e.handleFieldChange(n):r("update:modelValue",n)},d=t=>{
e.handleFieldSubmit?e.handleFieldSubmit(t):r("submit",t)},p=t=>{
i.value=!1,e.emitOnBlur&&e.modelValue&&d(t),r("blur",t)},h=e=>{
r("update:modelValue",e)},f=()=>{const t=[...e.extensions]
;return e.colorPicker&&t.push(Mme),t},m=Sy((()=>FVe({environment:e.environment,
isReadOnly:"modal"===e.layout
}))),g=Sy((()=>[...f(),m.value,ZVe])),v=bm(null),b=e=>"object"==typeof e?JSON.stringify(e):String(e??""),y=t=>{
const n=t.trim(),r=n.startsWith("[")||n.startsWith("{"),o=typeof e.modelValue
;if(Array.isArray(e.modelValue)&&!r&&n.includes(","))return n.split(",").map((e=>e.trim()))
;if(r||"number"===o||"boolean"===o)try{return JSON.parse(t)}catch{}return t
},{codeMirror:O}=Xwe({content:Pm((()=>b(e.modelValue))),onChange:e=>{u(e),T()},
onFocus:()=>{i.value=!0},onBlur:p,codeMirrorRef:v,
disableTabIndent:Pm((()=>e.disableTabIndent)),
disableEnter:Pm((()=>e.disableEnter)),
disableCloseBrackets:Pm((()=>e.disableCloseBrackets)),
lineNumbers:Pm((()=>e.lineNumbers)),language:Pm((()=>e.language)),
lint:Pm((()=>e.lint)),extensions:g,placeholder:Pm((()=>e.placeholder))})
;mg(O,(()=>{O.value&&Object.hasOwn(o,"autofocus")&&O.value.focus()}))
;const w=bm(!1),x=bm(""),k=bm({left:0,top:0
}),S=bm(null),{handleDropdownSelect:_,updateDropdownVisibility:T}=function(e){
const{codeMirror:t,query:n,showDropdown:r,dropdownPosition:o}=e;function a(){
return t.value?.state.selection.main.head||0}function i(e){
return t.value?.coordsAtPos(e)}function s(){const e=a()
;requestAnimationFrame((()=>{const t=i(e-n.value.length-2);t&&(o.value={
left:t.left,top:Math.max(t.bottom)})}))}function l(){
const e=a(),l=t.value?.state.doc.sliceString(0,e)||"",c=l.lastIndexOf("{{")
;c>l.lastIndexOf("}}")?(n.value=l.slice(c+2),r.value=!0,o.value=i(e)||{left:0,
top:0},""===n.value&&s()):r.value=!1}
return mg(n,s),mg((()=>t.value?.state.doc.toString()),l),{
handleDropdownSelect:function(e){
const o=`{{${e}}}`,i=a(),s=Math.max(0,i-n.value.length-2),l=i
;t.value?.dispatch({changes:{from:s,to:l,insert:o}}),r.value=!1},
updateDropdownVisibility:l}}({codeMirror:O,query:x,showDropdown:w,
dropdownPosition:k
}),E=Sy((()=>w.value&&e.withVariables&&"modal"!==e.layout&&!!e.environment)),A=(t,n)=>{
w.value?"down"===t||"up"===t?(n.preventDefault(),
S.value?.handleArrowKey(t)):"enter"===t&&(n.preventDefault(),
S.value?.handleSelect()):("escape"===t&&!e.disableTabIndent&&n.stopPropagation(),
"enter"===t&&n.target instanceof HTMLDivElement&&d(n.target.textContent??""))}
;return t({focus:e=>{if(!O.value||(O.value.focus(),!xH(e)))return
;const t="start"===e?0:"end"===e?O.value.state.doc.length:e;O.value.dispatch({
selection:{anchor:t},scrollIntoView:!0})},isFocused:i,handleChange:u,
handleSubmit:d,handleBlur:p,booleanOptions:l,codeMirror:O,
modelValue:e.modelValue,cursorPosition:()=>O.value?.state.selection.main.head,
serializeValue:b,deserializeValue:y}),(t,n)=>(Ub(),Qb(Mb,null,[e.disabled?(Ub(),
Qb("div",{key:0,
class:Ih(["text-c-2 flex cursor-default items-center justify-center",{
"font-code pr-2 pl-1 text-base":"modal"===e.layout,"px-2":"modal"!==e.layout,
"line-through":e.linethrough}]),"data-testid":"code-input-disabled"
},[Gb("span",QVe,Uh(e.modelValue),1)],2)):e.enum?.length?(Ub(),Hb(NVe,{key:1,
default:e.default,modelValue:e.modelValue,type:c.value,value:e.enum,
"onUpdate:modelValue":h
},null,8,["default","modelValue","type","value"])):s.value?(Ub(),Hb(NVe,{key:2,
default:e.default,modelValue:e.modelValue,value:l.value,"onUpdate:modelValue":h
},null,8,["default","modelValue","value"])):e.examples?.length?(Ub(),Hb(NVe,{
key:3,default:e.default,modelValue:e.modelValue,value:e.examples,
"onUpdate:modelValue":h
},null,8,["default","modelValue","value"])):(Ub(),Qb("div",iy({key:4,id:xm(a)
},t.$attrs,{ref_key:"codeMirrorRef",ref:v,
class:["group/input group-[.alert]:outline-orange group-[.error]:outline-red font-code peer relative w-full overflow-hidden text-xs leading-[1.44] whitespace-nowrap -outline-offset-1 has-[:focus-visible]:rounded-[4px] has-[:focus-visible]:outline",{
"line-wrapping has-[:focus-visible]:bg-b-1 has-[:focus-visible]:absolute has-[:focus-visible]:z-1":e.lineWrapping,
"flow-code-input--error":e.error,"line-through":e.linethrough}],
onKeydown:[n[0]||(n[0]=UO(BO((e=>A("down",e)),["stop"]),["down"])),n[1]||(n[1]=UO((e=>A("enter",e)),["enter"])),n[2]||(n[2]=UO((e=>A("escape",e)),["escape"])),n[3]||(n[3]=UO(BO((e=>A("up",e)),["stop"]),["up"]))]
}),[e.disableTabIndent?ny("",!0):(Ub(),
Qb("div",VVe,[...n[5]||(n[5]=[ey(" Press ",-1),Gb("kbd",{
class:"-mx-0.25 rounded border px-0.5 font-mono"
},"Esc",-1),ey(" then ",-1),Gb("kbd",{
class:"-mx-0.25 rounded border px-0.5 font-mono"
},"Tab",-1),ey(" to exit ",-1)])]))],16,HVe)),t.$slots.warning?(Ub(),
Qb("div",qVe,[kv(t.$slots,"warning",{},void 0,!0)])):ny("",!0),t.$slots.icon?(Ub(),
Qb("div",WVe,[kv(t.$slots,"icon",{},void 0,!0)])):ny("",!0),e.required?(Ub(),
Qb("div",XVe," Required ")):ny("",!0),E.value&&e.environment?(Ub(),Hb(UVe,{
key:8,ref_key:"dropdownRef",ref:S,dropdownPosition:k.value,
environment:e.environment,query:x.value,
onRedirect:n[4]||(n[4]=e=>r("redirectToEnvironment")),onSelect:xm(_)
},null,8,["dropdownPosition","environment","query","onSelect"])):ny("",!0)],64))
}}),YVe=sae(GVe,[["__scopeId","data-v-e2bff922"]]),KVe=["id"],JVe={
class:"pointer-events-none absolute top-0 left-0 block h-full w-full overflow-hidden rounded-lg border"
},eqe={class:"z-context-plus flex gap-1"},tqe={
class:"scroll-timeline-x scroll-timeline-x-hidden z-context-plus relative flex w-full bg-blend-normal"
},nqe={key:0,
class:"z-context absolute inset-x-0 top-[calc(100%+4px)] flex flex-col items-center rounded px-6"
},rqe={
class:"text-c-danger bg-b-danger border-c-danger flex items-center gap-1 rounded border p-1"
},oqe={class:"min-w-0 flex-1"},aqe={"aria-hidden":"true",
class:"inline-flex items-center gap-1"},iqe={class:"sr-only"},sqe=Qg({
__name:"AddressBar",props:{path:{},method:{},server:{},servers:{},history:{},
layout:{},eventBus:{},environment:{}},
emits:["execute","update:servers","select:history:item"],
setup(e,{expose:t,emit:n}){
const r=n,o=Hg(),{percentage:a,startLoading:i,stopLoading:s}=hVe(),l=Sy((()=>({
backgroundColor:`color-mix(in srgb, transparent 90%, ${AH[e.method].colorVar})`,
transform:`translate3d(-${a.value}%,0,0)`
}))),c=bm(null),u=bm(null),d=Sy((()=>u.value||c.value)),p=(t,n,r)=>{
const o=g.value?.cursorPosition()
;e.eventBus.emit("operation:update:pathMethod",{meta:{method:e.method,
path:e.path},payload:{method:t,path:n},callback:r=>{
("success"===r||"no-change"===r)&&(u.value=null,
c.value=null),"success"===r?e.eventBus.emit("ui:focus:address-bar",{position:o
}):"conflict"===r&&(t!==e.method&&(u.value=t),n!==e.path&&(c.value=n))}},r)
},h=t=>p(t,c.value??e.path),f=t=>{const n=t.startsWith("/")?t:`/${t}`
;p(u.value??e.method,n,{
debounceKey:`operation:update:pathMethod-${e.path}-${e.method}`})
},m=qg("sendButtonRef"),g=qg("addressBarRef"),v=()=>m.value?.$el?.focus(),b=t=>{
if(g.value?.isFocused&&"desktop"!==e.layout)return
;const n=t&&"position"in t?t.position:"end"
;g.value?.focus(n),t&&"event"in t&&t.event.preventDefault()};iv((()=>{
e.eventBus.on("ui:focus:address-bar",b),e.eventBus.on("ui:focus:send-button",v),
e.eventBus.on("hooks:on:request:sent",i),
e.eventBus.on("hooks:on:request:complete",s)})),cv((()=>{
e.eventBus.off("ui:focus:address-bar",b),
e.eventBus.off("ui:focus:send-button",v),
e.eventBus.off("hooks:on:request:sent",i),
e.eventBus.off("hooks:on:request:complete",s),s()}))
;const{copyToClipboard:y}=PG(),O=async()=>{await y(KQe({
environment:e.environment,server:e.server,path:e.path,pathVariables:{}}))}
;return t({methodConflict:u,pathConflict:c}),(t,n)=>(Ub(),Qb("div",{id:xm(o),
class:"scalar-address-bar order-last flex h-(--scalar-address-bar-height) w-full [--scalar-address-bar-height:32px] lg:order-none lg:w-auto"
},[Gb("div",{
class:Ih(["address-bar-bg-states text-xxs group relative order-last flex w-full max-w-[calc(100dvw-24px)] flex-1 flex-row items-stretch rounded-lg p-0.75 lg:order-none lg:max-w-[580px] lg:min-w-[580px] xl:max-w-[720px] xl:min-w-[720px]",{
"outline-c-danger outline":d.value}])},[Gb("div",JVe,[Gb("div",{
class:"absolute top-0 left-0 z-[1002] h-full w-full",style:Ah(l.value)
},null,4)]),Gb("div",eqe,[Yb(xm(rke),{isEditable:"modal"!==e.layout,isSquare:"",
method:u.value??e.method,teleport:"",onChange:h
},null,8,["isEditable","method"])]),Gb("div",tqe,[e.servers.length?(Ub(),
Hb(xm(CVe),{key:0,layout:e.layout,server:e.server,servers:e.servers,
target:xm(o),
"onUpdate:selectedServer":n[0]||(n[0]=t=>e.eventBus.emit("server:update:selected",t)),
"onUpdate:servers":n[1]||(n[1]=e=>r("update:servers")),
"onUpdate:variable":n[2]||(n[2]=t=>e.eventBus.emit("server:update:variables",t))
},null,8,["layout","server","servers","target"])):ny("",!0),n[7]||(n[7]=Gb("div",{
class:"fade-left"},null,-1)),Yb(xm(YVe),{ref_key:"addressBarRef",ref:g,
alwaysEmitChange:"","aria-label":"Path",class:"min-w-fit outline-none",
disableCloseBrackets:"",disabled:"modal"===e.layout,disableEnter:"",
disableTabIndent:"",emitOnBlur:!1,environment:e.environment,importCurl:"",
layout:e.layout,modelValue:e.path,
placeholder:e.server?"":"Enter a URL or cURL command",server:"",
onCurl:n[3]||(n[3]=t=>e.eventBus.emit("ui:open:command-palette",{
action:"import-curl-command",payload:{curl:t}})),
onSubmit:n[4]||(n[4]=e=>r("execute")),"onUpdate:modelValue":f
},null,8,["disabled","environment","layout","modelValue","placeholder"]),n[8]||(n[8]=Gb("div",{
class:"fade-right"},null,-1))]),Yb(xm(WS),{class:"hover:bg-b-3 mx-1",size:"xs",
variant:"ghost",onClick:O},{default:ig((()=>[Yb(xm(dT)),n[9]||(n[9]=Gb("span",{
class:"sr-only"},"Copy URL",-1))])),_:1}),Yb(yVe,{history:e.history,
target:xm(o),"onSelect:history:item":n[5]||(n[5]=e=>r("select:history:item",e))
},null,8,["history","target"]),d.value?(Ub(),
Qb("div",nqe,[Gb("div",rqe,[Yb(xm(p$),{size:"sm"
}),Gb("div",oqe,[n[10]||(n[10]=ey(" A ",-1)),Gb("em",null,Uh(u.value?.toUpperCase()??e.method.toUpperCase()),1),n[11]||(n[11]=ey(" request to ",-1)),Yb(xm(Zoe),{
text:c.value??e.path
},null,8,["text"]),n[12]||(n[12]=ey(" already exists in this document ",-1))])])])):ny("",!0),Yb(xm(WS),{
ref_key:"sendButtonRef",ref:m,
class:"z-context-plus relative h-auto shrink-0 overflow-hidden py-1 pr-2.5 pl-2 font-bold",
disabled:xm(a)<100,onClick:n[6]||(n[6]=e=>r("execute"))},{
default:ig((()=>[Gb("span",aqe,[Yb(xm(Gne),{
class:"relative shrink-0 fill-current",icon:"Play",size:"xs"
}),n[13]||(n[13]=Gb("span",{class:"text-xxs hidden lg:flex"
},"Send",-1))]),Gb("span",iqe," Send "+Uh(e.method)+" request to "+Uh(e.server?.url??"")+Uh(e.path),1)])),
_:1},8,["disabled"])],2)],8,KVe))}
}),lqe=sae(sqe,[["__scopeId","data-v-80d05ddf"]]),cqe={
class:"lg:min-h-header t-app__top-container flex w-full flex-wrap items-center justify-center p-2 pt-2 lg:p-1 lg:pt-1"
},uqe={
class:"mb-2 flex w-1/2 flex-row items-center justify-end gap-1 lg:mb-0 lg:flex-1 lg:px-2.5"
},dqe=Qg({__name:"Header",props:{path:{},method:{},layout:{},hideClientButton:{
type:Boolean,default:!1},integration:{},documentUrl:{},source:{},server:{},
servers:{},history:{},eventBus:{},environment:{}},
emits:["execute","update:servers","select:history:item"],setup(e,{emit:t}){
const n=t;return(t,r)=>(Ub(),Qb("div",cqe,[r[7]||(r[7]=Gb("div",{
class:"mb-2 flex w-1/2 flex-row items-center gap-1 lg:mb-0 lg:flex-1 lg:px-1"
},[Gb("div",{class:"size-8"})],-1)),Yb(xm(lqe),{environment:e.environment,
eventBus:e.eventBus,history:e.history,layout:e.layout,method:e.method,
path:e.path,server:e.server,servers:e.servers,
onExecute:r[0]||(r[0]=e=>n("execute")),
"onSelect:history:item":r[1]||(r[1]=e=>n("select:history:item",e)),
"onUpdate:servers":r[2]||(r[2]=e=>n("update:servers"))
},null,8,["environment","eventBus","history","layout","method","path","server","servers"]),Gb("div",uqe,["modal"===e.layout&&e.documentUrl&&!e.hideClientButton?(Ub(),
Hb(xm(lae),{key:0,buttonSource:"modal",class:"!w-fit lg:-mr-1",
integration:e.integration??null,source:e.source??"api-reference",
url:e.documentUrl
},null,8,["integration","source","url"])):ny("",!0),"modal"===e.layout&&"gitbook"!==e.source?(Ub(),
Qb("button",{key:1,
class:"app-exit-button zoomed:static zoomed:p-1 fixed top-2 right-2 rounded-full p-2",
type:"button",onClick:r[3]||(r[3]=t=>e.eventBus.emit("ui:close:client-modal"))
},[Yb(xm(Gne),{icon:"Close",size:"lg",thickness:"2"}),r[5]||(r[5]=Gb("span",{
class:"sr-only"
},"Close Client",-1))])):ny("",!0),"modal"===e.layout&&"gitbook"===e.source?(Ub(),
Qb("button",{key:2,
class:"text-c-1 hover:bg-b-2 active:text-c-1 -mr-1.5 rounded p-2",type:"button",
onClick:r[4]||(r[4]=t=>e.eventBus.emit("ui:close:client-modal"))},[Yb(xm(Gne),{
icon:"Close",size:"md",thickness:"1.75"}),r[6]||(r[6]=Gb("span",{class:"sr-only"
},"Close Client",-1))])):ny("",!0)])]))}
}),pqe=sae(dqe,[["__scopeId","data-v-43c7b0fc"]]);class hqe{postProcessors;code
;indentationCharacter;lineJoin;indentLine;unshift;push;blank;join
;addPostProcessor;constructor({indent:e,join:t}={}){
this.postProcessors=[],this.code=[],
this.indentationCharacter="",this.lineJoin="\n",
this.indentLine=(e,t=0)=>`${this.indentationCharacter.repeat(t)}${e}`,
this.unshift=(e,t)=>{const n=this.indentLine(e,t);this.code.unshift(n)
},this.push=(e,t)=>{const n=this.indentLine(e,t);this.code.push(n)
},this.blank=()=>{this.code.push("")},this.join=()=>{
const e=this.code.join(this.lineJoin)
;return this.postProcessors.reduce(((e,t)=>t(e)),e)},this.addPostProcessor=e=>{
this.postProcessors=[...this.postProcessors,e]},this.indentationCharacter=e||"",
this.lineJoin=null!=t?t:"\n"}}function fqe(e,t={}){
const{delimiter:n='"',escapeChar:r="\\",escapeNewlines:o=!0}=t
;return[...e.toString()].map((e=>"\b"===e?`${r}b`:"\t"===e?`${r}t`:"\n"===e?o?`${r}n`:e:"\f"===e?`${r}f`:"\r"===e?o?`${r}r`:e:e===r?r+r:e===n?r+n:e<" "||e>"~"?JSON.stringify(e).slice(1,-1):e)).join("")
}const mqe=e=>fqe(e,{delimiter:"'"}),gqe=e=>fqe(e,{delimiter:'"'})
;const vqe=(e=[])=>{const t=new URLSearchParams;return e.forEach((e=>{
t.append(e.name,e.value)})),t};const bqe={info:{key:"libcurl",title:"Libcurl",
link:"http://curl.haxx.se/libcurl",
description:"Simple REST and HTTP API Client for C"},
convert:({method:e,fullUrl:t,headersObj:n,allHeaders:r,postData:o})=>{
const{push:a,blank:i,join:s}=new hqe({indent:"  "})
;a("CURL *hnd = curl_easy_init();"),
i(),a(`curl_easy_setopt(hnd, CURLOPT_CUSTOMREQUEST, "${e.toUpperCase()}");`),
a(`curl_easy_setopt(hnd, CURLOPT_URL, "${t}");`);const l=Object.keys(n)
;return l.length&&(i(),a("struct curl_slist *headers = NULL;"),l.forEach((e=>{
n[e]?a(`headers = curl_slist_append(headers, "${e}: ${gqe(n[e])}");`):a(`headers = curl_slist_append(headers, "${e};");`)
})),
a("curl_easy_setopt(hnd, CURLOPT_HTTPHEADER, headers);")),r.cookie&&(i(),a(`curl_easy_setopt(hnd, CURLOPT_COOKIE, "${r.cookie}");`)),
null!=o&&(i(),
o.text?a(`curl_easy_setopt(hnd, CURLOPT_POSTFIELDS, ${JSON.stringify(o.text)});`):"application/x-www-form-urlencoded"===o.mimeType&&o.params?a(`curl_easy_setopt(hnd, CURLOPT_POSTFIELDS, "${vqe(o.params).toString()}");`):"multipart/form-data"===o.mimeType&&o.params&&(a("curl_mime *mime = curl_mime_init(hnd);"),
o.params.forEach((e=>{
i(),a("{"),a("curl_mimepart *part = curl_mime_addpart(mime);",1),
e.name&&a(`curl_mime_name(part, "${e.name}");`,1),
e.fileName?a(`curl_mime_filedata(part, "${e.fileName}");`,1):e.value&&a(`curl_mime_data(part, "${gqe(e.value)}", CURL_ZERO_TERMINATED);`,1),
a("}")
})),i(),a("curl_easy_setopt(hnd, CURLOPT_MIMEPOST, mime);"))),i(),a("CURLcode ret = curl_easy_perform(hnd);"),
s()}};function yqe(e,t){
const n=new URL(t?.url??""),r="/"===n.pathname?n.origin:n.toString(),o={
method:t?.method??"GET",url:r,httpVersion:"HTTP/1.1",cookies:[],
headers:t?.headers??[],headersSize:-1,bodySize:-1,
queryString:Array.from(n.searchParams.entries()).map((([e,t])=>({name:e,value:t
}))),postData:t?.postData},a=(o?.headers??[]).reduce(((e,t)=>({...e,
[t.name]:t.value})),{}),i=(o.queryString??[]).reduce(((e,t)=>({...e,
[t.name]:t.value})),{}),s=(o.cookies??[]).reduce(((e,t)=>({...e,[t.name]:t.value
})),{}),l=new URL(o.url),c={protocol:l.protocol,hostname:l.hostname,
host:l.hostname,port:l.port,
pathname:l.pathname.split("/").map((e=>encodeURIComponent(decodeURIComponent(e)))).join("/")+l.search,
path:l.pathname.split("/").map((e=>encodeURIComponent(decodeURIComponent(e)))).join("/")+l.search,
search:l.search,hash:l.hash,href:l.href,origin:l.origin,password:l.password,
searchParams:l.searchParams,username:l.username,toString:l.toString,
toJSON:()=>l.toJSON()},u={url:o.url,uriObj:c,
method:o.method?.toLocaleUpperCase()??"GET",httpVersion:o.httpVersion,
cookies:o.cookies??[],headers:o.headers??[],headersSize:o.headersSize,
headersObj:a??{},bodySize:o.bodySize,queryString:o.queryString??[],
postData:o.postData?{mimeType:o.postData.mimeType??"application/json",
text:o.postData.text??"",params:o.postData.params??[],
paramsObj:o.postData.params?.reduce(((e,t)=>(t.name&&void 0!==t.value&&(e[t.name]=t.value),
e)),{})??{}}:void 0,allHeaders:a??{},fullUrl:o.url,queryObj:i??{},
cookiesObj:s??{}}
;if("application/json"===u.postData?.mimeType&&u.postData.text)try{
u.postData.jsonObj=JSON.parse(u.postData.text)}catch(d){
console.error("Error parsing JSON:",d)}
return"function"==typeof e.convert?e.convert(u):""}const Oqe={target:"c",
client:"libcurl",title:"Libcurl",generate:e=>yqe(bqe,e)
},wqe=(e,t)=>Object.keys(e).find((e=>e.toLowerCase()===t.toLowerCase())),xqe=(e,t)=>{
const n=wqe(e,t);if(n)return e[n]},kqe=(e,t)=>Boolean(wqe(e,t));class Sqe{name
;toString;constructor(e){
this.name="",this.toString=()=>`:${this.name}`,this.name=e}}let _qe=class{path
;toString;constructor(e){
this.path="",this.toString=()=>`(clojure.java.io/file "${this.path}")`,
this.path=e}}
;const Tqe=e=>void 0===e?null:null===e?"null":e.constructor.name.toLowerCase(),Eqe=e=>"object"===Tqe(e)&&0===Object.keys(e).length,Aqe=e=>(Object.keys(e).filter((t=>Eqe(e[t]))).forEach((t=>{
delete e[t]})),e),Cqe=(e,t)=>{const n=" ".repeat(e)
;return t.replace(/\n/g,`\n${n}`)},$qe=e=>{switch(Tqe(e)){case"string":
return`"${e.replace(/"/g,'\\"')}"`;case"file":case"keyword":default:
return e.toString();case"null":return"nil";case"regexp":return`#"${e.source}"`
;case"object":{
const t=Object.keys(e).reduce(((t,n)=>`${t}:${n} ${Cqe(n.length+2,$qe(e[n]))}\n `),"").trim()
;return`{${Cqe(1,t)}}`}case"array":{
const t=e.reduce(((e,t)=>`${e} ${$qe(t)}`),"").trim();return`[${Cqe(1,t)}]`}}
},Pqe={info:{key:"clj_http",title:"clj-http",
link:"https://github.com/dakrone/clj-http",
description:"An idiomatic clojure http client wrapping the apache client."},
convert:({queryObj:e,method:t,postData:n,url:r,allHeaders:o},a)=>{
const{push:i,join:s}=new hqe({indent:null==a?void 0:a.indent})
;if(t=t.toLowerCase(),
!["get","post","put","delete","patch","head","options"].includes(t))return i("Method not supported"),
s();const l={headers:o,"query-params":e}
;switch(e&&Object.keys(e).length>0&&(r=r.split("?")[0]),
null==n?void 0:n.mimeType){case"application/json":{
l["content-type"]=new Sqe("json"),l["form-params"]=n.jsonObj
;const e=wqe(l.headers,"content-type");e&&delete l.headers[e]}break
;case"application/x-www-form-urlencoded":{l["form-params"]=n.paramsObj
;const e=wqe(l.headers,"content-type");e&&delete l.headers[e]}break
;case"text/plain":{l.body=n.text;const e=wqe(l.headers,"content-type")
;e&&delete l.headers[e]}break;case"multipart/form-data":if(n?.params){
l.multipart=n.params.map((e=>e.fileName&&!e.value?{name:e.name,
content:new _qe(e.fileName)}:{name:e.name,content:e.value}))
;const e=wqe(l.headers,"content-type");e&&delete l.headers[e]}}
if("application/json"===xqe(l.headers,"accept")){l.accept=new Sqe("json")
;const e=wqe(l.headers,"accept");e&&delete l.headers[e]}
if(i("(require '[clj-http.client :as client])\n"),
Eqe(Aqe(l)))i(`(client/${t} "${r}")`);else{const e=11+t.length+r.length
;i(`(client/${t} "${r}" ${Cqe(e,$qe(Aqe(l)))})`)}return s()}},Dqe={
target:"clojure",client:"clj_http",title:"clj-http",generate:e=>yqe(Pqe,e)
},Iqe={target:"csharp",client:"httpclient",title:"HttpClient",generate(e,t){
const n={method:"GET",url:"",...e};n.method=n.method.toUpperCase()
;const r=vqe(n.queryString),o=r.size?`?${r.toString()}`:"",a=`${n.url}${o}`,i=[]
;i.push("using var client = new HttpClient();"),i.push("");const s=function(e){
switch(e){case"GET":return"HttpMethod.Get";case"POST":return"HttpMethod.Post"
;case"PUT":return"HttpMethod.Put";case"DELETE":return"HttpMethod.Delete"
;case"PATCH":return"HttpMethod.Patch";case"HEAD":return"HttpMethod.Head"
;case"OPTIONS":return"HttpMethod.Options";default:return`new HttpMethod("${e}")`
}}(n.method)
;return i.push(`var request = new HttpRequestMessage(${s}, "${a}");`),
function(e,t,n){
const r=t.headers||[],o=t.cookies||[],a=r.find((e=>"authorization"===e.name.toLowerCase()))
;if(a){const[t,n]=a.value.split(" ",2)
;t&&n&&e.push(`request.Headers.Authorization = new AuthenticationHeaderValue("${t}", "${n}");`)
}else if(n?.auth?.username&&n?.auth?.password){
const t=BHe(`${n.auth.username}:${n.auth.password}`)
;e.push(`request.Headers.Authorization = new AuthenticationHeaderValue("Basic", "${t}");`)
}const i=new Map;for(const s of r){const e=s.name,t=s.value
;"authorization"!==e.toLowerCase()&&i.set(e,t)}
for(const[s,l]of i)if("accept"===s.toLowerCase()&&Nqe(l))e.push(`request.Headers.Accept.Add(new MediaTypeWithQualityHeaderValue("${l}"));`);else{
if("content-type"===s.toLowerCase()&&t.postData)continue
;e.push(`request.Headers.TryAddWithoutValidation("${s}", "${l}");`)}
if(o.length>0){const t=o.map((e=>`${e.name}=${e.value}`)).join("; ")
;e.push(`request.Headers.TryAddWithoutValidation("Cookie", "${t}");`)}
}(i,n,t),function(e,t){if(!t.postData)return
;const{mimeType:n,text:r,params:o}=t.postData;if("application/json"===n&&r)try{
const t=JSON.parse(r),n=Mqe(JSON.stringify(t,null,2))
;e.push("request.Content = new StringContent("),
e.push(`${n},`),e.push('System.Text.Encoding.UTF8, "application/json");')}catch{
const t=Mqe(r)
;e.push("request.Content = new StringContent("),e.push(`${t},`),e.push('System.Text.Encoding.UTF8, "application/json");')
}else if("application/x-www-form-urlencoded"===n&&o){const t=o.map((e=>e.name))
;if(t.length!==new Set(t).size){
e.push("var formParams = new List<KeyValuePair<string, string>>"),e.push("{")
;for(const t of o)e.push(`  new("${t.name}", "${t.value}"),`)
;e.push("};"),e.push("request.Content = new FormUrlEncodedContent(formParams);")
}else{e.push("var formParams = new Dictionary<string, string>"),e.push("{")
;for(const t of o)e.push(`  ["${t.name}"] = "${t.value}",`)
;e.push("};"),e.push("request.Content = new FormUrlEncodedContent(formParams);")
}}else if("multipart/form-data"===n&&o){
e.push("var content = new MultipartFormDataContent();")
;for(const t of o)void 0!==t.fileName?e.push(`content.Add(new StreamContent(File.OpenRead("${t.fileName}")), "${t.name}", "${t.fileName}");`):e.push(`content.Add(new StringContent("${t.value}"), "${t.name}");`)
;e.push("request.Content = content;")
}else if("application/octet-stream"===n&&r)e.push('var content = new ByteArrayContent(System.Text.Encoding.UTF8.GetBytes("'+r.replace(/"/g,'\\"')+'"));'),
e.push('content.Headers.ContentType = new MediaTypeHeaderValue("application/octet-stream");'),
e.push("request.Content = content;");else if(r){const t=Mqe(r)
;e.push("request.Content = new StringContent("),
e.push(`${t},`),e.push(`System.Text.Encoding.UTF8, "${n}");`)}}(i,n),i.push(""),
i.push("using var response = await client.SendAsync(request);"),i.join("\n")}}
;function Mqe(e){let t=3;for(;e.includes('"'.repeat(t));)t++
;const n='"'.repeat(t);return`${n}\n${e}\n${n}`}function Nqe(e){
return/^[a-zA-Z0-9][a-zA-Z0-9!#$&\-\^_]*\/[a-zA-Z0-9][a-zA-Z0-9!#$&\-\^_]*(\s*;\s*[a-zA-Z0-9][a-zA-Z0-9!#$&\-\^_]*=.*)?$/.test(e)
}const Rqe={info:{key:"restsharp",title:"RestSharp",
link:"http://restsharp.org/",
description:"Simple REST and HTTP API Client for .NET"},
convert:({allHeaders:e,method:t,fullUrl:n,headersObj:r,cookies:o,postData:a})=>{
const{push:i,join:s}=new hqe
;if(!["GET","POST","PUT","DELETE","PATCH","HEAD","OPTIONS"].includes(t.toUpperCase()))return"Method not supported"
;if(i(`var client = new RestClient("${n}");`),
i(`var request = new RestRequest(Method.${t.toUpperCase()});`),
Object.keys(r).forEach((e=>{i(`request.AddHeader("${e}", "${gqe(r[e])}");`)
})),null==o||o.forEach((({name:e,value:t})=>{
i(`request.AddCookie("${e}", "${t}");`)})),null==a?void 0:a.text){
const t=xqe(e,"content-type"),n=JSON.stringify(a.text)
;i(`request.AddParameter("${t}", ${n}, ParameterType.RequestBody);`)}
return i("IRestResponse response = client.Execute(request);"),s()}},Lqe={
target:"csharp",client:"restsharp",title:"RestSharp",generate:e=>yqe(Rqe,e)
},Bqe={target:"dart",client:"http",title:"Http",generate(e,t){const n={
method:"GET",...e};n.method=n.method.toUpperCase()
;let r="import 'package:http/http.dart' as http;\n\nvoid main() async {\n",o="",a=""
;n.cookies&&n.cookies.length>0&&(a=n.cookies.map((e=>`${encodeURIComponent(e.name)}=${encodeURIComponent(e.value)}`)).join("; "),
o=`  "Cookie": "${a}",\n`)
;const i=n.headers?.reduce(((e,t)=>(t.value&&!/[; ]/.test(t.name)&&(e[t.name]=t.value),
e)),{})||{};if(t?.auth){const{username:e,password:n}=t.auth;if(e&&n){
const t=`${e}:${n}`
;i.Authorization=`'Basic ' + base64Encode(utf8.encode('${t}'))`}}
if(o&&(i.Cookie=a),Object.keys(i).length>0){
r+="  final headers = <String,String>{\n"
;for(const[e,t]of Object.entries(i))t.includes("utf8.encode")?r+=`    '${e}': ${t},\n`:r+=`    '${e}': '${t}',\n`
;r+="  };\n\n"}
const s=n.queryString?.length?"?"+n.queryString.map((e=>`${encodeURIComponent(e.name)}=${encodeURIComponent(e.value)}`)).join("&"):"",l=`${n.url}${s}`
;let c=""
;if(n.postData)if("application/json"===n.postData.mimeType)c=`  final body = r'${n.postData.text}';\n\n`;else if("application/x-www-form-urlencoded"===n.postData.mimeType)c=`  final body = '${n.postData.params?.map((e=>`${encodeURIComponent(e.name)}=${encodeURIComponent(e.value??"")}`)).join("&")||""}';\n\n`;else if("multipart/form-data"===n.postData.mimeType){
c="  final body = <String,String>{\n";for(const e of n.postData.params||[]){
const t=e.value||"",n=e.fileName||"";c+=`    '${e.name}': '${n||t}',\n`}
c+="  };\n\n"
}else"application/octet-stream"===n.postData.mimeType&&(c=`  final body = '${n.postData.text}';\n\n`)
;c&&(r+=c)
;return r+=`  final response = await http.${n.method.toLowerCase()}(Uri.parse('${l}')${Object.keys(i).length>0?", headers: headers":""}${c?", body: body":""});\n`,
r+="  print(response.body);\n",r+="}",r}},jqe={target:"fsharp",
client:"httpclient",title:"HttpClient",generate:(e,t)=>{if(!e)return""
;const n=function(e,t){if(!e)return"";if(!t||0===t.length)return e
;return e+function(e){if(!e||0===e.length)return""
;const t=e.map((e=>`${e.name}=${e.value}`));return"?"+t.join("&")}(t)
}(e.url,e.queryString);let r=""
;return r+=`let httpRequestMessage = new HttpRequestMessage(\n  HttpMethod("${e.method}"),\n  new Uri("${Uqe(n)}")\n)\n\n`,
e.headers&&e.headers.length>0&&(r+=function(e){let t=""
;for(const n of e)t+=`httpRequestMessage.Headers.Add("${Uqe(n.name??"")}", "${Uqe(n.value??"")}")\n`
;return t+="\n",t}(e.headers)),e.postData&&(r+=function(e){if(!e)return""
;let t="";switch(e.mimeType){case"multipart/form-data":t+=function(e){
let t="let content = new MultipartFormDataContent()\n",n=0
;for(const r of e.params)if("BINARY"===r.value){const e=Uqe(r.fileName??"")
;t+=`let fileStreamContent_${n} = new StreamContent(File.OpenRead("${e}"))\n`,
t+=`fileStreamContent_${n}.Headers.ContentType <- MediaTypeHeaderValue("${Uqe(r.contentType??"")}")\n`,
t+=`content.Add(fileStreamContent_${n}, "${e}", "${e}")\n`,n++
}else t+=`content.Add(new StringContent("${Uqe(r.value??"")}"), "${Uqe(r.name??"")}")\n`
;return t}(e);break;case"application/x-www-form-urlencoded":t+=function(e){
let t="let formUrlEncodedContentDictionary = new Dictionary<string, string>()\n"
;for(const n of e.params)t+=`formUrlEncodedContentDictionary.Add("${Uqe(n.name??"")}", "${Uqe(n.value??"")}")\n`
;return t+="let content = new FormUrlEncodedContent(formUrlEncodedContentDictionary)\n",
t}(e);break;case"application/json":t+=function(e){let t;try{
t=JSON.stringify(JSON.parse(e.text??"{}"),null,2)}catch{t=e.text??"{}"}
return`let content = new StringContent("""${t}""", Encoding.UTF8, "application/json")\n`
}(e);break;default:t+=function(e,t){
let n=`let content = new StringContent("${Uqe(e.text??"")}", Encoding.UTF8, "${Uqe(t??"")}")\n`
;return n+=`content.Headers.ContentType <- MediaTypeHeaderValue("${Uqe(t??"")}")\n`,
n}(e,e.mimeType)}return t+="httpRequestMessage.Content <- content\n\n",t
}(e.postData)),e.cookies&&e.cookies.length>0&&e.url?(r+=function(e,t){
let n="let cookieContainer = CookieContainer()\n"
;for(const r of e)n+=`cookieContainer.Add(Uri("${Uqe(t)}"), Cookie("${Uqe(r.name??"")}", "${Uqe(r.value??"")}"))\n`
;return n+="use handler = new HttpClientHandler()\n",
n+="handler.CookieContainer <- cookieContainer\n\n",n
}(e.cookies,e.url),r+="let client = new HttpClient(handler)\n"):r+="let client = new HttpClient()\n",
r+="let! result = client.SendAsync(httpRequestMessage)\n",r}};function Uqe(e){
return null==e?"":e.replace(/\\/g,"\\\\").replace(/"/g,'\\"').replace(/\n/g,"\\n").replace(/\r/g,"\\r").replace(/\t/g,"\\t")
}const zqe={info:{key:"native",title:"NewRequest",
link:"http://golang.org/pkg/net/http/#NewRequest",
description:"Golang HTTP client request"},
convert:({postData:e,method:t,allHeaders:n,fullUrl:r},o={})=>{
const{blank:a,push:i,join:s,addPostProcessor:l}=new hqe({indent:"\t"
}),{showBoilerplate:c=!0,checkErrors:u=!1,printBody:d=!0,timeout:p=-1,insecureSkipVerify:h=!1}=o,f=u?"err":"_",m=c?1:0,g=()=>{
u&&(i("if err != nil {",m),i("panic(err)",m+1),i("}",m))},v=new Set
;c&&(i("package main"),a(),i("import ()"),l((e=>{const t=[...v];t.sort()
;const n=t.map((e=>`\t"${e}"`)).join("\n")
;return e.replace(/import \(\)/,`import (\n${n}\n)`)
})),v.add("fmt"),v.add("net/http"),
a(),i("func main() {")),h&&(v.add("crypto/tls"),
i("insecureTransport := http.DefaultTransport.(*http.Transport).Clone()",m),
i("insecureTransport.TLSClientConfig = &tls.Config{InsecureSkipVerify: true}",m))
;const b=p>0,y=b||h,O=y?"client":"http.DefaultClient"
;return y&&(i("client := http.Client{",m),
b&&(v.add("time"),i(`Timeout: time.Duration(${p} * time.Second),`,m+1)),
h&&i("Transport: insecureTransport,",m+1),
i("}",m),a()),i(`url := "${r}"`,m),a(),
null!=e&&(e.params||e.text)?"application/x-www-form-urlencoded"===e.mimeType&&e.params?(v.add("net/url"),
v.add("strings"),i("postData := url.Values{}",m),e.params.forEach((e=>{
i(`postData.Set("${e.name}", "${gqe(e.value)}")`,m)
})),a(),i(`req, ${f} := http.NewRequest("${t}", url, strings.NewReader(postData.Encode()))`,m)):"multipart/form-data"===e.mimeType&&e.params?(v.add("bytes"),
v.add("mime/multipart"),
i("payload := &bytes.Buffer{}",m),i("writer := multipart.NewWriter(payload)",m),
e.params.forEach((e=>{
a(),e.fileName?(i(`part, ${f} := writer.CreateFormFile("${e.name}", "${e.fileName}")`,m),
g(),
a(),i(`f, ${f} := os.Open("${e.fileName}")`,m),g(),i("defer f.Close()",m),a(),
i(`_, ${f} = io.Copy(part, f)`,m),
g()):(i(`${f} = writer.WriteField("${e.name}", "${gqe(e.value)}")`,m),g())
})),i("writer.Close()",m),
a(),i(`req, ${f} := http.NewRequest("${t}", url, payload)`,m)):(v.add("strings"),
i(`payload := strings.NewReader(${JSON.stringify(e.text)})`,m),
a(),i(`req, ${f} := http.NewRequest("${t}", url, payload)`,m)):i(`req, ${f} := http.NewRequest("${t}", url, nil)`,m),
g(),
a(),null!=e&&"multipart/form-data"===e.mimeType&&e.params&&i('req.Header.Set("Content-Type", writer.FormDataContentType())',m),
Object.keys(n).length&&(Object.keys(n).forEach((e=>{
i(`req.Header.Add("${e}", "${gqe(n[e])}")`,m)
})),a()),i(`res, ${f} := ${O}.Do(req)`,m),
g(),d&&(v.add("io"),a(),i("defer res.Body.Close()",m),
i(`body, ${f} := io.ReadAll(res.Body)`,m),
g()),a(),i("fmt.Println(res)",m),d&&i("fmt.Println(string(body))",m),
c&&(a(),i("}")),s()}},Fqe={target:"go",client:"native",title:"NewRequest",
generate:e=>yqe(zqe,e)},Zqe={target:"http",client:"http1.1",title:"HTTP/1.1",
generate(e){const t={method:"GET",headers:[],queryString:[],...e};let n,r
;t.method=t.method.toUpperCase();try{
n=new URL(t.url||"http://"),r=n.pathname+(n.search||"")}catch(l){r=t.url||"/"}
const o=n?.hostname||"UNKNOWN_HOSTNAME";let a=`${t.method} ${r} HTTP/1.1\r\n`
;if(t.queryString.length){
const e=t.queryString.map((e=>`${encodeURIComponent(e.name)}=${encodeURIComponent(e.value)}`)).join("&")
;a=`${t.method} ${r}?${e} HTTP/1.1\r\n`}const i=new Map
;if(i.set("Host",o),t.headers.forEach((e=>{
i.has(e.name)?i.set(e.name,`${i.get(e.name)}, ${e.value}`):i.set(e.name,e.value)
})),t.queryString.length){
const e=t.queryString.map((e=>`${encodeURIComponent(e.name)}=${encodeURIComponent(e.value)}`)).join("&")
;a=`${t.method} ${r}?${e} HTTP/1.1\r\n`}let s=""
;if(t.postData)if("application/json"===t.postData.mimeType&&t.postData.text)i.set("Content-Type","application/json"),
s=t.postData.text;else if("application/octet-stream"===t.postData.mimeType&&t.postData.text)i.set("Content-Type","application/octet-stream"),
s=t.postData.text;else if("application/x-www-form-urlencoded"===t.postData.mimeType&&t.postData.params){
const e=t.postData.params.map((e=>`${encodeURIComponent(e.name)}=${encodeURIComponent(e.value??"")}`)).join("&")
;i.set("Content-Type","application/x-www-form-urlencoded"),s=e
}else if("multipart/form-data"===t.postData.mimeType&&t.postData.params){
const e="----WebKitFormBoundary7MA4YWxkTrZu0gW"
;i.set("Content-Type",`multipart/form-data; boundary=${e}`),
s=t.postData.params.map((t=>t.fileName?`--${e}\r\nContent-Disposition: form-data; name="${t.name}"; filename="${t.fileName}"\r\n\r\n`:`--${e}\r\nContent-Disposition: form-data; name="${t.name}"\r\n\r\n${t.value}\r\n`)).join("")+`--${e}--\r\n`
}return i.forEach(((e,t)=>{a+=`${t}: ${e}\r\n`})),a+=`\r\n${s}`,a}},Qqe={info:{
key:"asynchttp",title:"AsyncHttp",
link:"https://github.com/AsyncHttpClient/async-http-client",
description:"Asynchronous Http and WebSocket Client library for Java"},
convert:({method:e,allHeaders:t,postData:n,fullUrl:r},o)=>{const a={indent:"  ",
...o},{blank:i,push:s,join:l}=new hqe({indent:a.indent})
;return s("AsyncHttpClient client = new DefaultAsyncHttpClient();"),
s(`client.prepare("${e.toUpperCase()}", "${r}")`),Object.keys(t).forEach((e=>{
s(`.setHeader("${e}", "${gqe(t[e])}")`,1)
})),(null==n?void 0:n.text)&&s(`.setBody(${JSON.stringify(n.text)})`,1),
s(".execute()",1),
s(".toCompletableFuture()",1),s(".thenAccept(System.out::println)",1),
s(".join();",1),i(),s("client.close();"),l()}},Hqe={target:"java",
client:"asynchttp",title:"AsyncHttp",generate:e=>yqe(Qqe,e)},Vqe={info:{
key:"nethttp",title:"java.net.http",
link:"https://openjdk.java.net/groups/net/httpclient/intro.html",
description:"Java Standardized HTTP Client API"},
convert:({allHeaders:e,fullUrl:t,method:n,postData:r},o)=>{const a={indent:"  ",
...o},{push:i,join:s}=new hqe({indent:a.indent})
;return i("HttpRequest request = HttpRequest.newBuilder()"),
i(`.uri(URI.create("${t}"))`,2),Object.keys(e).forEach((t=>{
i(`.header("${t}", "${gqe(e[t])}")`,2)
})),(null==r?void 0:r.text)?i(`.method("${n.toUpperCase()}", HttpRequest.BodyPublishers.ofString(${JSON.stringify(r.text)}))`,2):i(`.method("${n.toUpperCase()}", HttpRequest.BodyPublishers.noBody())`,2),
i(".build();",2),
i("HttpResponse<String> response = HttpClient.newHttpClient().send(request, HttpResponse.BodyHandlers.ofString());"),
i("System.out.println(response.body());"),s()}},qqe={target:"java",
client:"nethttp",title:"java.net.http",generate:e=>yqe(Vqe,e)},Wqe={info:{
key:"okhttp",title:"OkHttp",link:"http://square.github.io/okhttp/",
description:"An HTTP Request Client Library"},
convert:({postData:e,method:t,fullUrl:n,allHeaders:r},o)=>{const a={indent:"  ",
...o},{push:i,blank:s,join:l}=new hqe({indent:a.indent})
;return i("OkHttpClient client = new OkHttpClient();"),
s(),null!=e&&("application/x-www-form-urlencoded"===e.mimeType&&e.params?(i("FormBody formBody = new FormBody.Builder()"),
e.params.forEach((e=>{i(`.addEncoded("${e.name}", "${e.value}")`,1)
})),i(".build();",1),
s()):"multipart/form-data"===e.mimeType&&e.params?(i("MultipartBody body = new MultipartBody.Builder()"),
i(".setType(MultipartBody.FORM)",1),e.params.forEach((e=>{
void 0!==e.fileName?i(`.addFormDataPart("${e.name}", "${e.fileName}", RequestBody.create(MediaType.parse("application/octet-stream"), new File("${e.fileName}")))`,1):void 0!==e.value&&i(`.addFormDataPart("${e.name}", "${e.value}")`,1)
})),
i(".build();",1),s()):(i(`MediaType mediaType = MediaType.parse("${e.mimeType}");`),
i(`RequestBody body = RequestBody.create(mediaType, ${JSON.stringify(e.text)});`))),
i("Request request = new Request.Builder()"),
i(`.url("${n}")`,1),["GET","POST","PUT","DELETE","PATCH","HEAD"].includes(t.toUpperCase())?["POST","PUT","DELETE","PATCH"].includes(t.toUpperCase())?(null==e?void 0:e.text||e.params)?i(`.${t.toLowerCase()}(body)`,1):i(`.${t.toLowerCase()}(null)`,1):i(`.${t.toLowerCase()}()`,1):(null==e?void 0:e.text)?i(`.method("${t.toUpperCase()}", body)`,1):i(`.method("${t.toUpperCase()}", null)`,1),
Object.keys(r).forEach((e=>{i(`.addHeader("${e}", "${gqe(r[e])}")`,1)
})),i(".build();",1),
s(),i("Response response = client.newCall(request).execute();"),l()}},Xqe={
target:"java",client:"okhttp",title:"OkHttp",generate:e=>yqe(Wqe,e)},Gqe={info:{
key:"unirest",title:"Unirest",link:"http://unirest.io/java.html",
description:"Lightweight HTTP Request Client Library"},
convert:({method:e,allHeaders:t,postData:n,fullUrl:r},o)=>{const a={indent:"  ",
...o},{join:i,push:s}=new hqe({indent:a.indent})
;return["GET","POST","PUT","DELETE","PATCH","HEAD","OPTIONS"].includes(e.toUpperCase())?s(`HttpResponse<String> response = Unirest.${e.toLowerCase()}("${r}")`):s(`HttpResponse<String> response = Unirest.customMethod("${e.toUpperCase()}","${r}")`),
Object.keys(t).forEach((e=>{s(`.header("${e}", "${gqe(t[e])}")`,1)
})),(null==n?void 0:n.text)&&s(`.body(${JSON.stringify(n.text)})`,1),
s(".asString();",1),i()}},Yqe={target:"java",client:"unirest",title:"Unirest",
generate:e=>yqe(Gqe,e)},{toString:Kqe}=Object.prototype
;const{propertyIsEnumerable:Jqe}=Object.prototype;function eWe(e,t,n){const r=[]
;return function e(t,n={},o=""){const a=n.indent||"\t";let i
;i=void 0===n.inlineCharacterLimit?{newline:"\n",newlineOrSpace:"\n",pad:o,
indent:o+a}:{newline:"@@__STRINGIFY_OBJECT_NEW_LINE__@@",
newlineOrSpace:"@@__STRINGIFY_OBJECT_NEW_LINE_OR_SPACE__@@",
pad:"@@__STRINGIFY_OBJECT_PAD__@@",indent:"@@__STRINGIFY_OBJECT_INDENT__@@"}
;const s=e=>{if(void 0===n.inlineCharacterLimit)return e
;const t=e.replace(new RegExp(i.newline,"g"),"").replace(new RegExp(i.newlineOrSpace,"g")," ").replace(new RegExp(i.pad+"|"+i.indent,"g"),"")
;return t.length<=n.inlineCharacterLimit?t:e.replace(new RegExp(i.newline+"|"+i.newlineOrSpace,"g"),"\n").replace(new RegExp(i.pad,"g"),o).replace(new RegExp(i.indent,"g"),o+a)
};if(r.includes(t))return'"[Circular]"'
;if(null==t||"number"==typeof t||"boolean"==typeof t||"function"==typeof t||"symbol"==typeof t||(l=t,
"[object RegExp]"===Kqe.call(l)))return String(t);var l,c
;if(t instanceof Date)return`new Date('${t.toISOString()}')`
;if(Array.isArray(t)){if(0===t.length)return"[]";r.push(t)
;const l="["+i.newline+t.map(((r,s)=>{
const l=t.length-1===s?i.newline:","+i.newlineOrSpace;let c=e(r,n,o+a)
;return n.transform&&(c=n.transform(t,s,c)),i.indent+c+l})).join("")+i.pad+"]"
;return r.pop(),s(l)}if(function(e){const t=typeof e
;return null!==e&&("object"===t||"function"===t)}(t)){
let l=(c=t,[...Object.keys(c),...Object.getOwnPropertySymbols(c).filter((e=>Jqe.call(c,e)))])
;if(n.filter&&(l=l.filter((e=>n.filter(t,e)))),0===l.length)return"{}";r.push(t)
;const u="{"+i.newline+l.map(((r,s)=>{
const c=l.length-1===s?i.newline:","+i.newlineOrSpace,u="symbol"==typeof r,d=!u&&/^[a-z$_][$\w]*$/i.test(r),p=u||d?r:e(r,n)
;let h=e(t[r],n,o+a)
;return n.transform&&(h=n.transform(t,r,h)),i.indent+String(p)+": "+h+c
})).join("")+i.pad+"}";return r.pop(),s(u)}
return t=t.replace(/\\/g,"\\\\"),t=String(t).replace(/[\r\n]/g,(e=>"\n"===e?"\\n":"\\r")),
!1===n.singleQuotes?`"${t=t.replace(/"/g,'\\"')}"`:`'${t=t.replace(/'/g,"\\'")}'`
}(e,t,n)}const tWe={info:{key:"axios",title:"Axios",
link:"https://github.com/axios/axios",
description:"Promise based HTTP client for the browser and node.js"},
convert:({allHeaders:e,method:t,url:n,queryObj:r,postData:o},a)=>{const i={
indent:"  ",...a},{blank:s,push:l,join:c,addPostProcessor:u}=new hqe({
indent:i.indent});l("import axios from 'axios';"),s();const d={method:t,url:n}
;switch(Object.keys(r).length&&(d.params=r),
Object.keys(e).length&&(d.headers=e),null==o?void 0:o.mimeType){
case"application/x-www-form-urlencoded":
o?.params&&(l("const encodedParams = new URLSearchParams();"),
o.params.forEach((e=>{l(`encodedParams.set('${e.name}', '${e.value}');`)})),s(),
d.data="encodedParams,",u((e=>e.replace(/'encodedParams,'/,"encodedParams,"))))
;break;case"application/json":o?.jsonObj&&(d.data=o.jsonObj);break
;case"multipart/form-data":if(!o?.params)break
;l("const form = new FormData();"),o.params.forEach((e=>{
l(`form.append('${e.name}', '${e.value||e.fileName||""}');`)
})),s(),d.data="[form]";break;default:(null==o?void 0:o.text)&&(d.data=o.text)}
const p=eWe(d,{indent:"  ",inlineCharacterLimit:80}).replace('"[form]"',"form")
;return l(`const options = ${p};`),
s(),l("try {"),l("const { data } = await axios.request(options);",1),
l("console.log(data);",1),
l("} catch (error) {"),l("console.error(error);",1),l("}"),c()}},nWe={
target:"js",client:"axios",title:"Axios",generate:e=>yqe(tWe,e)}
;function rWe(e){return/\s|-/.test(e)}let oWe=class{constructor(e){this.value=e}
};function aWe(e,t=0){const n=[],r=" ".repeat(t),o=" ".repeat(t+2)
;if(0===Object.keys(e).length)return"{}";for(const[a,i]of Object.entries(e)){
const e=rWe(a)?`'${a}'`:a;if(i instanceof oWe){const t=i.value.split("\n")
;let r=`${i.value}`
;t.length>1&&(r=t.map(((e,t)=>0===t?e:`${o}${e}`)).join("\n")),
n.push(`${o}${e}: ${r}`)}else if(Array.isArray(i)){
const r=i.map((e=>"string"==typeof e?`'${e}'`:e&&"object"==typeof e?aWe(e):JSON.stringify(e)))
;if(r.some((e=>e.includes("\n")))){const a=r.map((e=>iWe(e,t+4))).join(",\n")
;n.push(`${o}${e}: [\n${a}\n${o}]`)}else n.push(`${o}${e}: [${r.join(", ")}]`)
}else if(i&&"object"==typeof i)n.push(`${o}${e}: ${aWe(i,t+2)}`);else if("string"==typeof i){
const t=`'${i}'`;n.push(`${o}${e}: ${t}`)}else n.push(`${o}${e}: ${i}`)}
return`{\n${n.join(",\n")}\n${r}}`}function iWe(e,t){const n=" ".repeat(t)
;return e.split("\n").map((e=>`${n}${e}`)).join("\n")}const sWe={target:"js",
client:"fetch",title:"Fetch",generate(e){const t={method:"GET",...e};let n=""
;t.method=t.method.toUpperCase();const r={
method:"GET"===t.method?void 0:t.method
},o=vqe(t.queryString),a=o.size?`?${o.toString()}`:""
;if(t.headers?.length&&(r.headers={},t.headers.forEach((e=>{
r.headers[e.name]=e.value
}))),t.cookies?.length&&(r.headers=r.headers||{},t.cookies.forEach((e=>{
r.headers["Set-Cookie"]=r.headers["Set-Cookie"]?`${r.headers["Set-Cookie"]}; ${e.name}=${e.value}`:`${e.name}=${e.value}`
}))),Object.keys(r).forEach((e=>{void 0===r[e]&&delete r[e]})),t.postData){
const{mimeType:e,text:o,params:a}=t.postData;if("application/json"===e&&o)try{
r.body=new oWe(`JSON.stringify(${aWe(JSON.parse(o))})`)}catch{r.body=o
}else if("multipart/form-data"===e&&a)n="const formData = new FormData()\n",
a.forEach((e=>{
void 0!==e.fileName?n+=`formData.append('${e.name}', new Blob([]), '${e.fileName}')\n`:void 0!==e.value&&(n+=`formData.append('${e.name}', '${e.value}')\n`)
})),
n+="\n",r.body=new oWe("formData");else if("application/x-www-form-urlencoded"===e&&a){
const e=Object.fromEntries(a.map((e=>[e.name,e.value])))
;r.body=new oWe(`new URLSearchParams(${aWe(e)})`)}else r.body=t.postData.text}
const i=Object.keys(r).length?`, ${aWe(r)}`:""
;return`${n}fetch('${t.url}${a}'${i})`}},lWe={info:{key:"jquery",title:"jQuery",
link:"http://api.jquery.com/jquery.ajax/",
description:"Perform an asynchronous HTTP (Ajax) requests with jQuery"},
convert:({fullUrl:e,method:t,allHeaders:n,postData:r},o)=>{let a;const i={
indent:"  ",...o},{blank:s,push:l,join:c}=new hqe({indent:i.indent}),u={
async:!0,crossDomain:!0,url:e,method:t,headers:n}
;switch(null==r?void 0:r.mimeType){case"application/x-www-form-urlencoded":
u.data=r?.paramsObj?r.paramsObj:r.text;break;case"application/json":
u.processData=!1,u.data=r.text;break;case"multipart/form-data":
if(!r?.params)break;if(l("const form = new FormData();"),r.params.forEach((e=>{
l(`form.append('${e.name}', '${e.value||e.fileName||""}');`)
})),u.processData=!1,
u.contentType=!1,u.mimeType="multipart/form-data",u.data="[form]",
kqe(n,"content-type")&&(null===(a=xqe(n,"content-type"))||void 0===a?void 0:a.includes("boundary"))){
const e=wqe(n,"content-type");e&&delete u.headers[e]}s();break;default:
(null==r?void 0:r.text)&&(u.data=r.text)}const d=eWe(u,{indent:i.indent
}).replace("'[form]'","form")
;return l(`const settings = ${d};`),s(),l("$.ajax(settings).done(function (response) {"),
l("console.log(response);",1),l("});"),c()}},cWe={target:"js",client:"jquery",
title:"jQuery",generate:e=>yqe(lWe,e)},uWe={target:"js",client:"ofetch",
title:"ofetch",generate(e){const t={method:"GET",...e}
;t.method=t.method.toUpperCase();const n={
method:"GET"===t.method?void 0:t.method}
;t.queryString?.length&&(n.query=Object.fromEntries(t.queryString.map((e=>[e.name,e.value])))),
t.headers?.length&&(n.headers={},t.headers.forEach((e=>{
n.headers[e.name]=e.value
}))),t.cookies?.length&&(n.headers=n.headers||{},t.cookies.forEach((e=>{
n.headers["Set-Cookie"]=n.headers["Set-Cookie"]?`${n.headers["Set-Cookie"]}; ${e.name}=${e.value}`:`${e.name}=${e.value}`
}))),Object.keys(n).forEach((e=>{void 0===n[e]&&delete n[e]
})),t.postData&&(n.body=t.postData.text,
"application/json"===t.postData.mimeType&&(n.body=JSON.parse(n.body)))
;const r=Object.keys(n).length?`, ${aWe(n)}`:""
;return`import { ofetch } from 'ofetch'\n\nofetch('${t.url}'${r})`}},dWe={info:{
key:"xhr",title:"XMLHttpRequest",
link:"https://developer.mozilla.org/en-US/docs/Web/API/XMLHttpRequest",
description:"W3C Standard API that provides scripted client functionality"},
convert:({postData:e,allHeaders:t,method:n,fullUrl:r},o)=>{let a;const i={
indent:"  ",cors:!0,...o},{blank:s,push:l,join:c}=new hqe({indent:i.indent})
;switch(null==e?void 0:e.mimeType){case"application/json":
l(`const data = JSON.stringify(${eWe(e?.jsonObj,{indent:i.indent})});`),s()
;break;case"multipart/form-data":if(!e?.params)break
;if(l("const data = new FormData();"),e.params.forEach((e=>{
l(`data.append('${e.name}', '${e.value||e.fileName||""}');`)
})),kqe(t,"content-type")&&(null===(a=xqe(t,"content-type"))||void 0===a?void 0:a.includes("boundary"))){
const e=wqe(t,"content-type");e&&delete t[e]}s();break;default:
l(`const data = ${(null==e?void 0:e.text)?`'${e.text}'`:"null"};`),s()}
return l("const xhr = new XMLHttpRequest();"),
i.cors&&l("xhr.withCredentials = true;"),
s(),l("xhr.addEventListener('readystatechange', function () {"),
l("if (this.readyState === this.DONE) {",1),
l("console.log(this.responseText);",2),
l("}",1),l("});"),s(),l(`xhr.open('${n}', '${r}');`),
Object.keys(t).forEach((e=>{l(`xhr.setRequestHeader('${e}', '${mqe(t[e])}');`)
})),s(),l("xhr.send(data);"),c()}},pWe={target:"js",client:"xhr",title:"XHR",
generate:e=>yqe(dWe,e)},hWe={info:{key:"okhttp",title:"OkHttp",
link:"http://square.github.io/okhttp/",
description:"An HTTP Request Client Library"},
convert:({postData:e,fullUrl:t,method:n,allHeaders:r},o)=>{const a={indent:"  ",
...o},{blank:i,join:s,push:l}=new hqe({indent:a.indent})
;return l("val client = OkHttpClient()"),
i(),null!=e&&("application/x-www-form-urlencoded"===e.mimeType&&e.params?(l("val formBody = FormBody.Builder()"),
e.params.forEach((e=>{l(`.addEncoded("${e.name}", "${e.value}")`,1)
})),l(".build()",1),
i()):"multipart/form-data"===e.mimeType&&e.params?(l("val body = MultipartBody.Builder()"),
l(".setType(MultipartBody.FORM)",1),e.params.forEach((e=>{
void 0!==e.fileName?l(`.addFormDataPart("${e.name}", "${e.fileName}", RequestBody.create(MediaType.parse("application/octet-stream"), File("${e.fileName}")))`,1):void 0!==e.value&&l(`.addFormDataPart("${e.name}", "${e.value}")`,1)
})),l(".build()",1),i()):(l(`val mediaType = MediaType.parse("${e.mimeType}")`),
l(`val body = RequestBody.create(mediaType, ${JSON.stringify(e.text)})`))),
l("val request = Request.Builder()"),
l(`.url("${t}")`,1),["GET","POST","PUT","DELETE","PATCH","HEAD"].includes(n.toUpperCase())?["POST","PUT","DELETE","PATCH"].includes(n.toUpperCase())?(null==e?void 0:e.text||e.params)?l(`.${n.toLowerCase()}(body)`,1):l(`.${n.toLowerCase()}(null)`,1):l(`.${n.toLowerCase()}()`,1):(null==e?void 0:e.text)?l(`.method("${n.toUpperCase()}", body)`,1):l(`.method("${n.toUpperCase()}", null)`,1),
Object.keys(r).forEach((e=>{l(`.addHeader("${e}", "${gqe(r[e])}")`,1)
})),l(".build()",1),
i(),l("val response = client.newCall(request).execute()"),s()}},fWe={
target:"kotlin",client:"okhttp",title:"OkHttp",generate:e=>yqe(hWe,e)},mWe={
info:{key:"axios",title:"Axios",link:"https://github.com/axios/axios",
description:"Promise based HTTP client for the browser and node.js"},
convert:({method:e,url:t,queryObj:n,allHeaders:r,postData:o},a)=>{const i={
indent:"  ",...a},{blank:s,join:l,push:c,addPostProcessor:u}=new hqe({
indent:i.indent});c("const axios = require('axios').default;");const d={
method:e,url:t}
;switch(Object.keys(n).length&&(d.params=n),Object.keys(r).length&&(d.headers=r),
null==o?void 0:o.mimeType){case"application/x-www-form-urlencoded":
o.params&&(c("const { URLSearchParams } = require('url');"),
s(),c("const encodedParams = new URLSearchParams();"),o.params.forEach((e=>{
c(`encodedParams.set('${e.name}', '${e.value}');`)
})),s(),d.data="encodedParams,",
u((e=>e.replace(/'encodedParams,'/,"encodedParams,"))));break
;case"application/json":s(),o?.jsonObj&&(d.data=o.jsonObj);break;default:
s(),(null==o?void 0:o.text)&&(d.data=o.text)}const p=eWe(d,{indent:"  ",
inlineCharacterLimit:80})
;return c(`const options = ${p};`),s(),c("try {"),c("const { data } = await axios.request(options);",1),
c("console.log(data);",1),
c("} catch (error) {"),c("console.error(error);",1),c("}"),l()}},gWe={
target:"node",client:"axios",title:"Axios",generate:e=>yqe(mWe,e)},vWe={
target:"node",client:"fetch",title:"Fetch",generate(e){const t={method:"GET",
...e};let n="";t.method=t.method.toUpperCase();const r={
method:"GET"===t.method?void 0:t.method
},o=vqe(t.queryString),a=o.size?`?${o.toString()}`:""
;if(t.headers?.length&&(r.headers={},t.headers.forEach((e=>{
r.headers[e.name]=e.value
}))),t.cookies?.length&&(r.headers=r.headers||{},t.cookies.forEach((e=>{
r.headers["Set-Cookie"]=r.headers["Set-Cookie"]?`${r.headers["Set-Cookie"]}; ${e.name}=${e.value}`:`${e.name}=${e.value}`
}))),Object.keys(r).forEach((e=>{void 0===r[e]&&delete r[e]})),t.postData){
const{mimeType:e,text:o,params:a}=t.postData;let i=!1
;if("application/json"===e&&o)try{
r.body=new oWe(`JSON.stringify(${aWe(JSON.parse(o))})`)}catch{r.body=o
}else if("multipart/form-data"===e&&a)n="const formData = new FormData()\n",
a.forEach((e=>{
void 0!==e.fileName?(i||(n=`import fs from 'node:fs'\n\n${n}`,i=!0),
n+=`formData.append('${e.name}', new Blob([fs.readFileSync('${e.fileName}')]), '${e.fileName}')\n`):void 0!==e.value&&(n+=`formData.append('${e.name}', '${e.value}')\n`)
})),
n+="\n",r.body=new oWe("formData");else if("application/x-www-form-urlencoded"===e&&a){
const e=Object.fromEntries(a.map((e=>[e.name,e.value])))
;r.body=new oWe(`new URLSearchParams(${aWe(e)})`)}else r.body=t.postData.text}
const i=Object.keys(r).length?`, ${aWe(r)}`:""
;return`${n}fetch('${t.url}${a}'${i})`}},bWe={target:"node",client:"ofetch",
title:"ofetch",generate(e){const t={method:"GET",...e}
;t.method=t.method.toUpperCase();const n={
method:"GET"===t.method?void 0:t.method}
;t.queryString?.length&&(n.query=Object.fromEntries(t.queryString.map((e=>[e.name,e.value])))),
t.headers?.length&&(n.headers={},t.headers.forEach((e=>{
n.headers[e.name]=e.value
}))),t.cookies?.length&&(n.headers=n.headers||{},t.cookies.forEach((e=>{
n.headers["Set-Cookie"]=n.headers["Set-Cookie"]?`${n.headers["Set-Cookie"]}; ${e.name}=${e.value}`:`${e.name}=${e.value}`
}))),Object.keys(n).forEach((e=>{void 0===n[e]&&delete n[e]
})),t.postData&&(n.body=t.postData.text,
"application/json"===t.postData.mimeType&&(n.body=JSON.parse(n.body)))
;const r=Object.keys(n).length?`, ${aWe(n)}`:""
;return`import { ofetch } from 'ofetch'\n\nofetch('${t.url}'${r})`}},yWe={
target:"node",client:"undici",title:"undici",generate(e){const t={method:"GET",
...e};t.method=t.method.toUpperCase();const n={
method:"GET"===t.method?void 0:t.method
},r=vqe(t.queryString),o=r.size?`?${r.toString()}`:""
;t.headers?.length&&(n.headers={},t.headers.forEach((e=>{
n.headers[e.name]=e.value
}))),t.cookies?.length&&(n.headers=n.headers||{},t.cookies.forEach((e=>{
n.headers["Set-Cookie"]=n.headers["Set-Cookie"]?`${n.headers["Set-Cookie"]}; ${e.name}=${e.value}`:`${e.name}=${e.value}`
}))),Object.keys(n).forEach((e=>{void 0===n[e]&&delete n[e]
})),t.postData&&(n.body=t.postData.text,
"application/json"===t.postData.mimeType&&(n.body=new oWe(`JSON.stringify(${aWe(JSON.parse(n.body))})`)))
;const a=Object.keys(n).length?`, ${aWe(n)}`:""
;return`import { request } from 'undici'\n\nconst { statusCode, body } = await request('${t.url}${o}'${a})`
}},OWe=(e,t,n,r)=>{const o=`${e} *${t} = `
;return`${o}${wWe(n,r?o.length:void 0)};`},wWe=(e,t)=>{
const n=void 0===t?", ":`,\n   ${" ".repeat(t)}`
;switch(Object.prototype.toString.call(e)){case"[object Number]":return`@${e}`
;case"[object Array]":return`@[ ${e.map((e=>wWe(e))).join(n)} ]`
;case"[object Object]":{const t=[],r=e
;for(const e in r)Object.hasOwn(r,e)&&t.push(`@"${e}": ${wWe(r[e])}`)
;return`@{ ${t.join(n)} }`}case"[object Boolean]":return e?"@YES":"@NO";default:
return null==e?"":`@"${e.toString().replace(/"/g,'\\"')}"`}},xWe={info:{
key:"nsurlsession",title:"NSURLSession",
link:"https://developer.apple.com/library/mac/documentation/Foundation/Reference/NSURLSession_class/index.html",
description:"Foundation's NSURLSession request"},
convert:({allHeaders:e,postData:t,method:n,fullUrl:r},o)=>{let a;const i={
indent:"    ",pretty:!0,timeout:10,...o},{push:s,join:l,blank:c}=new hqe({
indent:i.indent}),u={hasHeaders:!1,hasBody:!1}
;if(s("#import <Foundation/Foundation.h>"),
Object.keys(e).length&&(u.hasHeaders=!0,
c(),s(OWe("NSDictionary","headers",e,i.pretty))),
t&&(t.text||t.jsonObj||t.params))switch(u.hasBody=!0,t.mimeType){
case"application/x-www-form-urlencoded":
if(null===(a=t.params)||void 0===a?void 0:a.length){c();const[e,...n]=t.params
;s(`NSMutableData *postData = [[NSMutableData alloc] initWithData:[@"${e.name}=${e.value}" dataUsingEncoding:NSUTF8StringEncoding]];`),
n.forEach((({name:e,value:t})=>{
s(`[postData appendData:[@"&${e}=${t}" dataUsingEncoding:NSUTF8StringEncoding]];`)
}))}else u.hasBody=!1;break;case"application/json":
t.jsonObj&&(s(OWe("NSDictionary","parameters",t.jsonObj,i.pretty)),
c(),s("NSData *postData = [NSJSONSerialization dataWithJSONObject:parameters options:0 error:nil];"))
;break;case"multipart/form-data":
s(OWe("NSArray","parameters",t.params||[],i.pretty)),
s(`NSString *boundary = @"${t.boundary}";`),
c(),s("NSError *error;"),s("NSMutableString *body = [NSMutableString string];"),
s("for (NSDictionary *param in parameters) {"),
s('[body appendFormat:@"--%@\\r\\n", boundary];',1),
s('if (param[@"fileName"]) {',1),
s('[body appendFormat:@"Content-Disposition:form-data; name=\\"%@\\"; filename=\\"%@\\"\\r\\n", param[@"name"], param[@"fileName"]];',2),
s('[body appendFormat:@"Content-Type: %@\\r\\n\\r\\n", param[@"contentType"]];',2),
s('[body appendFormat:@"%@", [NSString stringWithContentsOfFile:param[@"fileName"] encoding:NSUTF8StringEncoding error:&error]];',2),
s("if (error) {",2),
s('NSLog(@"%@", error);',3),s("}",2),s("} else {",1),s('[body appendFormat:@"Content-Disposition:form-data; name=\\"%@\\"\\r\\n\\r\\n", param[@"name"]];',2),
s('[body appendFormat:@"%@", param[@"value"]];',2),
s("}",1),s("}"),s('[body appendFormat:@"\\r\\n--%@--\\r\\n", boundary];'),
s("NSData *postData = [body dataUsingEncoding:NSUTF8StringEncoding];");break
;default:
c(),s(`NSData *postData = [[NSData alloc] initWithData:[@"${t.text}" dataUsingEncoding:NSUTF8StringEncoding]];`)
}
return c(),s(`NSMutableURLRequest *request = [NSMutableURLRequest requestWithURL:[NSURL URLWithString:@"${r}"]`),
s("                                                       cachePolicy:NSURLRequestUseProtocolCachePolicy"),
s(`                                                   timeoutInterval:${i.timeout.toFixed(1)}];`),
s(`[request setHTTPMethod:@"${n}"];`),
u.hasHeaders&&s("[request setAllHTTPHeaderFields:headers];"),
u.hasBody&&s("[request setHTTPBody:postData];"),
c(),s("NSURLSession *session = [NSURLSession sharedSession];"),
s("NSURLSessionDataTask *dataTask = [session dataTaskWithRequest:request"),
s("                                            completionHandler:^(NSData *data, NSURLResponse *response, NSError *error) {"),
s("                                            if (error) {",1),
s('                                            NSLog(@"%@", error);',2),
s("                                            } else {",1),
s("                                            NSHTTPURLResponse *httpResponse = (NSHTTPURLResponse *) response;",2),
s('                                            NSLog(@"%@", httpResponse);',2),
s("                                            }",1),
s("                                            }];"),s("[dataTask resume];"),l()
}},kWe={target:"objc",client:"nsurlsession",title:"NSURLSession",
generate:e=>yqe(xWe,e)},SWe={info:{key:"cohttp",title:"CoHTTP",
link:"https://github.com/mirage/ocaml-cohttp",
description:"Cohttp is a very lightweight HTTP server using Lwt or Async for OCaml"
},convert:({fullUrl:e,allHeaders:t,postData:n,method:r},o)=>{const a={
indent:"  ",...o},{push:i,blank:s,join:l}=new hqe({indent:a.indent})
;i("open Cohttp_lwt_unix"),
i("open Cohttp"),i("open Lwt"),s(),i(`let uri = Uri.of_string "${e}" in`)
;const c=Object.keys(t)
;1===c.length?i(`let headers = Header.add (Header.init ()) "${c[0]}" "${gqe(t[c[0]])}" in`):c.length>1&&(i("let headers = Header.add_list (Header.init ()) ["),
c.forEach((e=>{i(`("${e}", "${gqe(t[e])}");`,1)
})),i("] in")),(null==n?void 0:n.text)&&i(`let body = Cohttp_lwt_body.of_string ${JSON.stringify(n.text)} in`),
s()
;const u=c.length?"~headers ":"",d=(null==n?void 0:n.text)?"~body ":"",p=["get","post","head","delete","patch","put","options"].includes(r.toLowerCase())?`\`${r.toUpperCase()}`:`(Code.method_of_string "${r}")`
;return i(`Client.call ${u}${d}${p} uri`),
i(">>= fun (res, body_stream) ->"),i("(* Do stuff with the result *)",1),l()}
},_We={target:"ocaml",client:"cohttp",title:"Cohttp",generate:e=>yqe(SWe,e)}
;function TWe(e){return" ".repeat(2*e)}class EWe{constructor(e){this.value=e}}
function AWe(e,t=0){if(null==e)return"null";if(e instanceof EWe){
const n=e.value.split("\n");if(n.length>1){const e=TWe(t+1)
;return n.map(((t,n)=>0===n?t:`${e}${t}`)).join("\n")}return e.value}
if("string"==typeof e)return`'${e.replace(/\\/g,"\\\\").replace(/'/g,"\\'")}'`
;if("number"==typeof e||"boolean"==typeof e)return String(e)
;if(Array.isArray(e)){if(0===e.length)return"[]"
;const n=e.map((e=>AWe(e,t+1))).join(",\n"+TWe(t+1))
;return`[\n${TWe(t+1)}${n}\n${TWe(t)}]`}if("object"==typeof e){
const n=Object.entries(e);if(0===n.length)return"[]"
;const r=n.map((([e,n])=>`'${e}' => ${AWe(n,t+1)}`)).join(",\n"+TWe(t+1))
;return`[\n${TWe(t+1)}${r}\n${TWe(t)}]`}return"null"}const CWe={target:"php",
client:"curl",title:"cURL",generate(e,t){const n={method:"GET",...e}
;n.method=n.method.toUpperCase()
;const r=[],o=n.queryString?.length?"?"+n.queryString.map((e=>`${encodeURIComponent(e.name)}=${encodeURIComponent(e.value)}`)).join("&"):"",a=`${n.url}${o}`
;if(r.push(`$ch = curl_init("${a}");`),
r.push(""),"POST"===n.method&&r.push("curl_setopt($ch, CURLOPT_POST, true);"),
t?.auth?.username&&t?.auth?.password&&r.push(`curl_setopt($ch, CURLOPT_USERPWD, '${t.auth.username}:${t.auth.password}');`),
n.headers?.length){const e=n.headers.map((e=>`'${e.name}: ${e.value}'`))
;r.push(`curl_setopt($ch, CURLOPT_HTTPHEADER, [${e.join(", ")}]);`)
;const t=n.headers.find((e=>"accept-encoding"===e.name.toLowerCase()))
;t&&/gzip|deflate/.test(t.value)&&r.push("curl_setopt($ch, CURLOPT_ENCODING, '');")
}if(n.cookies?.length){
const e=n.cookies.map((e=>`${encodeURIComponent(e.name)}=${encodeURIComponent(e.value)}`)).join("; ")
;r.push(`curl_setopt($ch, CURLOPT_COOKIE, '${e}');`)}
if(n.postData)if("application/json"===n.postData.mimeType){
if(n.postData.text)try{const e=AWe(JSON.parse(n.postData.text))
;r.push(`curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode(${e}));`)}catch{
r.push(`curl_setopt($ch, CURLOPT_POSTFIELDS, '${n.postData.text}');`)}
}else if("multipart/form-data"===n.postData.mimeType&&n.postData.params){
const e=n.postData.params.reduce(((e,t)=>(void 0!==t.fileName?e.push(`'${t.name}' => '@${t.fileName}'`):void 0!==t.value&&e.push(`'${t.name}' => '${t.value}'`),
e)),[])
;r.push("curl_setopt($ch, CURLOPT_HTTPHEADER, ['Content-Type: multipart/form-data']);"),
r.push(`curl_setopt($ch, CURLOPT_POSTFIELDS, [${e.join(", ")}]);`)
}else if("application/x-www-form-urlencoded"===n.postData.mimeType&&n.postData.params){
const e=n.postData.params.map((e=>`${encodeURIComponent(e.name)}=${e.value?encodeURIComponent(e.value):""}`)).join("&")
;r.push("curl_setopt($ch, CURLOPT_HTTPHEADER, ['Content-Type: application/x-www-form-urlencoded']);"),
r.push(`curl_setopt($ch, CURLOPT_POSTFIELDS, '${e}');`)
}else if("application/octet-stream"===n.postData.mimeType)r.push("curl_setopt($ch, CURLOPT_HTTPHEADER, ['Content-Type: application/octet-stream']);"),
r.push(`curl_setopt($ch, CURLOPT_POSTFIELDS, '${n.postData.text||""}');`);else if(n.postData.text)try{
const e=AWe(JSON.parse(n.postData.text))
;r.push(`curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode(${e}));`)}catch{
r.push(`curl_setopt($ch, CURLOPT_POSTFIELDS, '${n.postData.text}');`)}
return r.push(""),
r.push("curl_exec($ch);"),r.push(""),r.push("curl_close($ch);"),
r.join("\n").replace(/\n\n\n/g,"\n\n")}},$We={target:"php",client:"guzzle",
title:"Guzzle",generate(e,t){if(!e)return""
;const n={},r=(e.method||"GET").toUpperCase(),o=e.url||""
;if(e.headers&&Array.isArray(e.headers)&&e.headers.length>0){const t={}
;e.headers.forEach((e=>{
void 0===t[e.name]?t[e.name]=e.value:Array.isArray(t[e.name])?t[e.name].push(e.value):t[e.name]=[t[e.name],e.value]
})),n.headers=t}if(e.queryString&&e.queryString.length>0){const t={}
;e.queryString.forEach((e=>{t[e.name]=e.value})),n.query=t}
if(e.cookies&&e.cookies.length>0){const t={};e.cookies.forEach((e=>{
t[e.name]=e.value})),n.cookies=t}
if(t?.auth?.username&&t.auth.password&&(n.auth=[t.auth.username,t.auth.password]),
e.postData)if("application/json"===e.postData.mimeType)try{
n.json=JSON.parse(e.postData.text||"{}")}catch(i){n.body=e.postData.text
}else if("multipart/form-data"===e.postData.mimeType){
if(e.postData.params)n.multipart=e.postData.params.map((e=>({name:e.name,
contents:e.fileName?new EWe(`fopen('${e.fileName}', 'r')`):e.value||""
})));else if(e.postData.text)try{n.form_params=JSON.parse(e.postData.text)
}catch(i){n.body=e.postData.text}
}else if("application/x-www-form-urlencoded"===e.postData.mimeType){
if(e.postData.params){const t={};e.postData.params.forEach((e=>{
t[e.name]=e.value||""})),n.form_params=t}}else n.body=e.postData.text
;e.headers&&Array.isArray(e.headers)&&e.headers.some((e=>"Accept-Encoding"===e.name&&e.value.includes("gzip")))&&(n.decode_content=!0)
;let a="$client = new GuzzleHttp\\Client();\n\n";if(Object.keys(n).length>0){
a+=`$response = $client->request('${r}', '${o}', ${AWe(n)});`
}else a+=`$response = $client->request('${r}', '${o}');`;return a}
},PWe=e=>({method:t,headersObj:n,cookies:r,uriObj:o,fullUrl:a,postData:i,allHeaders:s})=>{
const{push:l,join:c}=new hqe
;if(!["GET","POST","PUT","DELETE","PATCH","HEAD","OPTIONS"].includes(t.toUpperCase()))return"Method not supported"
;const u=[],d=Object.keys(n);return d.length&&(l("$headers=@{}"),d.forEach((e=>{
"connection"!==e&&l(`$headers.Add("${e}", "${fqe(n[e],{escapeChar:"`"})}")`)})),
u.push("-Headers $headers")),
r.length&&(l("$session = New-Object Microsoft.PowerShell.Commands.WebRequestSession"),
r.forEach((e=>{
l("$cookie = New-Object System.Net.Cookie"),l(`$cookie.Name = '${e.name}'`),
l(`$cookie.Value = '${e.value}'`),
l(`$cookie.Domain = '${o.host}'`),l("$session.Cookies.Add($cookie)")
})),u.push("-WebSession $session")),
(null==i?void 0:i.text)&&(u.push(`-ContentType '${fqe(xqe(s,"content-type"),{
delimiter:"'",escapeChar:"`"
})}'`),u.push(`-Body '${i.text}'`)),l(`$response = ${e} -Uri '${a}' -Method ${t} ${u.join(" ")}`),
c()},DWe={info:{key:"restmethod",title:"Invoke-RestMethod",
link:"https://docs.microsoft.com/en-us/powershell/module/Microsoft.PowerShell.Utility/Invoke-RestMethod",
description:"Powershell Invoke-RestMethod client"},
convert:PWe("Invoke-RestMethod")},IWe={target:"powershell",client:"restmethod",
title:"Invoke-RestMethod",generate:e=>yqe(DWe,e)},MWe={info:{key:"webrequest",
title:"Invoke-WebRequest",
link:"https://docs.microsoft.com/en-us/powershell/module/Microsoft.PowerShell.Utility/Invoke-WebRequest",
description:"Powershell Invoke-WebRequest client"},
convert:PWe("Invoke-WebRequest")},NWe={target:"powershell",client:"webrequest",
title:"Invoke-WebRequest",generate:e=>yqe(MWe,e)};function RWe(e){
const t=[["true","True"],["false","False"],["null","None"]];let n=e
;for(const[r,o]of t){const e=[`(: )${r}(?=,|\\n)`,`^( +)${r}(?=,|\\n)`]
;for(const t of e)n=n.replace(new RegExp(t,"gm"),`$1${o}`)}return n}
function LWe(e,t,n){const r={url:"https://example.com",method:"get",...t
},o=r.method.toLowerCase(),a={}
;if(r.headers?.length&&(a.headers=r.headers.reduce(((e,t)=>(t.name in e||(e[t.name]=t.value),
e)),{})),
r.queryString?.length&&(a.params=Object.fromEntries(r.queryString.map((e=>[e.name,e.value])))),
r.cookies?.length&&(a.cookies=Object.fromEntries(r.cookies.map((e=>[e.name,e.value])))),
n?.auth?.username&&n?.auth?.password&&(a.auth=[n.auth.username,n.auth.password]),
r.postData){const{mimeType:e,text:t,params:n}=r.postData
;if("application/json"===e&&t)try{a.json=JSON.parse(t)}catch{a.data=t
}else if("application/octet-stream"===e&&t)a.data=t;else if("multipart/form-data"===e&&n){
const e=[],t={};n.forEach((n=>{void 0!==n.fileName?e.push({key:n.name,
file:`open("${n.fileName}", "rb")`}):void 0!==n.value&&(t[n.name]=n.value)
})),Object.keys(e).length&&(a.files=e),Object.keys(t).length&&(a.data=t)
}else"application/x-www-form-urlencoded"===e&&n&&(a.data=Object.fromEntries(n.map((e=>[e.name,e.value]))))
}const i=[],s=`"${r.url}"`;r.url.length>40?i.push(s):i.push("")
;for(const[l,c]of Object.entries(a))if("auth"===l)i.push(`${l}=(${RWe(JSON.stringify(c[0]))}, ${RWe(JSON.stringify(c[1]))})`);else if("files"===l){
const e="[\n"+c.map((({key:e,file:t})=>`      ("${e}", ${t})`)).join(",\n")+"\n    ]"
;i.push(`${l}=${e}`)}else if("json"===l){
const e=RWe(JSON.stringify(c,null,2).split("\n").map(((e,t)=>0===t?e:"    "+e)).join("\n"))
;i.push(`${l}=${e}`)
}else if("data"===l&&"application/octet-stream"===r.postData?.mimeType)i.push(`${l}=b"${c}"`);else{
const e=RWe(JSON.stringify(c,null,2).split("\n").map(((e,t)=>0===t?e:"    "+e)).join("\n"))
;i.push(`${l}=${e}`)}
return r.url.length>40?`${e}.${o}(\n    ${i.join(",\n    ")}\n)`:i.length<=1?`${e}.${o}(${s})`:`${e}.${o}(${s}${i.length>1?",":""}\n    ${i.slice(1).join(",\n    ")}\n)`
}const BWe={target:"python",client:"httpx_async",title:"HTTPX (Async)",
generate(e,t){let n=LWe("await client",e,t)
;return n=n.split("\n").map((e=>""===e.trim()?e:"    "+e)).join("\n"),
`async with httpx.AsyncClient() as client:\n${n}`}},jWe={target:"python",
client:"httpx_sync",title:"HTTPX (Sync)",generate:(e,t)=>LWe("httpx",e,t)},UWe={
info:{key:"python3",title:"http.client",
link:"https://docs.python.org/3/library/http.client.html",
description:"Python3 HTTP Client"},
convert:({uriObj:{path:e,protocol:t,host:n},postData:r,allHeaders:o,method:a},i={})=>{
const{insecureSkipVerify:s=!1}=i,{push:l,blank:c,join:u}=new hqe
;if(l("import http.client"),s&&l("import ssl"),c(),"https:"===t){
l(`conn = http.client.HTTPSConnection("${n}"${s?", context = ssl._create_unverified_context()":""})`),
c()}else l(`conn = http.client.HTTPConnection("${n}")`),c()
;const d=JSON.stringify(null==r?void 0:r.text);d&&(l(`payload = ${d}`),c())
;const p=o,h=Object.keys(p).length
;if(1===h)for(const f in p)l(`headers = { '${f}': "${gqe(p[f])}" }`),
c();else if(h>1){let e=1;l("headers = {")
;for(const t in p)e++!==h?l(`    '${t}': "${gqe(p[t])}",`):l(`    '${t}': "${gqe(p[t])}"`)
;l("}"),c()}
return l(d&&h?`conn.request("${a}", "${e}", payload, headers)`:d&&!h?`conn.request("${a}", "${e}", payload)`:!d&&h?`conn.request("${a}", "${e}", headers=headers)`:`conn.request("${a}", "${e}")`),
c(),
l("res = conn.getresponse()"),l("data = res.read()"),c(),l('print(data.decode("utf-8"))'),
u()}},zWe={target:"python",client:"python3",title:"http.client",
generate:e=>yqe(UWe,e)},FWe={target:"python",client:"requests",title:"Requests",
generate:(e,t)=>LWe("requests",e,t)},ZWe={info:{key:"httr",title:"httr",
link:"https://cran.r-project.org/web/packages/httr/vignettes/quickstart.html",
description:"httr: Tools for Working with URLs and HTTP"},
convert:({url:e,queryObj:t,queryString:n,postData:r,allHeaders:o,method:a},i={})=>{
let s,l;const{push:c,blank:u,join:d}=new hqe({
indent:null!==(s=i.indent)&&void 0!==s?s:"  "})
;c("library(httr)"),u(),c(`url <- "${e}"`),u();const p=t;delete t.key
;const h=Object.entries(p),f=h.length;if(1===f){const e=h[0]
;c(`queryString <- list(${e[0]} = "${e[1]}")`),u()
}else f>1&&(c("queryString <- list("),h.forEach((([e,t],n)=>{
c(`${e} = "${t}"${n!==f-1?",":""}`,1)})),c(")"),u())
;const m=JSON.stringify(null==r?void 0:r.text);if(m&&(c(`payload <- ${m}`),u()),
r&&(r.text||r.jsonObj||r.params))switch(r.mimeType){
case"application/x-www-form-urlencoded":c('encode <- "form"'),u();break
;case"application/json":c('encode <- "json"'),u();break
;case"multipart/form-data":c('encode <- "multipart"'),u();break;default:
c('encode <- "raw"'),u()}
const g=xqe(o,"cookie"),v=xqe(o,"accept"),b=g?`set_cookies(\`${String(g).replace(/;/g,'", `').replace(/` /g,"`").replace(/[=]/g,'` = "')}")`:void 0,y=v?`accept("${gqe(v)}")`:void 0,O=`content_type("${gqe(null!==(l=null==r?void 0:r.mimeType)&&void 0!==l?l:"application/octet-stream")}")`,w=Object.entries(o).filter((([e])=>!["cookie","accept","content-type"].includes(e.toLowerCase()))).map((([e,t])=>`'${e}' = '${mqe(t)}'`)).join(", "),x=w?`add_headers(${w})`:void 0
;let k=`response <- VERB("${a}", url`
;m&&(k+=", body = payload"),n.length&&(k+=", query = queryString")
;const S=[x,O,y,b].filter((e=>!!e)).join(", ")
;return S&&(k+=`, ${S}`),r&&(r.text||r.jsonObj||r.params)&&(k+=", encode = encode"),
k+=")",c(k),u(),c('content(response, "text")'),d()}},QWe={target:"r",
client:"httr",title:"httr",generate:e=>yqe(ZWe,e)},HWe={info:{key:"native",
title:"net::http",
link:"http://ruby-doc.org/stdlib-2.2.1/libdoc/net/http/rdoc/Net/HTTP.html",
description:"Ruby HTTP client"},
convert:({uriObj:e,method:t,fullUrl:n,postData:r,allHeaders:o},a={})=>{
const{insecureSkipVerify:i=!1}=a,{push:s,blank:l,join:c}=new hqe
;s("require 'uri'"),s("require 'net/http'"),l()
;const u=t.toUpperCase(),d=u.charAt(0)+u.substring(1).toLowerCase()
;["GET","POST","HEAD","DELETE","PATCH","PUT","OPTIONS","COPY","LOCK","UNLOCK","MOVE","TRACE"].includes(u)||(s(`class Net::HTTP::${d} < Net::HTTPRequest`),
s(`  METHOD = '${u.toUpperCase()}'`),
s(`  REQUEST_HAS_BODY = '${(null==r?void 0:r.text)?"true":"false"}'`),
s("  RESPONSE_HAS_BODY = true"),
s("end"),l()),s(`url = URI("${n}")`),l(),s("http = Net::HTTP.new(url.host, url.port)"),
"https:"===e.protocol&&(s("http.use_ssl = true"),
i&&s("http.verify_mode = OpenSSL::SSL::VERIFY_NONE")),
l(),s(`request = Net::HTTP::${d}.new(url)`);const p=Object.keys(o)
;return p.length&&p.forEach((e=>{s(`request["${e}"] = '${mqe(o[e])}'`)
})),(null==r?void 0:r.text)&&s(`request.body = ${JSON.stringify(r.text)}`),
l(),s("response = http.request(request)"),s("puts response.read_body"),c()}
},VWe={target:"ruby",client:"native",title:"net::http",generate:e=>yqe(HWe,e)}
;function qWe(e){return`"${function(e){
return e.replace(/\\/g,"\\\\").replace(/"/g,'\\"').replace(/\n/g,"\\n").replace(/\r/g,"\\r").replace(/\t/g,"\\t").replace(/\0/g,"\\0")
}(e)}"`}function WWe(e,t){return`${" ".repeat(4*e)}${t}`}function XWe(e,...t){
return WWe(1,`.${e}(${t.join(", ")})`)}const GWe={target:"rust",
client:"reqwest",title:"reqwest",generate(e,t){if(!e)return""
;const n=function(e){return{...e,method:(e.method||"GET").toUpperCase()}
}(e),r=(o=n.queryString,
o?.length?`?${o.map((e=>`${encodeURIComponent(e.name)}=${encodeURIComponent(e.value)}`)).join("&")}`:"")
;var o;const a=function(e,t){return`${e}${t}`}(n.url||"",r),i=function(e){
const t={}
;if(e.headers)for(const n of e.headers)n.value&&!/[; ]/.test(n.name)&&(t[n.name]=n.value)
;if(e.cookies&&e.cookies.length>0){
const n=e.cookies.map((e=>`${encodeURIComponent(e.name)}=${encodeURIComponent(e.value)}`)).join("; ")
;t.Cookie=n}return t}(n),s=[],l=KWe(t?.auth);l&&s.push(l),s.push(...JWe(i))
;const c=eXe(n.postData);return c&&s.push(c),tXe(a,n.method,s)}
},YWe=e=>e.fileName?[WWe(2,`let part = reqwest::multipart::Part::text(${qWe(e.value||"")})`),WWe(3,`.file_name(${qWe(e.fileName)});`),WWe(2,`form = form.part(${qWe(e.name)}, part);`)].join("\n"):WWe(2,`form = form.text(${qWe(e.name)}, ${qWe(e.value||"")});`),KWe=e=>e?.username&&e?.password?XWe("basic_auth",qWe(e.username),qWe(e.password)):null,JWe=e=>Object.entries(e).map((([e,t])=>XWe("header",qWe(e),qWe(t)))),eXe=e=>{
if(!e)return null;const{mimeType:t,text:n,params:r}=e;switch(t){
case"application/json":return XWe("json",`&serde_json::json!(${function(e){try{
const t=JSON.parse(e),n=JSON.stringify(t,null,4).split("\n")
;return n.map(((e,t)=>0===t?e:(n.length,WWe(1,e)))).join("\n")}catch{return e}
}(n)})`);case"application/x-www-form-urlencoded":
return XWe("form",`&[${r?.map((e=>`(${qWe(e.name)}, ${qWe(e.value||"")})`)).join(", ")||""}]`)
;case"multipart/form-data":{
const e=r?.map(YWe).join("\n")||"",t=[".multipart({",WWe(2,"let mut form = reqwest::multipart::Form::new();"),e,WWe(3,"form"),WWe(2,"})")].join("\n")
;return WWe(1,t)}default:return XWe("body",qWe(n||""))}},tXe=(e,t,n)=>{
const r=["let client = reqwest::Client::new();",""]
;n.length>0?(r.push("let request = client"),
r.push(WWe(1,`.${t.toLowerCase()}(${qWe(e)})`)),
r.push(...n)):r.push(`let request = client.${t.toLowerCase()}(${qWe(e)})`)
;const o=r[r.length-1]
;return r[r.length-1]=o+";",r.push(""),r.push("let response = request.send().await?;"),
r.join("\n")
},nXe=e=>e.replace(/'/g,"'\\''"),rXe=(e="")=>/^[a-z0-9-_/.@%^=:]+$/i.test(e)?e:`'${e.replace(/'/g,"'\\''")}'`,oXe={
info:{key:"httpie",title:"HTTPie",link:"http://httpie.org/",
description:"a CLI, cURL-like tool for humans"},
convert:({allHeaders:e,postData:t,queryObj:n,fullUrl:r,method:o,url:a},i)=>{
const s={body:!1,cert:!1,headers:!1,indent:"  ",pretty:!1,print:!1,
queryParams:!1,short:!1,style:!1,timeout:!1,verbose:!1,verify:!1,...i
},{push:l,join:c,unshift:u}=new hqe({indent:s.indent,
join:!1!==s.indent?` \\\n${s.indent}`:" "});let d=!1;const p=[]
;s.headers&&p.push(s.short?"-h":"--headers"),
s.body&&p.push(s.short?"-b":"--body"),
s.verbose&&p.push(s.short?"-v":"--verbose"),
s.print&&p.push(`${s.short?"-p":"--print"}=${s.print}`),
s.verify&&p.push(`--verify=${s.verify}`),
s.cert&&p.push(`--cert=${s.cert}`),s.pretty&&p.push(`--pretty=${s.pretty}`),
s.style&&p.push(`--style=${s.style}`),
s.timeout&&p.push(`--timeout=${s.timeout}`),
s.queryParams&&Object.keys(n).forEach((e=>{const t=n[e]
;Array.isArray(t)?t.forEach((t=>{l(`${e}==${rXe(t)}`)})):l(`${e}==${rXe(t)}`)
})),Object.keys(e).sort().forEach((t=>{l(`${t}:${rXe(e[t])}`)
})),"application/x-www-form-urlencoded"===(null==t?void 0:t.mimeType)?t.params?.length&&(p.push(s.short?"-f":"--form"),
t.params.forEach((e=>{l(`${e.name}=${rXe(e.value)}`)
}))):"multipart/form-data"===(null==t?void 0:t.mimeType)?t?.params?.length&&(p.push("--multipart"),
t.params.forEach((e=>{
e.fileName?l(`${e.name}@${rXe(e.fileName)}`):l(`${e.name}='${rXe(e.value)}'`)
}))):d=!0
;if(u(`http ${p.length?`${p.join(" ")} `:""}${o} ${a=rXe(s.queryParams?a:r)}`),
d&&(null==t?void 0:t.text)){u(`echo ${rXe(t.text)} | `)}return c()}},aXe={info:{
key:"wget",title:"Wget",link:"https://www.gnu.org/software/wget/",
description:"a free software package for retrieving files using HTTP, HTTPS"},
convert:({method:e,postData:t,allHeaders:n,fullUrl:r},o)=>{const a={indent:"  ",
short:!1,verbose:!1,...o},{push:i,join:s}=new hqe({indent:a.indent,
join:!1!==a.indent?` \\\n${a.indent}`:" "});var l
;return a.verbose?i("wget "+(a.short?"-v":"--verbose")):i("wget "+(a.short?"-q":"--quiet")),
i(`--method ${rXe(e)}`),Object.keys(n).forEach((e=>{const t=`${e}: ${n[e]}`
;i(`--header ${rXe(t)}`)
})),(null==t?void 0:t.text)&&i(`--body-data ${l=rXe(t.text),
l.replace(/\r/g,"\\r").replace(/\n/g,"\\n")}`),
i(a.short?"-O":"--output-document"),i(`- ${rXe(r)}`),s()}
},iXe=(e,t)=>t.repeat(e),sXe=(e,t,n,r)=>{
const o=iXe(r,n),a=iXe(r-1,n),i=t?`,\n${o}`:", "
;return t?`[\n${o}${e.join(i)}\n${a}]`:`[${e.join(i)}]`
},lXe=(e,t,n)=>`let ${e} = ${cXe(t,n)}`,cXe=(e,t,n)=>{const r=void 0===n?1:n+1
;switch(Object.prototype.toString.call(e)){case"[object Number]":return e
;case"[object Array]":{let n=!1
;const o=e.map((e=>("[object Object]"===Object.prototype.toString.call(e)&&(n=Object.keys(e).length>1),
cXe(e,t,r))));return sXe(o,n,t.indent,r)}case"[object Object]":{const n=[],o=e
;for(const e in o)Object.hasOwn(o,e)&&n.push(`"${e}": ${cXe(o[e],t,r)}`)
;return sXe(n,t.pretty&&n.length>1,t.indent,r)}case"[object Boolean]":
return e.toString();default:
return null==e?"":`"${e.toString().replace(/"/g,'\\"')}"`}},uXe={info:{
key:"nsurlsession",title:"NSURLSession",
link:"https://developer.apple.com/library/mac/documentation/Foundation/Reference/NSURLSession_class/index.html",
description:"Foundation's NSURLSession request"},
convert:({allHeaders:e,postData:t,fullUrl:n,method:r},o)=>{let a;const i={
indent:"  ",pretty:!0,timeout:"10",...o},{push:s,blank:l,join:c}=new hqe({
indent:i.indent}),u={hasHeaders:!1,hasBody:!1}
;if(s("import Foundation"),Object.keys(e).length&&(u.hasHeaders=!0,
l(),s(lXe("headers",e,i))),t&&(t.text||t.jsonObj||t.params))switch(u.hasBody=!0,
t.mimeType){case"application/x-www-form-urlencoded":
if(l(),null===(a=t.params)||void 0===a?void 0:a.length){const[e,...n]=t.params
;s(`let postData = NSMutableData(data: "${e.name}=${e.value}".data(using: String.Encoding.utf8)!)`),
n.forEach((({name:e,value:t})=>{
s(`postData.append("&${e}=${t}".data(using: String.Encoding.utf8)!)`)}))
}else u.hasBody=!1;break;case"application/json":
t.jsonObj&&(s(`${lXe("parameters",t.jsonObj,i)} as [String : Any]`),
l(),s("let postData = JSONSerialization.data(withJSONObject: parameters, options: [])"))
;break;case"multipart/form-data":
s(lXe("parameters",t.params,i)),l(),s(`let boundary = "${t.boundary}"`),
l(),s('var body = ""'),
s("var error: NSError? = nil"),s("for param in parameters {"),
s('let paramName = param["name"]!',1),
s('body += "--\\(boundary)\\r\\n"',1),s('body += "Content-Disposition:form-data; name=\\"\\(paramName)\\""',1),
s('if let filename = param["fileName"] {',1),
s('let contentType = param["content-type"]!',2),
s("let fileContent = String(contentsOfFile: filename, encoding: String.Encoding.utf8)",2),
s("if (error != nil) {",2),
s("print(error as Any)",3),s("}",2),s('body += "; filename=\\"\\(filename)\\"\\r\\n"',2),
s('body += "Content-Type: \\(contentType)\\r\\n\\r\\n"',2),
s("body += fileContent",2),
s('} else if let paramValue = param["value"] {',1),s('body += "\\r\\n\\r\\n\\(paramValue)"',2),
s("}",1),s("}");break;default:
l(),s(`let postData = NSData(data: "${t.text}".data(using: String.Encoding.utf8)!)`)
}
return l(),s(`let request = NSMutableURLRequest(url: NSURL(string: "${n}")! as URL,`),
s("                                        cachePolicy: .useProtocolCachePolicy,"),
s(`                                    timeoutInterval: ${Number.parseInt(i.timeout,10).toFixed(1)})`),
s(`request.httpMethod = "${r}"`),
u.hasHeaders&&s("request.allHTTPHeaderFields = headers"),
u.hasBody&&s("request.httpBody = postData as Data"),
l(),s("let session = URLSession.shared"),
s("let dataTask = session.dataTask(with: request as URLRequest, completionHandler: { (data, response, error) -> Void in"),
s("if (error != nil) {",1),
s("print(error as Any)",2),s("} else {",1),s("let httpResponse = response as? HTTPURLResponse",2),
s("print(httpResponse)",2),s("}",1),s("})"),l(),s("dataTask.resume()"),c()}
},dXe=[{key:"c",title:"C",default:"libcurl",clients:[Oqe]},{key:"csharp",
title:"C#",default:"restsharp",clients:[Iqe,Lqe]},{key:"clojure",
title:"Clojure",default:"clj_http",clients:[Dqe]},{key:"dart",title:"Dart",
default:"http",clients:[Bqe]},{key:"fsharp",title:"F#",default:"httpclient",
clients:[jqe]},{key:"go",title:"Go",default:"native",clients:[Fqe]},{key:"http",
title:"HTTP",default:"http1.1",clients:[Zqe]},{key:"java",title:"Java",
default:"unirest",clients:[Hqe,qqe,Xqe,Yqe]},{key:"js",title:"JavaScript",
default:"fetch",clients:[sWe,nWe,uWe,cWe,pWe]},{key:"kotlin",title:"Kotlin",
default:"okhttp",clients:[fWe]},{key:"node",title:"Node.js",default:"fetch",
clients:[vWe,gWe,bWe,yWe]},{key:"objc",title:"Objective-C",
default:"nsurlsession",clients:[kWe]},{key:"ocaml",title:"OCaml",
default:"cohttp",clients:[_We]},{key:"php",title:"PHP",default:"curl",
clients:[CWe,$We]},{key:"powershell",title:"PowerShell",default:"webrequest",
clients:[NWe,IWe]},{key:"python",title:"Python",default:"python3",
clients:[zWe,FWe,jWe,BWe]},{key:"r",title:"R",default:"httr",clients:[QWe]},{
key:"ruby",title:"Ruby",default:"native",clients:[VWe]},{key:"rust",
title:"Rust",default:"reqwest",clients:[GWe]},{key:"shell",title:"Shell",
default:"curl",clients:[{target:"shell",client:"curl",title:"Curl",
generate(e,t){const n={method:"GET",...e};n.method=n.method.toUpperCase()
;const r=["curl"],o=n.queryString?.length?"?"+n.queryString.map((e=>`${encodeURIComponent(e.name)}=${encodeURIComponent(e.value)}`)).join("&"):"",a=`${n.url}${o}`,i=/[\s<>[\]{}|\\^%$]/.test(a),s=o||i?`'${a}'`:a
;if(r[0]=`curl ${s}`,
"GET"!==n.method&&r.push(`--request ${n.method}`),t?.auth?.username&&t?.auth?.password){
const e=nXe(`${t.auth.username}:${t.auth.password}`);r.push(`--user '${e}'`)}
if(n.headers?.length){n.headers.forEach((e=>{
const t=nXe(`${e.name}: ${e.value}`);r.push(`--header '${t}'`)}))
;const e=n.headers.find((e=>"accept-encoding"===e.name.toLowerCase()))
;e&&/gzip|deflate/.test(e.value)&&r.push("--compressed")}if(n.cookies?.length){
const e=n.cookies.map((e=>`${encodeURIComponent(e.name)}=${encodeURIComponent(e.value)}`)).join("; "),t=nXe(e)
;r.push(`--cookie '${t}'`)}
if(n.postData)if("application/json"===n.postData.mimeType){
if(n.postData.text)try{
const e=JSON.parse(n.postData.text),t=JSON.stringify(e,null,2),o=nXe(t)
;r.push(`--data '${o}'`)}catch{const e=nXe(n.postData.text??"")
;r.push(`--data '${e}'`)}
}else if("application/octet-stream"===n.postData.mimeType){
const e=nXe(n.postData.text??"");r.push(`--data-binary '${e}'`)
}else if("application/x-www-form-urlencoded"===n.postData.mimeType&&n.postData.params)n.postData.params.forEach((e=>{
const t=nXe(e.value??""),n=encodeURIComponent(e.name),o=nXe(n)
;r.push(`--data-urlencode '${o}=${t}'`)
}));else if("multipart/form-data"===n.postData.mimeType&&n.postData.params)n.postData.params.forEach((e=>{
const t=nXe(e.name);if(void 0!==e.fileName){const n=nXe(e.fileName)
;r.push(`--form '${t}=@${n}'`)}else{const n=nXe(e.value??"")
;r.push(`--form '${t}=${n}'`)}}));else try{
const e=JSON.parse(n.postData.text??""),t=JSON.stringify(e,null,2),o=nXe(t)
;r.push(`--data '${o}'`)}catch{const e=nXe(n.postData.text??"")
;r.push(`--data '${e}'`)}return r.join(" \\\n  ")}},{target:"shell",
client:"wget",title:"Wget",generate:e=>yqe(aXe,e)},{target:"shell",
client:"httpie",title:"HTTPie",generate:e=>yqe(oXe,e)}]},{key:"swift",
title:"Swift",default:"nsurlsession",clients:[{target:"swift",
client:"nsurlsession",title:"NSURLSession",generate:e=>yqe(uXe,e)}]}]
;function pXe(){function e(e,t){
return dXe.find((({key:t})=>t===e))?.clients.find((e=>e.client===t))}return{
print:(t,n,r)=>e(t,n)?.generate(r),clients:()=>dXe,
plugins:()=>dXe.flatMap((({key:e,clients:t})=>t.map((t=>({target:e,
client:t.client}))))),findPlugin:e,hasPlugin:(t,n)=>Boolean(e(t,n))}}
const hXe=e=>`custom/${e.lang}`,fXe=(e=LQe)=>{const t=new Set(e)
;return pXe().clients().flatMap((e=>{const n=e.clients.flatMap((n=>{
const r=`${e.key}/${n.client}`;return t.has(r)?{id:r,
lang:"curl"===n.client?"curl":e.key,title:`${yh(e.title)} ${n.title}`,
label:n.title,targetKey:e.key,targetTitle:e.title,clientKey:n.client}:[]}))
;return 0===n.length?[]:{label:e.title,options:n}}))
},mXe=(e,t)=>"[{}]"===JSON.stringify(t)&&e?.length?e.find((e=>"{}"===JSON.stringify(e)))?e:[...e,{}]:t??e??[],gXe=e=>{
const t=e.some((e=>Object.keys(e).length>1))
;return e.some((e=>0===Object.keys(e).length))&&!t},vXe=(e,t,n=[],r=!1)=>{if(r){
if(t)return t}else if(e)return e;const o=gXe(n),a=n[0];return o||!a?{
selectedIndex:-1,selectedSchemes:[]}:{selectedIndex:0,selectedSchemes:[a]}
},bXe=["aria-controls","aria-selected","tabindex"],yXe=Qg({
__name:"SectionFilterButton",props:{selected:{type:Boolean},controls:{}},
setup:e=>(t,n)=>(Ub(),Qb("button",{"aria-controls":e.controls??"",
"aria-selected":!!e.selected,
class:Ih(["hover:bg-b-2 flex w-fit cursor-pointer items-center rounded p-1 px-2 text-center font-medium whitespace-nowrap has-[:focus-visible]:outline",{
"text-c-1 pointer-events-none":e.selected}]),role:"tab",
tabindex:e.selected?0:-1,type:"button"},[kv(t.$slots,"default")],10,bXe))
}),OXe={
class:"request-section-content request-section-content-filter fade-request-section-content text-c-3 pointer-events-auto relative hidden w-full justify-end gap-[1.5px] rounded py-1.75 text-xs xl:flex"
},wXe={
class:"filter-button context-bar-group-hover:text-c-1 absolute -right-[30px] flex items-center"
},xXe={class:"context-bar-group-hover:hidden mr-1.5"},kXe=Qg({
__name:"SectionFilter",props:Nv({filters:{default:()=>[]},filterIds:{}},{
modelValue:{},modelModifiers:{}}),emits:["update:modelValue"],setup(e){
const t=Kv(e,"modelValue"),n=bm(),r=r=>{
const o="prev"===r?-1:1,a=t.value?e.filters.indexOf(t.value):0,i=e.filters.length,s=(a+o+i)%i
;t.value=e.filters[s],Xm((()=>{if(n.value){
const e=n.value.querySelector('button[aria-selected="true"]');e&&e.focus()}}))}
;return(o,a)=>(Ub(),Qb("div",{ref_key:"tablist",ref:n,
class:"filter-hover context-bar-group ml-auto hidden lg:flex",role:"tablist",
onKeydown:[a[0]||(a[0]=UO((e=>r("prev")),["left"])),a[1]||(a[1]=UO((e=>r("next")),["right"]))]
},[Gb("div",OXe,[(Ub(!0),Qb(Mb,null,wv(e.filters,(n=>(Ub(),Hb(yXe,{key:n,
class:"filter-hover-item",controls:e.filterIds?.[n],role:"tab",
selected:t.value===n,onClick:e=>t.value=n},{default:ig((()=>[ey(Uh(n),1)])),_:2
},1032,["controls","selected","onClick"])))),128)),Gb("div",wXe,[Gb("span",xXe,Uh(t.value),1),Yb(xm(Gne),{
icon:"FilterList",size:"md",thickness:"2"})])])],544))}
}),SXe=sae(kXe,[["__scopeId","data-v-f97cc68c"]]),_Xe={key:0,
class:"request-response-header bg-b-1 -mb-1/2 sticky top-0 z-1 flex min-h-11 items-center border-b px-2.5 text-base font-medium xl:rounded-none"
},TXe=Qg({inheritAttrs:!1,__name:"ViewLayoutSection",setup(e){const{cx:t}=zS()
;return(e,n)=>(Ub(),
Qb("section",Mh(Kb(xm(t)("xl:custom-scroll bg-b-1 flex flex-1 flex-col xl:h-full xl:min-w-0"))),[e.$slots.title?(Ub(),
Qb("div",_Xe,[kv(e.$slots,"title")])):ny("",!0),kv(e.$slots,"default")],16))}
}),EXe=e=>{if(e instanceof File)return e.name},AXe=(e,t)=>{
if(!e||!("type"in e)||"string"!=typeof t)return{ok:!0}
;if("integer"===e.type||"number"===e.type){const n=Number(t);if(isNaN(n))return{
ok:!1,message:"Value must be a number (e.g., 42.5)"}
;if("integer"===e.type&&!Number.isInteger(n))return{ok:!1,
message:"Value must be a whole number (e.g., 42)"}
;if(void 0!==e.minimum&&n<e.minimum)return{ok:!1,
message:`Value must be ${e.minimum} or greater`}
;if(void 0!==e.maximum&&n>e.maximum)return{ok:!1,
message:`Value must be ${e.maximum} or less`}}if("string"===e.type&&e.format){
if("date"===e.format&&!/^\d{4}-\d{2}-\d{2}$/.test(t??""))return{ok:!1,
message:"Please enter a valid date in YYYY-MM-DD format (e.g., 2024-03-20)"}
;if("date-time"===e.format&&!/^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}(\.\d+)?(Z|[+-]\d{2}:\d{2})$/.test(t??""))return{
ok:!1,
message:"Please enter a valid date and time in RFC 3339 format (e.g., 2024-03-20T13:45:30Z)"
};if("email"===e.format&&!/^[^\s@]+@[^\s@]+\.[^\s@]+$/.test(t??""))return{ok:!1,
message:"Please enter a valid email address (e.g., user@example.com)"}
;if("uri"===e.format&&!/^[a-zA-Z][a-zA-Z0-9+.-]*:.+$/.test(t??""))return{ok:!1,
message:"Please enter a valid URI (e.g., https://example.com)"}}return{ok:!0}
},CXe=["aria-label","role"],$Xe={
class:"w-content text-xxs text-c-1 grid min-w-48 gap-1.5 rounded px-1.5 pt-2 pb-1.5 leading-none"
},PXe={key:0,class:"text-error-1"},DXe={key:1,
class:"schema text-c-2 flex items-center"},IXe={key:0},MXe={key:1},NXe={key:2
},RXe={key:3},LXe={key:4},BXe=Qg({__name:"RequestTableTooltip",props:{schema:{},
value:{},description:{}},setup(e){
const t=Sy((()=>AXe(e.schema,e.value))),n=Sy((()=>!1===t.value.ok))
;return(r,o)=>(Ub(),Hb(xm(Rre),{offset:4,placement:"left",teleport:""},{
popover:ig((()=>[Gb("div",$Xe,[!1===t.value.ok?(Ub(),
Qb("div",PXe,Uh(t.value.message),1)):e.schema&&("type"in e.schema||"format"in e.schema||"minimum"in e.schema||"maximum"in e.schema||"default"in e.schema)?(Ub(),
Qb("div",DXe,["type"in e.schema?(Ub(),
Qb("span",IXe,Uh(e.schema.type),1)):ny("",!0),"format"in e.schema?(Ub(),
Qb("span",MXe,Uh(e.schema.format),1)):ny("",!0),"minimum"in e.schema?(Ub(),
Qb("span",NXe,"min: "+Uh(e.schema.minimum),1)):ny("",!0),"maximum"in e.schema?(Ub(),
Qb("span",RXe,"max: "+Uh(e.schema.maximum),1)):ny("",!0),"default"in e.schema?(Ub(),
Qb("span",LXe,"default: "+Uh(e.schema.default),1)):ny("",!0)])):ny("",!0),e.description&&!n.value?(Ub(),
Hb(xm(mre),{key:2,class:"max-w-[16rem]",value:e.description
},null,8,["value"])):ny("",!0)])])),default:ig((()=>[Gb("button",{
"aria-label":n.value?"Input is invalid":"More Information",
class:"text-c-2 hover:text-c-1 hover:bg-b-2 rounded p-1",
role:n.value?"alert":"none",type:"button"},[n.value?(Ub(),Hb(xm(a$),{key:0,
class:"text-orange size-3.5 brightness-90 hover:brightness-75"
})):(Ub(),Hb(xm(mA),{key:1,class:"text-c-2 hover:text-c-1 size-3.5"
}))],8,CXe)])),_:1}))}}),jXe=sae(BXe,[["__scopeId","data-v-f2ab7aa3"]]),UXe={
class:"group contents"};const zXe=sae({},[["render",function(e,t){
return Ub(),Qb("tr",UXe,[kv(e.$slots,"default")])}]]),FXe=Qg({inheritAttrs:!1,
__name:"DataTableCell",props:{is:{default:"td"}},setup(e){const{cx:t}=zS()
;return(n,r)=>(Ub(),
Hb(bv(e.is),iy(xm(t)("box-content max-h-8 min-h-8 min-w-8 border-l-0 border-t border-b-0 border-r flex text-base last:border-r-0 group-last:border-b-transparent p-0 m-0 relative"),{
class:"group-[.alert]:bg-b-alert group-[.error]:bg-b-danger"}),{
default:ig((()=>[kv(n.$slots,"default")])),_:3},16))}
}),ZXe=["checked","disabled"],QXe=Qg({__name:"DataTableCheckbox",props:{
modelValue:{type:Boolean},disabled:{type:Boolean},align:{default:"center"}},
emits:["update:modelValue"],setup(e){const t=jS({
base:"w-8 h-8 flex items-center justify-center text-b-2 peer-checked:text-c-1 pointer-events-none absolute",
variants:{align:{left:"left-0",center:"centered"}}});return(n,r)=>(Ub(),Hb(FXe,{
class:"group/cell relative flex min-w-8"},{default:ig((()=>[Gb("input",{
checked:e.modelValue,
class:"peer absolute inset-0 cursor-pointer opacity-0 disabled:cursor-default",
disabled:!!e.disabled,type:"checkbox",
onChange:r[0]||(r[0]=e=>n.$emit("update:modelValue",e.target.checked))
},null,40,ZXe),Gb("div",{class:Ih(xm(t)({align:e.align}))},[Gb("div",{
class:Ih(["absolute m-auto size-3/4 rounded border-[1px] opacity-0",!e.disabled&&"group-has-[:focus-visible]/cell:border-c-accent group-hover:opacity-100 group-has-[:focus-visible]/cell:opacity-100"])
},null,2),Yb(xm(Gne),{icon:"Checkmark",size:"xs",thickness:"2.5"})],2)])),_:1}))
}}),HXe={
class:"text-c-2 filemask flex w-full max-w-[100%] items-center justify-center overflow-hidden p-1"
},VXe={key:1,class:"p-0.5"},qXe=Qg({__name:"RequestTableRow",props:{data:{},
hasCheckboxDisabled:{type:Boolean},invalidParams:{},label:{},environment:{},
showUploadButton:{type:Boolean}},
emits:["upsertRow","deleteRow","uploadFile","removeFile","navigate"],
setup(e,{emit:t}){
const n=t,r=bm(e.data.name??""),o=bm(Q_e(e.data.value)??""),a=bm(e.data.isDisabled??!1)
;mg((()=>e.data.name),(e=>r.value=e??"")),
mg((()=>e.data.value),(e=>o.value=Q_e(e)??"")),
mg((()=>e.data.isDisabled),(e=>a.value=e??!1))
;const i=Sy((()=>o.value instanceof File)),s=Sy((()=>(i.value?EXe(o.value):o.value)??"")),l=Sy((()=>e.data.schema?.default)),c=Sy((()=>e.data.schema?.enum)),u=Sy((()=>e.data.schema&&"minimum"in e.data.schema?e.data.schema.minimum:void 0)),d=Sy((()=>e.data.schema&&"maximum"in e.data.schema?e.data.schema.maximum:void 0)),p=Sy((()=>e.data.schema&&"type"in e.data.schema?e.data.schema.type:void 0)),h=Sy((()=>AXe(e.data.schema,o.value))),f=e=>{
void 0!==e.name&&(r.value=e.name),
void 0!==e.value&&(o.value=e.value),a.value=e.isDisabled??!1,n("upsertRow",{
name:r.value,value:o.value,isDisabled:a.value})};return(t,m)=>(Ub(),Hb(xm(zXe),{
id:e.data.name,class:Ih({alert:!1===h.value.ok,
error:!1===h.value.ok&&e.invalidParams?.has(e.data.name)})},{
default:ig((()=>[Yb(xm(QXe),{class:"!border-r",
disabled:e.hasCheckboxDisabled??!1,modelValue:!a.value,
"onUpdate:modelValue":m[0]||(m[0]=e=>f({isDisabled:!e}))
},null,8,["disabled","modelValue"]),Yb(xm(FXe),null,{
default:ig((()=>[Yb(xm(YVe),{"aria-label":`${e.label} Key`,
disableCloseBrackets:"",disabled:e.data.isReadonly,disableEnter:"",
disableTabIndent:"",environment:e.environment,lineWrapping:"",
modelValue:r.value,placeholder:"Key",required:!!e.data.isRequired,
onSelectVariable:m[1]||(m[1]=e=>f({name:e})),
"onUpdate:modelValue":m[2]||(m[2]=e=>f({name:e}))
},null,8,["aria-label","disabled","environment","modelValue","required"])])),_:1
}),Yb(xm(FXe),null,{default:ig((()=>[Yb(xm(YVe),{
"aria-label":`${e.label} Value`,
class:"pr-6 group-hover:pr-10 group-has-[.cm-focused]:pr-10",default:l.value,
disableCloseBrackets:"",disabled:e.data.isReadonly,disableEnter:"",
disableTabIndent:"",enum:c.value??[],environment:e.environment,
examples:e.data.schema?.examples?.map((e=>String(e)))??[],
linethrough:e.data.isOverridden,lineWrapping:"",max:d.value,min:u.value,
modelValue:s.value,placeholder:"Value",type:p.value,
"onUpdate:modelValue":m[5]||(m[5]=e=>f({value:e}))},{
icon:ig((()=>[!e.data.name&&!o.value||e.data.isRequired||!0===e.data.isReadonly?ny("",!0):(Ub(),
Hb(xm(WS),{key:0,
class:"text-c-2 hover:text-c-1 hover:bg-b-2 z-context -mr-0.5 hidden h-fit rounded p-1 group-hover:flex group-has-[.cm-focused]:flex",
size:"sm",variant:"ghost",onClick:m[3]||(m[3]=e=>n("deleteRow"))},{
default:ig((()=>[Yb(xm(KC),{class:"size-3.5"})])),_:1
})),void 0!==e.data.globalRoute?(Ub(),Hb(xm(ure),{key:1,
class:"text-c-2 hover:text-c-1 hover:bg-b-2 z-context -mr-0.5 h-fit",
icon:xm(zE),
label:"Global cookies are shared across the whole workspace. Click to navigate.",
size:"xs",tooltip:"top",variant:"ghost",
onClick:m[4]||(m[4]=t=>n("navigate",e.data.globalRoute))
},null,8,["icon"])):ny("",!0),e.data.isReadonly?(Ub(),Hb(jXe,{key:2,
description:"This is a readonly property and you can not modify it! If you want to change it you have to override it or disable it using the checkbox",
value:null})):e.data.schema?(Ub(),Hb(jXe,{key:3,description:e.data.description,
schema:e.data.schema,value:o.value
},null,8,["description","schema","value"])):ny("",!0)])),_:1
},8,["aria-label","default","disabled","enum","environment","examples","linethrough","max","min","modelValue","type"])])),
_:1}),e.showUploadButton?(Ub(),Hb(xm(FXe),{key:0,
class:"group/upload flex items-center justify-center whitespace-nowrap"},{
default:ig((()=>[i.value?(Ub(),Qb(Mb,{key:0
},[Gb("div",HXe,[Gb("span",null,Uh(s.value),1)]),Gb("button",{
class:"bg-b-2 centered-x centered-y absolute hidden w-[calc(100%_-_8px)] rounded p-0.5 text-center text-xs font-medium group-hover/upload:block",
type:"button",onClick:m[6]||(m[6]=e=>n("removeFile"))
}," Delete ")],64)):(Ub(),Qb("div",VXe,[Yb(xm(WS),{
class:"bg-b-2 hover:bg-b-3 text-c-2 h-fit border-0 py-px shadow-none",size:"sm",
variant:"outlined",onClick:m[7]||(m[7]=e=>n("uploadFile"))},{
default:ig((()=>[m[8]||(m[8]=Gb("span",null,"Select File",-1)),Yb(xm(Gne),{
class:"ml-1",icon:"Upload",size:"xs",thickness:"2.5"})])),_:1})]))])),_:1
})):ny("",!0)])),_:1},8,["id","class"]))}}),WXe=["role"],XXe={key:0,
class:"sr-only"},GXe=Qg({__name:"DataTable",props:{columns:{},scroll:{
type:Boolean},presentational:{type:Boolean}},setup(e){const{cx:t}=zS()
;return(n,r)=>(Ub(),
Qb("div",Mh(Kb(xm(t)(e.scroll?"overflow-x-auto custom-scroll":"overflow-visible","scalar-data-table"))),[Gb("table",{
class:Ih(["mb-0 grid min-h-8 auto-rows-auto",{"w-max min-w-full":e.scroll}]),
role:e.presentational?"presentation":"table",style:Ah({
gridTemplateColumns:e.columns.map((e=>e||"1fr")).join(" ")})
},[n.$slots.caption?(Ub(),
Qb("caption",XXe,[kv(n.$slots,"caption")])):ny("",!0),kv(n.$slots,"default")],14,WXe)],16))
}}),YXe=Qg({__name:"DataTableHeader",setup(e){const{cx:t}=zS()
;return(e,n)=>(Ub(),Hb(FXe,iy({is:"th"
},xm(t)("items-center font-medium px-2 min-w-0 -outline-offset-1")),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}}),KXe=Qg({
__name:"RequestTable",props:{data:{},hasCheckboxDisabled:{type:Boolean},
invalidParams:{},label:{},showUploadButton:{type:Boolean},
showAddRowPlaceholder:{type:Boolean,default:!0},environment:{}},
emits:["upsertRow","deleteRow","uploadFile","removeFile","navigate"],
setup(e,{emit:t}){
const n=t,r=Sy((()=>e.showUploadButton?["36px","","","auto"]:["36px","",""])),o=Sy((()=>{
if(!e.showAddRowPlaceholder)return e.data;const t=e.data.at(-1)
;return t&&""===t.name&&""===t.value?e.data:[...e.data,{name:"",value:"",
isDisabled:!0}]}));return(t,a)=>(Ub(),Hb(xm(GXe),{class:"group/table flex-1",
columns:r.value},{default:ig((()=>[Yb(xm(zXe),{class:"sr-only !block"},{
default:ig((()=>[Yb(xm(YXe),null,{
default:ig((()=>[ey(Uh(e.label)+" Enabled",1)])),_:1}),Yb(xm(YXe),null,{
default:ig((()=>[ey(Uh(e.label)+" Key",1)])),_:1}),Yb(xm(YXe),null,{
default:ig((()=>[ey(Uh(e.label)+" Value",1)])),_:1})])),_:1
}),(Ub(!0),Qb(Mb,null,wv(o.value,((t,r)=>(Ub(),Hb(qXe,{key:r,data:t,
environment:e.environment,hasCheckboxDisabled:e.hasCheckboxDisabled,
invalidParams:e.invalidParams,label:e.label,showUploadButton:e.showUploadButton,
onDeleteRow:e=>n("deleteRow",r),onNavigate:a[0]||(a[0]=e=>n("navigate",e)),
onRemoveFile:e=>n("removeFile",r),onUploadFile:e=>n("uploadFile",r),
onUpsertRow:e=>n("upsertRow",r,e)
},null,8,["data","environment","hasCheckboxDisabled","invalidParams","label","showUploadButton","onDeleteRow","onRemoveFile","onUploadFile","onUpsertRow"])))),128))])),
_:1},8,["columns"]))}}),JXe=sae(KXe,[["__scopeId","data-v-2dc74300"]])
;function eGe({multiple:e,accept:t,onChange:n,onError:r}={}){const o=bm(null)
;let a
;typeof document<"u"&&(a=document.createElement("input"),a.type="file",a.onchange=e=>{
const t=e.target;o.value=t.files,n?.(o.value)},a.onerror=()=>r?.(),a.multiple=e,
a.accept=t);return{files:im(o),open:()=>{if(!a)return r?.();a.click()}}}
const tGe=Qg({__name:"RequestBodyForm",props:{example:{},selectedContentType:{},
environment:{}},emits:["update:formValue"],setup(e,{emit:t}){const n=t,r=bm([])
;mg((()=>e.example),(t=>{
r.value=((e,t)=>!e?.value||"multipart/form-data"!==t&&"application/x-www-form-urlencoded"!==t?[]:Array.isArray(e.value)?e.value:"object"==typeof e.value&&e.value?Tje(e.value).map((([e,t])=>({
name:String(e),value:t,isDisabled:!1}))):[])(t,e.selectedContentType)}),{
immediate:!0});const o=(e,t)=>{if(e>=r.value.length)return r.value=[...r.value,{
name:"",value:"",...t,isDisabled:!1}],void n("update:formValue",r.value)
;r.value=r.value.map(((n,r)=>r===e?{...n,...t}:n)),n("update:formValue",r.value)
},a=e=>{r.value=r.value.filter(((t,n)=>n!==e)),n("update:formValue",r.value)
},i=e=>{const{open:t}=eGe({onChange:t=>{const n=t?.[0];if(n){const t=r.value[e]
;o(e,{name:t?.name||n.name,value:n})}},multiple:!1,accept:"*/*"});t()}
;return(t,n)=>"multipart/form-data"===e.selectedContentType?(Ub(),Hb(JXe,{key:0,
data:r.value,environment:e.environment,showUploadButton:"",onDeleteRow:a,
onRemoveFile:n[0]||(n[0]=e=>o(e,{value:void 0})),onUploadFile:i,onUpsertRow:o
},null,8,["data","environment"])):(Ub(),Hb(JXe,{key:1,data:r.value,
environment:e.environment,onDeleteRow:a,onUpsertRow:o
},null,8,["data","environment"]))}}),nGe=Qg({name:"ValueEmitter",props:{value:{}
},emits:["change"],setup(e,{emit:t}){const n=t
;return mg((()=>e.value),(e=>n("change",e)),{immediate:!0}),(e,t)=>null}
}),rGe=["aria-labelledby"],oGe={
class:"text-c-1 m-0 flex flex-1 items-center gap-1.5 leading-[20px]"
},aGe=["id"],iGe={key:0,class:"sr-only"},sGe={key:0,
class:"bg-b-2 text-c-2 inline-flex h-5 w-5 items-center justify-center rounded-full border text-xs font-semibold"
},lGe={class:"sr-only"},cGe={key:0,
class:"ui-not-open:hidden flex items-center gap-2 pr-0.75"},uGe=Qg({
name:"CollapsibleSection",props:{defaultOpen:{type:Boolean,default:!0},
itemCount:{default:0},isStatic:{type:Boolean}},emits:["update:modelValue"],
setup(e,{emit:t}){const n=t,r=Hg();return(t,o)=>(Ub(),Hb(xm(qx),{as:"div",
class:Ih(["group/collapse text-c-2 focus-within:text-c-1 last:ui-open:border-b-0 border-b",e.isStatic&&"last-of-type:first-of-type:border-b-0"]),
defaultOpen:e.defaultOpen,static:e.isStatic},{default:ig((({open:a})=>[Yb(nGe,{
value:a,onChange:o[0]||(o[0]=e=>n("update:modelValue",e))
},null,8,["value"]),Gb("section",{"aria-labelledby":xm(r),class:"contents"
},[Gb("div",{
class:Ih(["bg-b-2 flex items-center",e.isStatic&&"rounded-t-lg border border-b-0"])
},[Yb(xm(Wx),{
class:Ih(["hover:text-c-1 group box-content flex max-h-8 flex-1 items-center gap-2.5 overflow-hidden px-1 py-1.5 text-base font-medium outline-none md:px-1.5 xl:pr-0.5 xl:pl-2",e.isStatic&&"!pl-3"]),
disabled:e.isStatic},{default:ig((()=>[e.isStatic?ny("",!0):(Ub(),Hb(xm(Gne),{
key:0,
class:"text-c-3 group-hover:text-c-1 rounded-px ui-open:rotate-90 ui-not-open:rotate-0 outline-offset-2 group-focus-visible:outline",
icon:"ChevronRight",size:"md"})),Gb("h2",oGe,[Gb("span",{id:xm(r),
class:"contents"},[kv(t.$slots,"title",{open:a
}),a?ny("",!0):(Ub(),Qb("span",iGe," (Collapsed) "))],8,aGe),!a&&e.itemCount?(Ub(),
Qb("span",sGe,[ey(Uh(e.itemCount)+" ",1),Gb("span",lGe,"Item"+Uh(1===e.itemCount?"":"s"),1)])):ny("",!0)])])),
_:2
},1032,["class","disabled"]),t.$slots.actions?(Ub(),Qb("div",cGe,[kv(t.$slots,"actions",{
open:a})])):ny("",!0)],2),Yb(xm(Xx),iy(t.$attrs,{
class:"diclosure-panel h-full max-h-fit rounded-b"}),{
default:ig((()=>[kv(t.$slots,"default",{open:a})])),_:2},1040)],8,rGe)])),_:3
},8,["class","defaultOpen","static"]))}}),dGe={key:0,
class:"text-c-3 flex min-h-10 w-full items-center justify-center border-t p-2 text-sm"
},pGe={key:1,
class:"flex items-center justify-center overflow-hidden border-t p-1.5"},hGe={
class:"text-c-2 w-full max-w-full overflow-hidden rounded border px-1.5 py-1 text-xs whitespace-nowrap"
},fGe=Qg({__name:"RequestBody",props:{requestBody:{},exampleKey:{},title:{},
environment:{}},emits:["update:contentType","update:value","update:formValue"],
setup(e,{emit:t}){const n=t,r={"application/json":"json",
"application/xml":"xml","application/yaml":"yaml"},o={
"multipart/form-data":"Multipart Form",
"application/x-www-form-urlencoded":"Form URL Encoded",
"application/octet-stream":"Binary File","application/json":"JSON",
"application/xml":"XML","application/yaml":"YAML","application/edn":"EDN",
other:"Other",none:"None"
},a=Sy((()=>e.requestBody?.["x-scalar-selected-content-type"]?.[e.exampleKey]??Object.keys(e.requestBody?.content??{})[0]??"none"))
;mg((()=>e.requestBody?.["x-scalar-selected-content-type"]?.[e.exampleKey]),(e=>{
e||n("update:contentType",{value:a.value})}),{immediate:!0})
;const i=Object.entries(o).map((([e,t])=>({id:e,label:t}))),s=Sy({
get:()=>i.find((e=>e.id===a.value))??i.at(-1),set:e=>{n("update:contentType",{
value:e.id})}})
;const l=Sy((()=>e.requestBody&&fHe(e.requestBody,a.value,e.exampleKey))),c=Sy((()=>{
if(!l.value)return"";const e=l.value.value
;return"string"==typeof e?e:JSON.stringify(e,null,2)}))
;return(t,u)=>(Ub(),Hb(xm(uGe),null,{title:ig((()=>[ey(Uh(e.title),1)])),
default:ig((()=>[Yb(xm(GXe),{columns:[""],presentational:""},{
default:ig((()=>[Yb(xm(YXe),{
class:"relative col-span-full flex h-8 cursor-pointer items-center justify-between border-r-0 !p-0"
},{default:ig((()=>[Yb(xm(hre),{modelValue:s.value,
"onUpdate:modelValue":u[0]||(u[0]=e=>s.value=e),options:xm(i),teleport:""},{
default:ig((()=>[Yb(xm(WS),{
class:"text-c-2 hover:text-c-1 flex h-full w-fit gap-1.5 px-3 font-normal",
fullWidth:"",variant:"ghost"},{
default:ig((()=>[Gb("span",null,Uh(o[a.value]??a.value),1),Yb(xm(Gne),{
icon:"ChevronDown",size:"md"})])),_:1})])),_:1},8,["modelValue","options"])])),
_:1}),Yb(xm(zXe),null,{
default:ig((()=>["none"===a.value?(Ub(),Qb("div",dGe,[...u[5]||(u[5]=[Gb("span",null,"No Body",-1)])])):"application/octet-stream"===a.value?(Ub(),
Qb("div",pGe,[void 0!==xm(EXe)(xm(Q_e)(l.value?.value))?(Ub(),Qb(Mb,{key:0
},[Gb("span",hGe,Uh(xm(EXe)(xm(Q_e)(l.value?.value))),1),Yb(xm(WS),{
class:"bg-b-2 hover:bg-b-3 text-c-2 ml-1 border-0 shadow-none",size:"sm",
variant:"outlined",onClick:u[1]||(u[1]=e=>n("update:value",{payload:void 0,
contentType:a.value}))},{
default:ig((()=>[...u[6]||(u[6]=[ey(" Delete ",-1)])])),_:1
})],64)):(Ub(),Hb(xm(WS),{key:1,
class:"bg-b-2 hover:bg-b-3 text-c-2 border-0 shadow-none",size:"sm",
variant:"outlined",onClick:u[2]||(u[2]=()=>function(e){const{open:t}=eGe({
onChange:t=>{const n=t?.[0];n&&e(n)},multiple:!1,accept:"*/*"});t()
}((e=>n("update:value",{payload:e,contentType:a.value}))))},{
default:ig((()=>[u[7]||(u[7]=Gb("span",null,"Select File",-1)),Yb(xm(Gne),{
class:"ml-1",icon:"Upload",size:"xs",thickness:"2.5"})])),_:1
}))])):"multipart/form-data"===a.value||"application/x-www-form-urlencoded"===a.value?(Ub(),
Hb(tGe,{key:2,environment:e.environment,example:l.value,
selectedContentType:a.value,
"onUpdate:formValue":u[3]||(u[3]=e=>n("update:formValue",{payload:e,
contentType:a.value}))
},null,8,["environment","example","selectedContentType"])):(Ub(),Hb(xm(YVe),{
key:3,class:"border-t px-3",content:"",environment:e.environment,
language:r[a.value]??"plaintext",lineNumbers:"",lint:"",modelValue:c.value,
"onUpdate:modelValue":u[4]||(u[4]=e=>n("update:value",{payload:e,
contentType:a.value}))},null,8,["environment","language","modelValue"]))])),_:1
})])),_:1})])),_:1}))}}),mGe=sae(fGe,[["__scopeId","data-v-0a6f7696"]]),gGe=e=>{
const t=[],n=Array.isArray(e)?e.filter((e=>!e.isDisabled)).map((e=>[e.name,e.value])):Object.entries(e)
;for(const[r,o]of n)if(null!=o)if(o instanceof File){const e=Q_e(o);t.push({
name:r,value:`@${e.name}`})
}else if(Array.isArray(o))for(const e of o)if(e instanceof File){const n=Q_e(e)
;t.push({name:r,value:`@${n.name}`})}else t.push({name:r,value:String(e)
});else if("object"==typeof o){const e=gGe(o);for(const n of e)t.push({
name:`${r}.${n.name}`,value:n.value})}else t.push({name:r,value:String(o)})
;return t},vGe=e=>{if("header"===e.in)return{style:"simple",
explode:"explode"in e&&void 0!==e.explode&&e.explode};if("cookie"===e.in)return{
style:"form",explode:!("explode"in e)||void 0===e.explode||e.explode};const t={
path:"simple",query:"form",header:"simple",cookie:"form"
}[e.in],n="style"in e&&e.style?e.style:t;return{style:n,
explode:"explode"in e&&void 0!==e.explode?e.explode:"form"===n}},bGe=(e,t,n)=>{
const r=nHe(e,t,n);if(gHe(e,r))return;if(void 0!==r?.value)return r.value
;if(!("schema"in e)||!e.schema)return;const o="path"===e.in?{
emptyString:`{${e.name}}`}:{};return hHe(qke(e.schema),o)
},yGe=({harRequest:e,parameters:t,example:n})=>{
const r=[...e.headers],o=[...e.queryString];let a=e.url
;const i=(e=>(e??[]).map((e=>qke(e))))(t);for(const s of i){
if(!s.in||!s.name)continue;const t=bGe(s,n,void 0);if(void 0===t)continue
;const{style:i,explode:l}=vGe(s);switch(s.in){case"path":a=OGe(a,s,t,i,l);break
;case"query":if("content"in s&&s.content){
const e=Object.keys(s.content)[0]??"application/json",n=vHe(t,e);o.push({
name:s.name,value:n});break}switch(i){case"form":{const e=yHe(t,l)
;if(Array.isArray(e))for(const t of e){const e=t.key||s.name;o.push({name:e,
value:String(t.value)})}else o.push({name:s.name,value:String(e)});break}
case"spaceDelimited":{const e=wHe(t);o.push({name:s.name,value:e});break}
case"pipeDelimited":{const e=xHe(t);o.push({name:s.name,value:e});break}
case"deepObject":if(l){const e=kHe(s.name,t);for(const t of e)o.push({
name:t.key,value:t.value})}break;default:o.push({name:s.name,value:String(t)})}
break;case"header":{const e=bHe(t,l);r.push({name:s.name,value:String(e)});break
}case"cookie":{const n=OHe(t,l);if(Array.isArray(n))for(const t of n){
const n=t.key||s.name,r=null===t.value?"null":String(t.value);e.cookies.push({
name:n,value:r})}else{const t=null===n?"null":String(n);e.cookies.push({
name:s.name,value:t})}break}}}return{url:a,headers:r,queryString:o,
cookies:e.cookies}},OGe=(e,t,n,r,o)=>{switch(r){case"matrix":if(o){
if(Array.isArray(n)){const r=n.map((e=>`${t.name}=${e}`)).join(";")
;return e.replace(`{;${t.name}}`,`;${r}`)}if("object"==typeof n&&null!==n){
const r=Object.entries(n).map((([e,t])=>`${e}=${t}`)).join(";")
;return e.replace(`{;${t.name}}`,`;${r}`)}
return e.replace(`{;${t.name}}`,`;${t.name}=${n}`)}
if(Array.isArray(n))return e.replace(`{;${t.name}}`,`;${t.name}=${n.join(",")}`)
;if("object"==typeof n&&null!==n){
const r=Object.entries(n).map((([e,t])=>`${e},${t}`)).join(",")
;return e.replace(`{;${t.name}}`,`;${t.name}=${r}`)}
return e.replace(`{;${t.name}}`,`;${t.name}=${n}`);case"label":if(o){
if(Array.isArray(n))return e.replace(`{.${t.name}}`,`.${n.join(".")}`)
;if("object"==typeof n&&null!==n){
const r=Object.entries(n).map((([e,t])=>`${e}=${t}`)).join(".")
;return e.replace(`{.${t.name}}`,`.${r}`)}
return e.replace(`{.${t.name}}`,`.${n}`)}
if(Array.isArray(n))return e.replace(`{.${t.name}}`,`.${n.join(",")}`)
;if("object"==typeof n&&null!==n){
const r=Object.entries(n).map((([e,t])=>`${e},${t}`)).join(",")
;return e.replace(`{.${t.name}}`,`.${r}`)}
return e.replace(`{.${t.name}}`,`.${n}`);case"simple":{const r=bHe(n,o)
;return e.replace(`{${t.name}}`,String(r))}default:
return e.replace(`{${t.name}}`,String(n))}
},wGe=({includeDefaultHeaders:e=!1,operation:t,contentType:n,method:r,path:o,server:a=null,example:i,securitySchemes:s,globalCookies:l})=>{
const c=e?tHe({method:r,operation:t,exampleKey:i??"default",
hideDisabledHeaders:!0
}).filter((e=>!e.isOverridden)):[],u=t["x-scalar-disable-parameters"]?.["global-cookies"]?.[i??"default"]??{},d=((e,t)=>{
if(!e?.url)return t;const n=e.url;if(e.variables){
const r=Object.entries(e.variables).reduce(((e,[t,n])=>(void 0!==n.default&&(e[t]=n.default),
e)),{}),o=LH(n,r);return QH(o,t)}return QH(n,t)})(a,o),p={method:r,url:d,
headers:c.map((e=>({name:e.name,value:e.defaultValue}))),queryString:[],
postData:void 0,httpVersion:"HTTP/1.1",cookies:[],headersSize:-1,bodySize:-1}
;if(t.parameters){const{url:e,headers:n,queryString:r,cookies:o}=yGe({
harRequest:p,parameters:t.parameters,example:i}),a=l?.filter((t=>mHe({cookie:t,
url:e,disabledGlobalCookies:u})))?.map((e=>({name:e.name,value:e.value})))??[]
;p.url=e,p.headers=n,p.queryString=r,p.cookies=[...a,...o]}
const h=qke(t.requestBody);if(h?.content){
const e=(({requestBody:e,contentType:t,example:n})=>{
const r=t||Object.keys(e.content)[0]||"",o="multipart/form-data"===r||"application/x-www-form-urlencoded"===r,a="application/xml"===r,i=nHe(e,n,t)?.value
;if(typeof i<"u")return o&&"object"==typeof i&&null!==i?{mimeType:r,
params:gGe(i)}:a&&"object"==typeof i&&null!==i?{mimeType:r,text:_H(i)}:{
mimeType:r,text:"string"==typeof i?i:JSON.stringify(i)}
;const s=qke(e.content[r]?.schema);if(typeof s<"u"){const e=hHe(s,{mode:"write",
xml:a});if(void 0!==e)return o&&"object"==typeof e&&null!==e?{mimeType:r,
params:gGe(e)}:a&&"object"==typeof e&&null!==e?{mimeType:r,text:_H(e)}:{
mimeType:r,text:"string"==typeof e?e:JSON.stringify(e)}}})({requestBody:h,
contentType:n,example:i})
;if(e&&(p.postData=e,p.bodySize=e.text?.length??-1,e.mimeType)){
const t=p.headers.find((e=>"content-type"===e.name.toLowerCase()))
;t&&!t.value?t.value=e.mimeType:t||p.headers.push({name:"Content-Type",
value:e.mimeType})}}if(s){const{headers:e,queryString:t,cookies:n}=(e=>{
const t={headers:[],queryString:[],cookies:[]}
;for(const n of e)if("apiKey"!==n.type){if("http"!==n.type){
if("oauth2"===n.type&&n.flows){
const e=Object.values(n.flows).find((e=>e["x-scalar-secret-token"]))?.["x-scalar-secret-token"]||"YOUR_SECRET_TOKEN"
;t.headers.push({name:"Authorization",value:`Bearer ${e}`})}
}else if("basic"===n.scheme){
const e=`${n["x-scalar-secret-username"]||""}:${n["x-scalar-secret-password"]||""}`,r=":"===e?"username:password":BHe(e)
;t.headers.push({name:"Authorization",value:`Basic ${r}`})
}else if("bearer"===n.scheme){
const e=n["x-scalar-secret-token"]||"YOUR_SECRET_TOKEN";t.headers.push({
name:"Authorization",value:`Bearer ${e}`})}}else{
const e=n["x-scalar-secret-token"]||"YOUR_SECRET_TOKEN";if(!n.name)continue
;const r={name:n.name,value:e};switch(n.in){case"header":t.headers.push(r);break
;case"query":t.queryString.push(r);break;case"cookie":t.cookies.push(r)}}
return t})(s);p.headers.push(...e),p.queryString.push(...t),p.cookies.push(...n)
}let f=0
;for(const m of p.headers)f+=(m.name?.length??0)+2+(m.value?.length??0)+2
;return p.headersSize=f,p
},xGe="ws://replace.me",kGe=({clientId:e,customCodeSamples:t,includeDefaultHeaders:n=!1,operation:r,method:o,path:a,example:i,contentType:s,server:l,securitySchemes:c,globalCookies:u})=>{
try{if(!e)return""
;if(e.startsWith("custom"))return t.find((t=>hXe(t)===e))?.source??"Custom example not found"
;const d=wGe({operation:r,contentType:s,method:o,path:a,server:l,
securitySchemes:c,example:i,globalCookies:u,includeDefaultHeaders:n
}),[p,h]=e.split("/"),[f,m]=((t,r,o)=>{try{
if(!o.url)return[new Error("Please enter a URL to see a code snippet"),null]
;const e=o.url.startsWith("/")?"":"/";try{new URL(o.url)}catch(n){
console.error("[getSnippet] Invalid URL",n),o.url=`${xGe}${e}${o.url}`}
if("application/json"===o.postData?.mimeType)try{
JSON.parse(o.postData.text||"{}")}catch(n){
return console.error("[getSnippet] Invalid JSON body",n),
[new Error("Invalid JSON body"),null]}const a=t.replace("javascript","js")
;if(pXe().hasPlugin(a,r)){const t=pXe().print(a,r,o)
;return t?[null,t.replace(`${xGe}${e}`,"")]:[new Error("Error generating snippet"),null]
}}catch(e){
return console.error("[getSnippet] Error generating snippet",e),[new Error("Error generating snippet"),null]
}return[new Error("No snippet found"),null]})(p,h,d)
;return f?(console.error("[generateCodeSnippet]",f),
f.message??"Error generating code snippet"):m}catch(Kw){
return console.error("[generateCodeSnippet]",Kw),"Error generating code snippet"
}},SGe=(e,t)=>e.length?[{label:"Code Examples",options:e.map((e=>{
const t=hXe(e),n=e.label||e.lang||t;return{id:t,lang:e.lang||"plaintext",
title:n,label:n,clientKey:"custom"}}))
},...t]:t,_Ge=e=>["x-custom-examples","x-codeSamples","x-code-samples"].flatMap((t=>e[t]??[])),TGe=e=>e.flatMap((e=>"apiKey"===e.type?e["x-scalar-secret-token"]:"http"===e?.type?[e["x-scalar-secret-token"],e["x-scalar-secret-username"],e["x-scalar-secret-password"],BHe(`${e["x-scalar-secret-username"]}:${e["x-scalar-secret-password"]}`)]:"oauth2"===e.type?Object.values(e.flows).map((e=>e["x-scalar-secret-token"])):[])).filter(Boolean),EGe="shell/curl",AGe=e=>LQe.includes(e),CGe=(e,t)=>{
const n=e[0]?.options[0];if(t)for(const r of e){
const e=r.options.find((e=>e.id===t));if(e)return e}
if(!n?.id.startsWith("custom"))for(const r of e){
const e=r.options.find((e=>e.id===EGe));if(e)return e}return n},$Ge={
class:"flex flex-1"},PGe={class:"overflow-hidden"},DGe=Qg({
__name:"RequestCodeSnippet",props:{integration:{},clientOptions:{},
selectedClient:{},selectedServer:{default:null},selectedContentType:{},
selectedExample:{},eventBus:{},securitySchemes:{},method:{},path:{},
operation:{},fallback:{type:Boolean},generateLabel:{type:Function},isWebhook:{
type:Boolean},globalCookies:{}},setup(e){
const t=Sy((()=>_Ge(e.operation))),n=Sy((()=>SGe(t.value,e.clientOptions))),r=bm(CGe(n.value,e.selectedClient))
;mg((()=>e.selectedClient),(e=>{const t=CGe(n.value,e);t&&(r.value=t)}))
;const o=Sy((()=>TGe(e.securitySchemes??[]))),a=Sy((()=>kGe({
clientId:r.value?.id,customCodeSamples:t.value,operation:e.operation,
method:e.method,path:e.path,contentType:e.selectedContentType,
server:e.selectedServer,securitySchemes:e.securitySchemes,
example:e.selectedExample,globalCookies:e.globalCookies,
includeDefaultHeaders:"client"===e.integration})))
;return(t,i)=>(Ub(),Hb(xm(uGe),{class:"group/preview w-full border-t",
defaultOpen:!1},{title:ig((()=>[...i[1]||(i[1]=[ey("Code Snippet",-1)])])),
actions:ig((()=>[Gb("div",$Ge,[Yb(xm(HK),{modelValue:r.value,options:n.value,
placement:"bottom-end","onUpdate:modelValue":i[0]||(i[0]=t=>(t=>{
r.value=t,t&&!t.id.startsWith("custom")&&e.eventBus.emit("workspace:update:selected-client",t.id)
})(t))},{default:ig((({open:e})=>[Yb(xm(WS),{
class:"text-c-2 hover:text-c-1 flex h-full w-fit gap-1.5 px-0.5 py-0 text-base font-normal",
"data-testid":"client-picker",variant:"ghost"},{
default:ig((()=>[ey(Uh(r.value?.title)+" ",1),Yb(xm(L_),{
class:Ih(["mt-0.25 size-3 transition-transform duration-100",e&&"rotate-180"]),
weight:"bold"},null,8,["class"])])),_:2},1024)])),_:1
},8,["modelValue","options"])])])),default:ig((()=>[Yb(xm(v2),null,{
default:ig((()=>[Yb(xm(GXe),{columns:[""],presentational:""},{
default:ig((()=>[Yb(xm(zXe),null,{default:ig((()=>[Gb("div",PGe,[Yb(xm(LG),{
class:"text-base -outline-offset-2",content:a.value,hideCredentials:o.value,
lang:r.value?.lang??"plaintext",lineNumbers:""
},null,8,["content","hideCredentials","lang"])])])),_:1})])),_:1})])),_:1})])),
_:1}))}}),IGe={
class:"text-c-2 request-meta-buttons flex whitespace-nowrap opacity-0 group-hover/params:opacity-100 has-[:focus-visible]:opacity-100"
},MGe={class:"sr-only"},NGe=Qg({__name:"RequestParams",props:{rows:{},
exampleKey:{},title:{},label:{},invalidParams:{},globalRoute:{},
showAddRowPlaceholder:{type:Boolean,default:!0},environment:{},eventBus:{}},
emits:["upsert","delete","deleteAll"],setup(e,{emit:t}){
const n=t,r=Sy((()=>e.rows.length>1)),o=(e,t)=>{const{value:r,...o}=t
;r instanceof File||n("upsert",e,{...o,value:r??""})}
;return(t,a)=>(Ub(),Hb(xm(uGe),{class:"group/params",itemCount:e.rows.length},{
title:ig((()=>[ey(Uh(e.title),1)])),
actions:ig((()=>[Gb("div",IGe,[r.value?(Ub(),Hb(xm(Uoe),{key:0,
content:"Clear optional parameters",placement:"left"},{
default:ig((()=>[Yb(xm(WS),{class:"pr-0.75 pl-1 transition-none",size:"sm",
variant:"ghost",onClick:a[0]||(a[0]=BO((e=>n("deleteAll")),["stop"]))},{
default:ig((()=>[a[3]||(a[3]=ey(" Clear ",-1)),Gb("span",MGe,"All "+Uh(e.title),1)])),
_:1})])),_:1})):ny("",!0)])])),default:ig((()=>[Yb(JXe,{class:"flex-1",
columns:["32px","",""],data:e.rows,environment:e.environment,
exampleKey:e.exampleKey,globalRoute:e.globalRoute,invalidParams:e.invalidParams,
label:e.label,showAddRowPlaceholder:e.showAddRowPlaceholder,
onDeleteRow:a[1]||(a[1]=e=>n("delete",{index:e})),
onNavigate:a[2]||(a[2]=t=>e.eventBus.emit("ui:route:page",{name:t})),
onUpsertRow:o
},null,8,["data","environment","exampleKey","globalRoute","invalidParams","label","showAddRowPlaceholder"])])),
_:1},8,["itemCount"]))}
}),RGe=(e,t,n,{context:r,defaultParameters:o=0,globalParameters:a=0})=>{
const i=o+a;return{delete:e=>{const o=r[e.index]?.originalParameter
;o&&t.emit("operation:delete:parameter",{originalParameter:o,meta:n},{
skipUnpackProxy:!0})},deleteAll:()=>t.emit("operation:delete-all:parameters",{
type:e,meta:n}),upsert:(s,l)=>{const c=r[s];if(s<o+a){
const r=s<o?"default":"global"
;return t.emit("operation:update:extra-parameters",{type:r,in:e,meta:{...n,
name:c?.name?.toLowerCase?.()??"NON_VALID"},payload:{isDisabled:l.isDisabled??!1
}})}if(s>=i)return t.emit("operation:upsert:parameter",{type:e,payload:l,
originalParameter:c?.originalParameter??null,meta:n},{skipUnpackProxy:!0,
debounceKey:`update:parameter-${e}-${s-i}`})}}
},LGe=e=>"schema"in e&&e.schema?qke(e.schema):qke((e=>{
if("content"in e&&e.content){const t=Object.keys(e.content)
;return 1!==t.length?void 0:e.content[t[0]]}
})(e)?.schema),BGe=(e,t,n)=>e.reduce(((e,r)=>{const o=n?n(r):r
;return(e[r[t]]??=[]).push(o),e}),{}),jGe={
class:"text-c-2 mb-4 text-sm leading-normal"},UGe={
class:"flex justify-between gap-2"},zGe=Qg({__name:"DeleteRequestAuthModal",
props:{state:{},label:{}},emits:["close","delete"],setup(e,{emit:t}){
const n=t,r=()=>{n("delete")};return(t,o)=>(Ub(),Hb(xm(eae),{size:"xxs",
state:e.state,title:"Delete Security Scheme"},{
default:ig((()=>[Gb("p",jGe," This cannot be undone. You're about to delete the "+Uh(e.label)+" security scheme from the collection. ",1),Gb("div",UGe,[Yb(xm(WS),{
class:"flex h-8 cursor-pointer items-center gap-1.5 px-3 shadow-none focus:outline-none",
type:"button",variant:"outlined",onClick:o[0]||(o[0]=e=>n("close"))},{
default:ig((()=>[...o[1]||(o[1]=[ey(" Cancel ",-1)])])),_:1}),Yb(xm(WS),{
class:"flex h-8 cursor-pointer items-center gap-1.5 px-3 shadow-none focus:outline-none",
type:"submit",onClick:r},{default:ig((()=>[ey(" Delete "+Uh(e.label),1)])),_:1
})])])),_:1},8,["state"]))}}),FGe={apiKeyCookie:{label:"API Key in Cookies",
payload:{type:"apiKey",in:"cookie",name:"apiKeyCookie",
"x-scalar-secret-token":""}},apiKeyHeader:{label:"API Key in Headers",payload:{
type:"apiKey",in:"header",name:"apiKeyHeader","x-scalar-secret-token":""}},
apiKeyQuery:{label:"API Key in Query Params",payload:{type:"apiKey",in:"query",
name:"apiKeyQuery","x-scalar-secret-token":""}},httpBasic:{label:"HTTP Basic",
payload:{type:"http",scheme:"basic","x-scalar-secret-token":"",
"x-scalar-secret-username":"","x-scalar-secret-password":""}},httpBearer:{
label:"HTTP Bearer",payload:{type:"http",scheme:"bearer",
"x-scalar-secret-token":"","x-scalar-secret-username":"",
"x-scalar-secret-password":""}},oauth2Implicit:{label:"Oauth2 Implicit Flow",
payload:{type:"oauth2",flows:{implicit:{authorizationUrl:"",refreshUrl:"",
"x-scalar-secret-client-id":"","x-scalar-secret-redirect-uri":"",
"x-scalar-secret-token":"",scopes:{}}}}},oauth2Password:{
label:"Oauth2 Password Flow",payload:{type:"oauth2",flows:{password:{
tokenUrl:"",refreshUrl:"","x-scalar-secret-client-id":"",
"x-scalar-secret-username":"","x-scalar-secret-password":"",
"x-scalar-secret-token":"","x-scalar-secret-client-secret":"",scopes:{}}}}},
oauth2ClientCredentials:{label:"Oauth2 Client Credentials",payload:{
type:"oauth2",flows:{clientCredentials:{tokenUrl:"",refreshUrl:"",
"x-scalar-secret-client-id":"","x-scalar-secret-token":"",
"x-scalar-secret-client-secret":"",scopes:{}}}}},oauth2AuthorizationFlow:{
label:"Oauth2 Authorization Code",payload:{type:"oauth2",flows:{
authorizationCode:{authorizationUrl:"",tokenUrl:"",refreshUrl:"",
"x-scalar-secret-client-id":"","x-scalar-secret-client-secret":"",
"x-scalar-secret-token":"","x-scalar-secret-redirect-uri":"","x-usePkce":"no",
scopes:{}}}}}},ZGe=({name:e,type:t,value:n})=>({id:o_e(JSON.stringify(n)),
label:"openIdConnect"===t?`${e} (coming soon)`:e,value:n,isDeletable:!0
}),QGe=e=>ZGe({type:"complex",name:Object.keys(e).join(" & "),value:e
}),HGe=(e,t)=>{const n=Object.keys(e);if(n.length>1)return QGe(e);if(n[0]){
const r=qke(t[n[0]]);return r?ZGe({name:n[0],type:r.type,value:e}):void 0}
},VGe={class:"flex gap-2"},qGe={class:"flex max-h-8 flex-1"},WGe=Qg({
__name:"CommandActionForm",props:{loader:{},disabled:{type:Boolean,default:!1}},
emits:["submit","cancel","back"],setup(e){const{cx:t}=zS()
;return(n,r)=>(Ub(),Qb("form",{class:"flex w-full flex-col gap-3",
onKeydown:r[0]||(r[0]=UO(BO((()=>{}),["stop"]),["enter"])),
onSubmit:r[1]||(r[1]=BO((t=>!e.disabled&&n.$emit("submit")),["prevent","stop"]))
},[Gb("div",Mh(Kb(xm(t)("relative flex min-h-20 flex-col rounded"))),[kv(n.$slots,"default")],16),Gb("div",VGe,[Gb("div",qGe,[kv(n.$slots,"options")]),Yb(xm(WS),{
class:"max-h-8 px-3 text-xs",disabled:e.disabled,loader:e.loader,type:"submit"
},{
default:ig((()=>[kv(n.$slots,"submit",{},(()=>[r[2]||(r[2]=ey("Continue",-1))]))])),
_:3},8,["disabled","loader"])])],32))}}),XGe=["placeholder"],GGe=Qg({
inheritAttrs:!1,__name:"CommandActionInput",props:{modelValue:{},placeholder:{},
autofocus:{type:Boolean}},emits:["update:modelValue","onDelete"],
setup(e,{emit:t}){const n=e,r=t,o=bm(null);iv((()=>Xm((()=>{
n.autofocus&&o.value?.focus()}))));const a=Sy({get:()=>n.modelValue??"",
set:e=>r("update:modelValue",e)});return(e,t)=>sg((Ub(),Qb("textarea",iy({
id:"command-action-input",ref_key:"input",ref:o,
"onUpdate:modelValue":t[0]||(t[0]=e=>a.value=e),
class:"min-h-8 w-full flex-1 resize-none border border-transparent py-1.5 pl-8.5 text-sm outline-none focus:border-b-1",
placeholder:n.placeholder??"",wrap:"hard"},e.$attrs,{
onKeydown:[t[1]||(t[1]=UO((e=>function(e){
""===a.value&&(e.preventDefault(),e.stopPropagation(),r("onDelete",e))
}(e)),["delete"])),t[2]||(t[2]=UO((e=>function(e){
if(e.shiftKey||!e.target)return;e.preventDefault()
;const t=e.target,n=new Event("submit",{cancelable:!0});t.form?.dispatchEvent(n)
}(e)),["enter"]))]}),null,16,XGe)),[[TO,a.value]])}}),YGe={
class:"flex h-8 items-start gap-2 text-sm"},KGe={
class:"flex h-8 items-start gap-2 text-sm"},JGe=Qg({
__name:"OAuthScopesAddModal",props:{state:{},scopes:{}},
emits:["cancel","submit"],setup(e,{emit:t}){const n=t,r=bm({name:"",
description:""}),{toast:o}=CG(),a=()=>{
r.value.name?(n("submit",r.value),e.state.hide()):o("Please fill in the name before adding a scope.","error")
};return mg((()=>e.state.open),(e=>{e&&(r.value={name:"",description:""})
})),(t,o)=>(Ub(),Hb(xm(eae),{size:"xs",state:e.state,title:"Add Scope"},{
default:ig((()=>[Yb(WGe,{
disabled:!r.value.name||e.scopes.includes(r.value.name),
onCancel:o[2]||(o[2]=e=>n("cancel")),onSubmit:a},{
submit:ig((()=>[...o[5]||(o[5]=[ey("Add Scope",-1)])])),
default:ig((()=>[Gb("div",YGe,[o[3]||(o[3]=ey(" Name: ",-1)),Yb(GGe,{
modelValue:r.value.name,"onUpdate:modelValue":o[0]||(o[0]=e=>r.value.name=e),
autofocus:"",class:"!p-0",placeholder:"read:user"
},null,8,["modelValue"])]),Gb("div",KGe,[o[4]||(o[4]=ey(" Description: ",-1)),Yb(GGe,{
modelValue:r.value.description,
"onUpdate:modelValue":o[1]||(o[1]=e=>r.value.description=e),class:"!p-0",
placeholder:"Read user data"},null,8,["modelValue"])])])),_:1
},8,["disabled"])])),_:1},8,["state"]))}
}),eYe=sae(JGe,[["__scopeId","data-v-43df1726"]]),tYe=Qg({inheritAttrs:!1,
__name:"DataTableCell",props:{is:{default:"td"}},setup(e){const{cx:t}=zS()
;return(n,r)=>(Ub(),
Hb(bv(e.is),iy(xm(t)("box-content max-h-8 min-h-8 min-w-8 border-l-0 border-t border-b-0 border-r flex text-base last:border-r-0 group-last:border-b-transparent p-0 m-0 relative"),{
class:"group-[.alert]:bg-b-alert group-[.error]:bg-b-danger"}),{
default:ig((()=>[kv(n.$slots,"default")])),_:3},16))}}),nYe={
class:"group contents"};const rYe=sae({},[["render",function(e,t){
return Ub(),Qb("tr",nYe,[kv(e.$slots,"default")])
}]]),oYe=["checked","disabled"],aYe=Qg({__name:"DataTableCheckbox",props:{
modelValue:{type:Boolean},disabled:{type:Boolean},align:{default:"center"}},
emits:["update:modelValue"],setup(e){const t=jS({
base:"w-8 h-8 flex items-center justify-center text-border peer-checked:text-c-1 pointer-events-none absolute",
variants:{align:{left:"left-0",center:"centered"}}});return(n,r)=>(Ub(),Hb(tYe,{
class:"group/cell relative flex min-w-8"},{default:ig((()=>[Gb("input",{
checked:e.modelValue,
class:"peer absolute inset-0 cursor-pointer opacity-0 disabled:cursor-default",
disabled:!!e.disabled,type:"checkbox",
onChange:r[0]||(r[0]=e=>n.$emit("update:modelValue",e.target.checked))
},null,40,oYe),Gb("div",{class:Ih(xm(t)({align:e.align}))},[Gb("div",{
class:Ih(["absolute m-auto size-3/4 rounded border-[1px] opacity-0",!e.disabled&&"group-has-[:focus-visible]/cell:border-c-accent group-hover/cell:opacity-100 group-has-[:focus-visible]/cell:opacity-100"])
},null,2),Yb(xm(Gne),{icon:"Checkmark",size:"xs",thickness:"2.5"})],2)])),_:1}))
}}),iYe={class:"flex h-fit w-full"},sYe={class:"flex-1"},lYe={
class:"flex items-center gap-1.75"},cYe={class:"grid auto-rows-auto",style:{
gridTemplateColumns:"1fr auto"}},uYe={class:"font-code text-xs"},dYe={key:0
},pYe=Qg({__name:"OAuthScopesInput",props:{flowType:{},flow:{},selectedScopes:{}
},emits:["update:selectedScopes"],setup(e,{emit:t}){
const n=t,r=Sy((()=>Object.entries(e.flow?.scopes??{}).map((([e,t])=>({id:e,
label:e,description:t
}))))),o=Sy((()=>e.selectedScopes.length===Object.keys(e.flow?.scopes??{}).length))
;function a(t,r){if(r)return n("update:selectedScopes",{
scopes:Array.from(new Set([...e.selectedScopes,t]))})
;n("update:selectedScopes",{scopes:e.selectedScopes.filter((e=>e!==t))})}
const i=()=>n("update:selectedScopes",{scopes:Object.keys(e.flow?.scopes??{})
}),s=()=>n("update:selectedScopes",{scopes:[]}),l=Koe()
;return(t,c)=>(Ub(),Hb(xm(tYe),{
class:"h-auto !max-h-[initial] min-h-8 items-center"},{
default:ig((()=>[Gb("div",iYe,[c[5]||(c[5]=Gb("div",{
class:"text-c-1 h-full items-center"},null,-1)),Yb(xm(qx),{as:"div",
class:"bl flex w-full flex-col"},{default:ig((()=>[Yb(xm(Wx),{
class:Ih(["group/scopes-accordion hover:text-c-1 flex h-auto min-h-8 cursor-pointer items-center gap-1.5 pr-2.25 pl-3 text-left",(e.selectedScopes.length||0)>0?"text-c-1":"text-c-3"])
},{
default:ig((({open:t})=>[Gb("div",sYe," Scopes Selected "+Uh(e.selectedScopes.length||0)+" / "+Uh(Object.keys(e.flow?.scopes??{}).length||0),1),Gb("div",lYe,[Yb(xm(WS),{
class:"pr-0.75 pl-1 transition-none",size:"sm",variant:"ghost",
onClick:c[0]||(c[0]=BO((e=>xm(l).show()),["stop"]))},{
default:ig((()=>[...c[2]||(c[2]=[ey(" Add Scope ",-1)])])),_:1
}),o.value?(Ub(),Hb(xm(WS),{key:0,class:"pr-0.75 pl-1 transition-none",
size:"sm",variant:"ghost",onClick:BO(s,["stop"])},{
default:ig((()=>[...c[3]||(c[3]=[ey(" Deselect All ",-1)])])),_:1
})):ny("",!0),o.value?ny("",!0):(Ub(),Hb(xm(WS),{key:1,
class:"pr-0.75 pl-1 transition-none",size:"sm",variant:"ghost",
onClick:BO(i,["stop"])},{
default:ig((()=>[...c[4]||(c[4]=[ey(" Select All ",-1)])])),_:1})),Yb(xm(Gne),{
class:"text-c-3 group-hover/scopes-accordion:text-c-2",
icon:t?"ChevronDown":"ChevronRight",size:"md"},null,8,["icon"])])])),_:1
},8,["class"]),Yb(xm(Xx),{as:"template"},{
default:ig((()=>[Gb("table",cYe,[(Ub(!0),
Qb(Mb,null,wv(r.value,(({id:t,label:n,description:r})=>(Ub(),Hb(xm(rYe),{key:t,
class:"text-c-2",onClick:n=>a(t,!e.selectedScopes.includes(t))},{
default:ig((()=>[Yb(xm(tYe),{
class:"hover:text-c-1 box-border !max-h-[initial] w-full cursor-pointer px-3 py-1.5"
},{
default:ig((()=>[Gb("span",uYe,Uh(n),1),r?(Ub(),Qb("span",dYe,"   – "+Uh(r),1)):ny("",!0)])),
_:2},1024),Yb(xm(aYe),{modelValue:e.selectedScopes.includes(t),
"onUpdate:modelValue":e=>a(t,e)
},null,8,["modelValue","onUpdate:modelValue"])])),_:2
},1032,["onClick"])))),128))])])),_:1})])),_:1})]),Yb(eYe,{
scopes:Object.keys(e.flow.scopes??{}),state:xm(l),
onSubmit:c[1]||(c[1]=t=>n("update:selectedScopes",{scopes:e.selectedScopes,
newScopePayload:{...t,flowType:e.flowType}}))},null,8,["scopes","state"])])),_:1
}))}}),hYe=async(e,t,n,r,o)=>{const a=e[t];try{
if(!a)return[new Error("Flow not found"),null];const i=n.join(" ")
;if("clientCredentials"===t||"password"===t)return fYe(e,t,i,{proxyUrl:o},r)
;const s=(Math.random()+1).toString(36).substring(2,10),l=HH(e[t].authorizationUrl,{
baseUrl:r?.url}),c=new URL(l);let u=null
;if("implicit"===t)c.searchParams.set("response_type","token");else if("authorizationCode"===t){
const n=e[t]
;if(c.searchParams.set("response_type","code"),"no"!==n["x-usePkce"]){
const e=(()=>{const e=new Uint8Array(32)
;return crypto.getRandomValues(e),MHe(e,!0)})(),t=await(async(e,t)=>{
if("plain"===t)return e
;if("function"!=typeof crypto?.subtle?.digest)return console.warn("SHA-256 is only supported when using https, using a plain text code challenge instead."),
e;const n=(new TextEncoder).encode(e),r=await crypto.subtle.digest("SHA-256",n)
;return MHe(new Uint8Array(r),!0)})(e,n["x-usePkce"]);u={codeVerifier:e,
codeChallenge:t,codeChallengeMethod:"SHA-256"===n["x-usePkce"]?"S256":"plain"
},c.searchParams.set("code_challenge",t),
c.searchParams.set("code_challenge_method",u.codeChallengeMethod)}}const d=e[t]
;if(d["x-scalar-secret-redirect-uri"].startsWith("/")){
const e=r?.url||window.location.origin+window.location.pathname,t=new URL(d["x-scalar-secret-redirect-uri"],e).toString()
;c.searchParams.set("redirect_uri",t)
}else c.searchParams.set("redirect_uri",d["x-scalar-secret-redirect-uri"])
;a["x-scalar-security-query"]&&Object.keys(a["x-scalar-security-query"]).forEach((e=>{
const t=a["x-scalar-security-query"]?.[e];t&&c.searchParams.set(e,t)
})),c.searchParams.set("client_id",a["x-scalar-secret-client-id"]),
c.searchParams.set("state",s),i&&c.searchParams.set("scope",i)
;const p=window.open(c,"openAuth2Window","left=100,top=100,width=800,height=600")
;return p?new Promise((n=>{const l=setInterval((()=>{
let c=null,d=null,h=null,f=null;try{
const e=new URL(p.location.href).searchParams,t=a["x-tokenName"]||"access_token"
;c=e.get(t),d=e.get("code"),h=e.get("error"),f=e.get("error_description")
;const n=new URLSearchParams(p.location.href.split("#")[1])
;c||=n.get(t),d||=n.get("code"),
h||=n.get("error"),f||=n.get("error_description")}catch{}
if(p.closed||c||d||h)if(clearInterval(l),
p.close(),h)n([new Error(`OAuth error: ${h}${f?` (${f})`:""}`),null]);else if(c){
const e=p.location.href.match(/state=([^&]*)/)?.[1]
;n(e===s?[null,c]:[new Error("State mismatch"),null])
}else d&&"authorizationCode"===t?new URL(p.location.href).searchParams.get("state")===s?fYe(e,t,i,{
code:d,pkce:u,proxyUrl:o
},r).then(n):n([new Error("State mismatch"),null]):(clearInterval(l),
n([new Error("Window was closed without granting authorization"),null]))}),200)
})):[new Error("Failed to open auth window"),null]}catch{
return[new Error("Failed to authorize oauth2 flow"),null]}
},fYe=async(e,t,n,{code:r,pkce:o,proxyUrl:a}={},i)=>{const s=e[t]
;if(!s)return[new Error("OAuth2 flow was not defined"),null]
;const l=new URLSearchParams
;n&&("clientCredentials"===t||"password"===t)&&l.set("scope",n)
;const c="body"===s["x-scalar-credentials-location"]
;if(c&&(l.set("client_id",s["x-scalar-secret-client-id"]),
l.set("client_secret",s["x-scalar-secret-client-secret"])),
"x-scalar-secret-redirect-uri"in s&&s["x-scalar-secret-redirect-uri"]&&l.set("redirect_uri",s["x-scalar-secret-redirect-uri"]),
r)l.set("code",r),
l.set("grant_type","authorization_code"),o&&l.set("code_verifier",o.codeVerifier);else if("password"===t){
const n=e[t]
;l.set("grant_type","password"),l.set("username",n["x-scalar-secret-username"]),
l.set("password",n["x-scalar-secret-password"])
}else l.set("grant_type","client_credentials")
;s["x-scalar-security-body"]&&Object.entries(s["x-scalar-security-body"]).forEach((([e,t])=>{
t&&l.set(e,t)}));try{const e={"Content-Type":"application/x-www-form-urlencoded"
}
;c||(e.Authorization=`Basic ${BHe(`${s["x-scalar-secret-client-id"]}:${s["x-scalar-secret-client-secret"]}`)}`)
;const t=HH(s.tokenUrl,{baseUrl:i?.url
}),n=qH(a,t)?`${a}?${new URLSearchParams([["scalar_url",t]]).toString()}`:t,r=await(await fetch(n,{
method:"POST",headers:e,body:l})).json()
;return[null,r[s["x-tokenName"]||"access_token"]]}catch{
return[new Error("Failed to get an access token. Please check your credentials."),null]
}},mYe=["for"],gYe={class:"relative flex min-w-0 flex-1"
},vYe=["readOnly","type","value"],bYe={key:1,
class:"centered-y text-orange absolute right-7 text-xs"},yYe=Qg({
inheritAttrs:!1,__name:"DataTableInput",props:{id:{},type:{},containerClass:{},
required:{type:Boolean,default:!1},modelValue:{},canAddCustomEnumValue:{
type:Boolean,default:!0},readOnly:{type:Boolean,default:!1},enum:{},min:{},
max:{},environment:{},description:{},lineWrapping:{type:Boolean,default:!1}},
emits:["update:modelValue","inputFocus","inputBlur","selectVariable"],
setup(e,{emit:t}){
const n=e,r=t,o=bm(!0),a=bm(!1),i=qg("codeInput"),s=()=>!a.value&&r("inputBlur"),l=Sy((()=>"password"===n.type?"text":n.type??"text")),c=()=>{
!n.enum?.length&&!n.readOnly&&i.value?.focus()};return(t,a)=>(Ub(),Hb(FXe,{
class:Ih(["relative flex",e.containerClass])},{
default:ig((()=>[t.$slots.default?(Ub(),Qb("div",{key:0,
class:"text-c-1 flex items-center pr-0 pl-3",for:e.id??"",onClick:c
},[kv(t.$slots,"default",{},void 0,!0),a[6]||(a[6]=ey(": ",-1))],8,mYe)):ny("",!0),Gb("div",gYe,[n.enum&&n.enum.length?(Ub(),
Hb(NVe,{key:0,canAddCustomValue:n.canAddCustomEnumValue,modelValue:n.modelValue,
value:n.enum,"onUpdate:modelValue":a[0]||(a[0]=e=>r("update:modelValue",e))
},null,8,["canAddCustomValue","modelValue","value"])):(Ub(),Qb(Mb,{key:1
},[o.value&&"password"===e.type?(Ub(),Qb("input",iy({key:0},e.id?{...t.$attrs,
id:e.id}:t.$attrs,{autocomplete:"off",
class:["text-c-1 disabled:text-c-2 peer w-full min-w-0 border-none px-2 py-1.25 -outline-offset-1",{
"scalar-password-input":"password"===e.type}],"data-1p-ignore":"",
readOnly:e.readOnly,spellcheck:"false",type:l.value,value:e.modelValue,
onInput:a[1]||(a[1]=e=>r("update:modelValue",e.target.value??""))
}),null,16,vYe)):(Ub(),Hb(xm(YVe),iy({key:1},t.$attrs,{id:e.id,
ref_key:"codeInput",ref:i,
class:["text-c-1 disabled:text-c-2 peer w-full min-w-0 border-none -outline-offset-1",["password"===e.type&&e.description&&"pr-12",e.description&&"pr-8","password"===e.type&&"scalar-password-input"]],
description:e.description,disableCloseBrackets:"",disableTabIndent:"",
environment:e.environment,lineWrapping:!!e.lineWrapping,max:e.max,min:e.min,
modelValue:e.modelValue??"",readOnly:e.readOnly,required:!!e.required,
spellcheck:"false",type:l.value,onBlur:s,
onFocus:a[2]||(a[2]=e=>r("inputFocus")),
"onUpdate:modelValue":a[3]||(a[3]=e=>r("update:modelValue",e))
}),null,16,["id","class","description","environment","lineWrapping","max","min","modelValue","readOnly","required","type"]))],64))]),t.$slots.warning?(Ub(),
Qb("div",bYe,[kv(t.$slots,"warning",{},void 0,!0)])):ny("",!0),kv(t.$slots,"icon",{},void 0,!0),e.modelValue?(Ub(),
Hb(xm(ure),{key:2,class:"-ml-.25 h-6 w-6 self-center p-1.25",icon:xm(I$),
label:"Clear Value",onClick:a[4]||(a[4]=e=>r("update:modelValue",""))
},null,8,["icon"])):ny("",!0),"password"===e.type?(Ub(),Hb(xm(ure),{key:3,
class:"-ml-.5 mr-1.25 h-6 w-6 self-center p-1.25",
"data-testid":"data-table-password-toggle",icon:o.value?xm(DT):xm(jT),
label:o.value?"Show Password":"Hide Password",
onClick:a[5]||(a[5]=e=>o.value=!o.value)
},null,8,["icon","label"])):ny("",!0)])),_:3},8,["class"]))}
}),OYe=sae(yYe,[["__scopeId","data-v-3157c3c7"]]),wYe=["for"],xYe=Qg({
__name:"RequestAuthDataTableInput",props:Nv({containerClass:{},environment:{},
readOnly:{type:Boolean,default:!1},required:{type:Boolean,default:!1},type:{}},{
modelValue:{default:"",required:!0},modelModifiers:{}}),
emits:Nv(["inputFocus","inputBlur","selectVariable"],["update:modelValue"]),
setup(e,{emit:t}){const n=t,r=Kv(e,"modelValue"),o=Hg()
;return(t,a)=>(Ub(),Hb(xm(OYe),iy({id:xm(o)},t.$attrs,{modelValue:r.value,
"onUpdate:modelValue":a[0]||(a[0]=e=>r.value=e),
canAddCustomEnumValue:!e.readOnly,containerClass:e.containerClass,
environment:e.environment,lineWrapping:"",readOnly:e.readOnly,
required:e.required,type:e.type,onInputBlur:a[1]||(a[1]=e=>n("inputBlur")),
onInputFocus:a[2]||(a[2]=e=>n("inputFocus")),
onSelectVariable:a[3]||(a[3]=e=>n("selectVariable",e))}),{
default:ig((()=>[Gb("label",{for:xm(o)},[kv(t.$slots,"default")],8,wYe)])),
icon:ig((()=>[kv(t.$slots,"icon")])),_:3
},16,["id","modelValue","canAddCustomEnumValue","containerClass","environment","readOnly","required","type"]))
}}),kYe={class:"flex h-8 items-center justify-end gap-2 border-t"},SYe={
class:"flex h-8 w-full items-center justify-end border-t"},_Ye=Qg({
__name:"OAuth2",props:{environment:{},flows:{},type:{},selectedScopes:{},
server:{},proxyUrl:{}},emits:["update:securityScheme","update:selectedScopes"],
setup(e,{emit:t}){
const n=t,r=Goe(),{toast:o}=CG(),a=Sy((()=>e.flows[e.type])),i=Sy((()=>e.selectedScopes.filter((e=>e in(a.value.scopes??{}))))),s=t=>n("update:securityScheme",{
type:"oauth2",flows:{[e.type]:t}})
;mg((()=>a.value["x-scalar-secret-redirect-uri"]),(e=>{
e||typeof window>"u"||!("x-scalar-secret-redirect-uri"in a.value)||s({
"x-scalar-secret-redirect-uri":window.location.origin+window.location.pathname})
}),{immediate:!0});const l=async()=>{if(r.isLoading)return;r.start()
;const[t,n]=await hYe(e.flows,e.type,i.value,e.server,e.proxyUrl)
;await r.clear(),n?s({"x-scalar-secret-token":n
}):(console.error(t),o(t?.message??"Failed to authorize","error"))}
;return(t,o)=>a.value["x-scalar-secret-token"]?(Ub(),Qb(Mb,{key:0
},[Yb(xm(rYe),null,{default:ig((()=>[Yb(xYe,{class:"border-r-transparent",
environment:e.environment,modelValue:a.value["x-scalar-secret-token"],
placeholder:"QUxMIFlPVVIgQkFTRSBBUkUgQkVMT05HIFRPIFVT",type:"password",
"onUpdate:modelValue":o[0]||(o[0]=e=>s({"x-scalar-secret-token":e}))},{
default:ig((()=>[...o[12]||(o[12]=[ey(" Access Token ",-1)])])),_:1
},8,["environment","modelValue"])])),_:1}),Yb(xm(rYe),{class:"min-w-full"},{
default:ig((()=>[Gb("div",kYe,[Yb(xm(WS),{class:"mr-1 p-0 px-2 py-0.5",
loader:xm(r),size:"sm",variant:"outlined",onClick:o[1]||(o[1]=()=>s({
"x-scalar-secret-token":""}))},{
default:ig((()=>[...o[13]||(o[13]=[ey(" Clear ",-1)])])),_:1
},8,["loader"])])])),_:1})],64)):(Ub(),Qb(Mb,{key:1},[Yb(xm(rYe),null,{
default:ig((()=>["authorizationUrl"in a.value?(Ub(),Hb(xYe,{key:0,
containerClass:"border-r-0",environment:e.environment,
modelValue:a.value.authorizationUrl,
placeholder:"https://galaxy.scalar.com/authorize",
"onUpdate:modelValue":o[2]||(o[2]=e=>s({authorizationUrl:e}))},{
default:ig((()=>[...o[14]||(o[14]=[ey(" Auth URL ",-1)])])),_:1
},8,["environment","modelValue"])):ny("",!0),"tokenUrl"in a.value?(Ub(),Hb(xYe,{
key:1,environment:e.environment,modelValue:a.value.tokenUrl,
placeholder:"https://galaxy.scalar.com/token",
"onUpdate:modelValue":o[3]||(o[3]=e=>s({tokenUrl:e}))},{
default:ig((()=>[...o[15]||(o[15]=[ey(" Token URL ",-1)])])),_:1
},8,["environment","modelValue"])):ny("",!0)])),_:1
}),"x-scalar-secret-redirect-uri"in a.value?(Ub(),Hb(xm(rYe),{key:0},{
default:ig((()=>[Yb(xYe,{environment:e.environment,
modelValue:a.value["x-scalar-secret-redirect-uri"],
placeholder:"https://galaxy.scalar.com/callback",
"onUpdate:modelValue":o[4]||(o[4]=e=>s({"x-scalar-secret-redirect-uri":e}))},{
default:ig((()=>[...o[16]||(o[16]=[ey(" Redirect URL ",-1)])])),_:1
},8,["environment","modelValue"])])),_:1
})):ny("",!0),"x-scalar-secret-username"in a.value&&"x-scalar-secret-password"in a.value?(Ub(),
Qb(Mb,{key:1},[Yb(xm(rYe),null,{default:ig((()=>[Yb(xYe,{class:"text-c-2",
environment:e.environment,modelValue:a.value["x-scalar-secret-username"],
placeholder:"janedoe","onUpdate:modelValue":o[5]||(o[5]=e=>s({
"x-scalar-secret-username":e}))},{
default:ig((()=>[...o[17]||(o[17]=[ey(" Username ",-1)])])),_:1
},8,["environment","modelValue"])])),_:1}),Yb(xm(rYe),null,{
default:ig((()=>[Yb(xYe,{environment:e.environment,
modelValue:a.value["x-scalar-secret-password"],placeholder:"********",
type:"password","onUpdate:modelValue":o[6]||(o[6]=e=>s({
"x-scalar-secret-password":e}))},{
default:ig((()=>[...o[18]||(o[18]=[ey(" Password ",-1)])])),_:1
},8,["environment","modelValue"])])),_:1})],64)):ny("",!0),Yb(xm(rYe),null,{
default:ig((()=>[Yb(xYe,{environment:e.environment,
modelValue:a.value["x-scalar-secret-client-id"],placeholder:"12345",
"onUpdate:modelValue":o[7]||(o[7]=e=>s({"x-scalar-secret-client-id":e}))},{
default:ig((()=>[...o[19]||(o[19]=[ey(" Client ID ",-1)])])),_:1
},8,["environment","modelValue"])])),_:1
}),"x-scalar-secret-client-secret"in a.value?(Ub(),Hb(xm(rYe),{key:2},{
default:ig((()=>[Yb(xYe,{environment:e.environment,
modelValue:a.value["x-scalar-secret-client-secret"],placeholder:"XYZ123",
type:"password","onUpdate:modelValue":o[8]||(o[8]=e=>s({
"x-scalar-secret-client-secret":e}))},{
default:ig((()=>[...o[20]||(o[20]=[ey(" Client Secret ",-1)])])),_:1
},8,["environment","modelValue"])])),_:1
})):ny("",!0),"x-usePkce"in a.value?(Ub(),Hb(xm(rYe),{key:3},{
default:ig((()=>[Yb(xYe,{enum:xm(xke),environment:e.environment,
modelValue:a.value["x-usePkce"],readOnly:"",
"onUpdate:modelValue":o[9]||(o[9]=e=>s({"x-usePkce":e}))},{
default:ig((()=>[...o[21]||(o[21]=[ey(" Use PKCE ",-1)])])),_:1
},8,["enum","environment","modelValue"])])),_:1
})):ny("",!0),"implicit"!==e.type?(Ub(),Hb(xm(rYe),{key:4},{
default:ig((()=>[Yb(xYe,{enum:["header","body"],environment:e.environment,
modelValue:a.value["x-scalar-credentials-location"]||"header",
placeholder:"header",readOnly:"","onUpdate:modelValue":o[10]||(o[10]=e=>(e=>s({
"x-scalar-credentials-location":"body"===e?"body":"header"}))(e))},{
default:ig((()=>[...o[22]||(o[22]=[ey(" Credentials Location ",-1)])])),_:1
},8,["environment","modelValue"])])),_:1})):ny("",!0),Yb(xm(rYe),null,{
default:ig((()=>[Yb(pYe,{flow:a.value,flowType:e.type,selectedScopes:i.value,
"onUpdate:selectedScopes":o[11]||(o[11]=e=>n("update:selectedScopes",e))
},null,8,["flow","flowType","selectedScopes"])])),_:1}),Yb(xm(rYe),{
class:"min-w-full"},{default:ig((()=>[Gb("div",SYe,[Yb(xm(WS),{
class:"mr-0.75 p-0 px-2 py-0.5",loader:xm(r),size:"sm",variant:"outlined",
onClick:l},{default:ig((()=>[...o[23]||(o[23]=[ey(" Authorize ",-1)])])),_:1
},8,["loader"])])])),_:1})],64))}}),TYe={
class:"bg-b-1 text-c-2 outline-b-3 top-0 z-1 h-full w-full overflow-hidden px-3 py-1.25 text-ellipsis group-hover/auth:absolute group-hover/auth:h-auto group-hover/auth:border-b *:first:line-clamp-1 *:first:text-ellipsis group-hover/auth:*:first:line-clamp-none"
},EYe={class:"flex min-h-8 border-t text-base"},AYe={
class:"flex h-8 max-w-full gap-2.5 overflow-x-auto px-3"},CYe=["onClick"],$Ye={
class:"relative z-10"},PYe=Qg({__name:"RequestAuthTab",props:{environment:{},
isStatic:{type:Boolean},proxyUrl:{},selectedSecuritySchemas:{},
securitySchemes:{},server:{}},
emits:["update:securityScheme","update:selectedScopes"],setup(e,{emit:t}){
const n=t,r=Sy((()=>Object.entries(e.selectedSecuritySchemas).map((([t,n=[]])=>({
scheme:qke(e.securitySchemes[t]),name:t,scopes:n
}))))),o=bm(""),a=Sy((()=>r.value.length>1)),i=(e,t)=>{
const n=yh(e),r=t.description?`: ${t.description}`:"";switch(t.type){
case"apiKey":return`${n}${r||`: ${t.in}`}`;case"oauth2":{
const e=Object.keys(t.flows??{})[0];return`${n}: ${o.value||e}${r}`}case"http":
return`${n}: ${t.scheme}${r}`;default:return`${n}${r||`: ${t.type}`}`}
},s=(e,t)=>o.value===e||0===t&&!o.value,l=()=>e.isStatic&&"border-t",c=(e,t,r)=>n("update:securityScheme",{
type:"http",[e]:t},r),u=(e,t,r)=>n("update:securityScheme",{type:"apiKey",[e]:t
},r),d=(t,n)=>{
const r="floating-bg text-c-3 relative cursor-pointer border-b border-transparent py-1 text-base font-medium"
;return s(t,n)?`${r} !text-c-1 !rounded-none border-b !border-current ${e.isStatic?"opacity-100":""}`:r
}
;return(t,p)=>(Ub(!0),Qb(Mb,null,wv(r.value,(({scheme:t,name:r,scopes:h})=>(Ub(),
Qb(Mb,{key:r},[a.value&&t?(Ub(),Hb(xm(zXe),{key:0},{
default:ig((()=>[Yb(xm(FXe),{"aria-label":i(r,t),
class:"text-c-2 group/auth flex items-center leading-[22px] whitespace-nowrap outline-none hover:whitespace-normal"
},{default:ig((()=>[Gb("p",TYe,Uh(i(r,t)),1)])),_:2},1032,["aria-label"])])),_:2
},1024)):ny("",!0),t?.description&&!a.value?(Ub(),Hb(xm(zXe),{key:1},{
default:ig((()=>[Yb(xm(FXe),{"aria-label":t.description,class:"max-h-[auto]"},{
default:ig((()=>[Yb(xm(vre),{
class:"auth-description bg-b-1 text-c-2 min-w-0 flex-1 px-3 py-1.25",
value:t.description},null,8,["value"])])),_:2},1032,["aria-label"])])),_:2
},1024)):ny("",!0),"http"===t?.type?(Ub(),Qb(Mb,{key:2
},["bearer"===t.scheme?(Ub(),Hb(xm(zXe),{key:0},{default:ig((()=>[Yb(xYe,{
containerClass:l(),environment:e.environment,
modelValue:t["x-scalar-secret-token"],placeholder:"Token",type:"password",
"onUpdate:modelValue":e=>c("x-scalar-secret-token",e,r)},{
default:ig((()=>[...p[0]||(p[0]=[ey(" Bearer Token ",-1)])])),_:1
},8,["containerClass","environment","modelValue","onUpdate:modelValue"])])),_:2
},1024)):"basic"===t?.scheme?(Ub(),Qb(Mb,{key:1},[Yb(xm(zXe),null,{
default:ig((()=>[Yb(xYe,{class:"text-c-2",environment:e.environment,
modelValue:t["x-scalar-secret-username"],placeholder:"janedoe",required:"",
"onUpdate:modelValue":e=>c("x-scalar-secret-username",e,r)},{
default:ig((()=>[...p[1]||(p[1]=[ey(" Username ",-1)])])),_:1
},8,["environment","modelValue","onUpdate:modelValue"])])),_:2
},1024),Yb(xm(zXe),null,{default:ig((()=>[Yb(xYe,{environment:e.environment,
modelValue:t["x-scalar-secret-password"],placeholder:"********",type:"password",
"onUpdate:modelValue":e=>c("x-scalar-secret-password",e,r)},{
default:ig((()=>[...p[2]||(p[2]=[ey(" Password ",-1)])])),_:1
},8,["environment","modelValue","onUpdate:modelValue"])])),_:2
},1024)],64)):ny("",!0)],64)):"apiKey"===t?.type?(Ub(),Qb(Mb,{key:3
},[Yb(xm(zXe),null,{default:ig((()=>[Yb(xYe,{containerClass:l(),
environment:e.environment,modelValue:t.name,placeholder:"api-key",
"onUpdate:modelValue":e=>u("name",e,r)},{
default:ig((()=>[...p[3]||(p[3]=[ey(" Name ",-1)])])),_:1
},8,["containerClass","environment","modelValue","onUpdate:modelValue"])])),_:2
},1024),Yb(xm(zXe),null,{default:ig((()=>[Yb(xYe,{environment:e.environment,
modelValue:t["x-scalar-secret-token"],
placeholder:"QUxMIFlPVVIgQkFTRSBBUkUgQkVMT05HIFRPIFVT",type:"password",
"onUpdate:modelValue":e=>u("x-scalar-secret-token",e,r)},{
default:ig((()=>[...p[4]||(p[4]=[ey(" Value ",-1)])])),_:1
},8,["environment","modelValue","onUpdate:modelValue"])])),_:2
},1024)],64)):"oauth2"===t?.type?(Ub(),Qb(Mb,{key:4
},[Object.keys(t.flows).length>1?(Ub(),Hb(xm(zXe),{key:0},{
default:ig((()=>[Gb("div",EYe,[Gb("div",AYe,[(Ub(!0),
Qb(Mb,null,wv(t.flows,((e,t,n)=>(Ub(),Qb("button",{key:t,class:Ih(d(t,n)),
type:"button",onClick:e=>o.value=t
},[Gb("span",$Ye,Uh(t),1)],10,CYe)))),128))])])])),_:2
},1024)):ny("",!0),(Ub(!0),Qb(Mb,null,wv(t.flows,((o,a,i)=>(Ub(),Qb(Mb,{key:a
},[s(a,i)?(Ub(),Hb(_Ye,{key:0,environment:e.environment,flows:t.flows,
proxyUrl:e.proxyUrl,selectedScopes:h,server:e.server,type:a,
"onUpdate:securityScheme":e=>n("update:securityScheme",e,r),
"onUpdate:selectedScopes":t=>((t,r)=>{n("update:selectedScopes",{
id:Object.keys(e.selectedSecuritySchemas),name:t,...r})})(r,t)
},null,8,["environment","flows","proxyUrl","selectedScopes","server","type","onUpdate:securityScheme","onUpdate:selectedScopes"])):ny("",!0)],64)))),128))],64)):"openIdConnect"===t?.type?(Ub(),
Qb("div",{key:5,
class:Ih(["text-c-3 bg-b-1 flex min-h-[calc(4rem+1px)] items-center justify-center border-t border-b-0 px-4 text-base",{
"rounded-b-lg":e.isStatic}])}," Coming soon ",2)):ny("",!0)],64)))),128))}
}),DYe=["onClick"],IYe={class:"relative z-10 font-medium whitespace-nowrap"
},MYe={key:0,
class:"absolute inset-x-1 bottom-[var(--scalar-border-width)] left-1/2 z-1 h-px w-full -translate-x-1/2 bg-current"
},NYe=Qg({__name:"RequestAuthDataTable",props:{environment:{},isStatic:{
type:Boolean},selectedSchemeOptions:{},activeAuthIndex:{},proxyUrl:{},
securitySchemes:{default:()=>({})},server:{},eventBus:{},meta:{}},
setup(e,{expose:t}){
const n=Sy((()=>e.selectedSchemeOptions[e.activeAuthIndex])),r=Sy((()=>e.selectedSchemeOptions.length>1)),o=(t,n)=>e.eventBus.emit("auth:update:security-scheme",{
payload:t,name:n}),a=t=>e.eventBus.emit("auth:update:selected-scopes",{...t,
meta:e.meta}),i=t=>e.activeAuthIndex===t;return t({activeScheme:n
}),(t,s)=>(Ub(),Qb("form",{onSubmit:s[0]||(s[0]=BO((()=>{}),["prevent"]))
},[r.value?(Ub(),Qb("div",{key:0,
class:Ih(["box-content flex flex-wrap gap-x-2.5 overflow-hidden border border-b-0 px-3",{
"border-x-0":!e.isStatic}]),"data-testid":"auth-tabs"
},[(Ub(!0),Qb(Mb,null,wv(e.selectedSchemeOptions,((t,n)=>(Ub(),Qb("div",{
key:t.id,class:"relative z-1 -mb-[var(--scalar-border-width)] flex h-8"
},[Gb("button",{
class:Ih(["floating-bg relative cursor-pointer border-b border-transparent py-1 text-sm font-medium transition-colors",i(n)?"text-c-1":"text-c-3"]),
type:"button",onClick:t=>(t=>e.eventBus.emit("auth:update:active-index",{
index:t,meta:e.meta}))(n)
},[Gb("span",IYe,Uh(t.label),1)],10,DYe),i(n)?(Ub(),Qb("div",MYe)):ny("",!0)])))),128))],2)):ny("",!0),n.value?(Ub(),
Hb(xm(GXe),{key:1,class:Ih(["flex-1",{
"bg-b-1 rounded-b-lg border border-t-0":e.isStatic}]),columns:[""],
presentational:""},{default:ig((()=>[Yb(PYe,{environment:e.environment,
isStatic:e.isStatic,proxyUrl:e.proxyUrl,securitySchemes:e.securitySchemes,
selectedSecuritySchemas:n.value.value,server:e.server,
"onUpdate:securityScheme":o,"onUpdate:selectedScopes":a
},null,8,["environment","isStatic","proxyUrl","securitySchemes","selectedSecuritySchemas","server"])])),
_:1},8,["class"])):(Ub(),Qb("div",{key:2,
class:Ih(["bg-b-1 text-c-3 flex min-h-16 items-center justify-center border-t px-4 text-sm",{
"min-h-[calc(4rem+0.5px)] rounded-b-lg border":e.isStatic}])
}," No authentication selected ",2))],32))}}),RYe=["id"],LYe={
class:"min-w-0 flex-1 truncate"},BYe=Qg({__name:"AuthSelector",props:{
environment:{},eventBus:{},isStatic:{type:Boolean,default:!1},meta:{},
proxyUrl:{},securityRequirements:{},securitySchemes:{},selectedSecurity:{},
server:{},title:{}},setup(e,{expose:t}){
const n=Hg(),r=bm(null),o=bm(!1),a=Koe(),i=bm(null),s=Sy((()=>{
if(!e.securityRequirements?.length)return null
;const t=gXe(e.securityRequirements);return{icon:t?"Unlock":"Lock",
text:t?"Optional":"Required"}})),l=Sy((()=>((e,t,n)=>{
const{requiredFormatted:r,requiredSchemeNames:o,existingIds:a}=e.reduce(((e,n)=>{
const r=HGe(n,t);r&&(e.requiredFormatted.push(r),e.existingIds.add(r.id))
;for(const t of Object.keys(n))e.requiredSchemeNames.add(t);return e}),{
requiredFormatted:[],requiredSchemeNames:new Set,existingIds:new Set}),i=[]
;for(const[l,c]of Object.entries(t)){if(o.has(l))continue;const e=qke(c);if(e){
const t=ZGe({name:l,type:e.type,value:{[l]:[]}});i.push(t),a.add(t.id)}}
for(const l of n){const e=HGe(l,t);e&&!a.has(e.id)&&(i.push(e),a.add(e.id))}
const s=[{label:"Required authentication",options:r},{
label:"Available authentication",options:i}];return s.push({
label:"Add new authentication",options:Object.entries(FGe).map((([e,t])=>({id:e,
label:t.label,value:{[e]:[]},payload:t.payload,isDeletable:!1})))}),s
})(e.securityRequirements??[],e.securitySchemes??{},e.selectedSecurity?.selectedSchemes??[]))),c=Sy((()=>{
const t=e.selectedSecurity?.selectedSchemes;return t?.length?t.flatMap((t=>{
const n=Object.keys(t);if(0===n.length)return[];if(n.length>1)return QGe(t)
;const r=n[0];if(!r)return[];const o=qke(e.securitySchemes?.[r]);return o?ZGe({
name:r,type:o.type,value:t}):[]})):[]})),u=e=>{
o.value&&e.stopPropagation(),r.value?.$el.click()},d=t=>{
const n=t.filter((e=>void 0===e.payload)).map((e=>Q_e(e.value,{depth:2
}))),r=t.filter((e=>void 0!==e.payload)).map((e=>({name:e.label,scheme:e.payload
})));e.eventBus.emit("auth:update:selected-security-schemes",{
selectedRequirements:n,newSchemes:r,meta:e.meta})},p=e=>{i.value={label:e.label,
payload:e.value},a.show()},h=()=>{
i.value&&(e.eventBus.emit("auth:delete:security-scheme",{
names:Object.keys(i.value.payload)}),i.value=null,a.hide())};return t({
authIndicator:s,selectedSchemeOptions:c,schemeOptions:l
}),(t,f)=>(Ub(),Hb(xm(uGe),{class:"group/params relative",isStatic:e.isStatic,
itemCount:c.value.length,"onUpdate:modelValue":f[1]||(f[1]=e=>o.value=e)},{
title:ig((()=>[Gb("div",{id:xm(n),
class:"inline-flex items-center gap-0.5 leading-[20px]"
},[Gb("span",null,Uh(e.title),1),s.value?(Ub(),Qb("span",{key:0,
class:Ih(["text-c-3 hover:bg-b-3 hover:text-c-1 -mr-1 cursor-pointer rounded px-1 py-0.5 text-xs leading-[normal]",{
"text-c-1":"Required"===s.value.text}]),"data-testid":"auth-indicator",onClick:u
},Uh(s.value.text),3)):ny("",!0)],8,RYe)])),actions:ig((()=>[Yb(xm(VK),{
class:"w-72 text-xs",modelValue:c.value,multiple:"",options:l.value,
placement:"bottom-end",teleport:"",onDelete:p,"onUpdate:modelValue":d},{
option:ig((({option:e,selected:t})=>[Yb(xm(KG),{multiselect:"",selected:t
},null,8,["selected"]),Gb("div",LYe,Uh(e.label),1),e.isDeletable?(Ub(),
Hb(xm(ure),{key:0,
class:"-m-0.5 shrink-0 p-0.5 opacity-0 group-hover/item:opacity-100",
icon:xm(KC),label:`Delete ${e.label}`,size:"xs",onClick:BO((t=>p(e)),["stop"])
},null,8,["icon","label","onClick"])):ny("",!0)])),default:ig((()=>[Yb(xm(WS),{
ref_key:"comboboxButtonRef",ref:r,"aria-describedby":xm(n),
class:"group/combobox-button hover:text-c-1 text-c-2 flex h-fit w-full items-center gap-1 px-0.75 py-0.25 text-base font-normal",
variant:"ghost"},{default:ig((()=>[1===c.value.length?(Ub(),Qb(Mb,{key:0
},[f[2]||(f[2]=Gb("span",{class:"sr-only"
},"Selected Auth Type:",-1)),ey(" "+Uh(c.value[0]?.label),1)],64)):c.value.length>1?(Ub(),
Qb(Mb,{key:1},[f[3]||(f[3]=ey(" Multiple ",-1)),f[4]||(f[4]=Gb("span",{
class:"sr-only"},"Auth Types Selected",-1))],64)):(Ub(),Qb(Mb,{key:2
},[f[5]||(f[5]=Gb("span",{class:"sr-only"
},"Select",-1)),f[6]||(f[6]=ey(" Auth Type ",-1))],64)),Yb(xm(L_),{
class:"size-3 shrink-0 transition-transform duration-100 group-aria-expanded/combobox-button:rotate-180",
weight:"bold"})])),_:1},8,["aria-describedby"])])),_:1
},8,["modelValue","options"])])),default:ig((()=>[Yb(NYe,{
activeAuthIndex:e.selectedSecurity?.selectedIndex??0,environment:e.environment,
eventBus:e.eventBus,isStatic:e.isStatic,meta:e.meta,proxyUrl:e.proxyUrl,
securitySchemes:e.securitySchemes,selectedSchemeOptions:c.value,server:e.server
},null,8,["activeAuthIndex","environment","eventBus","isStatic","meta","proxyUrl","securitySchemes","selectedSchemeOptions","server"]),i.value?(Ub(),
Hb(zGe,{key:0,label:i.value.label,scheme:i.value,state:xm(a),
onClose:f[0]||(f[0]=e=>xm(a).hide()),onDelete:h
},null,8,["label","scheme","state"])):ny("",!0)])),_:1
},8,["isStatic","itemCount"]))}}),jYe={
class:"group pointer-events-none flex flex-1 items-center gap-1 lg:pr-24"
},UYe=["for"],zYe=["id","placeholder","value"],FYe={key:2,
class:"text-c-1 flex h-8 items-center"},ZYe=["id","role"],QYe=Qg({
__name:"RequestBlock",props:{selectedSecurity:{},authMeta:{default:()=>({
type:"document"})},clientOptions:{},environment:{},eventBus:{},exampleKey:{},
layout:{},method:{},operation:{},path:{},plugins:{},proxyUrl:{},
securityRequirements:{},securitySchemes:{},selectedClient:{},
selectedSecuritySchemes:{},server:{},globalCookies:{}},setup(e){
const t=Sy((()=>({method:e.method,path:e.path,exampleKey:e.exampleKey
}))),n=Sy((()=>BGe(e.operation.parameters?.map((e=>qke(e)))??[],"in",(t=>{
const n=nHe(t,e.exampleKey,void 0);return{name:t.name,value:n?.value??"",
description:t.description,schema:LGe(t),isRequired:t.required,
isDisabled:gHe(t,n),originalParameter:t}
})))),r=Sy((()=>BGe(n.value.header?.map((e=>({...e,name:e.name.toLowerCase()
})))??[],"name"))),o=Sy((()=>tHe({method:e.method,operation:e.operation,
exampleKey:e.exampleKey}))),a=Sy((()=>{
const t=e.operation["x-scalar-disable-parameters"]?.["default-headers"]?.[e.exampleKey]??{}
;return o.value.map((e=>{const n=r.value[e.name.toLowerCase()]?.[0];return{
name:e.name,value:e.defaultValue,schema:void 0,isOverridden:n&&!n?.isDisabled,
isReadonly:!0,isDisabled:t[e.name.toLowerCase()]??!1}}))
})),i=Sy((()=>[...a.value,...n.value.header??[]])),s=Sy((()=>{const t=KQe({
environment:e.environment,server:e.server,path:e.path,pathVariables:{}
}),n=e.operation["x-scalar-disable-parameters"]?.["global-cookies"]?.[e.exampleKey]??{}
;return e.globalCookies?.filter((e=>mHe({cookie:e,url:t,disabledGlobalCookies:{}
}))).map((e=>({name:e.name,value:e.value,
globalRoute:"document"===e.location?"document.cookies":"workspace.cookies",
isReadonly:!0,isDisabled:n[e.name.toLowerCase()]??!1})))??[]
})),l=Sy((()=>[...s.value??[],...n.value.cookie??[]])),c=bm("All"),u=["Auth","Variables","Cookies","Headers","Query","Body"],d={
All:Hg(),Auth:Hg(),Variables:Hg(),Cookies:Hg(),Headers:Hg(),Query:Hg(),Body:Hg()
},p=Sy((()=>{const t=new Set(["All",...u])
;return n.value.path?.length||t.delete("Variables"),
EH(e.method)||t.delete("Body"),f.value&&t.delete("Auth"),[...t]
})),h=Sy((()=>Object.fromEntries(p.value.map((e=>[e,d[e]]))))),f=Sy((()=>"modal"===e.layout&&!e.operation.security&&!Object.keys(e.securitySchemes??{}).length)),m=Sy((()=>e.operation.summary?e.operation.summary:e.path.replace(NH.PROTOCOL,"")||"Request Name")),g=e=>"All"===c.value||c.value===e
;mg((()=>e.method),(e=>{"Body"===c.value&&!EH(e)&&(c.value="All")}))
;const v=n=>{const r=n.target.value;e.eventBus.emit("operation:update:summary",{
meta:t.value,payload:{summary:r}})},b=Sy((()=>({
path:RGe("path",e.eventBus,t.value,{context:n.value.path??[]}),
cookie:RGe("cookie",e.eventBus,t.value,{context:l.value??[],
globalParameters:s.value.length}),header:RGe("header",e.eventBus,t.value,{
context:i.value,defaultParameters:a.value.length}),
query:RGe("query",e.eventBus,t.value,{context:n.value.query??[]})
}))),y=n=>e.eventBus.emit("operation:update:requestBody:contentType",{payload:{
contentType:n.value},meta:t.value}),O=({payload:n,contentType:r})=>{
const o="string"==typeof n?`update:requestBody:value-${r}`:void 0
;e.eventBus.emit("operation:update:requestBody:value",{payload:n,contentType:r,
meta:t.value},{debounceKey:o})},w=({payload:n,contentType:r})=>{
const o=`update:requestBody:${r}-form-value`
;e.eventBus.emit("operation:update:requestBody:formValue",{
payload:n.map((e=>Q_e(e,{depth:1}))),contentType:r,meta:t.value},{debounceKey:o
})},x=Hg();return(t,r)=>(Ub(),Hb(TXe,{
"aria-label":`Request: ${e.operation.summary}`},{
title:ig((()=>[Gb("div",jYe,["modal"!==e.layout?(Ub(),Qb("label",{key:0,
class:"pointer-events-auto absolute top-0 left-0 h-full w-full cursor-text opacity-0",
for:xm(x)},null,8,UYe)):ny("",!0),"modal"!==e.layout?(Ub(),Qb("input",{key:1,
id:xm(x),
class:"text-c-1 group-hover-input pointer-events-auto relative z-10 -ml-0.5 h-8 w-full rounded pl-1.25 has-[:focus-visible]:outline md:-ml-1.25",
placeholder:m.value,value:e.operation.summary,onInput:v
},null,40,zYe)):(Ub(),Qb("span",FYe,Uh(e.operation.summary),1))]),Yb(SXe,{
modelValue:c.value,"onUpdate:modelValue":r[0]||(r[0]=e=>c.value=e),
filterIds:h.value,filters:p.value
},null,8,["modelValue","filterIds","filters"])])),default:ig((()=>[Gb("div",{
id:h.value.All,
class:"request-section-content custom-scroll relative flex flex-1 flex-col",
role:"All"===c.value?"tabpanel":"none"},[sg(Yb(xm(BYe),{id:h.value.Auth,
environment:e.environment,eventBus:e.eventBus,meta:e.authMeta,
proxyUrl:e.proxyUrl,securityRequirements:e.securityRequirements,
securitySchemes:e.securitySchemes,selectedSecurity:e.selectedSecurity,
selectedSecuritySchemes:e.selectedSecuritySchemes,server:e.server,
title:"Authentication"
},null,8,["id","environment","eventBus","meta","proxyUrl","securityRequirements","securitySchemes","selectedSecurity","selectedSecuritySchemes","server"]),[[Jy,g("Auth")&&!f.value]]),sg(Yb(NGe,iy({
id:h.value.Variables,environment:e.environment,eventBus:e.eventBus,
exampleKey:e.exampleKey,rows:n.value.path??[],showAddRowPlaceholder:!1,
title:"Variables"
},_v(b.value.path)),null,16,["id","environment","eventBus","exampleKey","rows"]),[[Jy,g("Variables")&&n.value.path?.length]]),sg(Yb(NGe,iy({
id:h.value.Cookies,environment:e.environment,eventBus:e.eventBus,
exampleKey:e.exampleKey,rows:l.value??[],showAddRowPlaceholder:!0,
title:"Cookies"
},_v(b.value.cookie)),null,16,["id","environment","eventBus","exampleKey","rows"]),[[Jy,g("Cookies")]]),sg(Yb(NGe,iy({
id:h.value.Headers,environment:e.environment,eventBus:e.eventBus,
exampleKey:e.exampleKey,rows:i.value??[],title:"Headers"
},_v(b.value.header)),null,16,["id","environment","eventBus","exampleKey","rows"]),[[Jy,g("Headers")]]),sg(Yb(NGe,iy({
id:h.value.Query,environment:e.environment,eventBus:e.eventBus,
exampleKey:e.exampleKey,rows:n.value.query??[],title:"Query Parameters"
},_v(b.value.query)),null,16,["id","environment","eventBus","exampleKey","rows"]),[[Jy,g("Query")]]),sg(Yb(mGe,{
id:h.value.Body,environment:e.environment,exampleKey:e.exampleKey,
requestBody:xm(qke)(e.operation.requestBody),title:"Request Body",
"onUpdate:contentType":y,"onUpdate:formValue":w,"onUpdate:value":O
},null,8,["id","environment","exampleKey","requestBody"]),[[Jy,g("Body")&&xm(EH)(e.method)]]),(Ub(!0),
Qb(Mb,null,wv(e.plugins,((t,n)=>(Ub(),Hb(xm(v2),{key:n},{
default:ig((()=>[t?.components?.request?(Ub(),Hb(bv(t.components.request),{
key:0,operation:e.operation,selectedExample:e.exampleKey
},null,8,["operation","selectedExample"])):ny("",!0)])),_:2
},1024)))),128)),r[1]||(r[1]=Gb("div",{class:"flex flex-grow"
},null,-1)),sg(Yb(DGe,{clientOptions:e.clientOptions,eventBus:e.eventBus,
globalCookies:e.globalCookies,integration:"client",method:e.method,
operation:e.operation,path:e.path,securitySchemes:e.selectedSecuritySchemes,
selectedClient:e.selectedClient,
selectedContentType:xm(qke)(e.operation.requestBody)?.["x-scalar-selected-content-type"]?.[e.exampleKey],
selectedServer:e.server??void 0
},null,8,["clientOptions","eventBus","globalCookies","method","operation","path","securitySchemes","selectedClient","selectedContentType","selectedServer"]),[[Jy,"All"===c.value]])],8,ZYe)])),
_:1},8,["aria-label"]))}
}),HYe=sae(QYe,[["__scopeId","data-v-8c6cdddb"]]),VYe=["role"],qYe={key:0,
class:"sr-only"},WYe=Qg({__name:"DataTable",props:{columns:{},scroll:{
type:Boolean},presentational:{type:Boolean}},setup(e){const{cx:t}=zS()
;return(n,r)=>(Ub(),
Qb("div",Mh(Kb(xm(t)(e.scroll?"overflow-x-auto custom-scroll":"overflow-visible","scalar-data-table"))),[Gb("table",{
class:Ih(["mb-0 grid min-h-8 auto-rows-auto",{"w-max min-w-full":e.scroll}]),
role:e.presentational?"presentation":"table",style:Ah({
gridTemplateColumns:e.columns.map((e=>e||"1fr")).join(" ")})
},[n.$slots.caption?(Ub(),
Qb("caption",qYe,[kv(n.$slots,"caption")])):ny("",!0),kv(n.$slots,"default")],14,VYe)],16))
}}),XYe={class:"flex-1 px-2 py-1.5 whitespace-nowrap"},GYe=Qg({
__name:"DataTableText",props:{text:{}},setup:e=>(t,n)=>(Ub(),Hb(tYe,{
class:"relative flex"},{
default:ig((()=>[Gb("span",XYe,[kv(t.$slots,"default",{},(()=>[ey(Uh(e.text),1)]))])])),
_:3}))}),YYe=["href"],KYe=Qg({__name:"HelpfulLink",props:{href:{}},
setup:e=>(t,n)=>(Ub(),Qb("a",{
class:"decoration-c-3 cursor-help underline underline-offset-2",href:e.href,
rel:"noopener noreferrer",target:"_blank"},[kv(t.$slots,"default")],8,YYe))
}),JYe=[{name:"Accept",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Accept"},{
name:"Accept-CH",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Accept-CH"},{
name:"Accept-CH-Lifetime",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Accept-CH-Lifetime"
},{name:"Accept-Charset",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Accept-Charset"
},{name:"Accept-Encoding",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Accept-Encoding"
},{name:"Accept-Language",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Accept-Language"
},{name:"Accept-Patch",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Accept-Patch"},{
name:"Accept-Post",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Accept-Post"},{
name:"Accept-Ranges",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Accept-Ranges"},{
name:"Access-Control-Allow-Credentials",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Credentials"
},{name:"Access-Control-Allow-Headers",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Headers"
},{name:"Access-Control-Allow-Methods",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Methods"
},{name:"Access-Control-Allow-Origin",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Origin"
},{name:"Access-Control-Expose-Headers",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Expose-Headers"
},{name:"Access-Control-Max-Age",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Max-Age"
},{name:"Access-Control-Request-Headers",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Request-Headers"
},{name:"Access-Control-Request-Method",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Request-Method"
},{name:"Age",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Age"},{
name:"Allow",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Allow"},{
name:"Alt-Svc",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Alt-Svc"},{
name:"Alt-Used",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Alt-Used"},{
name:"Authorization",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Authorization"},{
name:"Cache-Control",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Cache-Control"},{
name:"Clear-Site-Data",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Clear-Site-Data"
},{name:"Connection",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Connection"},{
name:"Content-Disposition",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Disposition"
},{name:"Content-DPR",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-DPR"},{
name:"Content-Encoding",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Encoding"
},{name:"Content-Language",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Language"
},{name:"Content-Length",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Length"
},{name:"Content-Location",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Location"
},{name:"Content-Range",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Range"},{
name:"Content-Security-Policy",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Security-Policy"
},{name:"Content-Security-Policy-Report-Only",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Security-Policy-Report-Only"
},{name:"Content-Type",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Type"},{
name:"Cookie",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Cookie"},{
name:"Critical-CH",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Critical-CH"},{
name:"Cross-Origin-Embedder-Policy",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Cross-Origin-Embedder-Policy"
},{name:"Cross-Origin-Opener-Policy",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Cross-Origin-Opener-Policy"
},{name:"Cross-Origin-Resource-Policy",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Cross-Origin-Resource-Policy"
},{name:"Date",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Date"},{
name:"Device-Memory",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Device-Memory"},{
name:"Digest",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Digest"},{
name:"DNT",url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/DNT"
},{name:"Downlink",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Downlink"},{
name:"DPR",url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/DPR"
},{name:"Early-Data",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Early-Data"},{
name:"ECT",url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/ECT"
},{name:"ETag",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/ETag"},{
name:"Expect",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Expect"},{
name:"Expect-CT",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Expect-CT"},{
name:"Expires",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Expires"},{
name:"Forwarded",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Forwarded"},{
name:"From",url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/From"
},{name:"Host",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Host"},{
name:"If-Match",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/If-Match"},{
name:"If-Modified-Since",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/If-Modified-Since"
},{name:"If-None-Match",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/If-None-Match"},{
name:"If-Range",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/If-Range"},{
name:"If-Unmodified-Since",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/If-Unmodified-Since"
},{name:"Keep-Alive",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Keep-Alive"},{
name:"Large-Allocation",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Large-Allocation"
},{name:"Last-Modified",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Last-Modified"},{
name:"Link",url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Link"
},{name:"Location",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Location"},{
name:"Max-Forwards",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Max-Forwards"},{
name:"NEL",url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/NEL"
},{name:"Origin",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Origin"},{
name:"Permissions-Policy",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Permissions-Policy"
},{name:"Pragma",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Pragma"},{
name:"Proxy-Authenticate",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Proxy-Authenticate"
},{name:"Proxy-Authorization",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Proxy-Authorization"
},{name:"Range",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Range"},{
name:"Referer",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Referer"},{
name:"Referrer-Policy",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Referrer-Policy"
},{name:"Retry-After",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Retry-After"},{
name:"RTT",url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/RTT"
},{name:"Save-Data",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Save-Data"},{
name:"Sec-CH-Prefers-Reduced-Motion",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Sec-CH-Prefers-Reduced-Motion"
},{name:"Sec-CH-Prefers-Reduced-Transparency",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Sec-CH-Prefers-Reduced-Transparency"
},{name:"Sec-CH-UA",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Sec-CH-UA"},{
name:"Sec-CH-UA-Arch",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Sec-CH-UA-Arch"
},{name:"Sec-CH-UA-Bitness",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Sec-CH-UA-Bitness"
},{name:"Sec-CH-UA-Full-Version",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Sec-CH-UA-Full-Version"
},{name:"Sec-CH-UA-Full-Version-List",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Sec-CH-UA-Full-Version-List"
},{name:"Sec-CH-UA-Mobile",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Sec-CH-UA-Mobile"
},{name:"Sec-CH-UA-Model",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Sec-CH-UA-Model"
},{name:"Sec-CH-UA-Platform",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Sec-CH-UA-Platform"
},{name:"Sec-CH-UA-Platform-Version",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Sec-CH-UA-Platform-Version"
},{name:"Sec-Fetch-Dest",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Sec-Fetch-Dest"
},{name:"Sec-Fetch-Mode",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Sec-Fetch-Mode"
},{name:"Sec-Fetch-Site",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Sec-Fetch-Site"
},{name:"Sec-Fetch-User",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Sec-Fetch-User"
},{name:"Sec-GPC",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Sec-GPC"},{
name:"Sec-Purpose",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Sec-Purpose"},{
name:"Sec-WebSocket-Accept",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Sec-WebSocket-Accept"
},{name:"Server",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Server"},{
name:"Server-Timing",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Server-Timing"},{
name:"Service-Worker-Navigation-Preload",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Service-Worker-Navigation-Preload"
},{name:"Set-Cookie",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Set-Cookie"},{
name:"SourceMap",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/SourceMap"},{
name:"Strict-Transport-Security",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Strict-Transport-Security"
},{name:"TE",url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/TE"
},{name:"Timing-Allow-Origin",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Timing-Allow-Origin"
},{name:"Tk",url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Tk"
},{name:"Trailer",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Trailer"},{
name:"Transfer-Encoding",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Transfer-Encoding"
},{name:"Upgrade",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Upgrade"},{
name:"Upgrade-Insecure-Requests",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Upgrade-Insecure-Requests"
},{name:"User-Agent",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/User-Agent"},{
name:"Vary",url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Vary"
},{name:"Via",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Via"},{
name:"Viewport-Width",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Viewport-Width"
},{name:"Want-Digest",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Want-Digest"},{
name:"Warning",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Warning"},{
name:"Width",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Width"},{
name:"WWW-Authenticate",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/WWW-Authenticate"
},{name:"X-Content-Type-Options",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Content-Type-Options"
},{name:"X-DNS-Prefetch-Control",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-DNS-Prefetch-Control"
},{name:"Non-standard",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Non-standard"},{
name:"X-Forwarded-For",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Forwarded-For"
},{name:"Non-standard",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Non-standard"},{
name:"X-Forwarded-Host",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Forwarded-Host"
},{name:"Non-standard",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Non-standard"},{
name:"X-Forwarded-Proto",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Forwarded-Proto"
},{name:"Non-standard",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Non-standard"},{
name:"X-Frame-Options",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Frame-Options"
},{name:"X-XSS-Protection",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-XSS-Protection"
},{name:"Cf-Cache-Status",
url:"https://developers.cloudflare.com/cache/concepts/default-cache-behavior/#cloudflare-cache-responses"
},{name:"Cf-Ray",
url:"https://developers.cloudflare.com/fundamentals/get-started/reference/http-request-headers/#cf-ray"
},{name:"Report-To",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Security-Policy/report-to"
},{name:"X-Cloud-Trace-Context",
url:"https://cloud.google.com/trace/docs/trace-context#legacy-http-header"},{
name:"Speculation-Rules",
url:"https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Speculation-Rules"
}],eKe=Qg({__name:"DataTableHeader",setup(e){const{cx:t}=zS()
;return(e,n)=>(Ub(),Hb(tYe,iy({is:"th"
},xm(t)("items-center font-medium px-2 min-w-0 -outline-offset-1")),{
default:ig((()=>[kv(e.$slots,"default")])),_:3},16))}}),tKe={key:0,
class:"max-h-[calc(100%-32px)] overflow-y-auto"},nKe={key:1,
class:"text-c-3 bg-b-1 flex min-h-[64px] items-center justify-center border-t px-4 text-sm"
},rKe=Qg({__name:"Headers",props:{headers:{}},setup(e){
const t=e=>JYe.find((t=>t.name.toLowerCase()===e.toLowerCase()))
;return(n,r)=>(Ub(),Hb(xm(uGe),{class:"overflow-auto",defaultOpen:!1,
itemCount:e.headers.length},{title:ig((()=>[kv(n.$slots,"title")])),
default:ig((()=>[e.headers.length?(Ub(),Qb("div",tKe,[Yb(WYe,{
columns:["minmax(auto, min-content)","minmax(50%, 1fr)"],scroll:""},{
default:ig((()=>[Yb(rYe,{class:"sr-only !block"},{
default:ig((()=>[Yb(xm(eKe),null,{
default:ig((()=>[...r[0]||(r[0]=[ey("Header Key",-1)])])),_:1
}),Yb(xm(eKe),null,{default:ig((()=>[...r[1]||(r[1]=[ey("Header Value",-1)])])),
_:1})])),_:1}),(Ub(!0),Qb(Mb,null,wv(e.headers,(e=>(Ub(),Hb(rYe,{key:e.name,
class:"group/row text-c-1"},{default:ig((()=>[Yb(GYe,{
class:"bg-b-1 sticky left-0 z-1 max-w-full group-first/row:border-t-0"},{
default:ig((()=>["string"==typeof t(e.name)?.url?(Ub(),Hb(KYe,{key:0,
class:"decoration-c-3",href:t(e.name).url},{
default:ig((()=>[ey(Uh(e.name),1)])),_:2},1032,["href"])):(Ub(),Qb(Mb,{key:1
},[ey(Uh(e.name),1)],64))])),_:2},1024),Yb(GYe,{
class:"z-0 group-first/row:border-t-0",text:e.value},null,8,["text"])])),_:2
},1024)))),128))])),_:1})])):(Ub(),Qb("div",nKe," No headers "))])),_:3
},8,["itemCount"]))}}),oKe={"application/epub+zip":{extension:".epub"},
"application/gzip":{extension:".gz"},"application/java-archive":{
extension:".jar"},"application/javascript":{extension:".js",raw:!0},
"application/json":{extension:".json",raw:!0,language:"json"},
"application/ld+json":{extension:".jsonld",raw:!0,language:"json"},
"application/problem+json":{extension:".json",raw:!0,language:"json"},
"application/vnd.api+json":{extension:".json",raw:!0,language:"json"},
"application/dns-json":{extension:".json",raw:!0,language:"json"},
"application/msword":{extension:".doc"},"application/octet-stream":{
extension:".bin"},"application/ogg":{extension:".ogx"},"application/pdf":{
extension:".pdf",preview:"object"},"application/rtf":{extension:".rtf",raw:!0},
"application/vnd.amazon.ebook":{extension:".azw"},
"application/vnd.apple.installer+xml":{extension:".mpkg",raw:!0,language:"xml"},
"application/vnd.mozilla.xul+xml":{extension:".xul",raw:!0,language:"xml"},
"application/vnd.ms-excel":{extension:".xls"},"application/vnd.ms-fontobject":{
extension:".eot"},"application/vnd.ms-powerpoint":{extension:".ppt"},
"application/vnd.oasis.opendocument.presentation":{extension:".odp"},
"application/vnd.oasis.opendocument.spreadsheet":{extension:".ods"},
"application/vnd.oasis.opendocument.text":{extension:".odt"},
"application/vnd.openxmlformats-officedocument.presentationml.presentation":{
extension:".pptx"},
"application/vnd.openxmlformats-officedocument.spreadsheetml.sheet":{
extension:".xlsx"},
"application/vnd.openxmlformats-officedocument.wordprocessingml.document":{
extension:".docx"},"application/vnd.rar":{extension:".rar"},
"application/vnd.visio":{extension:".vsd"},"application/x-7z-compressed":{
extension:".7z"},"application/x-abiword":{extension:".abw"},
"application/x-bzip":{extension:".bz"},"application/x-bzip2":{extension:".bz2"},
"application/x-cdf":{extension:".cda"},"application/x-csh":{extension:".csh"},
"application/x-freearc":{extension:".arc"},"application/x-httpd-php":{
extension:".php",raw:!0},"application/x-sh":{extension:".sh",raw:!0},
"application/x-tar":{extension:".tar"},"application/xhtml+xml":{
extension:".xhtml",raw:!0,language:"html"},"application/xml":{extension:".xml",
raw:!0,language:"xml"},"application/yaml":{extension:".yaml",raw:!0,
language:"yaml"},"application/zip":{extension:".zip"},"audio/aac":{
extension:".aac"},"audio/midi":{extension:".midi"},"audio/mpeg":{
extension:".mp3",preview:"audio"},"audio/ogg":{extension:".oga"},"audio/wav":{
extension:".wav"},"audio/webm":{extension:".weba"},"font/otf":{extension:".otf"
},"font/ttf":{extension:".ttf"},"font/woff":{extension:".woff"},"font/woff2":{
extension:".woff2"},"image/apng":{extension:".apng",preview:"image",alpha:!0},
"image/avif":{extension:".avif",preview:"image"},"image/bmp":{extension:".bmp",
preview:"image"},"image/gif":{extension:".gif",preview:"image",alpha:!0},
"image/jpeg":{extension:".jpg",preview:"image"},"image/png":{extension:".png",
preview:"image",alpha:!0},"image/svg+xml":{extension:".svg",raw:!0,
language:"xml",preview:"image",alpha:!0},"image/tiff":{extension:".tiff"},
"image/vnd.microsoft.icon":{extension:".ico",preview:"image"},"image/webp":{
extension:".webp",preview:"image",alpha:!0},"text/calendar":{extension:".ics",
raw:!0},"text/css":{extension:".css",raw:!0,language:"css"},"text/csv":{
extension:".csv",raw:!0},"text/html":{extension:".html",raw:!0,language:"html",
preview:"object"},"text/javascript":{extension:".js",raw:!0},"text/plain":{
extension:".txt",raw:!0},"text/xml":{extension:".xml",raw:!0,language:"xml"},
"text/yaml":{extension:".yaml",raw:!0,language:"yaml"},"video/3gpp":{
extension:".3gp"},"audio/3gpp":{extension:".3gp"},"video/3gpp2":{
extension:".3g2"},"audio/3gpp2":{extension:".3g2"},"video/mp2t":{extension:".ts"
},"video/mp4":{extension:".mp4",preview:"video"},"video/mpeg":{extension:".mpeg"
},"video/ogg":{extension:".ogv"},"video/webm":{extension:".webm",preview:"video"
},"video/x-msvideo":{extension:".avi"}
},aKe=Object.entries(oKe).filter((([,e])=>e?.raw)).map((([e])=>e))
;const iKe=e=>{try{return decodeURIComponent(e)}catch{return e}}
;function sKe({data:e,headers:t}){
const n=t.find((e=>"content-type"===e.name.toLowerCase())),r=n?.value?new aVe(n.value):void 0,o=function(e){
let t="";if(e){
const n=e.match(/filename\*=UTF-8''([^;]+)/)?.[1]??e.match(/filename\s*=\s*"?([^";]+)"?/)?.[1]
;n&&(t=iKe(n.trim()))}return t
}(t.find((e=>"content-disposition"===e.name.toLowerCase()))?.value??""),a=(e=>e instanceof Blob)(e)?URL.createObjectURL(e):"string"==typeof e?URL.createObjectURL(new Blob([e],{
type:r?r.toString():void 0
})):e instanceof Object&&Object.keys(e).length?URL.createObjectURL(new Blob([JSON.stringify(e)],{
type:r?r.toString():void 0})):"";return{mimeType:r,attachmentFilename:o,
dataUrl:a}}const lKe=["download","href"],cKe=Qg({__name:"ResponseBodyDownload",
props:{href:{},type:{},filename:{}},setup(e){const t=e,n=Sy((()=>{
const e=sVe(t.type??"")?.extension??".unknown"
;return t.filename?t.filename:`response${e}`}));return(t,r)=>(Ub(),Qb("a",{
class:"text-c-3 text-xxs hover:bg-b-3 flex items-center gap-1 rounded px-1.5 py-0.5 no-underline",
download:`${n.value}`,href:e.href,onClick:r[0]||(r[0]=BO((()=>{}),["stop"]))
},[Yb(xm(Gne),{icon:"Download",size:"xs"
}),r[1]||(r[1]=Gb("span",null,[Gb("span",null,"Download"),Gb("span",{
class:"sr-only"},"Response Body")],-1))],8,lKe))}}),uKe={
class:"flex justify-center px-2 py-3"},dKe={class:"text-c-3 p-2 text-sm"}
;const pKe=sae({},[["render",function(e,t){
return Ub(),Qb("div",uKe,[Gb("div",dKe,[kv(e.$slots,"default")])])
}]]),hKe=["src"],fKe=["src","type"],mKe=["src","type"],gKe=["data","type"],vKe=Qg({
__name:"ResponseBodyPreview",props:{src:{},type:{},mode:{},alpha:{type:Boolean,
default:!1}},setup(e){const t=bm(!1)
;return mg((()=>e.src),(()=>t.value=!1)),(n,r)=>!t.value&&e.src?(Ub(),Qb("div",{
key:0,class:Ih(["flex justify-center overflow-auto rounded-b",{
"bg-preview p-2":e.alpha}])},["image"===e.mode?(Ub(),Qb("img",{key:0,
class:Ih(["h-full max-w-full",{rounded:e.alpha}]),src:e.src,
onError:r[0]||(r[0]=e=>t.value=!0)
},null,42,hKe)):"video"===e.mode?(Ub(),Qb("video",{key:1,autoplay:"",
controls:"",width:"100%",onError:r[1]||(r[1]=e=>t.value=!0)},[Gb("source",{
src:e.src,type:e.type},null,8,fKe)],32)):"audio"===e.mode?(Ub(),Qb("audio",{
key:2,class:"my-12",controls:"",onError:r[2]||(r[2]=e=>t.value=!0)
},[Gb("source",{src:e.src,type:e.type},null,8,mKe)],32)):(Ub(),Qb("object",{
key:3,class:"aspect-[4/3] w-full",data:e.src,type:e.type,
onError:r[3]||(r[3]=e=>t.value=!0)},null,40,gKe))],2)):(Ub(),Hb(pKe,{key:1},{
default:ig((()=>[...r[4]||(r[4]=[ey("Preview unavailable",-1)])])),_:1}))}
}),bKe=sae(vKe,[["__scopeId","data-v-c02b5bb8"]]),yKe={
class:"scalar-code-block group/code-block body-raw grid min-h-0 overflow-hidden p-px outline-none has-[:focus-visible]:outline"
},OKe={class:"body-raw-scroller custom-scroll relative pr-1",tabindex:"0"
},wKe=Qg({__name:"ResponseBodyRaw",props:{content:{},language:{}},setup(e){
const t=e,n=bm(null),r=Hg(),{codeMirror:o}=Xwe({codeMirrorRef:n,readOnly:!0,
lineNumbers:!0,content:Pm((()=>LX(t.content))),language:Pm((()=>t.language)),
forceFoldGutter:!0}),a=()=>o.value?.state.doc.toString()||"";return(e,t)=>(Ub(),
Qb("div",yKe,[a()?(Ub(),Hb(xm(MG),{key:0,class:"z-context top-2 mr-2",
content:a(),controls:xm(r)
},null,8,["content","controls"])):ny("",!0),Gb("div",OKe,[Gb("div",{
ref_key:"codeMirrorRef",ref:n},null,512)])]))}
}),xKe=sae(wKe,[["__scopeId","data-v-10022578"]]),kKe={
class:"text-c-3 text-xxs -my-1 flex justify-center gap-0.5 rounded p-0.5"
},SKe=Qg({__name:"ResponseBodyToggle",props:{modelValue:{type:Boolean}},
emits:["update:modelValue"],setup:e=>(t,n)=>(Ub(),Qb("div",kKe,[Gb("button",{
class:Ih(["hover:bg-b-3 rounded px-1",{
"bg-b-3 text-c-1 cursor-default":e.modelValue}]),type:"button",
onClick:n[0]||(n[0]=BO((e=>t.$emit("update:modelValue",!0)),["stop"]))
}," Preview ",2),Gb("button",{class:Ih(["hover:bg-b-3 rounded px-1",{
"bg-b-3 text-c-1 cursor-default":!e.modelValue}]),type:"button",
onClick:n[1]||(n[1]=BO((e=>t.$emit("update:modelValue",!1)),["stop"]))
}," Raw ",2)]))}),_Ke={key:0,
class:"bg-b-1 flex max-h-[calc(100%-32px)] flex-col overflow-hidden"},TKe={
class:"box-content flex min-h-8 items-center justify-between border-y px-3"
},EKe={class:"text-xxs font-code leading-3"},AKe=Qg({__name:"ResponseBody",
props:{title:{},layout:{},data:{},headers:{}},setup(e){
const t=bm(!0),n=Sy((()=>!(!i.value?.raw||!i.value.preview))),r=Sy((()=>t.value||!n.value)),o=Sy((()=>!t.value||!n.value)),a=Sy((()=>sKe({
data:e.data,headers:e.headers}))),i=Sy((()=>function(e){const t=oKe[e]
;return t||(e.endsWith("+json")?{extension:".json",raw:!0,language:"json"
}:void 0)}(a.value.mimeType?.essence??"")));return(s,l)=>(Ub(),Hb(xm(uGe),{
class:"max-h-content overflow-y-hidden",isStatic:"reference"===e.layout},xv({
title:ig((()=>[ey(Uh(e.title),1)])),
default:ig((()=>[e.data?(Ub(),Qb("div",_Ke,[Gb("div",TKe,[Gb("span",EKe,Uh(a.value.mimeType?.essence),1),n.value?(Ub(),
Hb(SKe,{key:0,modelValue:t.value,"onUpdate:modelValue":l[0]||(l[0]=e=>t.value=e)
},null,8,["modelValue"])):ny("",!0)]),i.value?.raw&&o.value?(Ub(),Hb(xKe,{
key:a.value.dataUrl,content:e.data,language:i.value.language
},null,8,["content","language"])):ny("",!0),i.value?.preview&&r.value?(Ub(),
Hb(bKe,{key:a.value.dataUrl,alpha:i.value.alpha,mode:i.value.preview,
src:a.value.dataUrl,type:a.value.mimeType?.essence??""
},null,8,["alpha","mode","src","type"])):ny("",!0),i.value?.raw||i.value?.preview?ny("",!0):(Ub(),
Hb(pKe,{key:2},{default:ig((()=>[...l[1]||(l[1]=[ey(" Binary file ",-1)])])),_:1
}))])):ny("",!0)])),_:2},[e.data&&a.value.dataUrl?{name:"actions",
fn:ig((()=>[Yb(cKe,{filename:a.value.attachmentFilename,href:a.value.dataUrl,
type:a.value.mimeType?.essence},null,8,["filename","href","type"])])),key:"0"
}:void 0]),1032,["isStatic"]))}
}),CKe=sae(AKe,[["__scopeId","data-v-32d6d6ca"]]),$Ke={
class:"flex w-full items-center justify-between"},PKe={key:0,
class:"mr-2 flex items-center gap-2"},DKe={key:0,
class:"text-red bg-b-danger sticky top-0 border-b p-2"},IKe={key:1,class:"p-2"
},MKe=Qg({__name:"ResponseBodyStreaming",props:{reader:{}},setup(e){
const t=Goe(),n=bm(""),r=bm(null),o=new TextDecoder,a=bm(null),i=()=>{
a.value&&(a.value.scrollTop=a.value.scrollHeight)};return mg(n,(()=>{Xm(i)
})),iv((()=>{t.start(),async function(){try{for(;t.isLoading;){
const{done:r,value:a}=await e.reader.read();if(r){t.clear();break}
a&&(n.value+=o.decode(a,{stream:!0}))}}catch(Kw){
console.error("Error reading stream:",Kw),t.clear(),r.value=Kw}finally{
n.value+=o.decode()}}(),r.value=null})),cv((()=>{e.reader.cancel(),t.clear()})),
(e,o)=>(Ub(),Hb(xm(uGe),{class:"max-h-content overflow-y-hidden"},{
title:ig((()=>[Gb("div",$Ke,[o[1]||(o[1]=Gb("div",null,"Body",-1)),xm(t).isLoading?(Ub(),
Qb("div",PKe,[Yb(xm(VS),{loadingState:xm(t),size:"xs"
},null,8,["loadingState"]),o[0]||(o[0]=Gb("span",{class:"text-c-2"
}," Listening… ",-1))])):ny("",!0)])])),default:ig((()=>[Gb("div",{
ref_key:"contentContainer",ref:a,
class:"text-xxs font-code h-full overflow-auto leading-2 whitespace-pre-wrap"
},[r.value?(Ub(),
Qb("div",DKe,Uh(r.value.message),1)):ny("",!0),n.value?(Ub(),Qb("div",IKe,Uh(n.value),1)):ny("",!0)],512)])),
_:1}))}}),NKe=Qg({__name:"ResponseBodyVirtual",props:{content:{},data:{},
headers:{}},setup(e){const t=Sy((()=>function(e){const t=e.trim()
;if("{"!==t[0]&&"["!==t[0])return e;try{
return JSON.stringify(JSON.parse(e),null,2)}catch{return e}
}(e.content))),n=Sy((()=>sKe({data:e.data,headers:e.headers})))
;return(e,r)=>(Ub(),Hb(xm(uGe),{
class:"!max-h-100% response-body-virtual overflow-x-auto"},xv({
title:ig((()=>[r[0]||(r[0]=ey("Body",-1))])),
default:ig((()=>[r[1]||(r[1]=Gb("div",{
class:"font-code text-xxs rounded-t border border-b-0 px-2.5 py-1.5"
}," This response body is massive! Syntax highlighting won't work here. ",-1)),Yb(xm(zoe),{
containerClass:"custom-scroll scalar-code-block border rounded-b flex flex-1 max-h-screen",
contentClass:"language-plaintext whitespace-pre font-code text-base",
lineHeight:20,text:t.value},null,8,["text"])])),_:2},[n.value.dataUrl?{
name:"actions",fn:ig((()=>[Yb(cKe,{filename:n.value.attachmentFilename,
href:n.value.dataUrl,type:n.value.mimeType?.essence
},null,8,["filename","href","type"])])),key:"0"}:void 0]),1024))}}),RKe={key:1,
class:"text-c-3 bg-b-1 flex min-h-[64px] items-center justify-center border-t px-4 text-sm"
},LKe=Qg({__name:"ResponseCookies",props:{cookies:{}},
setup:e=>(t,n)=>(Ub(),Hb(xm(uGe),{defaultOpen:!1,itemCount:e.cookies.length},{
title:ig((()=>[...n[0]||(n[0]=[ey("Cookies",-1)])])),
default:ig((()=>[(Ub(),Qb(Mb,{key:0},[e.cookies.length?(Ub(),Hb(WYe,{key:0,
class:"flex-1",columns:["",""]},{
default:ig((()=>[(Ub(!0),Qb(Mb,null,wv(e.cookies,(e=>(Ub(),Hb(rYe,{key:e.name},{
default:ig((()=>[Yb(GYe,{text:e.name},null,8,["text"]),Yb(GYe,{text:e.value
},null,8,["text"])])),_:2},1024)))),128))])),_:1
})):(Ub(),Qb("div",RKe," No cookies "))],64))])),_:1},8,["itemCount"]))
}),BKe="          .:=+++++=================-\n         .--#*                       :.\n        .-:-**                        -.\n      .:-::-+*                        =:\n     .:-:::-=#                         ::\n    .-:::----**                        ..\n   .-:::::---=#                         ..\n  :-::::::----**                         ..\n.:-::::::::----*=                        ..\n.-::::::::------+-                        ..\n..::::::::-------=                         ..\n .:::::----------++                        ..\n   .:::----------+**+*++*+*++*+++*++++++++++:.\n   ------------+*+=-=======================.\n   .----------+*+=========================:.\n    :--------+*+=-========================.\n    .=------+*+=-========================:.\n     .=----+*+=-------=================+-.\n     .----+*+=----------================.\n     .:=-+*+=----------=-==============-\n      .-+*+=----------------===========.\n       .-+=------------------====-====:.",jKe=Qg({
__name:"ScalarAsciiArt",props:{art:{},animate:{type:Boolean}},setup(e){
const t=e,n=Sy((()=>t.art.split("\n"))),r=(e,t)=>({
animationDuration:100*e+"ms, 500ms",
animationTimingFunction:`steps(${e}), step-end`,animationDelay:100*t+"ms, 0ms",
animationIterationCount:"1, "+100*((n.value?.length??0)+(n.value?.[n.value?.length-1]?.length??0)+5)/500
});return(t,o)=>(Ub(),Qb("div",{"aria-hidden":"true",
class:Ih(["ascii-art font-code flex flex-col items-start text-[6px] leading-[7px]",{
"ascii-art-animate":e.animate}]),role:"presentation",inert:""
},[(Ub(!0),Qb(Mb,null,wv(n.value,((e,t)=>(Ub(),Qb("span",{key:t,
class:"inline-block",style:Ah({width:`calc(${e.length+1}ch)`})},[Gb("span",{
class:"inline-block whitespace-pre overflow-hidden",style:Ah(r(e.length,t))
},Uh(e),5)],4)))),128))],2))}
}),UKe=sae(jKe,[["__scopeId","data-v-69ebd973"]]),zKe={
class:"flex-center flex w-full scale-75"},FKe={class:"relative"},ZKe={
class:"relative -ml-12"},QKe={class:"relative -ml-12"},HKe=Qg({
__name:"EmptyState",
setup:e=>(e,t)=>(Ub(),Qb("div",zKe,[Gb("div",FKe,[Yb(xm(L2),{
class:"keycap-hotkey right-14 border-transparent py-0 text-xl",hotkey:""
}),Yb(UKe,{art:xm(BKe),class:"text-c-3 !leading-[6px]"
},null,8,["art"])]),Gb("div",ZKe,[Yb(xm(L2),{
class:"keycap-hotkey right-14 border-transparent py-0 text-xl",hotkey:"",
modifier:["Shift"]}),Yb(UKe,{art:xm(BKe),class:"keycap-n !leading-[6px]"
},null,8,["art"])]),Gb("div",QKe,[t[0]||(t[0]=Gb("div",{
class:"keycap-hotkey right-16 text-xl"},"P",-1)),Yb(UKe,{art:xm(BKe),
class:"keycap-n !leading-[6px]"},null,8,["art"])])]))
}),VKe=sae(HKe,[["__scopeId","data-v-b1211b87"]]),qKe={
class:"flex-center relative flex flex-1 flex-col gap-6 p-2 capitalize"},WKe={
key:0,class:"scalar-version-number"},XKe={
class:"text-c-3 right-4 mt-auto flex w-full flex-col items-end gap-2 text-sm"
},GKe=Qg({__name:"ResponseEmpty",props:{layout:{},totalPerformedRequests:{},
appVersion:{},events:{}},
emits:["addRequest","sendRequest","openCommandPalette"],setup(e,{emit:t}){
const n=t,r=e=>{e?.createNew&&n("addRequest")}
;return iv((()=>e.events.hotKeys.on(r))),
cv((()=>e.events.hotKeys.off(r))),(t,r)=>(Ub(),Qb("div",qKe,[Gb("div",{
class:Ih(["flex h-[calc(100%_-_50px)] flex-col items-center justify-center",{
"hidden opacity-0":e.totalPerformedRequests<1&&"modal"!==e.layout}])
},["modal"!==e.layout?(Ub(),
Qb("div",WKe,[ey(" Scalar App V"+Uh(e.appVersion)+" Beta ",1),r[3]||(r[3]=Gb("div",{
class:"mt-2"},[Gb("a",{href:"https://github.com/scalar/scalar/issues/2669",
target:"_blank"}," Roadmap ")],-1))])):ny("",!0),r[4]||(r[4]=Gb("a",{
class:"gitbook-show scalar-version-number",href:"https://www.scalar.com",
target:"_blank"}," Powered By Scalar.com ",-1)),Yb(UKe,{
art:xm("                         .,,uod8B8bou,,.\n                ..,uod8BBBBBBBBBBBBBBBBRPFT?l!i:.\n           ||||||||||||||!?TFPRBBBBBBBBBBBBBBB8m=,\n           ||||   '\"\"^^!!||||||||||TFPRBBBVT!:...!\n           ||||            '\"\"^^!!|||||?!:.......!\n           ||||                     ||||.........!\n           ||||                     ||||.........!\n           ||||                     ||||.........!\n           ||||                     ||||.........!\n           ||||                     ||||.........!\n           ||||                     ||||.........!\n           ||||,                    ||||.........`\n           |||||!!-._               ||||.......;.\n           ':!|||||||||!!-._        ||||.....bBBBBWdou,.\n         bBBBBB86foi!|||||||!!-..:|||!..bBBBBBBBBBBBBBBY!\n         ::!?TFPRBBBBBB86foi!||||||||!!bBBBBBBBBBBBBBBY..!\n         :::::::::!?TFPRBBBBBB86ftiaabBBBBBBBBBBBBBBY....!\n         :::;`\"^!:;::::::!?TFPRBBBBBBBBBBBBBBBBBBBY......!\n         ;::::::...''^::::::::::!?TFPRBBBBBBBBBBY........!\n     .ob86foi;::::::::::::::::::::::::!?TFPRBY..........`\n    .b888888888886foi;:::::::::::::::::::::::..........`\n .b888888888888888888886foi;::::::::::::::::..........\n.b888888888888888888888888888886foi;:::::::::......`\n!Tf998888888888888888888888888888888886foi;:::....`\n  '\"^!|Tf9988888888888888888888888888888888!::..`\n       '\"^!|Tf998888888888888888888888889!! '`\n             '\"^!|Tf9988888888888888888!!`            iBBbo.\n                  '\"^!|Tf998888888889!`             WBBBBbo.\n                        '\"^!|Tf9989!`              YBBBP^'\n                              '\"^!`               `\n"),
class:"text-c-3"},null,8,["art"])],2),"modal"!==e.layout?(Ub(),Qb("div",{key:0,
class:Ih(["hidden h-[calc(100%_-_50px)] items-center justify-center pb-5",{
"!flex opacity-100":0==e.totalPerformedRequests}])
},[Yb(VKe)],2)):ny("",!0),Gb("div",XKe,["modal"!==e.layout?(Ub(),Qb("button",{
key:0,class:"flex items-center gap-1.5",type:"button",
onClick:r[0]||(r[0]=e=>n("openCommandPalette"))
},[r[5]||(r[5]=ey(" Get Started ",-1)),Yb(xm(L2),{hotkey:"p",
modifier:["default","Shift"]
})])):ny("",!0),"desktop"===e.layout?(Ub(),Qb("button",{key:1,
class:"flex items-center gap-1.5",type:"button",
onClick:r[1]||(r[1]=e=>n("addRequest"))
},[r[6]||(r[6]=ey(" New Request ",-1)),Yb(xm(L2),{hotkey:"N"
})])):ny("",!0),Gb("button",{class:"flex items-center gap-1.5",type:"button",
onClick:r[2]||(r[2]=e=>n("sendRequest"))
},[r[7]||(r[7]=ey(" Send Request ",-1)),Yb(xm(L2),{hotkey:"↵"})])])]))}
}),YKe=sae(GKe,[["__scopeId","data-v-159bd9b3"]]),KKe={key:0,
class:"bg-b-1 z-overlay absolute inset-0 flex flex-col items-center justify-center gap-6"
},JKe=Qg({__name:"ResponseLoadingOverlay",props:{events:{}},setup(e){
const t=Goe(),n=bm();return e.events.requestStatus.on((async e=>{
"start"===e?n.value=setTimeout((()=>t.start()),1e3):(clearTimeout(n.value),
n.value=void 0,await t.clear())})),(n,r)=>(Ub(),Hb(jy,null,{
default:ig((()=>[xm(t).isActive?(Ub(),Qb("div",KKe,[Yb(xm(VS),{class:"text-c-3",
loader:xm(t),size:"3xl"},null,8,["loader"]),Yb(xm(WS),{variant:"ghost",
onClick:r[0]||(r[0]=t=>e.events.cancelRequest.emit())},{
default:ig((()=>[...r[1]||(r[1]=[ey(" Cancel ",-1)])])),_:1})])):ny("",!0)])),
_:1}))}
}),eJe=sae(JKe,[["__scopeId","data-v-57ced68a"]]),tJe=e=>Number.isFinite(e)?e:0
;function nJe(e){switch(typeof e){case"number":
if(Number.isFinite(e))return function(e){return{days:Math.trunc(e/864e5),
hours:Math.trunc(e/36e5%24),minutes:Math.trunc(e/6e4%60),
seconds:Math.trunc(e/1e3%60),milliseconds:Math.trunc(e%1e3),
microseconds:Math.trunc(tJe(1e3*e)%1e3),nanoseconds:Math.trunc(tJe(1e6*e)%1e3)}
}(e);break;case"bigint":return function(e){return{days:e/86400000n,
hours:e/3600000n%24n,minutes:e/60000n%60n,seconds:e/1000n%60n,
milliseconds:e%1000n,microseconds:0n,nanoseconds:0n}}(e)}
throw new TypeError("Expected a finite number or bigint")}function rJe(e,t){
const n="bigint"==typeof e
;if(!n&&!Number.isFinite(e))throw new TypeError("Expected a finite number or bigint")
;const r=e<0?"-":"";e=e<0?-e:e,(t={...t
}).colonNotation&&(t.compact=!1,t.formatSubMilliseconds=!1,
t.separateMilliseconds=!1,
t.verbose=!1),t.compact&&(t.unitCount=1,t.secondsDecimalDigits=0,
t.millisecondsDecimalDigits=0);let o=[];const a=(e,n,r,a)=>{
if(0!==o.length&&t.colonNotation||!(e=>0===e||0n===e)(e)||t.colonNotation&&"m"===r){
if(a??=String(e),t.colonNotation){
const e=a.includes(".")?a.split(".")[0].length:a.length,t=o.length>0?2:1
;a="0".repeat(Math.max(0,t-e))+a
}else a+=t.verbose?" "+(i=n,1===(s=e)||1n===s?i:`${i}s`):r;var i,s;o.push(a)}
},i=nJe(e),s=BigInt(i.days)
;if(t.hideYearAndDays?a(24n*BigInt(s)+BigInt(i.hours),"hour","h"):(t.hideYear?a(s,"day","d"):(a(s/365n,"year","y"),
a(s%365n,"day","d")),
a(Number(i.hours),"hour","h")),a(Number(i.minutes),"minute","m"),
!t.hideSeconds)if(t.separateMilliseconds||t.formatSubMilliseconds||!t.colonNotation&&e<1e3&&!t.subSecondsAsDecimals){
const e=Number(i.seconds),n=Number(i.milliseconds),r=Number(i.microseconds),o=Number(i.nanoseconds)
;if(a(e,"second","s"),
t.formatSubMilliseconds)a(n,"millisecond","ms"),a(r,"microsecond","µs"),
a(o,"nanosecond","ns");else{
const e=n+r/1e3+o/1e6,i="number"==typeof t.millisecondsDecimalDigits?t.millisecondsDecimalDigits:0,s=e>=1?Math.round(e):Math.ceil(e),l=i?e.toFixed(i):s
;a(Number.parseFloat(l),"millisecond","ms",l)}}else{const r=((e,t)=>{
const n=Math.floor(e*10**t+1e-7);return(Math.round(n)/10**t).toFixed(t)
})((n?Number(e%86400000n):e)/1e3%60,"number"==typeof t.secondsDecimalDigits?t.secondsDecimalDigits:1),o=t.keepDecimalsOnWholeSeconds?r:r.replace(/\.0+$/,"")
;a(Number.parseFloat(o),"second","s",o)}
if(0===o.length)return r+"0"+(t.verbose?" milliseconds":"ms")
;const l=t.colonNotation?":":" "
;return"number"==typeof t.unitCount&&(o=o.slice(0,Math.max(t.unitCount,1))),
r+o.join(l)}const oJe=e=>{
const t=Number.parseInt(e.headers?.["Content-Length"]||e.headers?.["content-length"]||"0",10)
;if(!(isNaN(t)||t<=0))return _2(t)},aJe={class:"text-c-1 flex gap-1.5"},iJe={
key:0},sJe={key:0},lJe={key:1},cJe=Qg({__name:"ResponseMetaInformation",props:{
response:{},events:{}},setup(e){const t=bm(),n=bm(0)
;e.events.requestStatus.on((e=>{
"start"===e?t.value=setInterval((()=>n.value+=1e3),1e3):(clearInterval(t.value),
t.value=void 0,n.value=0)}));const r=Sy((()=>{const t=e.response.status
;if(t)return $H[t]??void 0}))
;return(o,a)=>(Ub(),Qb("div",aJe,[t.value&&n.value?(Ub(),
Qb("span",iJe,Uh(xm(rJe)(n.value)),1)):(Ub(),Qb(Mb,{key:1
},[Gb("span",null,[a[0]||(a[0]=Gb("span",{class:"sr-only"
},"Response Information, Duration:",-1)),ey(" "+Uh(xm(rJe)(e.response.duration)),1)]),xm(oJe)(e.response)?(Ub(),
Qb("span",sJe,[a[1]||(a[1]=Gb("span",{class:"sr-only"
},", Size:",-1)),ey(" "+Uh(xm(oJe)(e.response)),1)])):ny("",!0),r.value?(Ub(),
Qb(Mb,{key:1},[a[2]||(a[2]=Gb("span",{class:"sr-only"
},", Status:",-1)),r.value.url?(Ub(),Hb(KYe,{key:0,
class:"flex items-center gap-1.5",href:r.value.url},{
default:ig((()=>[ey(Uh(e.response.status)+" "+Uh(r.value.name)+" ",1),Gb("span",{
class:"block h-1.5 w-1.5 rounded-full",style:Ah({backgroundColor:r.value.color})
},null,4)])),_:1
},8,["href"])):(Ub(),Qb("span",lJe,[ey(Uh(e.response.status)+" "+Uh(r.value.name)+" ",1),Gb("span",{
class:"block h-1.5 w-1.5 rounded-full",style:Ah({backgroundColor:r.value.color})
},null,4)]))],64)):ny("",!0)],64))]))}}),uJe={
class:"flex h-8 flex-1 items-center"},dJe=["id","role"],pJe=2e5,hJe=Qg({
__name:"ResponseBlock",props:{response:{},request:{},layout:{},
totalPerformedRequests:{},appVersion:{},plugins:{},events:{},eventBus:{}},
emits:["sendRequest"],setup(e,{expose:t,emit:n}){const r=n,o=Sy((()=>{
const t=e.response?.headers;return t?Object.keys(t).map((e=>({name:e,
value:t[e]??""}))):[]})),a=Sy((()=>e.response?.cookieHeaderKeys.map((e=>(e=>{
if(!e||"string"!=typeof e)return null;const t=e.indexOf("=")
;if(-1===t)return null;const n=e.substring(0,t).trim(),r=e.substring(t+1).trim()
;return n?{name:n,value:r}:null
})(e))).filter(xH)??[])),i=["Cookies","Headers","Body"],s=bm("All"),l=Sy((()=>["All",...i])),c=Sy((()=>Object.fromEntries(l.value.map((e=>[e,Hg()]))))),u=Sy((()=>{
if(!e.response||!("size"in e.response))return!1
;const t=e.response.headers?.["content-type"]||e.response.headers?.["Content-Type"]
;return!(!t||(e.response.size??0)<=pJe||t.includes("text/html"))&&(aKe.some((e=>t.includes(e)))&&(e.response.size??0)>pJe)
})),d=Sy((()=>e.request?.headers?[...e.request.headers].map((e=>({name:e[0],
value:e[1],required:!1}))):[])),p=e=>"All"===s.value||s.value===e;return t({
responseHeaders:o,responseCookies:a,requestHeaders:d,shouldVirtualize:u,
activeFilter:s,filters:l}),(t,n)=>(Ub(),Hb(TXe,{"aria-label":"Response"},{
title:ig((()=>[Gb("div",uJe,[Gb("div",{"aria-live":"polite",
class:Ih(["flex items-center",{"animate-response-heading":e.response}])
},[n[4]||(n[4]=Gb("span",{class:"response-heading pointer-events-none absolute"
}," Response ",-1)),e.response?(Ub(),Hb(cJe,{key:0,
class:"animate-response-children",events:e.events,response:e.response
},null,8,["events","response"])):ny("",!0)],2),Yb(SXe,{modelValue:s.value,
"onUpdate:modelValue":n[0]||(n[0]=e=>s.value=e),filterIds:c.value,
filters:l.value},null,8,["modelValue","filterIds","filters"])])])),
default:ig((()=>[Gb("div",{id:c.value.All,
class:Ih(["custom-scroll response-section-content relative grid h-full justify-stretch",{
"content-start":e.response}]),role:"All"===s.value&&e.response?"tabpanel":"none"
},[e.response?(Ub(),Qb(Mb,{key:1},[p("Cookies")?(Ub(),Hb(LKe,{key:0,
id:c.value.Cookies,class:"response-section-content-cookies",cookies:a.value,
role:"All"===s.value?"none":"tabpanel"
},null,8,["id","cookies","role"])):ny("",!0),p("Headers")?(Ub(),Hb(rKe,{key:1,
id:c.value.Headers,class:"response-section-content-headers",headers:d.value,
role:"All"===s.value?"none":"tabpanel"},{
title:ig((()=>[...n[5]||(n[5]=[ey("Request Headers",-1)])])),_:1
},8,["id","headers","role"])):ny("",!0),p("Headers")?(Ub(),Hb(rKe,{key:2,
id:c.value.Headers,class:"response-section-content-headers",headers:o.value,
role:"All"===s.value?"none":"tabpanel"},{
title:ig((()=>[...n[6]||(n[6]=[ey("Response Headers",-1)])])),_:1
},8,["id","headers","role"])):ny("",!0),(Ub(!0),
Qb(Mb,null,wv(e.plugins,((t,n)=>(Ub(),Hb(xm(v2),{key:n},{
default:ig((()=>[t.components?.response&&e.request&&e.response?sg((Ub(),
Hb(bv(t.components.response),{key:0,request:e.request,response:e.response
},null,8,["request","response"])),[[Jy,"All"===s.value]]):ny("",!0)])),_:2
},1024)))),128)),"All"===s.value||"Body"===s.value?(Ub(),Qb(Mb,{key:3
},["reader"in e.response?(Ub(),Hb(MKe,{key:0,id:c.value.Body,
class:"response-section-content-body",reader:e.response.reader
},null,8,["id","reader"])):u.value&&"string"==typeof e.response?.data?(Ub(),
Hb(NKe,{key:1,id:c.value.Body,content:e.response.data,data:e.response?.data,
headers:o.value,role:"All"===s.value?"none":"tabpanel"
},null,8,["id","content","data","headers","role"])):(Ub(),Hb(CKe,{key:2,
id:c.value.Body,active:!0,class:"response-section-content-body",
data:e.response?.data,headers:o.value,layout:"client",
role:"All"===s.value?"none":"tabpanel",title:"Body"
},null,8,["id","data","headers","role"]))],64)):ny("",!0)],64)):(Ub(),Hb(YKe,{
key:0,appVersion:e.appVersion,events:e.events,layout:e.layout,
totalPerformedRequests:e.totalPerformedRequests,
onAddRequest:n[1]||(n[1]=t=>e.eventBus.emit("ui:open:command-palette",{
action:"create-request",payload:void 0})),
onOpenCommandPalette:n[2]||(n[2]=t=>e.eventBus.emit("ui:open:command-palette")),
onSendRequest:n[3]||(n[3]=e=>r("sendRequest"))
},null,8,["appVersion","events","layout","totalPerformedRequests"])),Yb(eJe,{
events:e.events},null,8,["events"])],10,dJe)])),_:1}))}
}),fJe=sae(hJe,[["__scopeId","data-v-aaba9a18"]]),mJe={
class:"bg-b-1 flex h-full flex-col"},gJe={
class:"lg:min-h-header flex w-full flex-wrap items-center justify-center p-2 lg:p-0"
},vJe=Qg({name:"OperationBlock",props:{eventBus:{},documentSecurity:{},
documentSelectedSecurity:{},appVersion:{},globalCookies:{default:()=>[]},
path:{},method:{},httpClients:{default:()=>LQe},layout:{},server:{},
selectedClient:{},servers:{},hideClientButton:{type:Boolean},integration:{},
documentUrl:{},source:{},operation:{},setOperationSecurity:{type:Boolean},
exampleKey:{},authMeta:{},securitySchemes:{},plugins:{default:()=>[]},
environment:{},proxyUrl:{}},emits:["update:servers"],setup(e,{emit:t}){
const n=t,r=Sy((()=>fXe(e.httpClients))),o=Sy((()=>mXe(e.documentSecurity,e.operation.security))),a=Sy((()=>vXe(e.documentSelectedSecurity,e.operation["x-scalar-selected-security"],o.value,e.setOperationSecurity))),i=Sy((()=>jHe(e.securitySchemes,a.value.selectedSchemes))),{toast:s}=CG(),l=bm(null),c=bm(null),u=bm(null),d=()=>l.value?.abort(E_e),p=async()=>{
const[t,n]=UHe({environment:e.environment,exampleKey:e.exampleKey,
globalCookies:e.globalCookies,method:e.method,operation:e.operation,path:e.path,
selectedSecuritySchemes:i.value,server:e.server,proxyUrl:e.proxyUrl})
;if(t)return void s(t.message,"error")
;l.value=n.controller,e.eventBus.emit("hooks:on:request:sent",{meta:{
method:e.method,path:e.path,exampleKey:e.exampleKey}});const[r,o]=await uVe({
isUsingProxy:n.isUsingProxy,operation:e.operation,plugins:e.plugins,
request:n.request});e.eventBus.emit("hooks:on:request:complete",{payload:o?{
response:o.originalResponse,request:o.request.clone(),
duration:o.response.duration,timestamp:o.timestamp}:void 0,meta:{
method:e.method,path:e.path,exampleKey:e.exampleKey}
}),r?s(r.message,"error"):(c.value=o.response,u.value=o.request)};iv((()=>{
e.eventBus.on("operation:send:request:hotkey",p),
e.eventBus.on("operation:cancel:request",d)})),cv((()=>{
e.eventBus.off("operation:send:request:hotkey",p),
e.eventBus.off("operation:cancel:request",d)}))
;const h=Sy((()=>(e.operation["x-scalar-history"]??[]).map((e=>({
method:e.request.method,path:e.request.url,duration:e.time,
status:e.response.status}))).reverse())),f=({index:t})=>{
const n=(e.operation["x-scalar-history"]?.length??0)-t-1,r=e.operation["x-scalar-history"]?.[n]
;if(!r)return;e.eventBus.emit("operation:reload:history",{meta:{path:e.path,
method:e.method},index:n,callback:()=>e.eventBus.emit("ui:route:example",{
exampleName:"draft",callback:async t=>{if("error"===t)return
;const n=(({harResponse:e,url:t="",method:n,path:r,duration:o=0})=>{
const a=QHe(e),{body:i,data:s,size:l}=HHe(e),c=ZHe(a);return{...new Response(i,{
status:e.status,statusText:e.statusText,headers:a}),
headers:Object.fromEntries(a.entries()),cookieHeaderKeys:c,duration:o,
status:e.status,statusText:e.statusText,method:n,path:r,data:s,size:l,url:t}})({
harResponse:r.response,url:r.request.url,method:e.method,path:e.path,
duration:r.time}),o=(({harRequest:e})=>{const t=zHe(e),n=FHe(e.postData)
;return new Request(e.url,{method:e.method,headers:t,body:n})})({
harRequest:r.request});c.value=n,u.value=o}})})}
;return mg([()=>e.path,()=>e.method,()=>e.exampleKey],(()=>{
c.value=null,u.value=null,d()})),cv((()=>{d()
})),(t,s)=>(Ub(),Qb("div",mJe,[Gb("div",gJe,[Yb(pqe,{documentUrl:e.documentUrl,
environment:e.environment,eventBus:e.eventBus,
hideClientButton:e.hideClientButton,history:h.value,integration:e.integration,
layout:e.layout,method:e.method,path:e.path,server:e.server,servers:e.servers,
source:e.source,onExecute:p,"onSelect:history:item":f,
"onUpdate:servers":s[0]||(s[0]=e=>n("update:servers"))
},null,8,["documentUrl","environment","eventBus","hideClientButton","history","integration","layout","method","path","server","servers","source"])]),Yb(VQe,{
class:"border-t"},{default:ig((()=>[Yb(WQe,{class:"flex-1"},{
default:ig((()=>[Yb(xm(HYe),{authMeta:e.authMeta,clientOptions:r.value,
environment:e.environment,eventBus:e.eventBus,exampleKey:e.exampleKey,
globalCookies:e.globalCookies,layout:e.layout,method:e.method,
operation:e.operation,path:e.path,plugins:e.plugins,proxyUrl:e.proxyUrl,
securityRequirements:o.value,securitySchemes:e.securitySchemes,
selectedClient:e.selectedClient,selectedSecurity:a.value,
selectedSecuritySchemes:i.value,server:e.server
},null,8,["authMeta","clientOptions","environment","eventBus","exampleKey","globalCookies","layout","method","operation","path","plugins","proxyUrl","securityRequirements","securitySchemes","selectedClient","selectedSecurity","selectedSecuritySchemes","server"]),Yb(xm(fJe),{
appVersion:e.appVersion,eventBus:e.eventBus,events:xm(ASe)(),layout:e.layout,
plugins:e.plugins,request:u.value,response:c.value,
totalPerformedRequests:h.value.length,onSendRequest:p
},null,8,["appVersion","eventBus","events","layout","plugins","request","response","totalPerformedRequests"])])),
_:1})])),_:1})]))}}),bJe={key:1,
class:"flex h-full w-full items-center justify-center"},yJe=Qg({
__name:"Operation",props:{documentSlug:{},document:{},eventBus:{},layout:{},
path:{},method:{},exampleName:{},environment:{},securitySchemes:{},
workspaceStore:{},activeWorkspace:{},plugins:{},options:{}},setup(e){
const t=Sy((()=>e.path?qke(e.document?.paths?.[e.path]):null)),n=Sy((()=>{
if(!e.path||!e.method)return null
;const n=qke(e.document?.paths?.[e.path]?.[e.method]);if(!n)return null
;if(!t.value)return n;const r=jQe(t.value.parameters,n.parameters);return{...n,
parameters:r}
})),r=Sy((()=>[...(e.workspaceStore.workspace?.["x-scalar-cookies"]??[]).map((e=>({
...e,location:"workspace"
}))),...(e.document?.["x-scalar-cookies"]??[]).map((e=>({...e,
location:"document"
})))])),o=Sy((()=>zQe(km(e.options)?.servers??n.value?.servers??t.value?.servers??e.document?.servers,{
baseServerUrl:km(e.options)?.baseServerURL,
documentUrl:e.document?.["x-scalar-original-source-url"]
}))),a=Sy((()=>UQe(e.document,o.value)));iv((()=>{
typeof e.document?.["x-scalar-selected-server"]>"u"&&o.value?.[0]?.url&&e.eventBus.emit("server:update:selected",{
url:o.value[0].url})}))
;const i=Sy((()=>e.document?.["x-scalar-set-operation-security"]?{
type:"operation",path:e.path??"",method:e.method??"get"}:{type:"document"
})),s=Sy((()=>BQe(km(e.options)?.hiddenClients)))
;return(t,l)=>e.path&&e.method&&e.exampleName&&n.value?(Ub(),Hb(xm(vJe),{key:0,
appVersion:xm("2.20.2"),authMeta:i.value,
documentSecurity:e.document?.security??[],
documentSelectedSecurity:e.document?.["x-scalar-selected-security"],
documentUrl:e.document?.["x-scalar-original-source-url"],
environment:e.environment,eventBus:e.eventBus,exampleKey:e.exampleName,
globalCookies:r.value,hideClientButton:km(e.options)?.hideClientButton??!1,
history:[],httpClients:s.value,layout:e.layout,method:e.method,
operation:n.value,path:e.path,plugins:e.plugins,
proxyUrl:e.workspaceStore.workspace["x-scalar-active-proxy"]??"",
securitySchemes:e.securitySchemes,
selectedClient:e.workspaceStore.workspace["x-scalar-default-client"],
server:a.value,servers:o.value,
setOperationSecurity:e.document?.["x-scalar-set-operation-security"]??!1,
"onUpdate:servers":l[0]||(l[0]=t=>e.eventBus.emit("ui:route:page",{
name:"document.servers"}))
},null,8,["appVersion","authMeta","documentSecurity","documentSelectedSecurity","documentUrl","environment","eventBus","exampleKey","globalCookies","hideClientButton","httpClients","layout","method","operation","path","plugins","proxyUrl","securitySchemes","selectedClient","server","servers","setOperationSecurity"])):(Ub(),
Qb("div",bJe,[...l[1]||(l[1]=[Gb("span",{class:"text-c-3"
},"Select an operation to view details",-1)])]))}}),OJe=(e,t)=>{
if(null===e)return OUe(_Ue,{})
;const n=e.workspace["x-scalar-active-environment"];if(!n)return OUe(_Ue,{})
;const r=e.workspace["x-scalar-environments"]?.[n]??{variables:[]
},o=t?.["x-scalar-environments"]?.[n]??{variables:[]};return OUe(_Ue,{...r,...o,
variables:[...r.variables,...o.variables]})},wJe={Enter:{
event:"operation:send:request:hotkey",modifiers:["default"]},b:{
event:"ui:toggle:sidebar",modifiers:["default"]},p:{
event:"ui:open:command-palette",modifiers:["shiftKey"]},l:{
event:"ui:focus:address-bar",modifiers:["default"]}},xJe={web:wJe,modal:{...wJe,
Escape:{event:"ui:close:client-modal",modifiers:[]},l:{
event:"ui:focus:send-button",modifiers:["default"]}},desktop:{...wJe,f:{
event:"ui:focus:search",modifiers:["default"]},n:{
event:"ui:open:command-palette",modifiers:["default"]},t:{event:"tabs:add:tab",
modifiers:["default"]},w:{event:"tabs:close:tab",modifiers:["default"]},
ArrowLeft:{event:"tabs:navigate:previous",modifiers:["default","altKey"]},
ArrowRight:{event:"tabs:navigate:next",modifiers:["default","altKey"]},1:{
event:"tabs:focus:tab",modifiers:["default"]},2:{event:"tabs:focus:tab",
modifiers:["default"]},3:{event:"tabs:focus:tab",modifiers:["default"]},4:{
event:"tabs:focus:tab",modifiers:["default"]},5:{event:"tabs:focus:tab",
modifiers:["default"]},6:{event:"tabs:focus:tab",modifiers:["default"]},7:{
event:"tabs:focus:tab",modifiers:["default"]},8:{event:"tabs:focus:tab",
modifiers:["default"]},9:{event:"tabs:focus:tab-last",modifiers:["default"]}}
},kJe=new Set(["Escape","ArrowDown","ArrowUp","Enter"]),SJe=(e,t,n)=>{
const r=" "===e.key?"Space":e.key,o=xJe[n][r];if(!o)return;const a={event:e}
;"Escape"!==r?((e,t)=>t.map((e=>"default"===e?C2()?"metaKey":"ctrlKey":e)).every((t=>!0===e[t])))(e,o.modifiers)?t.emit(o.event,a,{
skipUnpackProxy:!0}):((e,t)=>{if(!(e.target instanceof HTMLElement))return!1
;const n=e.target
;return"INPUT"===n.tagName?!kJe.has(t):"TEXTAREA"===n.tagName||"true"===n.contentEditable||n.hasAttribute("contenteditable")
})(e,r)||t.emit(o.event,a,{skipUnpackProxy:!0}):t.emit(o.event,a,{
skipUnpackProxy:!0})},_Je=e=>{const t=bm(""),n=bm(!1),r=()=>{const n=km(e)
;n&&(""!==t.value?n.style.overflow=t.value:n.style.removeProperty("overflow"))
},o=Sy({get:()=>n.value,set:o=>{n.value=o,o?(()=>{const n=km(e)
;n&&(t.value=n.style.overflow,n.style.overflow="hidden")})():r()}})
;return cv((()=>{n.value&&r()})),o},TJe=["aria-pressed"],EJe={class:"sr-only"
},AJe={class:"size-4",fill:"none",viewBox:"0 0 24 24",
xmlns:"http://www.w3.org/2000/svg"},CJe={"clip-path":"url(#mask)"},$Je=Qg({
__name:"SidebarToggle",props:{modelValue:{type:Boolean,required:!0},
modelModifiers:{}},emits:["update:modelValue"],setup(e){
const t=Kv(e,"modelValue");return(e,n)=>(Ub(),Qb("button",{
"aria-pressed":t.value,
class:"scalar-sidebar-toggle text-c-3 hover:bg-b-2 active:text-c-1 rounded-lg p-2",
type:"button",onClick:n[0]||(n[0]=e=>t.value=!t.value)
},[Gb("span",EJe,Uh(t.value?"Hide":"Show")+" sidebar",1),(Ub(),
Qb("svg",AJe,[n[1]||(n[1]=Gb("defs",null,[Gb("clipPath",{id:"mask"},[Gb("path",{
"clip-rule":"evenodd",d:"M9 3.2H4c-1.7 0-3 1.3-3 3v11.5c0 1.7 1.3 3 3 3h5V3.2z"
})])],-1)),Gb("g",CJe,[Gb("path",{
class:Ih(["transition-transform duration-300",t.value?"translate-x-0":"-translate-x-1/2"]),
d:"M1 3.2h8v17.5H1z",fill:"currentColor"},null,2)]),n[2]||(n[2]=Gb("path",{
d:"M20 20.8H4c-1.7 0-3-1.3-3-3V6.2c0-1.7 1.3-3 3-3h16c1.7 0 3 1.3 3 3v11.5c0 1.7-1.3 3-3 3zM9 3.2v17.5",
stroke:"currentColor","stroke-linecap":"round","stroke-linejoin":"round",
"stroke-width":"2"},null,-1))]))],8,TJe))}}),PJe=Qg({__name:"SidebarMenu",
props:{activeWorkspace:{},workspaces:{}},
emits:["create:workspace","select:workspace"],setup(e,{emit:t}){const n=t
;return(t,r)=>(Ub(),Hb(xm(Dre),null,{products:ig((()=>[...r[2]||(r[2]=[])])),
sections:ig((({close:o})=>[Yb(xm($re),null,{
default:ig((()=>[kv(t.$slots,"sidebarMenuActions",{},(()=>[Yb(xm(Nre),{
modelValue:e.activeWorkspace.id,workspaceOptions:e.workspaces,
onCreateWorkspace:r[0]||(r[0]=e=>n("create:workspace")),
"onUpdate:modelValue":r[1]||(r[1]=e=>n("select:workspace",e))
},null,8,["modelValue","workspaceOptions"]),Yb(xm(_re),{is:xm(Jxe),icon:xm(OE),
to:"/settings",onClick:o},{
default:ig((()=>[...r[3]||(r[3]=[ey(" Settings ",-1)])])),_:1
},8,["is","icon","onClick"])]))])),_:2},1024),Yb(xm(Pre)),Yb(xm(Ire))])),_:3}))}
}),DJe="scalar-dragging",IJe=Qg({__name:"Resize",props:{width:{}},
emits:["update:width"],setup(e,{emit:t}){const n=t,r=bm(!1),o=t=>{
t.preventDefault();const o=t.clientX,a=e.width,i=e=>{
r.value=!0,document.body.classList.add(DJe);let t=a+e.clientX-o
;t>420&&(t=420+.2*(t-420)),t<240&&(t=240),n("update:width",t)},s=()=>{
r.value=!1,
document.body.classList.remove(DJe),document.documentElement.removeEventListener("mousemove",i,!1),
document.documentElement.removeEventListener("mouseup",s,!1),
e.width>420?n("update:width",360):e.width<240&&n("update:width",240)}
;document.documentElement.addEventListener("mousemove",i,!1),
document.documentElement.addEventListener("mouseup",s,!1)}
;return(t,n)=>(Ub(),Qb("div",{class:"relative",style:Ah({width:`${e.width}px`})
},[kv(t.$slots,"default",{},void 0,!0),Gb("div",{class:"resizer",onMousedown:o
},null,32)],4))}}),MJe=sae(IJe,[["__scopeId","data-v-e2c54c18"]])
;function NJe(e){const t=[];function n(e,r){e.forEach((e=>{(function(e,t,n){
if("operation"===e.type){const r=qke(n?.paths?.[e.path]?.[e.method])??{}
;return void t.push({type:"operation",title:e.title,id:e.id,
description:r.description||"",method:e.method,path:e.path,
operationId:r.operationId,entry:e,documentName:n?.info.title??""})}
if("tag"===e.type&&!1===e.isGroup)return void t.push({id:e.id,title:e.title,
description:e.description||"",type:"tag",entry:e,documentName:n?.info.title??""
});if("tag"===e.type&&!0===e.isGroup)return void t.push({id:e.id,title:e.title,
description:"Tag Group",type:"tag",entry:e,documentName:n?.info.title??""})
;if("text"===e.type)t.push({id:e.id,type:"heading",title:e.title??"",
description:"Heading",entry:e,documentName:n?.info.title??""})
})(e,t,r),"children"in e&&e.children&&n(e.children,r)}))}
return e?.forEach((e=>n(e["x-scalar-navigation"]?.children??[],e))),t}
function RJe(e){const t=Sy((()=>{const t=new Qxe([],{keys:[{name:"title",
weight:.7},{name:"description",weight:.3},{name:"operationId",weight:.6},{
name:"path",weight:.5},{name:"tag",weight:.4},{name:"method",weight:.3},{
name:"documentName",weight:.3}],threshold:.3,distance:100,includeScore:!0,
includeMatches:!0,ignoreLocation:!0,useExtendedSearch:!0,findAllMatches:!0})
;return t.setCollection(NJe(km(e))),t})),n=bm("");return{
results:Sy((()=>0!==n.value.length?t.value.search(n.value,{limit:25
}):t.value._docs.slice(0,25).map(((e,t)=>({item:e,refIndex:t}))))),query:n}}
const LJe={class:"flex min-w-0 flex-col gap-0.5"},BJe={key:0,
class:"text-c-3 truncate text-xs font-medium"},jJe={class:"sr-only"},UJe={
class:"inline-flex items-center gap-1"},zJe={class:"sr-only"},FJe=Qg({
__name:"SearchResult",props:{id:{},isSelected:{type:Boolean},result:{}},
setup(e){const t={heading:HC,operation:BC,tag:PC},n={heading:"Heading",
operation:"Operation",tag:"Tag"};return(r,o)=>(Ub(),Hb(xm(Vre),{id:e.id,
icon:t[e.result.item.type],selected:e.isSelected},xv({
default:ig((()=>[Gb("div",LJe,[e.result.item.documentName?(Ub(),
Qb("span",BJe,Uh(e.result.item.documentName),1)):ny("",!0),Gb("span",{class:Ih({
"text-decoration-line":"operation"===e.result.item.entry.type&&e.result.item.entry.isDeprecated
})
},[Gb("span",jJe,[ey(Uh(n[e.result.item.type])+":  ",1),"operation"===e.result.item.entry.type&&e.result.item.entry.isDeprecated?(Ub(),
Qb(Mb,{key:0
},[ey(" (Deprecated)  ")],64)):ny("",!0)]),ey(" "+Uh(e.result.item.title)+" ",1),o[0]||(o[0]=Gb("span",{
class:"sr-only"},",",-1))],2)])])),_:2},["operation"===e.result.item.type?{
name:"description",
fn:ig((()=>[Gb("span",UJe,["operation"===e.result.item.type?(Ub(),Qb(Mb,{key:0
},[Yb(xm(iDe),{"aria-hidden":"true",method:e.result.item.method??"get"
},null,8,["method"]),Gb("span",zJe," HTTP Method: "+Uh(e.result.item.method??"get"),1)],64)):ny("",!0),o[1]||(o[1]=Gb("span",{
class:"sr-only"},"Path: ",-1)),ey(" "+Uh(e.result.item.path),1)])])),key:"0"
}:e.result.item.description?{name:"description",
fn:ig((()=>[o[2]||(o[2]=Gb("span",{class:"sr-only"
},"Description: ",-1)),ey(" "+Uh(e.result.item.description),1)])),key:"1"
}:void 0]),1032,["id","icon","selected"]))}}),ZJe={class:"mb-0 flex flex-col",
role:"search"},QJe=Qg({__name:"SearchModal",props:{modalState:{},documents:{},
eventBus:{}},setup(e){
const t=BX(),n=`${t}-search-result`,r=`${t}-search-instructions`,{query:o,results:a}=RJe((()=>e.documents)),i=bm(void 0)
;mg((()=>e.modalState.open),(e=>{e&&(o.value="")}));const s=e=>{
const t="up"===e?-1:1,n=a.value.length
;"number"==typeof i.value?i.value=(i.value+t+n)%n:i.value=-1===t?n-1:0}
;function l(t){if("number"!=typeof t||!a.value[t])return;const n=a.value[t]
;e.modalState.hide(),e.eventBus.emit("scroll-to:nav-item",{id:n.item.id})}
const c=Sy((()=>{const e=a.value[i.value??-1]
;return e?`search-result-${e.item.id}`:void 0}));return(t,u)=>(Ub(),Hb(xm(eae),{
"aria-label":"Reference Search",state:e.modalState,variant:"search",
onKeydown:u[5]||(u[5]=UO(BO((t=>e.modalState.hide()),["stop"]),["esc"]))},{
default:ig((()=>[Gb("div",ZJe,[Yb(xm(Bre),{modelValue:xm(o),
"onUpdate:modelValue":u[0]||(u[0]=e=>vm(o)?o.value=e:null),
"aria-activedescendant":c.value,"aria-autocomplete":"list","aria-controls":n,
"aria-describedby":r,role:"combobox",onBlur:u[1]||(u[1]=e=>i.value=void 0),
onKeydown:[u[2]||(u[2]=UO(BO((e=>s("down")),["stop","prevent"]),["down"])),u[3]||(u[3]=UO(BO((()=>l(i.value)),["stop","prevent"]),["enter"])),u[4]||(u[4]=UO(BO((e=>s("up")),["stop","prevent"]),["up"]))]
},null,8,["modelValue","aria-activedescendant"])]),Yb(xm(qre),{id:n,
"aria-label":"Reference Search Results",class:"custom-scroll p-1 pt-0",
noResults:!xm(a).length},{query:ig((()=>[ey(Uh(xm(o)),1)])),
default:ig((()=>[(Ub(!0),Qb(Mb,null,wv(xm(a),((e,t)=>(Ub(),Hb(FJe,{
id:`search-result-${e.item.id}`,key:e.refIndex,isSelected:i.value===t,result:e,
onClick:BO((()=>l(t)),["prevent"])
},null,8,["id","isSelected","result","onClick"])))),128))])),_:1
},8,["noResults"]),Gb("div",{id:r,class:"ref-search-meta"
},[...u[6]||(u[6]=[Gb("span",{"aria-hidden":"true",class:"contents"
},[Gb("span",null,"↑↓ Navigate"),Gb("span",null,"⏎ Select")],-1),Gb("span",{
class:"sr-only"
}," Press up arrow / down arrow to navigate, enter to select, type to filter results ",-1)])])])),
_:1},8,["state"]))}}),HJe=sae(QJe,[["__scopeId","data-v-0c30b37a"]]),VJe=Qg({
__name:"SearchButton",props:{forceIcon:{type:Boolean},searchHotKey:{default:"k"
},hideModels:{type:Boolean,default:!1},documents:{},eventBus:{}},setup(e){
const t=bm(),n=Koe(),r=t=>{
(C2()?t.metaKey:t.ctrlKey)&&t.key===e.searchHotKey&&(t.preventDefault(),
t.stopPropagation(),n.open?n.hide():n.show())};function o(){n.show()}
return mg((()=>n.open),(async(e,n)=>{!e&&n&&(await Xm(),t.value?.$el.focus())
})),
iv((()=>window.addEventListener("keydown",r))),cv((()=>window.removeEventListener("keydown",r))),
(r,a)=>(Ub(),Qb(Mb,null,[e.forceIcon?(Ub(),Hb(xm(ure),{key:0,icon:xm(ZA),
label:"Search",onClick:o},null,8,["icon"])):(Ub(),Hb(xm(boe),{key:1,
ref_key:"button",ref:t,class:Ih(["w-full",r.$attrs.class]),onClick:o},{
shortcut:ig((()=>[xm(C2)()?(Ub(),Qb(Mb,{key:0},[a[0]||(a[0]=Gb("span",{
class:"sr-only"},"Command",-1)),a[1]||(a[1]=Gb("span",{"aria-hidden":"true"
},"⌘",-1))],64)):(Ub(),Qb(Mb,{key:1},[a[2]||(a[2]=Gb("span",{class:"sr-only"
},"CTRL",-1)),a[3]||(a[3]=Gb("span",{"aria-hidden":"true"
},"⌃",-1))],64)),ey(" "+Uh(e.searchHotKey),1)])),
default:ig((()=>[a[4]||(a[4]=Gb("span",{class:"sr-only"
},"Open Search",-1)),a[5]||(a[5]=Gb("span",{"aria-hidden":"true",
class:"sidebar-search-placeholder"}," Search ",-1))])),_:1
},8,["class"])),Yb(HJe,{documents:e.documents,eventBus:e.eventBus,
hideModels:e.hideModels,modalState:xm(n)
},null,8,["documents","eventBus","hideModels","modalState"])],64))}}),qJe={
class:"bg-sidebar-b-1 z-1 flex flex-col gap-1.5 px-3 pb-1.5"},WJe={
class:"flex items-center justify-between"},XJe={key:1},GJe=Qg({__name:"Sidebar",
props:Nv({sidebarState:{},layout:{},activeWorkspace:{},workspaces:{},
eventBus:{},documents:{},isDroppable:{type:[Boolean,Function]}},{sidebarWidth:{
required:!0,default:288},sidebarWidthModifiers:{}}),
emits:Nv(["selectItem","select:workspace","create:workspace","reorder"],["update:sidebarWidth"]),
setup(e,{emit:t}){
const n=t,r=$v(),o=bm(!1),a=Kv(e,"sidebarWidth"),i=e=>"example"===e.type&&"draft"===e.title
;return(t,s)=>(Ub(),Hb(xm(MJe),{width:a.value,
"onUpdate:width":s[5]||(s[5]=e=>a.value=e),class:"flex flex-col"},{
default:ig((()=>[Yb(xm(BBe),{class:"flex w-auto flex-1 pt-2",indent:15,
isDraggable:"modal"!==e.layout,isDroppable:e.isDroppable,
isExpanded:e.sidebarState.isExpanded,isSelected:e.sidebarState.isSelected,
items:e.sidebarState.items.value,layout:"client",
onReorder:s[3]||(s[3]=(e,t)=>n("reorder",e,t)),
onSelectItem:s[4]||(s[4]=e=>n("selectItem",e))},xv({
header:ig((()=>[Gb("div",qJe,[Gb("div",WJe,["desktop"===e.layout?(Ub(),Hb(PJe,{
key:0,activeWorkspace:e.activeWorkspace,workspaces:e.workspaces,
"onCreate:workspace":s[0]||(s[0]=e=>n("create:workspace")),
"onSelect:workspace":s[1]||(s[1]=e=>n("select:workspace",e))},{
sidebarMenuActions:ig((()=>[kv(t.$slots,"sidebarMenuActions")])),_:3
},8,["activeWorkspace","workspaces"])):"modal"===e.layout?(Ub(),
Qb("div",XJe)):ny("",!0),"web"!==e.layout?(Ub(),Hb(xm(ure),{key:2,icon:xm(ZA),
label:"Search",onClick:s[2]||(s[2]=e=>o.value=!o.value)
},null,8,["icon"])):ny("",!0)]),o.value||"web"===e.layout?(Ub(),Hb(xm(VJe),{
key:0,documents:e.documents,eventBus:e.eventBus
},null,8,["documents","eventBus"])):ny("",!0)])])),
decorator:ig((e=>[kv(t.$slots,"decorator",Mh(Kb(e)))])),
icon:ig((e=>[r.icon||i(e.item)?(Ub(),Qb(Mb,{key:0},[i(e.item)?(Ub(),Hb(xm(VT),{
key:0})):ny("",!0),kv(t.$slots,"icon",Mh(Kb(e)))],64)):ny("",!0)])),
before:ig((()=>[kv(t.$slots,"workspaceButton")])),
footer:ig((()=>[kv(t.$slots,"footer")])),_:2},[r.empty?{name:"empty",
fn:ig((e=>[kv(t.$slots,"empty",Mh(Kb(e)))])),key:"0"
}:void 0]),1032,["isDraggable","isDroppable","isExpanded","isSelected","items"])])),
_:3},8,["width"]))}}),YJe={class:"scalar scalar-app"},KJe={
class:"scalar-container"},JJe=["id"],e0e={key:0,class:"relative flex flex-1"
},t0e={key:1,class:"flex h-full w-full items-center justify-center"},n0e=Qg({
__name:"Modal",props:{workspaceStore:{},document:{},path:{},eventBus:{},
method:{},exampleName:{},modalState:{},sidebarState:{},plugins:{},options:{}},
setup(e,{expose:t}){
typeof window<"u"&&(window.dataDumpWorkspace=()=>e.workspaceStore);const n={
label:"default",id:"default"},r=bm(!1);NQe({eventBus:e.eventBus,isSidebarOpen:r,
sidebarState:e.sidebarState,modalState:e.modalState,store:e.workspaceStore
}),((e,t)=>{const n=n=>SJe(n,e,t)
;iv((()=>window.addEventListener("keydown",n))),
cv((()=>window.removeEventListener("keydown",n)))})(e.eventBus,"modal")
;const o=bm(null),a=Hg(),{activate:i,deactivate:s}=function(e,t={}){let n
;const{immediate:r,...o}=t,a=ym(!1),i=ym(!1),s=e=>n&&n.activate(e),l=e=>n&&n.deactivate(e)
;return mg(Sy((()=>W1(km(e)).map((e=>{const t=km(e)
;return"string"==typeof t?t:K1(t)})).filter(j1))),(e=>{if(e.length)if(n){
const t=null==n?void 0:n.active;null==n||n.updateContainerElements(e),!t&&r&&s()
}else n=_je(e,{...o,onActivate(){a.value=!0,t.onActivate&&t.onActivate()},
onDeactivate(){a.value=!1,t.onDeactivate&&t.onDeactivate()}}),r&&s()}),{
flush:"post"}),N1((()=>l())),{hasFocus:a,isPaused:i,activate:s,deactivate:l,
pause:()=>{n&&(n.pause(),i.value=!0)},unpause:()=>{n&&(n.unpause(),i.value=!1)}}
}(o,{allowOutsideClick:!0,fallbackFocus:`#${a}`}),l=()=>{
s(),e.eventBus.emit("operation:cancel:request")
},c=_Je((()=>typeof window<"u"?window.document.body:null))
;mg((()=>e.modalState.open),(e=>{c.value=e,e?i({checkCanFocusTrap:()=>Xm()}):l()
})),av((()=>oae())),cv((()=>l()))
;const u=Sy((()=>e.workspaceStore?.workspace?.["x-scalar-sidebar-width"]??288)),d=t=>e.workspaceStore?.update("x-scalar-sidebar-width",t),p=Sy((()=>OJe(e.workspaceStore,e.document.value))),h=Sy((()=>qZe(e.document.value?.components?.securitySchemes,km(e.options)?.authentication?.securitySchemes)))
;return t({sidebarWidth:u,environment:p
}),(t,i)=>sg((Ub(),Qb("div",YJe,[Gb("div",KJe,[Gb("div",{id:xm(a),
ref_key:"client",ref:o,"aria-label":"API Client","aria-modal":"true",
class:"scalar-app-layout scalar-client flex",role:"dialog",tabindex:"-1"
},[Yb(xm(xoe),null,{
default:ig((()=>[Yb(xm($G)),e.document.value&&e.path?.value&&e.method?.value?(Ub(),
Qb("main",e0e,[Yb(xm($Je),{modelValue:r.value,
"onUpdate:modelValue":i[0]||(i[0]=e=>r.value=e),
class:"absolute top-2 left-3 z-[10001]"},null,8,["modelValue"]),sg(Yb(xm(GJe),{
sidebarWidth:u.value,"onUpdate:sidebarWidth":[i[1]||(i[1]=e=>u.value=e),d],
activeWorkspace:n,class:"z-[10000] h-full max-md:absolute! max-md:w-full!",
documents:[e.document.value],eventBus:e.eventBus,isDroppable:()=>!1,
layout:"modal",sidebarState:e.sidebarState.state,workspaces:[],
onSelectItem:e.sidebarState.handleSelectItem
},null,8,["sidebarWidth","documents","eventBus","sidebarState","onSelectItem"]),[[Jy,r.value]]),Yb(yJe,{
activeWorkspace:n,class:"flex-1",document:e.document.value,
documentSlug:e.document.value["x-scalar-navigation"]?.id??"",
environment:p.value,eventBus:e.eventBus,exampleName:e.exampleName?.value,
layout:"modal",method:e.method?.value,options:e.options,path:e.path?.value,
plugins:e.plugins,securitySchemes:h.value,workspaceStore:e.workspaceStore
},null,8,["document","documentSlug","environment","eventBus","exampleName","method","options","path","plugins","securitySchemes","workspaceStore"])])):(Ub(),
Qb("div",t0e,[...i[3]||(i[3]=[Gb("span",{class:"text-c-3"
},"No document selected",-1)])]))])),_:1})],8,JJe),Gb("div",{
class:"scalar-app-exit",onClick:i[2]||(i[2]=t=>e.modalState.hide())
})])],512)),[[Jy,e.modalState.open]])}
}),r0e=sae(n0e,[["__scopeId","data-v-9f4696a7"]]),o0e=({el:e,eventBus:t=H_e({
debug:!1
}),mountOnInitialize:n=!0,plugins:r=[],workspaceStore:o,options:a={}})=>{
const i={path:"default",method:"default",example:"default",
documentSlug:o.workspace["x-scalar-active-document"]||"default"},s=am({...i
}),l=e=>{Object.assign(s,i,e)
},c=Sy((()=>rDe(o,s))),u=Sy((()=>c.value.documentSlug)),d=Sy((()=>c.value.path)),p=Sy((()=>c.value.method)),h=Sy((()=>c.value.example)),f=Sy((()=>o.workspace.documents[u.value??""]??null)),m=(({workspaceStore:e,documentSlug:t,path:n,method:r,exampleName:o,route:a})=>{
const i=Sy((()=>e?.workspace.documents[km(t)??""]?.["x-scalar-navigation"]?.children??[])),s=UBe(i),l=Sy((()=>jBe({
items:i.value,nestedKey:"children",
filter:e=>"operation"===e.type||"example"===e.type,getId:e=>{
const n=J_e("operation",e);return FBe({document:km(t)??"",path:n?.path,
method:n?.method,example:"example"===e.type?e.name:void 0})}
}))),c=e=>l.value.get(FBe({document:e.document,path:e.path,method:e.method,
example:e.example}))||l.value.get(FBe({document:e.document,path:e.path,
method:e.method}));return mg([t,n,r,o],(([e,t,n,r])=>{
if(!e)return void s.setSelected(null);const o=c({document:e,path:t,method:n,
example:r});o&&(s.setSelected(o.id),s.setExpanded(o.id,!0))}),{immediate:!0}),{
handleSelectItem:e=>{const n=s.getEntryById(e);if(n){
if("operation"===n.type||"example"===n.type){
if(s.isSelected(e))return void s.setExpanded(e,!s.isExpanded(e))
;const r=J_e("operation",n),o=zBe("example",n)
;return o?(s.setSelected(o.id),s.setExpanded(o.id,!0)):s.setSelected(e),r?a({
documentSlug:km(t),path:r.path,method:r.method,example:o?.name??"default"
}):void 0}s.setExpanded(e,!s.isExpanded(e))
}else console.warn(`Could not find sidebar entry with id ${e} to select`)},
state:s,getEntryByLocation:c}})({workspaceStore:o,documentSlug:u,path:d,
method:p,exampleName:h,route:l}),g=Koe(),v=HO(r0e,{document:f,eventBus:t,
exampleName:h,method:p,modalState:g,path:d,plugins:r,sidebarState:m,
workspaceStore:o,options:a});v.config.idPrefix="scalar-client";const b=(t=e)=>{
t?v.mount(t):console.error("[@scalar/api-client] Could not create the API client Modal.","Invalid HTML element provided.","Read more: https://github.com/scalar/scalar/tree/main/packages/api-client")
};return n&&b(),{app:v,open:e=>{g.open=!0,e&&l(e)},mount:b,route:l,modalState:g}
},a0e=(e,t)=>{
const n=performance.now(),r=t(),o=performance.now(),a=Math.round(o-n)
;return console.info(`${e}: ${a} ms`),r},i0e=async(e,t)=>{
const n=performance.now(),r=await t(),o=performance.now(),a=Math.round(o-n)
;return console.info(`${e}: ${a} ms`),r};function s0e(e){let t=0;const n=[]
;return async r=>{t>=e&&await new Promise((e=>n.push(e))),t++;try{
return await r()}finally{t--,(()=>{if(0===n.length||t>=e)return
;const r=n.shift();r&&r()})()}}}function l0e(e){if(null!==e){
if("string"==typeof e){if(""===e.trim())return;try{return JSON.parse(e)
}catch(t){const n=/^[^:]+:/.test(e),r=e.slice(0,50).trimStart().startsWith("{")
;if(!n||r)return;return xX(e,{maxAliasCount:1e4,merge:!0})}}return e}}
const c0e=e=>{try{return new URL(e).host}catch{return null}};function u0e(e){
const t=e?.limit?s0e(e.limit):e=>e();return{type:"loader",validate:l_e,
exec:n=>async function(e,t,n){try{
const r=c0e(e),o=n?.headers?.find((e=>void 0!==e.domains.find((e=>e===r))))?.headers,a=n?.fetch??fetch,i=await t((()=>a(e,{
headers:o})));if(i.ok){const e=await i.text();return{ok:!0,data:l0e(e),raw:e}}
const s=i.headers.get("Content-Type")??""
;return["text/html","application/xml"].includes(s)&&console.warn(`[WARN] We only support JSON/YAML formats, received ${s}`),
console.warn(`[WARN] Fetch failed with status ${i.status} ${i.statusText} for URL: ${e}`),
{ok:!1}}catch{
return console.warn(`[WARN] Failed to parse JSON/YAML from URL: ${e}`),{ok:!1}}
}(n,t,e)}}class d0e extends Error{constructor(e){
super(e),this.name="InvalidChangesDetectedError"}}const p0e=(e,t)=>{
const n=(e,t,r,o=0)=>{
if(void 0===t[o])throw new d0e(`Process aborted. Path ${t.join(".")} at depth ${o} is undefined, check diff object`)
;if(o>=t.length-1)"add"===r.type||"update"===r.type?e[t[o]]=r.changes:Array.isArray(e)?e.splice(Number.parseInt(t[o]),1):delete e[t[o]];else{
if(void 0===e[t[o]]||"object"!=typeof e[t[o]])throw new d0e("Process aborted, check diff object")
;n(e[t[o]],t,r,o+1)}};for(const r of t)n(e,r.path,r);return e},h0e=(e,t)=>{
const n=[],r=(e,t,o=[])=>{if(typeof e!=typeof t)return void 0===e?void n.push({
path:o,changes:t,type:"add"}):void 0===t?void n.push({path:o,changes:e,
type:"delete"}):void n.push({path:o,changes:t,type:"update"})
;if("object"!=typeof e||"object"!=typeof t||null===e||null===t)e!==t&&n.push({
path:o,changes:t,type:"update"});else{
const n=new Set([...Object.keys(e),...Object.keys(t)])
;for(const a of n)r(e[a],t[a],[...o,a])}};return r(e,t),n};class f0e{
constructor(e,t){this.value=e,this.children=t}}class m0e{root;constructor(){
this.root=new f0e(null,{})}addPath(e,t){let n=this.root
;for(const r of e)n.children[r]||(n.children[r]=new f0e(null,{})),
n=n.children[r];n.value=t}findMatch(e,t){let n=this.root;for(const o of e){
null!==n.value&&t(n.value);const e=n.children[o];if(!e)return;n=e}const r=e=>{
for(const t of Object.keys(e?.children??{}))e&&Object.hasOwn(e.children,t)&&r(e?.children[t])
;e?.value&&t(e.value)};r(n)}}const g0e=(e,t)=>{if(typeof e!=typeof t)return!0
;if("object"==typeof e&&"object"==typeof t&&null!==e&&null!==t){
const n=new Set([...Object.keys(e),...Object.keys(t)])
;for(const r of n)if(void 0!==e[r]&&void 0!==t[r]&&g0e(e[r],t[r]))return!0
;return!1}return e!==t},v0e=(e,t)=>{for(const n in t)if(n in e){
const r=e[n],o=t[n]
;"object"==typeof r&&null!==r&&"object"==typeof o&&null!==o&&(e[n]=v0e(r,o))
}else e[n]=t[n];return e},b0e=(e,t)=>{if(e.length!==t.length)return!1
;for(let n=0;n<=e.length;++n)if(e[n]!==t[n])return!1;return!0},y0e=(e,t)=>{
const n=new m0e;for(const[l,c]of e.entries())n.addPath(c.path,{index:l,changes:c
});const r=new Set,o=new Set,a=new Map,i=new Map
;for(const[l,c]of t.entries())n.findMatch(c.path,(e=>{
if("delete"===c.type)if("delete"===e.changes.type)e.changes.path.length>c.path.length?r.add(e.index):o.add(e.index);else{
r.add(e.index),o.add(l);const t=i.get(l)
;void 0!==t?t[0].push(e.changes):i.set(l,[[e.changes],[c]])}
if("add"===c.type||"update"===c.type){
if(b0e(c.path,e.changes.path)&&"delete"!==e.changes.type&&!g0e(c.changes,e.changes.changes))return r.add(e.index),
void("object"==typeof c.changes&&v0e(c.changes,e.changes.changes))
;r.add(e.index),o.add(l);const t=a.get(e.index)
;void 0!==t?t[1].push(c):a.set(e.index,[[e.changes],[c]])}}))
;const s=[...a.values(),...i.values()];return{
diffs:[...e.filter(((e,t)=>!r.has(t))),...t.filter(((e,t)=>!o.has(t)))],
conflicts:s}
},O0e=new Set(["x-scalar-navigation","x-ext","x-ext-urls","$status","x-scalar-is-dirty"]),w0e=e=>!e.path.some((e=>O0e.has(e)))&&!(e.path.at(-1)??"").startsWith("x-scalar-secret-"),x0e=(e,t=new WeakMap)=>{
if("object"!=typeof e||null===e)return e;if(t.has(e))return t.get(e)
;const n=Array.isArray(e)?[]:{};return t.set(e,n),Object.keys(e).forEach((r=>{
n[r]=x0e(e[r],t)})),n};function k0e(e,t){return t.reduce(((e,t)=>{
if(null!=e)return e[t]}),e)}const S0e=(e,t)=>{
if(e&&"object"==typeof e&&"$ref"in e&&"string"==typeof e.$ref&&e.$ref.startsWith("#")){
const n=r_e(e.$ref.slice(1));return S0e(k0e(t.rootNode,n),t)}return e}
;function _0e(e){return"url"in e?u0e({fetch:e.fetch
}).exec(e.url):Promise.resolve({ok:!0,data:e.document,
raw:JSON.stringify(e.document)})}const T0e=e=>{if("url"in e)return e.url
},E0e=e=>{const t={},n=t=>{
e?.plugins?.forEach((e=>e.hooks?.onWorkspaceStateChanges?.(t)))},r=am(F_e({
...e?.meta,documents:{},get activeDocument(){return r.documents[s()]}},{hooks:{
onAfterChange(e){const t=e[0];if("documents"===t){
if(e.length<2)return void console.log("[WARN]: Overriding entire documents object is not supported")
;const t=e[1],o=r.documents[t]??{openapi:"3.1.0",info:{title:"",version:""},
"x-scalar-original-document-hash":""},a={type:"documents",documentName:t,
value:Q_e(o),path:e.slice(2)}
;return a.path.length>0&&"x-scalar-is-dirty"!==a.path[0]&&(o["x-scalar-is-dirty"]=!0),
void n(a)}if("activeDocument"===t){const t=s(),o=r.documents[t]??{
openapi:"3.1.0",info:{title:"",version:""},"x-scalar-original-document-hash":""
},a={type:"documents",documentName:t,value:Q_e(o),path:e.slice(2)}
;return a.path.length>0&&"x-scalar-is-dirty"!==a.path[0]&&(o["x-scalar-is-dirty"]=!0),
void n(a)}const{activeDocument:o,documents:a,...i}=r,l={type:"meta",
value:Q_e(i,{depth:1})};n(l)}}
})),{originalDocuments:o,intermediateDocuments:a,overrides:i}=F_e({
originalDocuments:{},intermediateDocuments:{},overrides:{}},{hooks:{
onAfterChange(e){const t=e[0];if(!t)return;if(e.length<2)return;const r=e[1]
;if("originalDocuments"===t){const a={type:t,documentName:r,value:Q_e(o[r]??{}),
path:e.splice(2)};n(a)}if("intermediateDocuments"===t){const o={type:t,
documentName:r,value:Q_e(a[r]??{}),path:e.splice(2)};n(o)}if("overrides"===t){
const e={type:t,documentName:r,value:Q_e(i[r]??{})};n(e)}}}});function s(){
return r[kUe.activeDocument]??Object.keys(r.documents)[0]??""}function l(e,t,n){
const r=a[e]
;if(r)return"json"===t?n?JSON.stringify(r):JSON.stringify(r,null,2):SX.stringify(r)
}async function c(n,s){
const{name:l,meta:c}=n,u=a0e("deepClone",(()=>x0e(n.document)))
;a0e("initialize",(()=>{
!1!==n.initialize&&(o[l]=x0e(u),a[l]=x0e(u),i[l]=n.overrides??{},t[l]={
fetch:n.fetch})}));const d=a0e("upgrade",(()=>y_e(x0e(u)))),p=aSe({...d,...c,
"x-original-oas-version":o[l]?.openapi??o[l]?.swagger,
"x-scalar-original-document-hash":n.documentHash,
"x-scalar-original-source-url":n.documentSource},{showInternal:!0})
;if(void 0===p[xUe.navigation]){await i0e("bundle",(async()=>await b_e(sSe(p),{
treeShake:!1,plugins:[u0e({fetch:t[l]?.fetch??e?.fetch}),{type:"lifecycle",
onAfterNodeProcess:async(e,t)=>{const n=e.externalValue,r=t.resolutionCache
;if("string"!=typeof n)return;const o=t.loaders.find((e=>e.validate(n)))
;if(!o)return;r.has(n)||r.set(n,o.exec(n));const a=await r.get(n)
;a?.ok&&(e.value=a.data)}},{type:"lifecycle",onBeforeNodeProcess:async(e,t)=>{
const{path:n,resolutionCache:r,parentNode:o}=t,a=e.$ref
;if("string"!=typeof a)return;if(!o||!n.length)return
;const i=t.loaders.find((e=>e.validate(a)));if(i&&"info"===n[0]){
r.has(a)||r.set(a,i.exec(a));const e=await r.get(a);e?.ok&&(o[n.at(-1)]=e.data)}
}},{type:"lifecycle",onAfterNodeProcess:(e,t)=>{const{path:n}=t
;if(3===n.length&&"components"===n[0]&&"securitySchemes"===n[1]){
const n=S0e(e,t)
;"object"==typeof n&&null!==n&&"scheme"in n&&"string"==typeof n.scheme&&n.scheme.toLowerCase()!==n.scheme&&(n.scheme=n.scheme.toLowerCase())
}}}],urlMap:!0,origin:n.documentSource})))
;const r=a0e("coerceValue",(()=>OUe(BZe,x0e(p))))
;a0e("mergeObjects",(()=>Eje(p,r)))}if(!Yje(BZe,p)){
const e=Array.from(function(...e){
const t=3===e.length?aUe(e[0],e[1],"",e[2]):aUe(e[0],[],"",e[1])
;return new rUe(t)}(BZe,p))
;console.warn("document validation errors: "),console.warn(e.map((e=>({
message:e.message,path:e.path,schema:e.schema,value:e.value}))))}
if(void 0===p[xUe.navigation]){const e=eDe(l,p,s);p[xUe.navigation]=e}
r.documents[l]=pSe(aSe(sSe(p)),{overrides:Q_e(i[l])})}async function u(t,n){
const{name:o,meta:a}=t,i=(s={fetch:t.fetch??e?.fetch,
proxyUrl:r["x-scalar-active-proxy"]
}).fetch?s.fetch:(e,t)=>fetch(VH(s.proxyUrl,e.toString()),t);var s
;const l=await i0e("loadDocument",(async()=>await _0e({...t,fetch:i})))
;return await i0e("addDocument",(async()=>l.ok?lSe(l.data)?(await c({...t,
document:l.data,documentSource:T0e(t),documentHash:o_e(l.raw)
},n),!0):(console.error(`Failed to load document '${o}': response data is not a valid object`),
r.documents[o]={...a,openapi:"3.1.0",info:{
title:`Document '${o}' could not be loaded`,version:"unknown"},
"x-scalar-original-document-hash":"not-a-hash"
},!1):(console.error(`Failed to fetch document '${o}': request was not successful`),
r.documents[o]={...a,openapi:"3.1.0",info:{
title:`Document '${o}' could not be loaded`,version:"unknown"},
"x-scalar-original-document-hash":"not-a-hash"},!1)))}const d=new Set;return{
get workspace(){return r},update(e,t){rQe(e),Object.assign(r,{[e]:t})},
updateDocument(e,t,n){const o=r.documents["active"===e?s():e]
;if(!o)throw"Please select a valid document";rQe(t),Object.assign(o,{[t]:n})},
async replaceDocument(e,t){const n=r.documents[e]
;if(!n)return console.error(`Document '${e}' does not exist in the workspace.`)
;await c({name:e,document:t,documentSource:n["x-scalar-original-source-url"],
documentHash:n["x-scalar-original-document-hash"],meta:{
"x-scalar-active-auth":n["x-scalar-active-auth"],
"x-scalar-active-server":n["x-scalar-active-server"]},initialize:!1})},
resolve:e=>{const t=r.activeDocument,n=k0e(t,e);return lSe(n)?b_e(n,{root:t,
treeShake:!1,plugins:[u0e(),{type:"lifecycle",onResolveStart:e=>{
e.$status="loading"},onResolveError:e=>{e.$status="error"},onResolveSuccess:e=>{
delete e.$status}},{type:"lifecycle",onAfterNodeProcess:async(e,t)=>{
const n=e.externalValue,r=t.resolutionCache;if("string"!=typeof n)return
;const o=t.loaders.find((e=>e.validate(n)));if(!o)return
;r.has(n)||r.set(n,o.exec(n));const a=await r.get(n);a?.ok&&(e.value=a.data)}}],
urlMap:!0,visitedNodes:d
}):(console.error(`Invalid path provided for resolution. Path: [${e.join(", ")}]. Found value of type: ${typeof n}. Expected an object.`),
Promise.resolve())},addDocument:u,deleteDocument:e=>{if(!r.documents[e])return
;delete r.documents[e],delete o[e],delete a[e],delete i[e],delete t[e]
;const s=Object.keys(r.documents)
;r["x-scalar-active-document"]===e&&(r["x-scalar-active-document"]=s[0]??void 0),
n({type:"deleteDocument",documentName:e})},exportDocument:l,
exportActiveDocument:(e,t)=>l(s(),e,t),buildSidebar:e=>{const t=r.documents[e]
;if(!t)return console.error(`Document '${e}' does not exist in the workspace.`),
!1;const n=eDe(e,t);return t[xUe.navigation]=n,!0},
saveDocument:async function(e){const t=a[e],n=r.documents[e];if(!n)return
;const o=Q_e(n)
;if(!t||!o)return void console.warn("Failed to save document, intermediate document and/or active document is missing")
;const i=((e,t)=>{
const n=h0e(e,t),[r,o]=(a=w0e,n.reduce((([e,t],n)=>a(n)?[[...e,n],t]:[e,[...t,n]]),[[],[]]))
;var a;return p0e(e,r),o})(t,await b_e(x0e(o),{plugins:[{type:"lifecycle",
onBeforeNodeProcess:(e,t)=>{const n=e.$ref,r=t.rootNode["x-ext-urls"]
;if("string"!=typeof n||"object"!=typeof r||null===r||!n.startsWith("#"))return
;const o=n.split("/").at(-1)??"";e.$ref=r[o]??n}}],treeShake:!1,urlMap:!0}))
;return n["x-scalar-is-dirty"]=!1,i},async revertDocumentChanges(e){
const t=r.documents[e],n=a[e];t&&n&&await c({name:e,document:n,
documentSource:t["x-scalar-original-source-url"],
documentHash:t["x-scalar-original-document-hash"],initialize:!1})},
commitDocument(e){
console.warn(`Commit operation for document '${e}' is not implemented yet.`)},
exportWorkspace(){const{activeDocument:e,documents:t,...n}=Q_e(r);return{
documents:{...Object.fromEntries(Object.entries(t).map((([e,t])=>[e,Q_e(t)])))},
meta:Q_e(n)??{},originalDocuments:Q_e(o),intermediateDocuments:Q_e(a),
overrides:Q_e(i)}},loadWorkspace(e){
cSe(r.documents,Object.fromEntries(Object.entries(e.documents).map((([t,n])=>[t,pSe(aSe(n),{
overrides:e.overrides[t]
})])))),cSe(o,e.originalDocuments),cSe(a,e.intermediateDocuments),
cSe(i,e.overrides),cSe(r,e.meta)},importWorkspaceFromSpecification:e=>{
const{documents:t,overrides:n,info:o,workspace:a,...i}=e
;return cSe(r,i),Promise.all(Object.entries(t??{}).map((([e,t])=>u({url:t.$ref,
name:e,overrides:n?.[e]}))))},rebaseDocument:async n=>{
const{name:s}=n,l=o[s],u=a[s],d=r.documents[s]?hm(sSe(fSe(r.documents[s]))):void 0
;if(!l||!u||!d)return{ok:!1,type:"CORRUPTED_STATE",
message:`Cannot rebase document '${s}': missing original, intermediate, or active document state`
};const p=await i0e("loadDocument",(async()=>await _0e({...n,
fetch:n.fetch??e?.fetch})));if(!p.ok||!lSe(p.data))return{ok:!1,
type:"FETCH_FAILED",
message:`Failed to fetch document '${s}': request was not successful or returned invalid data`
};const h=o_e(p.raw);if(d["x-scalar-original-document-hash"]===h)return{ok:!1,
type:"NO_CHANGES_DETECTED",
message:`No changes detected for document '${s}': document hash matches the active document`
};const f=p.data;i[s]=n.overrides??{},t[s]={fetch:n.fetch};const m=h0e(l,f)
;if(0===m.length)return{ok:!1,type:"NO_CHANGES_DETECTED",
message:`No changes detected for document '${s}' after fetching the latest version.`
};const g=h0e(l,u),v=y0e(m,g);return{ok:!0,conflicts:v.conflicts,
applyChanges:async e=>{const t=v.diffs.concat(e),r=p0e(x0e(l),t);a[s]=r,o[s]=f
;const i=h0e(u,r),h=h0e(u,d),m=y0e(i,h),g=m.diffs.concat(m.conflicts.flatMap((e=>e[0]))),b=OUe(BZe,p0e(x0e(r),g))
;await c({...n,document:{...b,[xUe.navigation]:void 0},documentSource:T0e(n),
documentHash:o_e(p.raw),initialize:!1})}}}}},A0e={Date:!0,RegExp:!0,String:!0,
Number:!0};function C0e(e,t,n={cyclesFix:!0},r=[]){let o=[]
;const a=Array.isArray(e);for(const s in e){const i=e[s],l=a?+s:s;if(!(s in t)){
o.push({type:"REMOVE",path:[l],oldValue:e[s]});continue}
const c=t[s],u="object"==typeof i&&"object"==typeof c&&Array.isArray(i)===Array.isArray(c)
;!(i&&c&&u)||A0e[Object.getPrototypeOf(i)?.constructor?.name]||n.cyclesFix&&r.includes(i)?i===c||Number.isNaN(i)&&Number.isNaN(c)||u&&(isNaN(i)?i+""==c+"":+i==+c)||o.push({
path:[l],type:"CHANGE",value:c,oldValue:i
}):o.push.apply(o,C0e(i,c,n,n.cyclesFix?r.concat([i]):[]).map((e=>(e.path.unshift(l),
e))))}const i=Array.isArray(t);for(const s in t)s in e||o.push({type:"CREATE",
path:[i?+s:s],value:t[s]});return o}const $0e=(e,t)=>{const n=e.__vccOpts||e
;for(const[r,o]of t)n[r]=o;return n},P0e={
class:"references-classic-header-container"},D0e={
class:"references-classic-header"},I0e={
class:"references-classic-header-content"}
;const M0e=$0e({},[["render",function(e,t){
return Ub(),Qb("div",P0e,[Gb("div",D0e,[Gb("div",I0e,[kv(e.$slots,"default",{},void 0,!0)]),kv(e.$slots,"dark-mode-toggle",{},void 0,!0)])])
}],["__scopeId","data-v-9198d025"]]),N0e={class:"min-w-0 flex-1 truncate"
},R0e=Qg({__name:"ExamplePicker",props:Nv({examples:{default:()=>({})}},{
modelValue:{required:!0},modelModifiers:{}}),emits:["update:modelValue"],
setup(e){
const t=Kv(e,"modelValue"),n=Sy((()=>Object.entries(e.examples).map((([e,t])=>({
id:e,label:t?.summary??e}))))),r=Sy({
get:()=>n.value.find((({id:e})=>e===t.value)),set:e=>t.value=e?.id??""})
;return(e,t)=>(Ub(),Hb(xm(hre),{modelValue:r.value,
"onUpdate:modelValue":t[0]||(t[0]=e=>r.value=e),class:"w-fit min-w-32",
options:n.value,placement:"bottom-start",teleport:""},{
default:ig((()=>[Yb(xm(WS),{
class:"text-c-2 hover:text-c-1 flex h-full w-fit min-w-0 gap-1.5 px-1.5 py-0.75 text-base font-normal",
"data-testid":"example-picker",variant:"ghost"},{
default:ig((()=>[Gb("div",N0e,Uh(r.value?.label??"Select an example"),1),Yb(xm(L_),{
class:"ui-open:rotate-180 mt-0.25 size-3 transition-transform duration-100",
weight:"bold"})])),_:1})])),_:1},8,["modelValue","options"]))}}),L0e=e=>{
if(!e)return()=>null;const t=e.getBoundingClientRect().top;let n=null
;const r=new MutationObserver((r=>{
r.some((e=>"childList"===e.type||"attributes"===e.type&&("style"===e.attributeName||"class"===e.attributeName)))&&(null!==n&&cancelAnimationFrame(n),
n=requestAnimationFrame((()=>{const r=e.getBoundingClientRect().top;if(r!==t){
const e=r-t;window.scrollBy(0,e)}n=null})))}));return r.observe(document.body,{
childList:!0,subtree:!0,attributes:!0,attributeFilter:["style","class"],
characterData:!1}),()=>{null!==n&&cancelAnimationFrame(n),r.disconnect()}
},B0e=Qg({__name:"HttpMethod",props:{as:{},property:{},short:{type:Boolean},
method:{}},setup(e){
const t=e,n=Sy((()=>CH(String(t.method||"")))),r=Sy((()=>aDe(t.method)))
;return(t,o)=>(Ub(),Hb(bv(e.as??"span"),{class:"uppercase",style:Ah({
[e.property||"color"]:n.value.colorVar})},{
default:ig((()=>[kv(t.$slots,"default"),ey(" "+Uh(e.short?n.value.short:r.value),1)])),
_:3},8,["style"]))}}),j0e=["innerHTML"],U0e=["id"],z0e={key:0,
class:"request-card-footer-addon"},F0e={class:"request-header"},Z0e=Qg({
__name:"OperationCodeSample",props:{integration:{},clientOptions:{},
selectedClient:{},selectedServer:{default:null},selectedContentType:{},
selectedExample:{},eventBus:{},securitySchemes:{default:()=>[]},method:{},
path:{},operation:{},fallback:{type:Boolean},generateLabel:{type:Function},
isWebhook:{type:Boolean},globalCookies:{}},setup(e){const t=Sy((()=>{
const t=qke(e.operation.requestBody)?.content??{},n=e.selectedContentType||Object.keys(t)[0]
;return n?t[n]?.examples??{}:{}
})),n=bm(e.selectedExample??Object.keys(t.value)[0]??""),r=Sy((()=>_Ge(e.operation))),o=Sy((()=>SGe(r.value,e.clientOptions))),a=bm(CGe(o.value,e.selectedClient))
;mg((()=>e.selectedClient),(e=>{const t=CGe(o.value,e);t&&(a.value=t)}))
;const i=Sy((()=>{if(!e.isWebhook)return null;try{return wGe({
operation:e.operation,method:e.method,path:e.path,example:n.value})}catch(fw){
return console.error("[webhookHar]",fw),null}
})),s=Sy((()=>e.isWebhook?i.value?.postData?.text??"":kGe({
includeDefaultHeaders:"client"===e.integration,clientId:a.value?.id,
customCodeSamples:r.value,operation:e.operation,method:e.method,path:e.path,
contentType:e.selectedContentType,server:e.selectedServer,
securitySchemes:e.securitySchemes,example:n.value,globalCookies:e.globalCookies
}))),l=Sy((()=>e.isWebhook?c.value:a.value?.lang)),c=Sy((()=>{
if(!i.value?.postData)return"json";const e=i.value.postData.mimeType
;return e?.includes("json")?"json":e?.includes("xml")?"xml":e?.includes("yaml")||e?.includes("yml")?"yaml":e?.includes("text/plain")?"text":"json"
})),u=Sy((()=>TGe(e.securitySchemes))),d=bm(null),p=Sy((()=>(s.value.length??0)>2e4)),h=Hg()
;return(r,i)=>s.value?(Ub(),Hb(xm(GS),{key:0,ref_key:"elem",ref:d,
class:"request-card dark-mode"},{default:ig((()=>[Yb(xm(t_),{class:"pr-2.5"
},xv({default:ig((()=>[i[2]||(i[2]=Gb("span",{class:"sr-only"
},"Request Example for",-1)),Yb(B0e,{as:"span",class:"request-method",
method:e.method},null,8,["method"]),e.generateLabel?(Ub(),Qb("span",{key:0,
innerHTML:e.generateLabel()
},null,8,j0e)):ny("",!0),kv(r.$slots,"header",{},void 0,!0)])),_:2
},[!e.isWebhook&&o.value.length?{name:"actions",fn:ig((()=>[Yb(xm(HK),{
class:"max-h-80",modelValue:a.value,options:o.value,placement:"bottom-end",
teleport:"","onUpdate:modelValue":i[0]||(i[0]=t=>(t=>{if(d.value){
const e=L0e(d.value.$el);setTimeout((()=>{e()}),300)}
a.value=t,t&&!t.id.startsWith("custom")&&e.eventBus.emit("workspace:update:selected-client",t.id)
})(t))},{default:ig((()=>[Yb(xm(WS),{
class:"text-c-2 hover:text-c-1 flex h-full w-fit gap-1.5 px-0.5 py-0 text-base font-normal",
"data-testid":"client-picker",variant:"ghost"},{
default:ig((()=>[ey(Uh(a.value?.title)+" ",1),Yb(xm(L_),{
class:"ui-open:rotate-180 mt-0.25 size-3 transition-transform duration-100",
weight:"bold"})])),_:1})])),_:1},8,["modelValue","options"])])),key:"0"
}:void 0]),1024),Yb(xm(YS),{class:"request-editor-section custom-scroll p-0"},{
default:ig((()=>[Gb("div",{id:`${xm(h)}-example`,class:"code-snippet"
},[p.value?(Ub(),Hb(xm(zoe),{key:1,
containerClass:"custom-scroll scalar-code-block border rounded-b flex flex-1 max-h-screen",
contentClass:"language-plaintext whitespace-pre font-code text-base",
lineHeight:20,text:s.value},null,8,["text"])):(Ub(),Hb(xm(LG),{key:0,
class:"bg-b-2 !min-h-full -outline-offset-2",content:s.value,
hideCredentials:u.value,lang:l.value,lineNumbers:""
},null,8,["content","hideCredentials","lang"]))],8,U0e)])),_:1
}),Object.keys(t.value).length>1||r.$slots.footer?(Ub(),Hb(xm(KS),{key:0,
class:"request-card-footer bg-b-3"},{
default:ig((()=>[Object.keys(t.value).length>1?(Ub(),
Qb("div",z0e,[Object.keys(t.value).length?(Ub(),Hb(R0e,{key:0,
modelValue:n.value,"onUpdate:modelValue":i[1]||(i[1]=e=>n.value=e),
examples:t.value
},null,8,["modelValue","examples"])):ny("",!0)])):ny("",!0),kv(r.$slots,"footer",{},void 0,!0)])),
_:3})):ny("",!0)])),_:3},512)):e.fallback?(Ub(),Hb(xm(GS),{key:1,
class:"request-card dark-mode"},{default:ig((()=>[Yb(xm(YS),{
class:"request-card-simple"},{default:ig((()=>[Gb("div",F0e,[Yb(B0e,{as:"span",
class:"request-method",method:e.method
},null,8,["method"]),kv(r.$slots,"header",{},void 0,!0)]),kv(r.$slots,"footer",{},void 0,!0)])),
_:3})])),_:3})):ny("",!0)}
}),Q0e=sae(Z0e,[["__scopeId","data-v-59889f40"]]),H0e=["shell/curl","ruby/native","node/undici","php/guzzle","python/python3"],V0e=(e,t=H0e)=>Boolean(e&&t.includes(e)),q0e={
class:"client-libraries-text"},W0e={"aria-hidden":"true",
class:"client-libraries-icon__more"},X0e={key:1,class:"client-libraries-icon",
height:"50",role:"presentation",viewBox:"0 0 50 50",width:"50",
xmlns:"http://www.w3.org/2000/svg"},G0e={key:0,
class:"client-libraries-text client-libraries-text-more"},Y0e=$0e(Qg({
__name:"ClientDropdown",props:{clientOptions:{},selectedClient:{},
featuredClients:{},eventBus:{}},setup(e){
const t=bm(),n=e=>`programming-language-${"js"===e?"javascript":e}`,r=Sy((()=>e.selectedClient?.split("/")[0]))
;return(o,a)=>(Ub(),Qb("div",{ref_key:"containerRef",ref:t,
class:"client-libraries-content"
},[(Ub(!0),Qb(Mb,null,wv(e.featuredClients,(t=>(Ub(),Hb(xm(Lk),{key:t.clientKey,
class:Ih(["client-libraries rendered-code-sdks",{
"client-libraries__active":t.id===e.selectedClient}])},{
default:ig((()=>[Gb("div",{class:Ih(`client-libraries-icon__${t.targetKey}`)
},[Yb(xm(Gne),{class:"client-libraries-icon",icon:n(t.targetKey)
},null,8,["icon"])],2),Gb("span",q0e,Uh(t.targetTitle),1)])),_:2
},1032,["class"])))),128)),Yb(xm(HK),{
modelValue:xm(CGe)(e.clientOptions,e.selectedClient),options:e.clientOptions,
placement:"bottom-end",teleport:"","onUpdate:modelValue":a[0]||(a[0]=n=>(n=>{
if(!t.value)return;const r=L0e(t.value);setTimeout((()=>{r()
}),300),"custom"!==n.clientKey&&e.eventBus.emit("workspace:update:selected-client",n.id)
})(n))},{default:ig((()=>[Gb("button",{
class:Ih(["client-libraries client-libraries__select",{
"client-libraries__active":e.selectedClient&&!xm(V0e)(e.selectedClient)}]),
type:"button"
},[Gb("div",W0e,[e.selectedClient&&!xm(V0e)(e.selectedClient)?(Ub(),Qb("div",{
key:0,class:Ih(`client-libraries-icon__${r.value}`)},[r.value?(Ub(),Hb(xm(Gne),{
key:0,class:"client-libraries-icon",icon:n(r.value)
},null,8,["icon"])):ny("",!0)],2)):(Ub(),Qb("svg",X0e,[...a[1]||(a[1]=[Gb("g",{
fill:"currentColor","fill-rule":"nonzero"},[Gb("path",{
d:"M10.71 25.3a3.87 3.87 0 1 0 7.74 0 3.87 3.87 0 0 0-7.74 0M21.13 25.3a3.87 3.87 0 1 0 7.74 0 3.87 3.87 0 0 0-7.74 0M31.55 25.3a3.87 3.87 0 1 0 7.74 0 3.87 3.87 0 0 0-7.74 0"
})],-1)])]))]),e.clientOptions.length?(Ub(),
Qb("span",G0e," More ")):ny("",!0),a[2]||(a[2]=Gb("span",{class:"sr-only"
},"Select from all clients",-1))],2)])),_:1},8,["modelValue","options"])],512))}
}),[["__scopeId","data-v-6a49c111"]]),K0e={key:0,ref:"wrapper-ref"
},J0e=["id"],e1e={key:1,class:"selected-client card-footer border-t-0 p-0",
role:"tabpanel",tabindex:"1"},t1e=["id"],n1e=Qg({__name:"ClientSelector",props:{
xScalarSdkInstallation:{},clientOptions:{},selectedClient:{default:()=>EGe},
eventBus:{}},setup(e,{expose:t}){
const n=Hg(),r=Hg(),o=Sy((()=>e.clientOptions.flatMap((t=>t.options.find((t=>t.id===e.selectedClient))??[]))[0])),a=Sy((()=>((e,t=H0e)=>{
const n=new Map;for(const r of e)for(const e of r.options)n.set(e.id,e)
;return t.flatMap((e=>n.get(e)??[]))
})(e.clientOptions))),i=Sy((()=>a.value.findIndex((t=>e.selectedClient===t.id)))),s=qg("wrapper-ref"),l=t=>{
const n=a.value[t]
;n&&s.value&&e.eventBus.emit("workspace:update:selected-client",n.id)
},c=Sy((()=>{
if(!Array.isArray(e.xScalarSdkInstallation)||!e.xScalarSdkInstallation?.length)return
;const t=e.xScalarSdkInstallation.find((t=>{
const n=e.selectedClient?.split("/")[0]?.toLowerCase()
;return t.lang.toLowerCase()===n}));return t||void 0}));return t({
selectedClientOption:o
}),(t,s)=>e.clientOptions.length?(Ub(),Qb("div",K0e,[Yb(xm(Nk),{manual:"",
selectedIndex:i.value,onChange:l},{default:ig((()=>[Gb("div",{id:xm(n),
class:"client-libraries-heading"}," Client Libraries ",8,J0e),Yb(xm(Rk),{
"aria-labelledby":xm(n),class:"client-libraries-list"},{
default:ig((()=>[Yb(Y0e,{clientOptions:e.clientOptions,eventBus:e.eventBus,
featuredClients:a.value,morePanel:xm(r),selectedClient:e.selectedClient
},null,8,["clientOptions","eventBus","featuredClients","morePanel","selectedClient"])])),
_:1},8,["aria-labelledby"]),Yb(xm(Bk),null,{
default:ig((()=>[c.value?.source||c.value?.description?(Ub(),Qb(Mb,{key:0
},[c.value.description?(Ub(),Qb("div",{key:0,
class:Ih(["selected-client card-footer -outline-offset-2",c.value.source&&"rounded-b-none"]),
role:"tabpanel",tabindex:"0"},[Yb(xm(mre),{value:c.value.description
},null,8,["value"])],2)):ny("",!0),c.value.source?(Ub(),
Qb("div",e1e,[Yb(xm(LG),{
class:"rounded-t-none rounded-b-lg px-3 py-2 -outline-offset-1 has-focus:outline",
content:c.value.source,copy:!0,lang:"shell"
},null,8,["content"])])):ny("",!0)],64)):xm(V0e)(e.selectedClient)?(Ub(!0),
Qb(Mb,{key:1},wv(a.value,(e=>(Ub(),Hb(xm(jk),{key:e.id,
class:"selected-client card-footer -outline-offset-2"},{
default:ig((()=>[ey(Uh(e.title),1)])),_:2},1024)))),128)):(Ub(),Qb("div",{key:2,
id:xm(r),class:"selected-client card-footer -outline-offset-2",role:"tabpanel",
tabindex:"0"},Uh(o.value?.title),9,t1e))])),_:1})])),_:1
},8,["selectedIndex"])],512)):ny("",!0)}
}),r1e=$0e(n1e,[["__scopeId","data-v-e59e2ca0"]]),o1e=$0e(Qg({__name:"Badge",
props:{color:{}},setup(e){const t=Sy((()=>e.color?{
"--badge-background-color":e.color,
"--badge-text-color":`color-mix(in srgb, ${e.color}, black 40%)`}:{}))
;return(e,n)=>(Ub(),Qb("div",{class:"badge",style:Ah(t.value)
},[kv(e.$slots,"default",{},void 0,!0)],4))}
}),[["__scopeId","data-v-3dedb7e4"]]),a1e=$0e(Qg({__name:"DownloadLink",props:{
documentDownloadType:{},eventBus:{}},setup(e){const t=t=>{
e.eventBus.emit("ui:download:document",{format:t})}
;return(n,r)=>["yaml","json","both","direct"].includes(e.documentDownloadType)?(Ub(),
Qb("div",{key:0,class:Ih(["download-container group",{
"download-both":"both"===e.documentDownloadType}])
},["json"===e.documentDownloadType||"both"===e.documentDownloadType||"direct"===e.documentDownloadType?(Ub(),
Qb("button",{key:0,class:"download-button",type:"button",
onClick:r[0]||(r[0]=BO((()=>t("direct"===e.documentDownloadType?"direct":"json")),["prevent"]))
},[r[3]||(r[3]=Gb("span",null," Download OpenAPI Document ",-1)),Yb(o1e,{
class:"extension hidden group-hover:flex"},{
default:ig((()=>[...r[2]||(r[2]=[ey("json",-1)])])),_:1
})])):ny("",!0),"yaml"===e.documentDownloadType||"both"===e.documentDownloadType?(Ub(),
Qb("button",{key:1,class:"download-button",type:"button",
onClick:r[1]||(r[1]=BO((()=>t("yaml")),["prevent"]))
},[r[5]||(r[5]=Gb("span",null," Download OpenAPI Document ",-1)),Yb(o1e,{
class:"extension hidden group-hover:flex"},{
default:ig((()=>[...r[4]||(r[4]=[ey("yaml",-1)])])),_:1
})])):ny("",!0)],2)):ny("",!0)}
}),[["__scopeId","data-v-59b5011b"]]),i1e=$0e(Qg({__name:"IntroductionCard",
props:{row:{type:Boolean}},setup:e=>(t,n)=>(Ub(),Qb("div",{
class:Ih(["introduction-card",{"introduction-card-row":e.row}])
},[kv(t.$slots,"default",{},void 0,!0)],2))
}),[["__scopeId","data-v-a8605b85"]]),s1e=(e,t)=>{const n=e=>{
const t=e.offsetHeight;return`${t/2}px 0px ${t/2}px 0px`};iv((()=>{if(e.value){
const o={rootMargin:n(e.value),
threshold:(r=e.value,r.offsetHeight<window.innerHeight?.8:.5)}
;!function(e,t,n={}){
const{root:r,rootMargin:o="0px",threshold:a=0,window:i=G1,immediate:s=!0}=n,l=r2((()=>i&&"IntersectionObserver"in i)),c=Sy((()=>W1(km(e)).map(K1).filter(j1)))
;let u=F1;const d=ym(s),p=l.value?mg((()=>[c.value,K1(r),d.value]),(([e,n])=>{
if(u(),!d.value)return;if(!e.length)return;const r=new IntersectionObserver(t,{
root:K1(n),rootMargin:o,threshold:a});e.forEach((e=>e&&r.observe(e))),u=()=>{
r.disconnect(),u=F1}}),{immediate:s,flush:"post"}):F1,h=()=>{u(),p(),d.value=!1}
;N1(h)}(e,(([e])=>{e?.isIntersecting&&t()}),o)}var r}))},l1e=$0e(Qg({
__name:"Section",emits:["intersecting"],setup(e,{emit:t}){
const n=t,r=qg("section")
;return s1e(r,(()=>n("intersecting"))),(e,t)=>(Ub(),Qb("section",{
ref_key:"section",ref:r,class:"section"
},[kv(e.$slots,"default",{},void 0,!0)],512))}
}),[["__scopeId","data-v-be4443e9"]]),c1e={
class:"section-accordion-button-content"},u1e={key:0,
class:"section-accordion-button-actions"},d1e={key:0,
class:"section-accordion-description"},p1e={
class:"section-accordion-content-card"},h1e=$0e(Qg({__name:"SectionAccordion",
props:{transparent:{type:Boolean},modelValue:{type:Boolean}},
emits:["update:modelValue"],setup(e,{emit:t}){
const n=t,r=bm(),o=function(e,t={}){
const{delayEnter:n=0,delayLeave:r=0,triggerOnRemoval:o=!1,window:a=G1}=t,i=ym(!1)
;let s;const l=e=>{const t=e?n:r
;s&&(clearTimeout(s),s=void 0),t?s=setTimeout((()=>i.value=e),t):i.value=e}
;return a?(J1(e,"mouseenter",(()=>l(!0)),{passive:!0
}),J1(e,"mouseleave",(()=>l(!1)),{passive:!0
}),o&&o2(Sy((()=>K1(e))),(()=>l(!1))),i):i}(r);return(t,a)=>(Ub(),Hb(xm(qx),{
as:"section",class:Ih(["section-accordion",{
"section-accordion-transparent":e.transparent}])},{default:ig((()=>[Yb(xm(Wx),{
ref_key:"button",ref:r,class:"section-accordion-button",
onClick:a[0]||(a[0]=()=>n("update:modelValue",!e.modelValue))},{
default:ig((()=>[Gb("div",c1e,[kv(t.$slots,"title",{},void 0,!0)]),t.$slots.actions?(Ub(),
Qb("div",u1e,[kv(t.$slots,"actions",{active:xm(o)||e.modelValue
},void 0,!0)])):ny("",!0),Yb(xm(Q_),{
class:Ih(["section-accordion-chevron size-4.5 transition-transform",{
"rotate-90":e.modelValue}])},null,8,["class"])])),_:3
},512),e.modelValue?(Ub(),Hb(xm(Xx),{key:0,class:"section-accordion-content",
static:""},{
default:ig((()=>[t.$slots.description?(Ub(),Qb("div",d1e,[kv(t.$slots,"description",{},void 0,!0)])):ny("",!0),Gb("div",p1e,[kv(t.$slots,"default",{},void 0,!0)])])),
_:3})):ny("",!0)])),_:3},8,["class"]))}
}),[["__scopeId","data-v-ff689b94"]]),f1e={class:"section-column"}
;const m1e=$0e({},[["render",function(e,t){
return Ub(),Qb("div",f1e,[kv(e.$slots,"default",{},void 0,!0)])
}],["__scopeId","data-v-699c28e3"]]),g1e={class:"section-columns"}
;const v1e=$0e({},[["render",function(e,t){
return Ub(),Qb("div",g1e,[kv(e.$slots,"default",{},void 0,!0)])
}],["__scopeId","data-v-8b9602bf"]]),b1e={key:1,class:"section-container"
},y1e=$0e(Qg({__name:"SectionContainer",props:{omit:{type:Boolean}},
setup:e=>(t,n)=>e.omit?kv(t.$slots,"default",{key:0
},void 0,!0):(Ub(),Qb("div",b1e,[kv(t.$slots,"default",{},void 0,!0)]))
}),[["__scopeId","data-v-20a1472a"]]),O1e={class:"section-accordion-wrapper"
},w1e={class:"section-accordion-title"},x1e=$0e(Qg({
__name:"SectionContainerAccordion",props:{modelValue:{type:Boolean}},
emits:["update:modelValue"],setup(e,{emit:t}){const n=t
;return(t,r)=>(Ub(),Qb("section",O1e,[Yb(xm(qx),{as:"div",
class:"section-accordion"},{default:ig((()=>[Yb(xm(Wx),{
class:"section-accordion-button",
onClick:r[0]||(r[0]=t=>n("update:modelValue",!e.modelValue))},{
default:ig((()=>[Yb(xm(Q_),{
class:Ih(["section-accordion-chevron size-5 transition-transform",{
"rotate-90":e.modelValue}])
},null,8,["class"]),Gb("div",w1e,[kv(t.$slots,"title",{},void 0,!0)])])),_:3
}),e.modelValue?(Ub(),Hb(xm(Xx),{key:0,class:"section-accordion-content",
static:""},{default:ig((()=>[kv(t.$slots,"default",{},void 0,!0)])),_:3
})):ny("",!0)])),_:3})]))}}),[["__scopeId","data-v-9419dd23"]]),k1e=$0e(Qg({
__name:"LoadingSkeleton",props:{lines:{default:1}},
setup:e=>(t,n)=>(Ub(!0),Qb(Mb,null,wv([...Array(e.lines).keys()],(t=>(Ub(),
Qb("div",{key:t,class:Ih(["loading",{"single-line":1===e.lines}])
},null,2)))),128))}),[["__scopeId","data-v-8e0226d7"]]),S1e={
class:"section-content"},_1e=$0e(Qg({__name:"SectionContent",props:{loading:{
type:Boolean,default:!1}},
setup:e=>(t,n)=>(Ub(),Qb("div",S1e,[e.loading?(Ub(),Hb(k1e,{key:1,lines:8
})):kv(t.$slots,"default",{key:0},void 0,!0)]))
}),[["__scopeId","data-v-9735459e"]]),T1e={
class:"section-header-wrapper xl:gap-12"},E1e=$0e(Qg({__name:"SectionHeader",
props:{loading:{type:Boolean},tight:{type:Boolean}},
setup:e=>(t,n)=>(Ub(),Qb("div",T1e,[e.loading?(Ub(),Hb(k1e,{key:0
})):(Ub(),Qb("div",{key:1,class:Ih(["section-header",{tight:e.tight}])
},[kv(t.$slots,"default",{},void 0,!0)],2)),t.$slots.links?kv(t.$slots,"links",{
key:2},void 0,!0):ny("",!0)]))}),[["__scopeId","data-v-465a7a78"]]),A1e=$0e(Qg({
__name:"SectionHeaderTag",props:{level:{default:1}},
setup:e=>(t,n)=>(Ub(),Hb(bv(`h${e.level}`),{class:"section-header-label"},{
default:ig((()=>[kv(t.$slots,"default",{},void 0,!0)])),_:3}))
}),[["__scopeId","data-v-f1ac6c38"]]),C1e={key:0,class:"screenreader-only"
},$1e=$0e(Qg({__name:"ScreenReader",props:{if:{type:Boolean,default:!0}},
setup:e=>(e,t)=>e.$props.if?(Ub(),
Qb("span",C1e,[kv(e.$slots,"default",{},void 0,!0)])):kv(e.$slots,"default",{
key:1},void 0,!0)}),[["__scopeId","data-v-df2e1026"]]),P1e=["id"],D1e={
class:"relative"},I1e=Qg({__name:"Anchor",emits:["copyAnchorUrl"],
setup(e,{emit:t}){const n=t,r=Hg(),{cx:o}=zS()
;return(e,t)=>(Ub(),Qb("span",Mh(Kb(xm(o)("group/heading word-break-all relative"))),[Gb("span",{
id:xm(r),class:"contents"
},[kv(e.$slots,"default")],8,P1e),Gb("span",D1e,[t[2]||(t[2]=Gb("span",null,"​",-1)),Yb(xm(WS),{
"aria-describedby":xm(r),
class:"absolute top-1/2 left-0 inline-block h-fit -translate-y-1/2 px-1.5 py-1 opacity-0 group-hover/heading:opacity-100 group-has-focus-visible/heading:opacity-100",
variant:"ghost",onClick:t[0]||(t[0]=BO((()=>n("copyAnchorUrl")),["stop"]))},{
default:ig((()=>[Yb(xm(tA),{"aria-hidden":"true",class:"size-4.5"
}),Yb($1e,null,{default:ig((()=>[...t[1]||(t[1]=[ey("Copy link",-1)])])),_:1
})])),_:1},8,["aria-describedby"])])],16))}}),M1e=["id"],N1e={class:"sr-only"
},R1e=Qg({__name:"WithBreadcrumb",props:{breadcrumb:{},eventBus:{}},
setup:e=>(t,n)=>e.breadcrumb&&e.breadcrumb.length>0?(Ub(),Qb("div",{key:0,
id:e.breadcrumb.join("."),class:"relative scroll-mt-24"
},[kv(t.$slots,"default"),Gb("button",{
class:"text-c-3 hover:text-c-1 absolute -top-2 -left-4.5 flex h-[calc(100%+16px)] w-4.5 cursor-pointer items-center justify-center pr-1.5 opacity-0 group-hover:opacity-100 focus-visible:opacity-100",
type:"button",onClick:n[0]||(n[0]=()=>e.eventBus?.emit("copy-url:nav-item",{
id:e.breadcrumb.join(".")}))},[Yb(xm(xA),{class:"size-3",weight:"bold"
}),Gb("span",N1e,[kv(t.$slots,"sr-label",{},(()=>[n[1]||(n[1]=ey("Copy link to ",-1)),kv(t.$slots,"default")]))])])],8,M1e)):kv(t.$slots,"default",{
key:1})
}),L1e=["aria-label"],B1e=["id","aria-controls","aria-expanded"],j1e=$0e(Qg({
__name:"CompactSection",props:{id:{},label:{},modelValue:{type:Boolean}},
emits:["update:modelValue","copyAnchorUrl"],setup(e,{emit:t}){const n=t
;return(t,r)=>(Ub(),Qb("section",{"aria-label":e.label,
class:"collapsible-section"},[Gb("button",{id:e.id,"aria-controls":e.id,
"aria-expanded":e.modelValue,class:Ih(["collapsible-section-trigger",{
"collapsible-section-trigger-open":e.modelValue}]),type:"button",
onClick:r[1]||(r[1]=t=>n("update:modelValue",!e.modelValue))},[Yb(xm(Q_),{
class:Ih(["size-3 transition-transform duration-100",{"rotate-90":e.modelValue
}]),weight:"bold"},null,8,["class"]),Yb(xm(I1e),{
class:"collapsible-section-header",
onCopyAnchorUrl:r[0]||(r[0]=()=>n("copyAnchorUrl"))},{
default:ig((()=>[kv(t.$slots,"heading",{},void 0,!0)])),_:3
})],10,B1e),e.modelValue?(Ub(),Hb(l1e,{key:0,
class:"collapsible-section-content",label:e.label},{
default:ig((()=>[kv(t.$slots,"default",{},void 0,!0)])),_:3
},8,["label"])):ny("",!0)],8,L1e))}
}),[["__scopeId","data-v-999a158a"]]),U1e=e=>e?Object.fromEntries(Object.entries(e).filter((([e])=>e.startsWith("x-")))):{},z1e=({plugins:e=[]})=>{
const t=new Map;return e.forEach((e=>{const n=e();t.set(n.name,n)})),{
getSpecificationExtensions:e=>{const n=[]
;for(const r of t.values())for(const t of r.extensions)t.name===e&&n.push(t)
;return n},getViewComponents:e=>{const n=[];for(const r of t.values()){
const t=r.views?.[e];t&&n.push(...t)}return n}}},F1e=Symbol(),Z1e=()=>{
const e=ug(F1e);return e||z1e({})},Q1e={key:0,class:"text-base"},H1e=Qg({
__name:"SpecificationExtension",props:{value:{}},setup(e){
const{getSpecificationExtensions:t}=Z1e();const n=Sy((()=>{
return t=e.value,Object.keys(t??{}).filter((e=>e.startsWith("x-")));var t
})),r=Sy((()=>n.value.flatMap((e=>t(e))).filter((e=>e.component))))
;return(t,n)=>"object"==typeof e.value&&r.value.length?(Ub(),
Qb("div",Q1e,[(Ub(!0),Qb(Mb,null,wv(r.value,(t=>(Ub(),Hb(xm(v2),null,{
default:ig((()=>[t.renderer?(Ub(),Hb(bv(t.renderer),iy({key:0,ref_for:!0},{
[t.name]:e.value?.[t.name],component:t.component
}),null,16)):(Ub(),Hb(bv(t.component),iy({key:1,ref_for:!0},{
[t.name]:e.value?.[t.name]}),null,16))])),_:2},1024)))),256))])):ny("",!0)}
}),V1e=Qg({__name:"InfoMarkdownSection",props:{id:{},content:{},
transformHeading:{type:Function},eventBus:{}},setup(e){const t=qg("element")
;return s1e(t,(()=>e.id?e.eventBus?.emit("intersecting:nav-item",{id:e.id
}):void 0)),(n,r)=>(Ub(),Qb("div",{ref_key:"element",ref:t,
class:"introduction-description-heading scroll-mt-16"},[Yb(xm(mre),{
transform:e.transformHeading,transformType:"heading",value:e.content,
withImages:""},null,8,["transform","value"])],512))}}),q1e={key:0,
class:"introduction-description mt-6 flex flex-col"},W1e=$0e(Qg({
__name:"InfoDescription",props:{eventBus:{},headingSlugGenerator:{type:Function
},description:{}},setup(e){const t=Sy((()=>{if(!e.description)return[]
;const t=new rTe;return wH(e.description).map((n=>{const r=yH(n)[0];return{
id:r?e.headingSlugGenerator({...r,slug:t.slug(r.value)}):void 0,content:n}}))
})),n=t=>{const n=new rTe;return t.data={hProperties:{
id:e.headingSlugGenerator({depth:t.depth,value:t.children[0].value,
slug:n.slug(t.children[0].value)})}},t}
;return(r,o)=>e.description?(Ub(),Qb("div",q1e,[(Ub(!0),
Qb(Mb,null,wv(t.value,(t=>(Ub(),Hb(V1e,{id:t.id,key:t.id,content:t.content,
eventBus:e.eventBus,transformHeading:n
},null,8,["id","content","eventBus"])))),128))])):ny("",!0)}
}),[["__scopeId","data-v-fe80002d"]]),X1e=$0e(Qg({__name:"LinkList",setup(e){
const t=bm(),n=bm(!1),r=()=>{if(!t.value)return
;const{scrollWidth:e,clientWidth:r}=t.value;n.value=e>r};let o=null
;return iv((()=>{
r(),window.addEventListener("resize",r),t.value&&(o=new MutationObserver((()=>{
r()})),o.observe(t.value,{childList:!0,subtree:!0}))})),uv((()=>{
window.removeEventListener("resize",r),o&&(o.disconnect(),o=null)
})),(e,r)=>(Ub(),Qb("div",{ref_key:"containerRef",ref:t,class:Ih([{
"icons-only":n.value
},"custom-scroll mb-3 flex h-auto min-h-8 max-w-full items-center gap-2 overflow-x-auto text-xs whitespace-nowrap xl:mb-1.5"])
},[kv(e.$slots,"default",{},void 0,!0)],2))}
}),[["__scopeId","data-v-0939d4d9"]]),G1e={key:0,
class:"group flex items-center last:border-r-0 xl:border-r xl:first:ml-auto"
},Y1e=["href"],K1e={key:0,class:"ml-1 empty:hidden"},J1e={key:1,
class:"ml-1 empty:hidden"},e2e=Qg({__name:"ExternalDocs",props:{value:{}},
setup:e=>(t,n)=>e.value?(Ub(),Qb("div",G1e,[Gb("a",{href:e.value.url,
class:"text-c-1 hover:bg-b-2 mr-2 flex min-h-7 min-w-7 items-center rounded-lg border px-2 py-1 no-underline group-last:mr-0 xl:border-none",
target:"_blank",rel:"noopener noreferrer"},[Yb(xm(g_),{weight:"bold",
class:"size-3 text-current"
}),e.value.description?(Ub(),Qb("span",K1e,Uh(e.value.description),1)):(Ub(),
Qb("span",J1e,Uh(e.value.url),1))],8,Y1e)])):ny("",!0)}),t2e={key:0,
class:"group flex items-center last:border-r-0 xl:border-r xl:first:ml-auto"
},n2e=["href"],r2e={class:"ml-1 empty:hidden"},o2e=Qg({__name:"Contact",props:{
value:{}},setup(e){const t=jS({
base:"text-c-1 mr-2 flex min-h-7 min-w-7 items-center rounded-lg border px-2 py-1 group-last:mr-0 xl:border-none",
variants:{link:{true:"no-underline hover:bg-b-2"}}});return(n,r)=>e.value?(Ub(),
Qb("div",t2e,[e.value?.email?(Ub(),Qb("a",{key:0,class:Ih(xm(t)({link:!0})),
href:`mailto:${e.value?.email}`},[Yb(xm(_T),{weight:"bold",
class:"size-3 text-current"
}),Gb("span",r2e,Uh(e.value.name),1)],10,n2e)):e.value?.name?(Ub(),Qb("span",{
key:1,class:Ih(xm(t)({link:!1}))},Uh(e.value.name),3)):ny("",!0)])):ny("",!0)}
}),a2e={
class:"group flex h-fit items-center last:border-r-0 xl:border-r xl:first:ml-auto"
},i2e=["href"],s2e={class:"ml-1 empty:hidden"},l2e={class:"ml-1 empty:hidden"
},c2e=Qg({__name:"License",props:{value:{}},
setup:e=>(t,n)=>(Ub(),Qb("div",a2e,[e.value?.url?(Ub(),Qb("a",{key:0,
class:"text-c-1 hover:bg-b-2 mr-2 flex min-h-7 min-w-7 items-center rounded-lg border px-2 py-1 no-underline group-last:mr-0 xl:border-none",
href:e.value.url,target:"_blank",rel:"noopener noreferrer"},[Yb(xm(hE),{
weight:"bold",class:"size-3 text-current"
}),Gb("span",s2e,Uh(e.value?.name||e.value.identifier||e.value.url),1)],8,i2e)):(Ub(),
Qb(Mb,{key:1},[Yb(xm(hE),{weight:"bold",class:"size-3 text-current"
}),Gb("span",l2e,Uh(e.value?.name),1)],64))]))}),u2e={key:0,
class:"group flex items-center last:border-r-0 xl:border-r xl:first:ml-auto"
},d2e=["href"],p2e=Qg({__name:"TermsOfService",props:{value:{}},
setup:e=>(t,n)=>e.value?(Ub(),Qb("div",u2e,[Gb("a",{
class:"text-c-1 hover:bg-b-2 mr-2 flex min-h-7 min-w-7 items-center rounded-lg border px-2 py-1 no-underline group-last:mr-0 xl:border-none",
href:e.value,target:"_blank",rel:"noopener noreferrer"},[Yb(xm(vC),{
weight:"bold",class:"size-3 text-current"}),n[0]||(n[0]=Gb("span",{
class:"ml-1 empty:hidden"},"Terms of Service",-1))],8,d2e)])):ny("",!0)
}),h2e=Qg({__name:"InfoLinks",props:{info:{},externalDocs:{}},
setup:e=>(t,n)=>(Ub(),Hb(xm(X1e),null,{default:ig((()=>[Yb(xm(e2e),{
value:e.externalDocs},null,8,["value"]),e.info.contact?(Ub(),Hb(xm(o2e),{key:0,
value:e.info.contact
},null,8,["value"])):ny("",!0),e.info.license?(Ub(),Hb(xm(c2e),{key:1,
value:e.info.license
},null,8,["value"])):ny("",!0),e.info.termsOfService?(Ub(),Hb(xm(p2e),{key:2,
value:e.info.termsOfService},null,8,["value"])):ny("",!0)])),_:1}))}),f2e=Qg({
__name:"InfoVersion",props:{version:{}},setup(e){const t=Sy((()=>{
if(null==e.version)return e.version;const t=String(e.version)
;return/^\d/.test(t)?`v${t}`:t}));return(e,n)=>t.value?(Ub(),Hb(xm(o1e),{key:0
},{default:ig((()=>[ey(Uh(t.value),1)])),_:1})):ny("",!0)}}),m2e=Qg({
__name:"OpenApiVersion",props:{oasVersion:{}},
setup:e=>(t,n)=>e.oasVersion?(Ub(),Hb(xm(o1e),{key:0},{
default:ig((()=>[ey("OAS "+Uh(e.oasVersion),1)])),_:1})):ny("",!0)}),g2e={
class:"flex gap-1.5"},v2e={class:"sticky-cards"},b2e=$0e(Qg({
__name:"IntroductionLayout",props:{id:{},oasVersion:{},info:{},externalDocs:{},
documentExtensions:{},infoExtensions:{},headingSlugGenerator:{type:Function},
eventBus:{}},setup:e=>(t,n)=>(Ub(),Hb(xm(y1e),null,{
default:ig((()=>[Yb(xm(l1e),{id:e.id,"aria-label":"Introduction",
class:"introduction-section z-1 gap-12",
onIntersecting:n[0]||(n[0]=()=>e.id&&e.eventBus?.emit("intersecting:nav-item",{
id:e.id}))},{default:ig((()=>[Yb(xm(_1e),{loading:!e.info},{
default:ig((()=>[Gb("div",g2e,[e.info?(Ub(),Hb(f2e,{key:0,
version:e.info?.version},null,8,["version"])):ny("",!0),Yb(m2e,{
oasVersion:e.oasVersion},null,8,["oasVersion"])]),Yb(xm(E1e),{
loading:!e.info?.title,tight:""},{links:ig((()=>[e.info?(Ub(),Hb(h2e,{key:0,
externalDocs:e.externalDocs,info:e.info
},null,8,["externalDocs","info"])):ny("",!0)])),default:ig((()=>[Yb(xm(A1e),{
level:1},{default:ig((()=>[ey(Uh(e.info?.title),1)])),_:1})])),_:1
},8,["loading"]),Yb(xm(v1e),null,{default:ig((()=>[Yb(xm(m1e),null,{
default:ig((()=>[kv(t.$slots,"download-link",{},void 0,!0),Yb(W1e,{
description:e.info?.description,eventBus:e.eventBus,
headingSlugGenerator:e.headingSlugGenerator
},null,8,["description","eventBus","headingSlugGenerator"])])),_:3
}),t.$slots.aside?(Ub(),Hb(xm(m1e),{key:0},{
default:ig((()=>[Gb("div",v2e,[kv(t.$slots,"aside",{},void 0,!0)])])),_:3
})):ny("",!0)])),_:3}),Yb(xm(H1e),{value:e.documentExtensions
},null,8,["value"]),Yb(xm(H1e),{value:e.infoExtensions},null,8,["value"])])),_:3
},8,["loading"]),kv(t.$slots,"after",{},void 0,!0)])),_:3},8,["id"])])),_:3}))
}),[["__scopeId","data-v-0b1e2255"]]),y2e=Qg({__name:"InfoBlock",props:{id:{},
oasVersion:{},info:{},externalDocs:{},documentExtensions:{},infoExtensions:{},
eventBus:{},headingSlugGenerator:{type:Function},layout:{},
documentDownloadType:{default:"both"}},setup(e){
const t=Sy((()=>"classic"===e.layout?"after":"aside"))
;return(n,r)=>(Ub(),Hb(b2e,{id:e.id,documentExtensions:e.documentExtensions,
eventBus:e.eventBus,externalDocs:e.externalDocs,
headingSlugGenerator:e.headingSlugGenerator,info:e.info,
infoExtensions:e.infoExtensions,oasVersion:e.oasVersion},{
[t.value]:ig((()=>[Yb(i1e,{row:"classic"===e.layout},{
default:ig((()=>[kv(n.$slots,"selectors")])),_:3},8,["row"])])),
"download-link":ig((()=>[Yb(a1e,{documentDownloadType:e.documentDownloadType,
eventBus:e.eventBus},null,8,["documentDownloadType","eventBus"])])),_:2
},1032,["id","documentExtensions","eventBus","externalDocs","headingSlugGenerator","info","infoExtensions","oasVersion"]))
}}),O2e={class:"introduction-card-item"}
;const w2e=$0e({},[["render",function(e,t){
return Ub(),Qb("div",O2e,[kv(e.$slots,"default",{},void 0,!0)])
}],["__scopeId","data-v-708aae59"]]),x2e={class:"overflow-x-auto"},k2e={key:1,
class:"text-c-1 flex h-auto w-full items-center gap-0.75 rounded-b-lg px-3 py-1.5 text-base leading-[20px] whitespace-nowrap"
},S2e={class:"overflow-x-auto"},_2e=Qg({__name:"Selector",props:{
selectedServer:{},servers:{},target:{}},emits:["update:modelValue"],
setup(e,{expose:t,emit:n}){const r=n,o=Sy((()=>e.servers.map((e=>({id:e.url,
label:e.url
}))))),a=Sy((()=>e.selectedServer?.url?.replace(/\/$/,"")||"")),i=Sy((()=>o.value.find((t=>t.id===e.selectedServer?.url))))
;return t({servers:e.servers,serverUrlWithoutTrailingSlash:a,serverOptions:o,
selectedServer:e.selectedServer}),(t,n)=>o.value.length>1?(Ub(),Hb(xm(hre),{
key:0,ref:"elem",class:"group",modelValue:i.value,options:o.value,
placement:"bottom-start",resize:"",target:e.target,
"onUpdate:modelValue":n[0]||(n[0]=e=>r("update:modelValue",e.id))},{
default:ig((()=>[Yb(xm(WS),{
class:"bg-b-1 text-c-1 h-auto w-full justify-start gap-1.5 overflow-x-auto rounded-t-none rounded-b-lg px-3 py-1.5 text-base font-normal whitespace-nowrap -outline-offset-1",
variant:"ghost"},{default:ig((()=>[n[1]||(n[1]=Gb("span",{class:"sr-only"
},"Server:",-1)),Gb("span",x2e,Uh(a.value||"Select a server"),1),Yb(xm(L_),{
class:"text-c-2 ui-open:rotate-180 mt-0.25 size-3 transition-transform duration-100",
weight:"bold"})])),_:1})])),_:1
},8,["modelValue","options","target"])):(Ub(),Qb("div",k2e,[n[2]||(n[2]=Gb("span",{
class:"sr-only"},"Server:",-1)),Gb("span",S2e,Uh(a.value),1)]))}
}),T2e=["id"],E2e=Qg({__name:"ServerSelector",props:{eventBus:{},
selectedServer:{},servers:{}},setup(e){const t=Hg(),n=t=>{
e.eventBus.emit("server:update:selected",{url:e.selectedServer?.url===t?"":t})
},r=(t,n)=>{const r=e.servers.findIndex((t=>t.url===e.selectedServer?.url))
;-1!==r&&e.eventBus.emit("server:update:variables",{index:r,key:t,value:n})}
;return(o,a)=>(Ub(),Qb(Mb,null,[a[0]||(a[0]=Gb("label",{
class:"bg-b-2 flex h-8 items-center rounded-t-lg border border-b-0 px-3 py-2.5 font-medium"
}," Server ",-1)),Gb("div",{id:xm(t),class:Ih(["border",{
"rounded-b-lg":!e.selectedServer?.description&&!e.selectedServer?.variables}])
},[e.servers.length?(Ub(),Hb(_2e,{key:0,selectedServer:e.selectedServer,
servers:e.servers,target:xm(t),"onUpdate:modelValue":n
},null,8,["selectedServer","servers","target"])):ny("",!0)],10,T2e),Yb(xm(G_e),{
layout:"reference",variables:e.selectedServer?.variables,"onUpdate:variable":r
},null,8,["variables"]),e.selectedServer?.description?(Ub(),Hb(xm(mre),{key:0,
class:"text-c-3 rounded-b-lg border border-t-0 px-3 py-1.5",
value:e.selectedServer.description},null,8,["value"])):ny("",!0)],64))}
}),A2e=e=>e&&"oauth2"===e.type?e["x-default-scopes"]??[]:[],C2e=(e,t,n)=>{
const r=qke(n[t]);e[t]=A2e(r)},$2e=(e,t,n)=>{if(t)return((e,t)=>{
if(!Array.isArray(e)){const n=qke(t[e]);return{[e]:A2e(n)}}const n={}
;for(const r of e)if(Array.isArray(r))for(const e of r)C2e(n,e,t);else C2e(n,r,t)
;return n})(t,n);const r=e[0];return r?Q_e(r,{depth:1}):null},P2e=Qg({
__name:"Auth",props:{options:{},document:{},eventBus:{},securitySchemes:{},
selectedServer:{},environment:{}},setup(e){
const t=Sy((()=>mXe(e.document?.security))),n=Sy((()=>vXe(e.document?.["x-scalar-selected-security"],void 0,t.value)))
;return mg((()=>e.document?.["x-scalar-selected-security"]),(n=>{
if(void 0!==n)return
;const r=$2e(t.value,e.options.authentication?.preferredSecurityScheme,e.securitySchemes)
;r&&e.eventBus.emit("auth:update:selected-security-schemes",{
selectedRequirements:[r],newSchemes:[],meta:{type:"document"}})}),{immediate:!0
}),(r,o)=>Object.keys(e.securitySchemes).length?(Ub(),Hb(xm(BYe),{key:0,
environment:e.environment,eventBus:e.eventBus,isStatic:"",layout:"reference",
meta:{type:"document"},persistAuth:e.options.persistAuth,
proxyUrl:e.options.proxyUrl??"",securityRequirements:t.value,
securitySchemes:e.securitySchemes,selectedSecurity:n.value,
server:e.selectedServer,title:"Authentication"
},null,8,["environment","eventBus","persistAuth","proxyUrl","securityRequirements","securitySchemes","selectedSecurity","server"])):ny("",!0)
}}),D2e=e=>{if(null===e||"object"!=typeof e||Array.isArray(e))return!1
;if("oneOf"in e||"anyOf"in e||"allOf"in e||"not"in e)return!1;const t="type"in e
;if(t&&Array.isArray(e.type))return e.type.includes("object")
;const n=t&&"object"===e.type;if(n)return!0;if(t&&!n)return!1
;return"properties"in e||"additionalProperties"in e||"patternProperties"in e
},I2e=e=>{if(!D2e(e))return!1
;const t=0===Object.keys(e.properties??{}).length,n=void 0===e.additionalProperties||!1===e.additionalProperties,r=0===Object.keys(e.patternProperties??{}).length
;return t&&n&&r},M2e={key:0,class:"schema-type"},N2e=["title"],R2e=$0e(Qg({
__name:"SchemaHeading",props:{value:{},name:{}},setup(e){
const t=Sy((()=>"type"in e.value?e.value.type:e.value.enum?"enum":dQe(e.value)&&e.value.items?"array":D2e(e.value)&&(e.value.properties||e.value.additionalProperties)?"object":"unknown"))
;return(n,r)=>"object"==typeof e.value?(Ub(),Qb("span",M2e,[Gb("span",{
class:"schema-type-icon",
title:"type"in e.value&&"string"==typeof e.value.type?e.value.type:"type"in e.value&&Array.isArray(e.value.type)?e.value.type.join(" | "):"unknown type"
},[xm(D2e)(e.value)?(Ub(),Qb(Mb,{key:0
},[ey(" {} ")],64)):ny("",!0),xm(dQe)(e.value)?(Ub(),Qb(Mb,{key:1
},[ey(" [] ")],64)):ny("",!0),e.value.enum?(Ub(),Qb(Mb,{key:2
},[ey(" enum ")],64)):ny("",!0)],8,N2e),e.name?(Ub(),Hb(xm(Zoe),{key:0,
text:e.name,preset:"property"},null,8,["text"])):(Ub(),Qb(Mb,{key:1
},[ey(Uh(t.value),1)],64))])):ny("",!0)}
}),[["__scopeId","data-v-70cb5c13"]]),L2e=(e,t)=>e.reduce(((e,n)=>{
const r=t?.[n];return r&&(e[n]=r),e
}),{}),B2e=(e,t,{hideReadOnly:n=!1,hideWriteOnly:r=!1,orderSchemaPropertiesBy:o="alpha",orderRequiredPropertiesFirst:a=!0}={})=>{
if(!D2e(e)||!e.properties)return[]
;const i=Object.keys(e.properties),s=new Set(e.required||[])
;return i.sort(((e,n)=>{
const r=e===t?.propertyName,i=n===t?.propertyName,l=s.has(e),c=s.has(n)
;if(r&&!i)return-1;if(!r&&i)return 1;if(a){if(l&&!c)return-1;if(!l&&c)return 1}
return"alpha"===o?e.localeCompare(n):0})).filter((t=>{
const o=e.properties&&qke(e.properties[t])
;return(!n||!0!==o?.readOnly)&&(!r||!0!==o?.writeOnly)}))
},j2e=["oneOf","anyOf","allOf","not"],U2e=["allOf","oneOf","anyOf"],z2e=e=>"type"in e&&e.type?Array.isArray(e.type)?e.type.includes("object"):"object"===e.type:"properties"in e,F2e=e=>"$ref"in e||"discriminator"in e||U2e.some((t=>t in e)),Z2e=e=>{
if(!e||!dQe(e)||"object"!=typeof e.items)return!1;if("$ref"in e.items)return!0
;const t=qke(e.items);return!!t&&(!!F2e(t)||(!!z2e(t)||(e=>{
if(!dQe(e)||"object"!=typeof e.items)return!1;if("$ref"in e.items)return!0
;const t=qke(e.items);return!!t&&(z2e(t)||F2e(t)||dQe(t))})(t)))
},Q2e=e=>e?j2e.map((t=>{if(((e,t)=>{if(!e||!dQe(e))return!1;const n=e.items
;return!(!n||"object"!=typeof n||!(t in n)||Z2e(e))
})(e,t)&&dQe(e)&&e.items)return{composition:t,value:qke(e.items)};if(e[t]){
if(!(dQe(e)&&e.items&&"object"==typeof e.items&&t in e.items))return{
composition:t,value:qke(e)}}return null})).filter(xH):[],H2e={integer:{
_default:"Integer numbers.",
int32:"Signed 32-bit integers (commonly used integer type).",
int64:"Signed 64-bit integers (long type)."},string:{
date:"full-date notation as defined by RFC 3339, section 5.6, for example, 2017-07-21",
"date-time":"the date-time notation as defined by RFC 3339, section 5.6, for example, 2017-07-21T17:32:28Z",
password:"a hint to UIs to mask the input",
base64:"base64-encoded characters, for example, U3dhZ2dlciByb2Nrcw==",
byte:"base64-encoded characters, for example, U3dhZ2dlciByb2Nrcw==",
binary:"binary data, used to describe files"}};const V2e=e=>{
if(!("$ref"in e))return null;const t=e.$ref;if(!t)return null
;const n=t.match(NH.REF_NAME);return n?n[1]:null},q2e=(e,t=!1)=>{
if(!e.items)return t?"array":e.title||e.xml?.name||"array"
;const n=(e=>e?`array ${e.includes(" | ")?`(${e})`:e}[]`:"array")(W2e(e.items))
;return t?n:e.nullable?`${n} | null`:n},W2e=e=>{if(!e)return"";const t=qke(e)
;if(void 0!==t.const)return"const";if("type"in t&&Array.isArray(t.type)){
if(t.type.includes("array")&&t.items){
const e=q2e(t,!0),n=t.type.filter((e=>"array"!==e))
;return n.length>0?`${e} | ${n.join(" | ")}`:e}return t.type.join(" | ")}
if(dQe(t))return q2e(t,!1);if(t.title)return t.title
;if(t.xml?.name)return t.xml.name
;if("type"in t&&t.type&&t.contentEncoding)return`${t.type} • ${t.contentEncoding}`
;if("$ref"in e){const t=V2e(e);if(t)return t}return"type"in t?t.type:""
},X2e=(e,t)=>{if(!e?.allOf?.length||!Array.isArray(e.allOf))return t||{}
;const n={},{allOf:r,...o}=e;for(const a of e.allOf){
if(!a||"object"!=typeof a)continue;const e=qke(a);if(e.allOf){const t=X2e(e)
;G2e(n,t)}else G2e(n,e)}
if(Object.keys(o).length>0&&G2e(n,o,!0),t&&"object"==typeof t)if(t.allOf){
const e=X2e(t);G2e(n,e,!0)}else G2e(n,t,!0);return n},G2e=(e,t,n=!1)=>{
const r=MH(t);if(0!==r.length)for(const o of r){const r=qke(t[o])
;if(void 0!==r)if("required"===o)Array.isArray(r)&&r.length>0&&(e.required?.length?e.required=[...new Set([...e.required,...r])]:e.required=r.slice());else if("properties"===o)r&&"object"==typeof r&&(e.properties||(e.properties={}),
Y2e(e.properties,r));else if("items"===o){const n=qke(r)
;if(n)if(dQe(t))if(e.items||(e.items={}),n.allOf){const t=X2e(n)
;Object.assign(e.items,t)}else K2e(qke(e.items),n);else if(n.allOf){
const t=X2e(n)
;"properties"in t&&("properties"in e||(e.properties={}),"properties"in e&&Y2e(e.properties,t.properties))
}else"items"in e||(e.items=n)
}else if("enum"===o)Array.isArray(r)&&r.length>0&&(e.enum=[...new Set([...e.enum||[],...r])]);else if("oneOf"===o||"anyOf"===o){
if(Array.isArray(r)){"properties"in e||(e.properties={});for(const t of r){
const n=qke(t);n.properties&&"properties"in e&&Y2e(e.properties,n.properties)}}
}else{if("allOf"===o)continue;(n||void 0===e[o])&&(e[o]=r)}}},Y2e=(e,t)=>{
const n=Object.keys(t??{});if(t&&e&&0!==n.length)for(const r of n){
const n=qke(t[r]);if(!n){delete e[r];continue}if("object"!=typeof n){e[r]=n
;continue}if(!e[r]){n.allOf?e[r]=X2e(n):dQe(n)&&qke(n.items)?.allOf?e[r]={...n,
items:X2e(qke(n.items))}:t[r]&&(e[r]=t[r]);continue}const o=qke(e[r])
;if(n.allOf)e[r]=X2e({allOf:[o,...n.allOf]});else if(dQe(n)&&dQe(o)&&n.items){
const t=qke(o.items);e[r]={...o,type:"array",
items:t?J2e(t,qke(n.items)):qke(n.items)}
}else if("properties"in o&&"properties"in n){const t={...o,...n};t.properties={
...o.properties},Y2e(t.properties,n.properties),e[r]=t}else e[r]={...n,...o}}
},K2e=(e,t)=>{if(t.allOf||e.allOf){const n=[]
;if(e.allOf)for(const t of e.allOf)n.push(qke(t));else n.push(e)
;if(t.allOf)for(const e of t.allOf)n.push(qke(e));else n.push(t);const r=X2e({
allOf:n});Object.assign(e,r)
}else Object.assign(e,t),"properties"in e&&"properties"in t&&Y2e(e.properties,t.properties)
},J2e=(e,t)=>{if(e.allOf||t.allOf){const n=[]
;if(e.allOf)for(const t of e.allOf)n.push(qke(t));else n.push(e)
;if(t.allOf)for(const e of t.allOf)n.push(qke(e));else n.push(t);return X2e({
allOf:n})}const n={...e,...t}
;return"properties"in e&&"properties"in t&&(n.properties={...e.properties
},Y2e(n.properties,t.properties)),n},e4e={class:"property-rule"},t4e={
class:"composition-selector bg-b-1.5 hover:bg-b-2 flex w-full cursor-pointer items-center gap-1 rounded-t-lg border border-b-0 px-2 py-1.25 pr-3 text-left",
type:"button"},n4e={class:"text-c-2"},r4e={key:0,class:"text-red"},o4e={
class:"composition-panel"},a4e=Qg({__name:"SchemaComposition",props:{
composition:{},discriminator:{},name:{},schema:{},level:{},compact:{
type:Boolean,default:!1},hideHeading:{type:Boolean,default:!1},breadcrumb:{},
eventBus:{},options:{}},setup(e){
const t=e,n=Sy((()=>[t.schema[t.composition]].flat().map((e=>({value:qke(e),
original:e}))).filter((e=>xH(e.value))))),r=Sy((()=>n.value.map(((e,t)=>({
id:String(t),label:W2e(e.original)||"Schema"
}))))),o=bm(r.value[0]),a=Sy((()=>n.value[Number(o.value?.id??"0")]?.value))
;return(n,i)=>(Ub(),Qb("div",e4e,["allOf"===t.composition?(Ub(),Hb(G4e,{key:0,
breadcrumb:e.breadcrumb,compact:e.compact,discriminator:e.discriminator,
eventBus:e.eventBus,hideHeading:e.hideHeading,level:e.level,name:e.name,
noncollapsible:!0,options:e.options,schema:xm(X2e)(e.schema)
},null,8,["breadcrumb","compact","discriminator","eventBus","hideHeading","level","name","options","schema"])):(Ub(),
Qb(Mb,{key:1},[Yb(xm(hre),{modelValue:o.value,
"onUpdate:modelValue":i[0]||(i[0]=e=>o.value=e),options:r.value,resize:""},{
default:ig((()=>{
return[Gb("button",t4e,[Gb("span",n4e,Uh((e=t.composition,e.replace(/([A-Z])/g," $1").replace(/^./,(e=>e.toUpperCase())).toLowerCase().replace(/^(\w)/,(e=>e.toUpperCase())))),1),Gb("span",{
class:Ih(["composition-selector-label text-c-1",{
"line-through":a.value?.deprecated}])
},Uh(o.value?.label||"Schema"),3),a.value?.deprecated?(Ub(),
Qb("div",r4e," deprecated ")):ny("",!0),Yb(xm(L_))])];var e})),_:1
},8,["modelValue","options"]),Gb("div",o4e,[Yb(G4e,{breadcrumb:e.breadcrumb,
compact:e.compact,discriminator:e.discriminator,eventBus:e.eventBus,
hideHeading:e.hideHeading,level:e.level+1,name:e.name,noncollapsible:!0,
options:e.options,schema:a.value
},null,8,["breadcrumb","compact","discriminator","eventBus","hideHeading","level","name","options","schema"])])],64))]))
}}),i4e={class:"property-enum-value"},s4e={class:"property-enum-value-content"
},l4e={class:"property-enum-value-label"},c4e={key:0,
class:"property-enum-value-description"},u4e=$0e(Qg({
__name:"SchemaEnumPropertyItem",props:{label:{},description:{}},
setup:e=>(t,n)=>(Ub(),Qb("li",i4e,[Gb("div",s4e,[Gb("span",l4e,[Yb(xm(Zoe),{
text:e.label,preset:"property"
},null,8,["text"])]),e.description?(Ub(),Qb("span",c4e,[Yb(xm(mre),{
value:e.description},null,8,["value"])])):ny("",!0)])]))
}),[["__scopeId","data-v-88bc950e"]]),d4e={key:0,class:"property-enum"},p4e={
class:"property-enum-values"},h4e={key:1},f4e=$0e(Qg({__name:"SchemaEnumValues",
props:{value:{}},setup(e){
const t=Sy((()=>e.value&&(e.value.enum||dQe(e.value)&&qke(e.value.items)?.enum)||[])),n=Sy((()=>t.value.length>9)),r=Sy((()=>n.value?5:t.value.length)),o=Sy((()=>t.value.slice(0,r.value))),a=Sy((()=>t.value.slice(r.value))),i=(t,n)=>{
const r=e.value?.["x-enumDescriptions"]??e.value?.["x-enum-descriptions"]
;if(r)return Array.isArray(r)?r[n]:"object"==typeof r&&null!==r?r[String(t)]:void 0
},s=(t,n)=>{
const r=e.value?.["x-enum-varnames"]??e.value?.["x-enumNames"],o=Array.isArray(r)?r[n]:void 0
;return o?`${t} = ${o}`:String(t)},l=bm(!1),c=()=>{l.value=!l.value}
;return(e,u)=>t.value.length>0?(Ub(),
Qb("div",d4e,[Gb("ul",p4e,[(Ub(!0),Qb(Mb,null,wv(o.value,((e,t)=>(Ub(),Hb(u4e,{
key:String(e),description:i(e,t),label:s(e,t)
},null,8,["description","label"])))),128)),n.value&&l.value?(Ub(!0),Qb(Mb,{key:0
},wv(a.value,((e,t)=>(Ub(),Hb(u4e,{key:String(e),description:i(e,r.value+t),
label:s(e,r.value+t)
},null,8,["description","label"])))),128)):ny("",!0),n.value?(Ub(),
Qb("li",h4e,[Yb(xm(WS),{
class:"enum-toggle-button my-2 flex h-fit gap-1 rounded-full border py-1.5 pr-2.5 pl-2 leading-none",
variant:"ghost",onClick:c},{default:ig((()=>[Yb(xm(uC),{class:Ih({
"rotate-45":l.value}),weight:"bold"
},null,8,["class"]),ey(" "+Uh(l.value?"Hide values":"Show all values"),1)])),_:1
})])):ny("",!0)])])):ny("",!0)}}),[["__scopeId","data-v-d4946030"]]),m4e=e=>{
if(!e)return null;if("$ref"in e){const t=V2e(e);if(t)return t}const t=qke(e)
;return t.title?t.title:t.name?t.name:null
},g4e=(e,t)=>`${e} ${t}${"array"===e?"[]":""}`,v4e=Qg({__name:"RenderString",
props:{value:{}},setup(e){
const t=Sy((()=>""===e.value?"''":null===e.value?"null":void 0===e.value?"undefined":e.value))
;return(e,n)=>Uh(t.value)}}),b4e={key:0,class:"property-detail-prefix"},y4e={
key:1,class:"property-detail-value"},O4e={key:2,class:"property-detail-value"
},w4e=$0e(Qg({__name:"SchemaPropertyDetail",props:{truncate:{type:Boolean},
code:{type:Boolean}},setup:e=>(t,n)=>(Ub(),Qb("span",{
class:Ih(["property-detail",{"property-detail-truncate":e.truncate}])
},[t.$slots.prefix?(Ub(),
Qb("div",b4e,[kv(t.$slots,"prefix",{},void 0,!0),n[0]||(n[0]=ey("  ",-1))])):ny("",!0),e.code?(Ub(),
Qb("code",y4e,[kv(t.$slots,"default",{},void 0,!0)])):(Ub(),
Qb("span",O4e,[kv(t.$slots,"default",{},void 0,!0)]))],2))
}),[["__scopeId","data-v-827ea49d"]]);function x4e(e){
return Array.isArray(e)?`[${e.map((e=>"string"==typeof e?`"${e.toString().trim()}"`:"object"==typeof e?JSON.stringify(e):void 0===e?"undefined":null===e?"null":e)).join(", ")}]`:null===e?"null":"object"==typeof e?"value"in e?e.value:"externalValue"in e?e.externalValue:JSON.stringify(e):void 0===e?"undefined":"string"==typeof e?e.trim():e.toString().trim()
}const k4e={key:0,class:"property-example"},S4e={
class:"property-example-value-list"},_4e={key:1,class:"property-example"},T4e={
class:"property-example-label",type:"button"},E4e={
class:"property-example-value-list"},A4e=["onClick"],C4e=$0e(Qg({
__name:"SchemaPropertyExamples",props:{examples:{},example:{}},setup(e){
const{copyToClipboard:t}=PG()
;return(n,r)=>(Ub(),Qb(Mb,null,[e.example?(Ub(),Qb("div",k4e,[r[1]||(r[1]=Gb("button",{
class:"property-example-label",type:"button"
},[Gb("span",null,"Example")],-1)),Gb("div",S4e,[Gb("button",{
class:"property-example-value group",type:"button",
onClick:r[0]||(r[0]=n=>xm(t)(xm(x4e)(e.example)))
},[Gb("span",null,Uh(xm(x4e)(e.example)),1),Yb(xm(Gne),{
class:"group-hover:text-c-1 text-c-3 ml-auto min-h-3 min-w-3",icon:"Clipboard",
size:"xs"
})])])])):ny("",!0),e.examples&&"object"==typeof e.examples&&Object.keys(e.examples).length>0?(Ub(),
Qb("div",_4e,[Gb("button",T4e,[Gb("span",null,Uh(1===Object.keys(e.examples).length?"Example":"Examples"),1)]),Gb("div",E4e,[(Ub(!0),
Qb(Mb,null,wv(e.examples,((e,n)=>(Ub(),Qb("button",{key:n,
class:"property-example-value group",type:"button",onClick:n=>xm(t)(xm(x4e)(e))
},[Gb("span",null,Uh(xm(x4e)(e)),1),Yb(xm(Gne),{
class:"text-c-3 group-hover:text-c-1 ml-auto min-h-3 min-w-3",icon:"Clipboard",
size:"xs"})],8,A4e)))),128))])])):ny("",!0)],64))}
}),[["__scopeId","data-v-72def0ea"]]),$4e={class:"property-heading"},P4e={key:1,
class:"property-discriminator"},D4e={key:3,class:"property-additional"},I4e={
key:4,class:"property-deprecated"},M4e={key:5,class:"property-const"},N4e={
key:7,class:"property-write-only"},R4e={key:8,class:"property-read-only"},L4e={
key:9,class:"property-required"},B4e=$0e(Qg({__name:"SchemaPropertyHeading",
props:{value:{},enum:{type:Boolean},isDiscriminator:{type:Boolean,default:!1},
required:{type:Boolean,default:!1},additional:{type:Boolean},withExamples:{
type:Boolean,default:!0},hideModelNames:{type:Boolean,default:!1}},setup(e){
const t=e,n=Pm(t,"value"),r=Sy((()=>{if(!n.value)return;const e=n.value
;if(void 0!==e.const)return e.const;if(1===e.enum?.length)return e.enum[0]
;if(dQe(e)&&e.items){const t=qke(e.items);if(xH(t.const))return t.const
;if(1===t.enum?.length)return t.enum[0]}})),o=Sy((()=>{if(!n.value)return[]
;const e=n.value,t=[];return dQe(e)&&((e.minItems||e.maxItems)&&t.push({
key:"array-range",value:`${e.minItems||""}…${e.maxItems||""}`
}),e.uniqueItems&&t.push({key:"unique-items",value:"unique!"
})),pQe(e)&&(e.minLength&&t.push({key:"min-length",prefix:"min length: ",
value:e.minLength}),e.maxLength&&t.push({key:"max-length",prefix:"max length: ",
value:e.maxLength}),e.pattern&&t.push({key:"pattern",value:e.pattern,code:!0,
truncate:!0})),(pQe(e)||hQe(e))&&e.format&&t.push({key:"format",value:e.format,
truncate:!0}),hQe(e)&&(xH(e.exclusiveMinimum)&&t.push({key:"exclusive-minimum",
prefix:"greater than: ",value:e.exclusiveMinimum}),xH(e.minimum)&&t.push({
key:"minimum",prefix:"min: ",value:e.minimum}),xH(e.exclusiveMaximum)&&t.push({
key:"exclusive-maximum",prefix:"less than: ",value:e.exclusiveMaximum
}),xH(e.maximum)&&t.push({key:"maximum",prefix:"max: ",value:e.maximum
}),xH(e.multipleOf)&&t.push({key:"multiple-of",prefix:"multiple of: ",
value:e.multipleOf})),t})),a=Sy((()=>t.value?((e,t=!1)=>{
if(!("type"in e)||t)return null;const n=e.type,r=m4e(e)
;if(r&&e.title)return"array"===n?`array ${r}[]`:r;if(dQe(e)&&e.items){
const t=qke(e.items),r=t.title;if(r)return g4e(n,r);const o=m4e(e.items)
;return o&&"type"in t&&o!==t.type?g4e(n,o):g4e(n,"type"in t?Array.isArray(t.type)?t.type.join(" | "):t.type:"object")
}if(r&&r!==n)return r.startsWith("Array of ")?`array ${r.slice(9)}[]`:r
;return null
})(t.value,t.hideModelNames):null)),i=Sy((()=>!(!t.value||!("type"in t.value))&&("array"===t.value.type||!r.value))),s=Sy((()=>t.value?a.value||W2e(t.value):"")),l=Sy((()=>{
const e=t.value
;return null===e?.default?"null":Array.isArray(e?.default)&&1===e?.default.length?String(e?.default[0]):"string"==typeof e?.default?JSON.stringify(e.default):Array.isArray(e?.default)||"object"==typeof e?.default?JSON.stringify(e?.default):e?.default
}));return(e,n)=>(Ub(),Qb("div",$4e,[e.$slots.name?(Ub(),Qb("div",{key:0,
class:Ih(["property-name",{deprecated:t.value?.deprecated}])
},[kv(e.$slots,"name",{},void 0,!0)],2)):ny("",!0),t.isDiscriminator?(Ub(),
Qb("div",P4e," Discriminator ")):ny("",!0),t.value?(Ub(),Qb(Mb,{key:2
},[i.value?(Ub(),Hb(w4e,{key:0,truncate:""},{default:ig((()=>[Yb($1e,null,{
default:ig((()=>[...n[0]||(n[0]=[ey("Type: ",-1)])])),_:1
}),ey(Uh(s.value),1)])),_:1
})):ny("",!0),(Ub(!0),Qb(Mb,null,wv(o.value,(e=>(Ub(),Hb(w4e,{key:e.key,
code:e.code,truncate:e.truncate},xv({
default:ig((()=>["format"===e.key?(Ub(),Hb($1e,{key:0},{
default:ig((()=>[...n[1]||(n[1]=[ey("Format:",-1)])])),_:1
})):"pattern"===e.key?(Ub(),Hb($1e,{key:1},{
default:ig((()=>[...n[2]||(n[2]=[ey(" Pattern: ",-1)])])),_:1
})):ny("",!0),ey(" "+Uh(e.value),1)])),_:2},[e.prefix?{name:"prefix",
fn:ig((()=>[ey(Uh(e.prefix),1)])),key:"0"
}:void 0]),1032,["code","truncate"])))),128)),t.enum?(Ub(),Hb(w4e,{key:1},{
default:ig((()=>[...n[3]||(n[3]=[ey("enum",-1)])])),_:1
})):ny("",!0),void 0!==l.value?(Ub(),Hb(w4e,{key:2,truncate:""},{
prefix:ig((()=>[...n[4]||(n[4]=[ey("default:",-1)])])),
default:ig((()=>[ey(Uh(l.value),1)])),_:1
})):ny("",!0)],64)):ny("",!0),t.additional?(Ub(),
Qb("div",D4e,[t.value?.["x-additionalPropertiesName"]?(Ub(),Qb(Mb,{key:0
},[ey(Uh(t.value["x-additionalPropertiesName"]),1)],64)):(Ub(),Qb(Mb,{key:1
},[ey("additional properties")],64))])):ny("",!0),t.value?.deprecated?(Ub(),
Qb("div",I4e,[Yb(xm(o1e),null,{
default:ig((()=>[...n[5]||(n[5]=[ey("deprecated",-1)])])),_:1
})])):ny("",!0),void 0!==r.value?(Ub(),Qb("div",M4e,[Yb(w4e,{truncate:""},{
prefix:ig((()=>[...n[6]||(n[6]=[ey("const: ",-1)])])),default:ig((()=>[Yb(v4e,{
value:r.value},null,8,["value"])])),_:1})])):(Ub(),Qb(Mb,{key:6
},[!0===t.value?.nullable?(Ub(),Hb(w4e,{key:0},{
default:ig((()=>[...n[7]||(n[7]=[ey(" nullable ",-1)])])),_:1
})):ny("",!0)],64)),t.value?.writeOnly?(Ub(),
Qb("div",N4e," write-only ")):t.value?.readOnly?(Ub(),
Qb("div",R4e," read-only ")):ny("",!0),t.required?(Ub(),
Qb("div",L4e," required ")):ny("",!0),t.withExamples?(Ub(),Hb(C4e,{key:10,
example:t.value?.example||t.value&&xm(dQe)(t.value)&&xm(qke)(t.value?.items)?.example,
examples:t.value?.examples},null,8,["example","examples"])):ny("",!0)]))}
}),[["__scopeId","data-v-5d03e993"]]),j4e={key:0,
class:"property-name-pattern-properties"},U4e={key:1,
class:"property-name-additional-properties"},z4e={key:1,
class:"property-description"},F4e={key:3,class:"children"},Z4e={key:4,
class:"children"},Q4e=$0e(Qg({__name:"SchemaProperty",props:{is:{},schema:{},
noncollapsible:{type:Boolean},level:{default:0},name:{},required:{type:Boolean,
default:!1},compact:{type:Boolean,default:!1},discriminator:{},description:{},
hideModelNames:{type:Boolean,default:!1},hideHeading:{type:Boolean},variant:{},
breadcrumb:{},eventBus:{},options:{}},setup(e){const t=e,n=Sy((()=>function(e){
if(!e||"object"!=typeof e)return e;const t=j2e.find((t=>t in e&&"not"!==t))
;if(!t)return{...e};const n=e[t];if(!Array.isArray(n))return{...e}
;const{[t]:r,nullable:o,...a}=e,i=Object.keys(a).length>0,{filteredSchemas:s,hasNullSchema:l}=n.reduce(((e,t)=>{
const n=qke(t)
;return"type"in n&&"null"===n.type?e.hasNullSchema=!0:e.filteredSchemas.push(n),
e}),{filteredSchemas:[],hasNullSchema:!1}),c=l||!0===o;if(1===s.length){
const e={...a,...s[0]};return c&&(e.nullable=!0),e}
if(("oneOf"===t||"anyOf"===t)&&(i||s.some((e=>e.allOf)))){const e=s.map((e=>{
const t=qke(e);if(1===t.allOf?.length){const{allOf:e,...n}=t;return{...a,...n,
...qke(e[0])}}return{...a,...t}})),n={[t]:e};return c&&(n.nullable=!0),n}
if(s.length!==n.length){const n={...e,[t]:s};return c&&(n.nullable=!0),n}return{
...e}
}(t.schema))),r=Sy((()=>t.breadcrumb&&t.name?[...t.breadcrumb,t.name]:void 0)),o=Sy((()=>t.level<=1)),a=Sy((()=>Z2e(n.value))),i=Sy((()=>c.value.length>0)),s=Sy((()=>{
const e=n.value
;return!!e&&(D2e(e)&&("properties"in e||"additionalProperties"in e))
})),l=Sy((()=>{const e=n.value
;return!(!e||!dQe(e)||"object"!=typeof e.items)&&a.value})),c=Sy((()=>(e=>{
if(!e)return[];if(e.enum)return e.enum;if(dQe(e)&&"object"==typeof e.items){
const t=qke(e.items);if(t&&"enum"in t&&t.enum)return t.enum}return[]
})(n.value))),u=Sy((()=>(e=>{if(void 0===(t=e)||!("type"in t))return null;var t
;const n=Array.isArray(e.type)?e.type[0]:e.type;if(!n)return null;const r=H2e[n]
;return r?r["format"in e&&e.format||"contentEncoding"in e&&e.contentEncoding||"_default"]??null:null
})(n.value))),d=Sy((()=>{
return e=n.value,r=t.description,e?"properties"in e||"additionalProperties"in e||"patternProperties"in e||e.allOf?null:r||e.description||null:null
;var e,r
})),p=Sy((()=>((e,t,n=!1)=>!(!t&&!n)||!!e&&(!0===e.deprecated||void 0!==e.const||1===e.enum?.length||"type"in e&&void 0!==e.type||"nullable"in e&&!0===e.nullable||!0===e.writeOnly||!0===e.readOnly))(n.value,t.name,t.required))),h=Sy((()=>Q2e(n.value))),f=Sy((()=>{
const e=n.value;if(e&&dQe(e)&&"object"==typeof e.items)return qke(e.items)
})),m=Sy((()=>Boolean(t.name&&t.discriminator?.propertyName===t.name)))
;return(a,c)=>(Ub(),Hb(bv(e.is??"li"),{
class:Ih(["property",[`property--level-${e.level}`,{
"property--compact":e.compact,"property--deprecated":n.value?.deprecated}]])},{
default:ig((()=>[p.value?(Ub(),Hb(B4e,{key:0,class:"group",enum:i.value,
hideModelNames:e.hideModelNames,isDiscriminator:m.value,required:e.required,
value:n.value},xv({_:2},[e.name?{name:"name",fn:ig((()=>[Yb(xm(R1e),{
breadcrumb:o.value?r.value:void 0,eventBus:e.eventBus},{
default:ig((()=>["patternProperties"===e.variant?(Ub(),
Qb("span",j4e,[Yb(xm(Zoe),{preset:"property",text:e.name
},null,8,["text"])])):"additionalProperties"===e.variant?(Ub(),
Qb("span",U4e,[Yb(xm(Zoe),{preset:"property",text:e.name
},null,8,["text"])])):(Ub(),Hb(xm(Zoe),{key:2,preset:"property",text:e.name
},null,8,["text"]))])),_:1},8,["breadcrumb","eventBus"])])),key:"0"
}:void 0,n.value?.example?{name:"example",
fn:ig((()=>[ey(" Example: "+Uh(n.value.example),1)])),key:"1"
}:void 0]),1032,["enum","hideModelNames","isDiscriminator","required","value"])):ny("",!0),d.value||u.value?(Ub(),
Qb("div",z4e,[Yb(xm(mre),{value:d.value||u.value||""
},null,8,["value"])])):ny("",!0),i.value?(Ub(),Hb(f4e,{key:2,value:n.value
},null,8,["value"])):ny("",!0),s.value?(Ub(),Qb("div",F4e,[Yb(G4e,{
breadcrumb:r.value,compact:e.compact,eventBus:e.eventBus,level:e.level+1,
name:e.name,noncollapsible:e.noncollapsible,options:e.options,schema:n.value
},null,8,["breadcrumb","compact","eventBus","level","name","noncollapsible","options","schema"])])):ny("",!0),l.value&&f.value?(Ub(),
Qb("div",Z4e,[Yb(G4e,{compact:e.compact,eventBus:e.eventBus,level:e.level+1,
name:e.name,noncollapsible:e.noncollapsible,options:e.options,schema:f.value
},null,8,["compact","eventBus","level","name","noncollapsible","options","schema"])])):ny("",!0),(Ub(!0),
Qb(Mb,null,wv(h.value,(n=>(Ub(),Hb(a4e,{key:n.composition,
breadcrumb:e.breadcrumb,compact:e.compact,composition:n.composition,
discriminator:e.schema?.discriminator,eventBus:e.eventBus,
hideHeading:e.hideHeading,level:e.level,name:e.name,
noncollapsible:e.noncollapsible,options:e.options,schema:xm(qke)(t.schema)
},null,8,["breadcrumb","compact","composition","discriminator","eventBus","hideHeading","level","name","noncollapsible","options","schema"])))),128)),Yb(xm(H1e),{
value:n.value},null,8,["value"])])),_:1},8,["class"]))}
}),[["__scopeId","data-v-7ddcdaa6"]]),H4e=Qg({__name:"SchemaObjectProperties",
props:{schema:{},discriminator:{},compact:{type:Boolean},hideHeading:{
type:Boolean},level:{},hideModelNames:{type:Boolean},breadcrumb:{},eventBus:{},
options:{}},setup(e){
const t=Sy((()=>B2e(e.schema,e.discriminator,e.options))),n=e=>{const t=qke(e)
;return"object"==typeof t&&"string"==typeof t["x-additionalPropertiesName"]&&t["x-additionalPropertiesName"].trim().length>0?`${t["x-additionalPropertiesName"].trim()}`:"propertyName"
};return(r,o)=>{
return Ub(),Qb(Mb,null,[xm(D2e)(e.schema)&&e.schema.properties?(Ub(!0),Qb(Mb,{
key:0},wv(t.value,(t=>(Ub(),Hb(Q4e,{key:t,breadcrumb:e.breadcrumb,
compact:e.compact,discriminator:e.discriminator,eventBus:e.eventBus,
hideHeading:e.hideHeading,hideModelNames:e.hideModelNames,level:e.level,name:t,
options:e.options,required:e.schema.required?.includes(t),
schema:xm(qke)(e.schema.properties[t])
},null,8,["breadcrumb","compact","discriminator","eventBus","hideHeading","hideModelNames","level","name","options","required","schema"])))),128)):ny("",!0),xm(D2e)(e.schema)&&e.schema.patternProperties?(Ub(!0),
Qb(Mb,{key:1
},wv(Object.entries(e.schema.patternProperties),(([t,n])=>(Ub(),Hb(Q4e,{key:t,
breadcrumb:e.breadcrumb,compact:e.compact,discriminator:e.discriminator,
eventBus:e.eventBus,hideHeading:e.hideHeading,hideModelNames:e.hideModelNames,
level:e.level,name:t,options:e.options,schema:xm(qke)(n)
},null,8,["breadcrumb","compact","discriminator","eventBus","hideHeading","hideModelNames","level","name","options","schema"])))),128)):ny("",!0),xm(D2e)(e.schema)&&e.schema.additionalProperties?(Ub(),
Hb(Q4e,{key:2,breadcrumb:e.breadcrumb,compact:e.compact,
discriminator:e.discriminator,eventBus:e.eventBus,hideHeading:e.hideHeading,
hideModelNames:e.hideModelNames,level:e.level,
name:n(e.schema.additionalProperties),noncollapsible:"",options:e.options,
schema:(a=e.schema.additionalProperties,
!0===a||"object"==typeof a&&0===Object.keys(a).length||"object"!=typeof a||!("type"in a)?{
type:"anything",..."object"==typeof a?a:{}}:a),variant:"additionalProperties"
},null,8,["breadcrumb","compact","discriminator","eventBus","hideHeading","hideModelNames","level","name","options","schema"])):ny("",!0)],64)
;var a}}}),V4e={key:0,class:"schema-card-description"},q4e={key:1,class:"pt-2"
},W4e={key:0,class:"schema-properties"},X4e=Qg({__name:"Schema",props:{
schema:{},level:{default:0},name:{},compact:{type:Boolean},noncollapsible:{
type:Boolean,default:!1},hideHeading:{type:Boolean},additionalProperties:{
type:Boolean},hideModelNames:{type:Boolean,default:!1},discriminator:{},
breadcrumb:{},eventBus:{},options:{}},setup(e){
const t=Sy((()=>!e.noncollapsible&&e.level>0)),n=Sy((()=>e.schema?.allOf&&e.schema.allOf.length>0&&"Request Body"===e.name?e.schema.description||e.schema.allOf[0]?.description||null:e.schema?.description&&"string"==typeof e.schema.description?e.schema.oneOf||e.schema.anyOf||e.schema.enum?null:"properties"in e.schema||"patternProperties"in e.schema||"additionalProperties"in e.schema?e.schema.description:null:null)),r=t=>e.noncollapsible&&t.stopPropagation()
;return(o,a)=>"object"==typeof e.schema&&Object.keys(e.schema).length?(Ub(),
Hb(xm(qx),{key:0,defaultOpen:e.noncollapsible},{
default:ig((({open:o})=>[Gb("div",{
class:Ih(["schema-card",[`schema-card--level-${e.level}`,{
"schema-card--compact":e.compact,"schema-card--open":o},{
"border-t":e.additionalProperties&&o}]])
},[n.value?(Ub(),Qb("div",V4e,[Yb(xm(mre),{value:n.value
},null,8,["value"])])):ny("",!0),xm(I2e)(e.schema)?(Ub(),
Qb("div",q4e," Empty object ")):ny("",!0),Gb("div",{
class:Ih(["schema-properties",{"schema-properties-open":o}])
},[e.additionalProperties?sg((Ub(),Qb("div",W4e,[Yb(xm(Wx),{as:"button",
class:"schema-card-title schema-card-title--compact",onClickCapture:r},{
default:ig((()=>[Yb(xm(Gne),{class:"schema-card-title-icon",icon:"Add",size:"sm"
}),a[0]||(a[0]=ey(" Show additional properties ",-1)),e.name?(Ub(),Hb($1e,{key:0
},{default:ig((()=>[ey("for "+Uh(e.name),1)])),_:1})):ny("",!0)])),_:1
})],512)),[[Jy,!o]]):t.value?sg((Ub(),Hb(xm(Wx),{key:1,
as:e.noncollapsible?"div":"button",class:Ih(["schema-card-title",{
"schema-card-title--compact":e.compact}]),style:Ah({
top:`calc(var(--refs-viewport-offset) +  calc(var(--schema-title-height) * ${e.level}))`
}),onClickCapture:r},{default:ig((()=>[e.compact?(Ub(),Qb(Mb,{key:0
},[Yb(xm(Gne),{class:Ih(["schema-card-title-icon",{
"schema-card-title-icon--open":o}]),icon:"Add",size:"sm"
},null,8,["class"]),o?(Ub(),Qb(Mb,{key:0
},[ey(" Hide "+Uh(e.schema?.title??"Child Attributes"),1)],64)):(Ub(),Qb(Mb,{
key:1
},[ey(" Show "+Uh(e.schema?.title??"Child Attributes"),1)],64)),e.name?(Ub(),
Hb($1e,{key:2},{default:ig((()=>[ey("for "+Uh(e.name),1)])),_:1
})):ny("",!0)],64)):(Ub(),Qb(Mb,{key:1},[Yb(xm(Gne),{
class:Ih(["schema-card-title-icon",{"schema-card-title-icon--open":o}]),
icon:"Add",size:"sm"},null,8,["class"]),Yb(R2e,{name:e.schema?.title??e.name,
value:e.schema},null,8,["name","value"])],64))])),_:2
},1032,["as","class","style"])),[[Jy,!(e.hideHeading||e.noncollapsible&&e.compact)]]):ny("",!0),!e.additionalProperties||o?(Ub(),
Hb(xm(Xx),{key:2,as:"ul",static:!t.value},{
default:ig((()=>[xm(D2e)(e.schema)?(Ub(),Hb(H4e,{key:0,breadcrumb:e.breadcrumb,
compact:e.compact,discriminator:e.discriminator,eventBus:e.eventBus,
hideHeading:e.hideHeading,hideModelNames:e.hideModelNames,level:e.level+1,
options:e.options,schema:e.schema
},null,8,["breadcrumb","compact","discriminator","eventBus","hideHeading","hideModelNames","level","options","schema"])):(Ub(),
Qb(Mb,{key:1},[e.schema?(Ub(),Hb(Q4e,{key:0,breadcrumb:e.breadcrumb,
compact:e.compact,eventBus:e.eventBus,hideHeading:e.hideHeading,
hideModelNames:e.hideModelNames,level:e.level,options:e.options,schema:e.schema
},null,8,["breadcrumb","compact","eventBus","hideHeading","hideModelNames","level","options","schema"])):ny("",!0)],64))])),
_:1},8,["static"])):ny("",!0)],2)],2)])),_:1},8,["defaultOpen"])):ny("",!0)}
}),G4e=$0e(X4e,[["__scopeId","data-v-4d81600f"]]),Y4e={key:0,class:"properties"
},K4e={key:1},J4e=$0e(Qg({__name:"ClassicLayout",props:{id:{},name:{},schema:{},
isCollapsed:{type:Boolean},eventBus:{},options:{}},
setup:e=>(t,n)=>(Ub(),Hb(xm(h1e),{"aria-label":e.schema.title??e.name,
modelValue:!e.isCollapsed,
"onUpdate:modelValue":n[1]||(n[1]=t=>e.eventBus?.emit("toggle:nav-item",{
id:e.id,open:t}))},{title:ig((()=>[Yb(xm(I1e),{class:"reference-models-anchor",
eventBus:e.eventBus,
onCopyAnchorUrl:n[0]||(n[0]=()=>e.eventBus?.emit("copy-url:nav-item",{id:e.id}))
},{default:ig((()=>[Yb(xm(A1e),{level:3},{default:ig((()=>[Yb(xm(R2e),{
class:"reference-models-label",name:e.schema.title??e.name,value:e.schema
},null,8,["name","value"])])),_:1})])),_:1},8,["eventBus"])])),
default:ig((()=>["properties"in e.schema?(Ub(),
Qb("div",Y4e,[(Ub(!0),Qb(Mb,null,wv(Object.entries(e.schema.properties??{}),(([t,n])=>(Ub(),
Hb(xm(Q4e),{key:t,eventBus:e.eventBus,name:t,options:e.options,
required:e.schema.required?.includes(t),schema:xm(qke)(n)
},null,8,["eventBus","name","options","required","schema"])))),128))])):(Ub(),
Qb("div",K4e,[Yb(xm(Q4e),{eventBus:e.eventBus,options:e.options,schema:e.schema
},null,8,["eventBus","options","schema"])]))])),_:1
},8,["aria-label","modelValue"]))}),[["__scopeId","data-v-161968a4"]]),e8e=Qg({
__name:"ModernLayout",props:{id:{},name:{},schema:{},isCollapsed:{type:Boolean},
eventBus:{},options:{}},setup:e=>(t,n)=>(Ub(),Hb(xm(j1e),{id:e.id,key:e.name,
label:e.name,modelValue:!e.isCollapsed,
onCopyAnchorUrl:n[0]||(n[0]=()=>e.eventBus?.emit("copy-url:nav-item",{id:e.id
})),"onUpdate:modelValue":n[1]||(n[1]=t=>e.eventBus?.emit("toggle:nav-item",{
id:e.id,open:t}))},{heading:ig((()=>[Yb(xm(A1e),{level:3},{
default:ig((()=>[Yb(xm(R2e),{name:e.schema.title??e.name,value:e.schema
},null,8,["name","value"])])),_:1})])),default:ig((()=>[Yb(xm(v2),null,{
default:ig((()=>[Yb(xm(G4e),{eventBus:e.eventBus,hideHeading:"",
hideModelNames:"",level:1,noncollapsible:"",options:e.options,schema:e.schema
},null,8,["eventBus","options","schema"])])),_:1})])),_:1
},8,["id","label","modelValue"]))}),t8e=Qg({__name:"Model",props:{id:{},name:{},
options:{},schema:{},isCollapsed:{type:Boolean},eventBus:{}},setup(e){
const t=qg("section")
;return s1e(t,(()=>e.eventBus?.emit("intersecting:nav-item",{id:e.id
}))),(n,r)=>e.schema?(Ub(),Qb("div",{key:0,ref_key:"section",ref:t
},["classic"===e.options.layout?(Ub(),Hb(J4e,{key:0,id:e.id,eventBus:e.eventBus,
isCollapsed:e.isCollapsed,name:e.name,options:e.options,schema:e.schema
},null,8,["id","eventBus","isCollapsed","name","options","schema"])):(Ub(),
Hb(e8e,{key:1,id:e.id,eventBus:e.eventBus,isCollapsed:e.isCollapsed,name:e.name,
options:e.options,schema:e.schema
},null,8,["id","eventBus","isCollapsed","name","options","schema"]))],512)):ny("",!0)
}
}),n8e=e=>e.replace(/^\/+|\/+$/g,""),r8e=(e,t,n)=>"string"==typeof t?((e,t,n)=>{
const r="string"==typeof e?new URL(e):e,o=n8e(t),a=o?`/${o.split("/").map((e=>encodeURIComponent(e))).join("/")}`:""
;if(r.pathname.startsWith(a)){
const e=r.pathname.slice(a.length),t=decodeURIComponent(e.startsWith("/")?e.slice(1):e)
;return n?`${n}${t?"/":""}${t}`:t}return n??""})(e,t,n):((e,t)=>{
const n="string"==typeof e?new URL(e):e,r=decodeURIComponent(n.hash.slice(1))
;return t?`${t}${r?"/":""}${r}`:r})(e,n),o8e=(e,t,n)=>{
if("undefined"==typeof window)return;const r=n?e:(e=>{
const t=e.endsWith("/"),n=e.split("/").filter(Boolean).slice(1).join("/")
;return t&&n?`${n}/`:n})(e),o=new URL(window.location.href)
;if("string"==typeof t){const e=n8e(t);o.pathname=`${e}/${r}`}else o.hash=r
;return o
},a8e=am(new Set),i8e=am(new Set),s8e=am(new Set),l8e=bm(!1),c8e=bm(!1),u8e=am(new Set),d8e=new Set,p8e=()=>{
const e=BX();return u8e.add(e),()=>setTimeout((()=>u8e.delete(e)),100)
},h8e=Sy((()=>0===u8e.size));!function(e,t,n={}){
const{debounce:r=0,maxWait:o,...a}=n;X1(e,t,{...a,eventFilter:V1(r,{maxWait:o})
})}([()=>i8e.size,()=>a8e.size,()=>l8e.value],(()=>{
(i8e.size>0||a8e.size>0)&&!l8e.value&&(()=>{if("undefined"==typeof window)return
;const e=p8e(),t=async()=>{if(i8e.size>0||a8e.size>0){l8e.value=!0
;for(const e of[...i8e,...a8e])s8e.add(e),i8e.delete(e),a8e.delete(e)}
await Xm(),d8e.forEach((e=>e())),d8e.clear(),e(),l8e.value=!1,c8e.value=!0}
;window.requestIdleCallback?window.requestIdleCallback(t,{timeout:1500}):Xm(t)
})()}),{debounce:300,maxWait:1500});const f8e=e=>{e&&a8e.add(e)}
;function m8e(e){return(e=>{e&&!a8e.has(e)&&i8e.add(e)})(e),cv((()=>{(e=>{
a8e.delete(e),i8e.delete(e),s8e.delete(e)})(e)})),{
isReady:Sy((()=>"undefined"==typeof window||a8e.has(e)||s8e.has(e)))}}
const g8e=(e,t,n)=>{
const r=n(e),o=!s8e.has(e)||r?.children?.some((e=>!s8e.has(e.id)))?b8e(e):void 0
;var a;(a=o)&&d8e.add(a);const i=p8e(),{rawId:s}=(e=>{
const t=e.match(/(.*)(\.body\.|\.path\.|\.query\.|\.header\.)(.*)/)
;return t&&"string"==typeof t[1]&&"string"==typeof t[2]?{rawId:t[1],
params:t[2].slice(1)+t[3]}:{rawId:e,params:""}})(e)
;if(f8e(e),f8e(s),r?.children&&r.children.slice(0,2).forEach((e=>{f8e(e.id)
})),r?.parent){const t=n(r.parent.id),o=t?.children?.findIndex((t=>t.id===e))
;void 0!==o&&o>=0&&t?.children?.slice(o,o+2).forEach((e=>{f8e(e.id)}))}
v8e(e,Date.now()+1e3,i,o),t(s,!0);const l=e=>{const r=n(e)?.parent
;r&&(f8e(r.id),t(r.id,!0),l(r.id))};l(s)},v8e=(e,t,n,r)=>{
const o=document.getElementById(e);o?(o.scrollIntoView({block:"start"
}),n()):Date.now()<t?requestAnimationFrame((()=>v8e(e,t,n))):(n(),r?.())
},b8e=e=>{let t=!1;const n=r=>{const o=document.getElementById(e)
;o&&o.scrollIntoView({block:"start"}),r||requestAnimationFrame((()=>n(t)))}
;return n(!1),()=>{t=!0}},y8e=Qg({__name:"Lazy",props:{id:{}},setup(e){
const{isReady:t}=m8e(e.id);return(e,n)=>xm(t)?kv(e.$slots,"default",{key:0
}):ny("",!0)}}),O8e={class:"show-more",type:"button"},w8e=$0e(Qg({
__name:"ShowMoreButton",
setup:e=>(e,t)=>(Ub(),Qb("button",O8e,[t[0]||(t[0]=ey(" Show More ",-1)),Yb(xm(L_),{
class:"text-c-2 mt-0.25 size-3",weight:"bold"})]))
}),[["__scopeId","data-v-d1c2b649"]]),x8e=Qg({__name:"ModelTag",props:{id:{},
isCollapsed:{type:Boolean},eventBus:{},layout:{}},setup:e=>(t,n)=>(Ub(),Hb(y8e,{
id:"models"},{default:ig((()=>["modern"===e.layout?(Ub(),Hb(y1e,{key:0,
id:"model"},{default:ig((()=>[Yb(xm(l1e),{id:e.id,"aria-label":"Models",
onIntersecting:n[1]||(n[1]=()=>e.eventBus?.emit("intersecting:nav-item",{id:e.id
}))},{default:ig((()=>[Yb(xm(E1e),null,{default:ig((()=>[Yb(A1e,{level:2},{
default:ig((()=>[...n[3]||(n[3]=[ey(" Models ",-1)])])),_:1})])),_:1
}),e.isCollapsed?(Ub(),Hb(w8e,{key:1,id:e.id,class:"top-0",
onClick:n[0]||(n[0]=()=>e.eventBus.emit("toggle:nav-item",{id:e.id,open:!0}))
},null,8,["id"])):kv(t.$slots,"default",{key:0})])),_:3},8,["id"])])),_:3
})):(Ub(),Hb(x1e,{key:1,"aria-label":"Models",class:"pb-12",
modelValue:!e.isCollapsed,
"onUpdate:modelValue":n[2]||(n[2]=()=>e.eventBus?.emit("toggle:nav-item",{
id:e.id,open:e.isCollapsed}))},{title:ig((()=>[Yb(xm(E1e),{level:2},{
default:ig((()=>[...n[4]||(n[4]=[ey("Models",-1)])])),_:1})])),
default:ig((()=>[kv(t.$slots,"default")])),_:3},8,["modelValue"]))])),_:3}))
}),k8e=$0e(Qg({__name:"ClassicLayout",props:{tag:{},isCollapsed:{type:Boolean},
eventBus:{}},setup:e=>(t,n)=>(Ub(),Hb(xm(x1e),{"aria-label":e.tag.title,
class:"tag-section",modelValue:!e.isCollapsed,
"onUpdate:modelValue":n[1]||(n[1]=t=>e.eventBus?.emit("toggle:nav-item",{
id:e.tag.id,open:t}))},{title:ig((()=>[Yb(xm(E1e),{class:"tag-name"},{
default:ig((()=>[Yb(xm(I1e),{
onCopyAnchorUrl:n[0]||(n[0]=()=>e.eventBus?.emit("copy-url:nav-item",{
id:e.tag.id}))},{default:ig((()=>[Yb(xm(A1e),{level:2},{
default:ig((()=>[ey(Uh(e.tag.title),1)])),_:1})])),_:1})])),_:1}),Yb(xm(mre),{
class:"tag-description",value:e.tag?.description,withImages:""
},null,8,["value"])])),default:ig((()=>[kv(t.$slots,"default",{},void 0,!0)])),
_:3},8,["aria-label","modelValue"]))
}),[["__scopeId","data-v-1124be5d"]]),S8e=Qg({__name:"HttpMethod",props:{as:{},
property:{},short:{type:Boolean},method:{}},setup(e){
const t=e,n=Sy((()=>CH(String(t.method||"")))),r=Sy((()=>aDe(t.method)))
;return(t,o)=>(Ub(),Hb(bv(e.as??"span"),{class:"uppercase",style:Ah({
[e.property||"color"]:n.value.colorVar})},{
default:ig((()=>[kv(t.$slots,"default"),ey(" "+Uh(e.short?n.value.short:r.value),1)])),
_:3},8,["style"]))}}),_8e=$0e(Qg({__name:"OperationsListItem",props:{
operation:{},isCollapsed:{type:Boolean},eventBus:{}},setup(e){
const t=Sy((()=>"path"in e.operation?e.operation.path:e.operation.title))
;return(n,r)=>(Ub(),Qb("li",{key:e.operation.id,class:"contents"
},[e.isCollapsed?(Ub(),Hb(xm(A1e),{key:0,class:"sr-only",level:3},{
default:ig((()=>[ey(Uh(e.operation.title)+" (Hidden) ",1)])),_:1
})):ny("",!0),Gb("a",{class:"endpoint",
onClick:r[0]||(r[0]=BO((()=>e.eventBus?.emit("scroll-to:nav-item",{
id:e.operation.id})),["prevent"]))},[Yb(xm(S8e),{
class:"endpoint-method items-center justify-end gap-2",method:e.operation.method
},{default:ig((()=>{return[(t=e.operation,"webhook"===t.type?(Ub(),Hb(xm(T$),{
key:0,class:"size-3.5",style:Ah({color:xm(CH)(e.operation.method).colorVar})
},null,8,["style"])):ny("",!0))];var t})),_:1},8,["method"]),Gb("span",{
class:Ih(["endpoint-path",{deprecated:e.operation.isDeprecated}])
},Uh(t.value),3)])]))}
}),[["__scopeId","data-v-ad8530a6"]]),T8e=["aria-label"],E8e=$0e(Qg({
__name:"OperationsList",props:{tag:{},eventBus:{}},setup(e){
const t=Sy((()=>e.tag.children?.filter((e=>"operation"===e.type||"webhook"===e.type))??[]))
;return(n,r)=>e.tag.children&&e.tag.children?.length>0?(Ub(),Hb(xm(GS),{key:0,
class:"endpoints-card"},{default:ig((()=>[Yb(xm(t_),{muted:""},{
default:ig((()=>[Yb($1e,null,{default:ig((()=>[ey(Uh(e.tag.title),1)])),_:1
}),ey(" "+Uh(e.tag.isWebhooks?"Webhooks":"Operations"),1)])),_:1}),Yb(xm(YS),{
class:"custom-scroll max-h-[60vh]"},{default:ig((()=>[Gb("ul",{
"aria-label":`${e.tag.title} endpoints`,class:"endpoints"
},[(Ub(!0),Qb(Mb,null,wv(t.value,(t=>(Ub(),Hb(_8e,{key:t.id,eventBus:e.eventBus,
operation:t},null,8,["eventBus","operation"])))),128))],8,T8e)])),_:1})])),_:1
})):ny("",!0)}}),[["__scopeId","data-v-f726f753"]]),A8e=Qg({__name:"TagSection",
props:{tag:{},headerId:{},isCollapsed:{type:Boolean},isLoading:{type:Boolean},
eventBus:{}},setup:e=>(t,n)=>e.tag?(Ub(),Hb(xm(l1e),{key:0,id:e.tag.id,
role:"none",
onIntersecting:n[1]||(n[1]=()=>e.eventBus?.emit("intersecting:nav-item",{
id:e.tag.id}))},{default:ig((()=>[sg(Yb(xm(E1e),null,{
default:ig((()=>[Yb(xm(I1e),{
onCopyAnchorUrl:n[0]||(n[0]=()=>e.eventBus?.emit("copy-url:nav-item",{
id:e.tag.id}))},{default:ig((()=>[Yb(xm(A1e),{id:e.headerId,level:2},{
default:ig((()=>[ey(Uh(e.tag.title)+" ",1),e.isCollapsed?(Ub(),Hb($1e,{key:0},{
default:ig((()=>[...n[2]||(n[2]=[ey(" (Collapsed)",-1)])])),_:1})):ny("",!0)])),
_:1},8,["id"])])),_:1})])),_:1},512),[[Jy,!e.isLoading]]),Yb(xm(_1e),{
loading:e.isLoading},{default:ig((()=>[Yb(xm(v1e),null,{
default:ig((()=>[Yb(xm(m1e),null,{default:ig((()=>[Yb(xm(mre),{
clamp:e.isCollapsed?7:void 0,value:e.tag?.description??"",withImages:""
},null,8,["clamp","value"])])),_:1}),Yb(xm(m1e),null,{
default:ig((()=>[Yb(xm(E8e),{eventBus:e.eventBus,tag:e.tag
},null,8,["eventBus","tag"])])),_:1})])),_:1})])),_:1
},8,["loading"]),Yb(xm(H1e),{value:e.tag.xKeys},null,8,["value"])])),_:1
},8,["id"])):ny("",!0)}),C8e=$0e(Qg({__name:"ModernLayout",props:{tag:{},
moreThanOneTag:{type:Boolean},isLoading:{type:Boolean},isCollapsed:{type:Boolean
},eventBus:{}},setup(e){
const t=bm(),n=bm(),r=Hg(),o=Sy((()=>e.moreThanOneTag||"default"!==e.tag?.title||""!==e.tag?.description)),a=Sy((()=>(e.tag?.children?.length??0)>0))
;return(i,s)=>(Ub(),Hb(xm(y1e),{ref_key:"sectionContainerRef",ref:t,
"aria-labelledby":xm(r),class:"tag-section-container",role:"region"},{
default:ig((()=>[Yb(y8e,{id:e.tag.id},{default:ig((()=>[o.value?(Ub(),Hb(A8e,{
key:0,eventBus:e.eventBus,headerId:xm(r),isCollapsed:e.isCollapsed,
isLoading:e.isLoading,tag:e.tag
},null,8,["eventBus","headerId","isCollapsed","isLoading","tag"])):ny("",!0),e.isCollapsed&&e.moreThanOneTag&&a.value?(Ub(),
Hb(w8e,{key:1,id:e.tag.id,"aria-label":`Show all ${e.tag.title} endpoints`,
onClick:s[0]||(s[0]=()=>e.eventBus?.emit("toggle:nav-item",{id:e.tag.id,open:!0
}))},null,8,["id","aria-label"])):ny("",!0)])),_:1
},8,["id"]),e.isCollapsed&&e.moreThanOneTag?ny("",!0):(Ub(),Qb("div",{key:0,
ref_key:"contentsRef",ref:n,class:"contents"
},[kv(i.$slots,"default",{},void 0,!0)],512))])),_:3},8,["aria-labelledby"]))}
}),[["__scopeId","data-v-d207e09e"]]),$8e=Qg({__name:"Tag",props:{tag:{},
layout:{},moreThanOneTag:{type:Boolean},isLoading:{type:Boolean},isCollapsed:{
type:Boolean},eventBus:{}},setup:e=>(t,n)=>"classic"===e.layout?(Ub(),Hb(k8e,{
key:0,eventBus:e.eventBus,isCollapsed:e.isCollapsed,layout:e.layout,tag:e.tag},{
default:ig((()=>[kv(t.$slots,"default")])),_:3
},8,["eventBus","isCollapsed","layout","tag"])):(Ub(),Hb(C8e,{key:1,
eventBus:e.eventBus,isCollapsed:e.isCollapsed,isLoading:e.isLoading,
layout:e.layout,moreThanOneTag:e.moreThanOneTag,tag:e.tag},{
default:ig((()=>[kv(t.$slots,"default")])),_:3
},8,["eventBus","isCollapsed","isLoading","layout","moreThanOneTag","tag"]))
}),P8e=e=>Object.keys(e).sort().join(","),D8e={key:0},I8e=Qg({
__name:"OperationPath",props:{path:{},deprecated:{type:Boolean}},setup(e){
const t=e,n=e=>e.startsWith("{")&&e.endsWith("}"),r=Sy((()=>t.path.split(/({[^}]+})/)))
;return(t,o)=>(Ub(),Qb("span",{class:Ih(["operation-path",{
deprecated:e.deprecated}])},[(Ub(!0),Qb(Mb,null,wv(r.value,((e,t)=>(Ub(),Qb(Mb,{
key:t},[n(e)?(Ub(),Qb("em",D8e,Uh(e),1)):(Ub(),Qb(Mb,{key:1
},[ey(Uh(e),1)],64))],64)))),128))],2))}
}),M8e=$0e(I8e,[["__scopeId","data-v-ec6c8861"]]),N8e={key:3,class:"empty-state"
},R8e=$0e(Qg({__name:"ExampleResponse",props:{response:{},example:{}},setup(e){
const t=Sy((()=>n.value.length>2e4)),n=Sy((()=>LX(void 0!==e.example?VZe(e.example)?.value??"":e.response?.schema?hHe(qke(e.response.schema),{
emptyString:"string",mode:"read"}):"")))
;return(r,o)=>void 0===e.example||t.value?e.response?.schema&&!t.value?(Ub(),
Hb(xm(LG),{key:1,class:"bg-b-2 -outline-offset-2",lang:"json",
prettyPrintedContent:n.value
},null,8,["prettyPrintedContent"])):(void 0!==e.example||e.response?.schema)&&t.value?(Ub(),
Hb(xm(zoe),{key:2,
containerClass:"custom-scroll scalar-code-block border rounded-b flex flex-1 max-h-screen",
contentClass:"language-plaintext whitespace-pre font-code text-base",
lineHeight:20,text:n.value
},null,8,["text"])):(Ub(),Qb("div",N8e," No Body ")):(Ub(),Hb(xm(LG),{key:0,
class:"bg-b-2 -outline-offset-2",lang:"json",prettyPrintedContent:n.value
},null,8,["prettyPrintedContent"]))}
}),[["__scopeId","data-v-ab9ce344"]]),L8e=$0e(Qg({__name:"ExampleResponseTab",
setup:e=>(e,t)=>(Ub(),Hb(xm(Lk),{as:"template"},{
default:ig((({selected:t})=>[Gb("button",{class:Ih(["tab",{"tab-selected":t}]),
type:"button"},[Gb("span",null,[kv(e.$slots,"default",{},void 0,!0)])],2)])),_:3
}))}),[["__scopeId","data-v-c8207e48"]]),B8e=$0e(Qg({
__name:"ExampleResponseTabList",emits:["change"],setup(e,{emit:t}){
const n=t,r=e=>{n("change",e)};return(e,t)=>(Ub(),Hb(xm(t_),{
class:"scalar-card-header scalar-card-header-tabs"},{
actions:ig((()=>[kv(e.$slots,"actions",{},void 0,!0)])),
default:ig((()=>[Yb(xm(Nk),{onChange:r},{default:ig((()=>[Yb(xm(Rk),{
class:"tab-list custom-scroll"},{
default:ig((()=>[kv(e.$slots,"default",{},void 0,!0)])),_:3})])),_:3})])),_:3}))
}}),[["__scopeId","data-v-fec8fbbb"]]);function j8e(e){
const t=AX(e?.content),n=MH(t??{});return function(e){if(!e)return!1
;const t=Boolean(e.schema),n="example"in e&&null!==e.example,r=Boolean(e.examples)
;return t||n||r
}(t?.["application/json"]??t?.["application/xml"]??t?.["text/plain"]??t?.["text/html"]??t?.["*/*"]??t?.[n[0]??""])
}const U8e={key:1,class:"scalar-card-checkbox"},z8e=["aria-controls"],F8e={
key:0,class:"response-description"},Z8e=$0e(Qg({__name:"ExampleResponses",
props:{responses:{}},setup(e){
const t=Hg(),{copyToClipboard:n}=PG(),r=Sy((()=>Object.keys(e.responses??{}).sort())),o=Sy((()=>r.value.filter((t=>j8e(qke(e.responses?.[t])))))),a=bm(0)
;mg(o,(e=>{
0===e.length?(a.value=0,c.value=""):a.value>=e.length&&(a.value=e.length-1,
c.value="")}));const i=Sy((()=>{const t=km(o)[km(a)]??""
;return qke(e.responses?.[t])})),s=Sy((()=>{
const e=AX(i.value?.content),t=MH(e??{})
;return e?.["application/json"]??e?.["application/xml"]??e?.["text/plain"]??e?.["text/html"]??e?.["*/*"]??e?.[t[0]??""]??void 0
})),l=Sy((()=>!!s.value?.examples&&Object.keys(s.value?.examples??{}).length>1)),c=bm(Object.keys(s.value?.examples??{})[0]??""),u=Sy((()=>l.value&&c.value?s.value?.examples?.[c.value]:(()=>{
const e=km(s);if(!e)return;if(Array.isArray(e.examples))return e.examples[0]
;const t=Object.keys(e.examples??{})[0]??"",n=e.examples?.[t];return n
})())),d=e=>{a.value=e,c.value=""},p=bm(!1)
;return(e,r)=>o.value.length?(Ub(),Hb(xm(GS),{key:0,
"aria-label":"Example Responses",class:"response-card",role:"region"},{
default:ig((()=>[Yb(B8e,{onChange:d},{
actions:ig((()=>[s.value?.example?(Ub(),Qb("button",{key:0,class:"code-copy",
type:"button",onClick:r[0]||(r[0]=()=>xm(n)(s.value?.example))},[Yb(xm(Gne),{
icon:"Clipboard",width:"12px"
})])):ny("",!0),s.value?.schema?(Ub(),Qb("label",U8e,[r[4]||(r[4]=ey(" Show Schema ",-1)),sg(Gb("input",{
"onUpdate:modelValue":r[1]||(r[1]=e=>p.value=e),"aria-controls":xm(t),
class:"scalar-card-checkbox-input",type:"checkbox"
},null,8,z8e),[[EO,p.value]]),r[5]||(r[5]=Gb("span",{
class:"scalar-card-checkbox-checkmark"},null,-1))])):ny("",!0)])),
default:ig((()=>[(Ub(!0),Qb(Mb,null,wv(o.value,(e=>(Ub(),Hb(L8e,{key:e,
"aria-controls":xm(t)},{default:ig((()=>[Yb($1e,null,{
default:ig((()=>[...r[3]||(r[3]=[ey("Status:",-1)])])),_:1}),ey(" "+Uh(e),1)])),
_:2},1032,["aria-controls"])))),128))])),_:1}),Yb(xm(YS),{class:"grid flex-1"},{
default:ig((()=>[p.value&&s.value?.schema?(Ub(),Hb(xm(LG),{key:0,id:xm(t),
class:"-outline-offset-2",content:xm(VZe)(s.value?.schema),lang:"json"
},null,8,["id","content"])):(Ub(),Hb(R8e,{key:1,id:xm(t),example:u.value,
response:s.value},null,8,["id","example","response"]))])),_:1
}),i.value?.description||l.value?(Ub(),Hb(xm(KS),{key:0,
class:"response-card-footer"},{
default:ig((()=>[i.value?.description?(Ub(),Qb("div",F8e,[Yb(xm(mre),{
class:"markdown",value:i.value.description
},null,8,["value"])])):ny("",!0),l.value?(Ub(),Hb(xm(R0e),{key:1,
modelValue:c.value,"onUpdate:modelValue":r[2]||(r[2]=e=>c.value=e),
class:"response-example-selector",examples:s.value?.examples
},null,8,["modelValue","examples"])):ny("",!0)])),_:1})):ny("",!0)])),_:1
})):ny("",!0)}}),[["__scopeId","data-v-97958459"]]),Q8e=Qg({
__name:"ContentTypeSelect",props:Nv({content:{}},{modelValue:{required:!0},
modelModifiers:{}}),emits:["update:modelValue"],setup(e){
const t=Kv(e,"modelValue"),n=Sy((()=>Object.keys(e.content??{}))),r=Sy({
get:()=>o.value.find((e=>e.id===t.value)),set:e=>{e&&(t.value=e.id)}
}),o=Sy((()=>n.value.map((e=>({id:e,label:e}))))),a=jS({
base:"font-normal text-c-2 bg-b-2 py-0.75 flex cursor-pointer items-center gap-1 rounded-full text-xs",
variants:{dropdown:{true:"border hover:text-c-1 pl-2 pr-1.5",false:"px-2"}}})
;return(e,i)=>n.value.length>1?(Ub(),Hb(xm(hre),{key:0,modelValue:r.value,
"onUpdate:modelValue":i[1]||(i[1]=e=>r.value=e),options:o.value,
placement:"bottom-end",onClick:i[2]||(i[2]=BO((()=>{}),["stop"]))},{
default:ig((({open:e})=>[Yb(xm(WS),{class:Ih(["h-fit",xm(a)({dropdown:!0})]),
variant:"ghost",onClick:i[0]||(i[0]=BO((()=>{}),["stop"]))},{
default:ig((()=>[Yb($1e,null,{
default:ig((()=>[...i[3]||(i[3]=[ey("Selected Content Type:",-1)])])),_:1
}),Gb("span",null,Uh(t.value),1),Yb(xm(L_),{
class:Ih(["size-2.75 transition-transform duration-100",{"rotate-180":e}]),
weight:"bold"},null,8,["class"])])),_:2},1032,["class"])])),_:1
},8,["modelValue","options"])):(Ub(),Qb("div",{key:1,
class:Ih(["selected-content-type",xm(a)({dropdown:!1})]),tabindex:"0"
},[Gb("span",null,Uh(t.value),1)],2))}}),H8e=Qg({__name:"Header",props:{
header:{},name:{},breadcrumb:{},eventBus:{},orderSchemaPropertiesBy:{},
orderRequiredPropertiesFirst:{type:Boolean}},
setup:e=>(t,n)=>"schema"in e.header&&e.header.schema?(Ub(),Hb(Q4e,{key:0,
breadcrumb:e.breadcrumb?[...e.breadcrumb,"headers"]:void 0,
description:e.header.description,eventBus:e.eventBus,name:e.name,options:{
orderRequiredPropertiesFirst:e.orderRequiredPropertiesFirst,
orderSchemaPropertiesBy:e.orderSchemaPropertiesBy},
schema:xm(qke)(e.header.schema)
},null,8,["breadcrumb","description","eventBus","name","options","schema"])):ny("",!0)
}),V8e=$0e(Qg({__name:"Headers",props:{headers:{},breadcrumb:{},eventBus:{},
orderRequiredPropertiesFirst:{type:Boolean},orderSchemaPropertiesBy:{}},
setup:e=>(t,n)=>(Ub(),Hb(xm(qx),null,{default:ig((({open:t})=>[Gb("div",{
class:Ih(["headers-card headers-card--compact",[{"headers-card--open":t}]])
},[Gb("div",{class:Ih(["headers-properties",{"headers-properties-open":t}])
},[Yb(xm(Wx),{class:"headers-card-title headers-card-title--compact",style:{
top:"calc(var(--refs-viewport-offset)))"}},{default:ig((()=>[Yb(xm(Gne),{
class:Ih(["headers-card-title-icon",{"headers-card-title-icon--open":t}]),
icon:"Add",size:"sm"},null,8,["class"]),t?(Ub(),Qb(Mb,{key:0
},[ey(" Hide Headers ")],64)):(Ub(),Qb(Mb,{key:1
},[ey(" Show Headers ")],64))])),_:2},1024),Yb(xm(Xx),null,{
default:ig((()=>[(Ub(!0),Qb(Mb,null,wv(e.headers,((t,n)=>(Ub(),Hb(H8e,{key:n,
breadcrumb:e.breadcrumb?[...e.breadcrumb,"headers"]:void 0,eventBus:e.eventBus,
header:xm(qke)(t),name:n,
orderRequiredPropertiesFirst:e.orderRequiredPropertiesFirst,
orderSchemaPropertiesBy:e.orderSchemaPropertiesBy
},null,8,["breadcrumb","eventBus","header","name","orderRequiredPropertiesFirst","orderSchemaPropertiesBy"])))),128))])),
_:1})],2)],2)])),_:1}))}),[["__scopeId","data-v-6fb09984"]]),q8e={
class:"parameter-item group/parameter-item"},W8e={
class:"parameter-item-name min-w-0"},X8e={key:1,class:"flex-1"},G8e=$0e(Qg({
__name:"ParameterListItem",props:{parameter:{},name:{},breadcrumb:{},
eventBus:{},collapsableItems:{type:Boolean},options:{}},setup(e){
const t=Sy((()=>"schema"in e.parameter&&e.parameter.schema?qke(e.parameter.schema):null)),n=Sy((()=>"content"in e.parameter&&e.parameter.content?e.parameter.content:null)),r=bm(Object.keys(n.value||{})[0]??""),o=Sy((()=>"headers"in e.parameter&&e.parameter.headers?e.parameter.headers:null)),a=Sy((()=>{
const o=n.value?n.value?.[r.value]?.schema:t.value,a="deprecated"in e.parameter?e.parameter.deprecated:t.value?.deprecated,i="examples"in e.parameter?e.parameter.examples:{},s=t.value?.examples??[],l=[...Object.values({
...i,...n.value?.[r.value]?.examples}),...s];return{...qke(o),deprecated:a,
..."example"in e.parameter&&xH(e.parameter.example)&&{
example:e.parameter.example},examples:l}
})),i=Sy((()=>Boolean(e.collapsableItems&&(n.value||o.value||t.value))))
;return(t,s)=>(Ub(),Qb("li",q8e,[Yb(xm(qx),null,{
default:ig((({open:t})=>[i.value?(Ub(),Hb(xm(Wx),{key:0,
class:Ih(["parameter-item-trigger",{"parameter-item-trigger-open":t}])},{
default:ig((()=>[Gb("div",W8e,[Yb(xm(Q_),{
class:Ih(["parameter-item-icon size-3 transition-transform duration-100",{
"rotate-90":t}]),weight:"bold"},null,8,["class"]),Gb("div",null,[Yb(xm(Zoe),{
preset:"property",text:e.name
},null,8,["text"])])]),!t&&e.parameter.description?(Ub(),Hb(xm(vre),{key:0,
class:"parameter-item-description-summary min-w-0 flex-1",controlled:"",
value:e.parameter.description
},null,8,["value"])):(Ub(),Qb("div",X8e)),Gb("div",{class:Ih({
"w-0 overflow-hidden group-focus-within/parameter-item:w-auto group-hover/parameter-item:w-auto":!t
})},[i.value&&n.value?(Ub(),Hb(Q8e,{key:0,modelValue:r.value,
"onUpdate:modelValue":s[0]||(s[0]=e=>r.value=e),class:"",content:n.value
},null,8,["modelValue","content"])):ny("",!0)],2)])),_:2
},1032,["class"])):ny("",!0),Yb(xm(Xx),{
class:"parameter-item-container parameter-item-container-markdown",
static:!i.value},{
default:ig((()=>[i.value&&e.parameter.description?(Ub(),Hb(xm(mre),{key:0,
class:"parameter-item-description",value:e.parameter.description
},null,8,["value"])):ny("",!0),o.value?(Ub(),Hb(V8e,{key:1,
breadcrumb:e.breadcrumb,eventBus:e.eventBus,headers:o.value,
orderRequiredPropertiesFirst:e.options.orderRequiredPropertiesFirst,
orderSchemaPropertiesBy:e.options.orderSchemaPropertiesBy
},null,8,["breadcrumb","eventBus","headers","orderRequiredPropertiesFirst","orderSchemaPropertiesBy"])):ny("",!0),Yb(Q4e,{
is:"div",breadcrumb:e.breadcrumb,compact:"",
description:i.value?"":e.parameter.description,eventBus:e.eventBus,
hideWriteOnly:!0,name:i.value?"":e.name,noncollapsible:!0,options:{
hideWriteOnly:!0,
orderRequiredPropertiesFirst:e.options.orderRequiredPropertiesFirst,
orderSchemaPropertiesBy:e.options.orderSchemaPropertiesBy},
required:"required"in e.parameter&&e.parameter.required,schema:a.value
},null,8,["breadcrumb","description","eventBus","name","options","required","schema"])])),
_:1},8,["static"])])),_:1})]))}}),[["__scopeId","data-v-2b6dfab9"]]),Y8e={key:0,
class:"mt-6"},K8e=["id"],J8e=["aria-labelledby"],e6e=Qg({__name:"ParameterList",
props:{parameters:{},breadcrumb:{},eventBus:{},collapsableItems:{type:Boolean},
options:{}},setup(e){const t=Hg()
;return(n,r)=>e.parameters?.length?(Ub(),Qb("div",Y8e,[Gb("div",{id:xm(t),
class:"text-c-1 mt-3 mb-3 text-lg leading-[1.45] font-medium"
},[kv(n.$slots,"title")],8,K8e),Gb("ul",{"aria-labelledby":xm(t),
class:"mb-3 list-none p-0 text-sm"
},[(Ub(!0),Qb(Mb,null,wv(e.parameters,(t=>(Ub(),Hb(G8e,{key:t.name,
breadcrumb:e.breadcrumb,collapsableItems:e.collapsableItems,eventBus:e.eventBus,
name:t.name,options:e.options,parameter:t
},null,8,["breadcrumb","collapsableItems","eventBus","name","options","parameter"])))),128))],8,J8e)])):ny("",!0)
}}),t6e={key:0,"aria-label":"Request Body",class:"request-body",role:"group"
},n6e={class:"request-body-header"},r6e={class:"request-body-title"},o6e={key:0,
class:"request-body-required"},a6e={key:0,class:"request-body-description"
},i6e={key:0,class:"request-body-schema"},s6e={key:1,class:"request-body-schema"
},l6e=$0e(Qg({__name:"RequestBody",props:{breadcrumb:{},requestBody:{},
eventBus:{},options:{}},setup(e){
const t=Sy((()=>Object.keys(e.requestBody?.content??{}))),n=bm("application/json")
;e.requestBody?.content&&t.value[0]&&(n.value=t.value[0])
;const r=Sy((()=>qke(e.requestBody?.content?.[n.value]?.schema))),o=Sy((()=>{
if(!r.value||!D2e(r.value))return null
;const t=B2e(r.value,r.value.discriminator,{hideReadOnly:!0,
orderSchemaPropertiesBy:e.options.orderSchemaPropertiesBy,
orderRequiredPropertiesFirst:e.options.orderRequiredPropertiesFirst})
;if(t.length<=12)return null;const{properties:n,...o}=r.value;return n?{
visibleProperties:{...o,properties:L2e(t.slice(0,12),n)},collapsedProperties:{
...o,properties:L2e(t.slice(12),n)}}:null
})),a=Sy((()=>Object.keys(e.requestBody?.content??{}).length>0||e.requestBody?.description||e.requestBody?.required))
;return(t,i)=>e.requestBody&&a.value?(Ub(),
Qb("div",t6e,[Gb("div",n6e,[Gb("div",r6e,[kv(t.$slots,"title",{},void 0,!0),e.requestBody.required?(Ub(),
Qb("div",o6e," required ")):ny("",!0)]),Yb(Q8e,{modelValue:n.value,
"onUpdate:modelValue":i[0]||(i[0]=e=>n.value=e),content:e.requestBody.content
},null,8,["modelValue","content"]),e.requestBody.description?(Ub(),
Qb("div",a6e,[Yb(xm(mre),{value:e.requestBody.description
},null,8,["value"])])):ny("",!0)]),o.value?(Ub(),Qb("div",i6e,[Yb(xm(G4e),{
breadcrumb:e.breadcrumb,compact:"",eventBus:e.eventBus,name:"Request Body",
noncollapsible:"",options:{hideReadOnly:!0,
orderRequiredPropertiesFirst:e.options.orderRequiredPropertiesFirst,
orderSchemaPropertiesBy:e.options.orderSchemaPropertiesBy},
schema:o.value.visibleProperties
},null,8,["breadcrumb","eventBus","options","schema"]),Yb(xm(G4e),{
additionalProperties:"",breadcrumb:e.breadcrumb,compact:"",eventBus:e.eventBus,
name:"Request Body",options:{hideReadOnly:!0,
orderRequiredPropertiesFirst:e.options.orderRequiredPropertiesFirst,
orderSchemaPropertiesBy:e.options.orderSchemaPropertiesBy},
schema:o.value.collapsedProperties
},null,8,["breadcrumb","eventBus","options","schema"])])):r.value?(Ub(),
Qb("div",s6e,[Yb(xm(G4e),{breadcrumb:e.breadcrumb,compact:"",
eventBus:e.eventBus,hideReadOnly:!0,name:"Request Body",noncollapsible:"",
options:{hideReadOnly:!0,
orderRequiredPropertiesFirst:e.options.orderRequiredPropertiesFirst,
orderSchemaPropertiesBy:e.options.orderSchemaPropertiesBy},schema:r.value
},null,8,["breadcrumb","eventBus","options","schema"])])):ny("",!0)])):ny("",!0)
}}),[["__scopeId","data-v-e9972a68"]]),c6e=Qg({__name:"OperationParameters",
props:{breadcrumb:{},parameters:{default:()=>[]},requestBody:{},eventBus:{},
options:{}},setup(e){const t=Sy((()=>(e.parameters??[]).reduce(((e,t)=>{
const n=qke(t);var r
;return r=n,!0!==r?.["x-internal"]&&!0!==r?.["x-scalar-ignore"]&&e[n.in].push(n),
e}),{cookie:[],header:[],path:[],query:[]})))
;return(n,r)=>(Ub(),Qb(Mb,null,[Yb(e6e,{
breadcrumb:e.breadcrumb?[...e.breadcrumb,"path"]:void 0,eventBus:e.eventBus,
options:e.options,parameters:t.value.path},{
title:ig((()=>[...r[0]||(r[0]=[ey("Path Parameters",-1)])])),_:1
},8,["breadcrumb","eventBus","options","parameters"]),Yb(e6e,{
breadcrumb:e.breadcrumb?[...e.breadcrumb,"query"]:void 0,eventBus:e.eventBus,
options:e.options,parameters:t.value.query},{
title:ig((()=>[...r[1]||(r[1]=[ey("Query Parameters",-1)])])),_:1
},8,["breadcrumb","eventBus","options","parameters"]),Yb(e6e,{
breadcrumb:e.breadcrumb?[...e.breadcrumb,"headers"]:void 0,eventBus:e.eventBus,
options:e.options,parameters:t.value.header},{
title:ig((()=>[...r[2]||(r[2]=[ey("Headers",-1)])])),_:1
},8,["breadcrumb","eventBus","options","parameters"]),Yb(e6e,{
breadcrumb:e.breadcrumb?[...e.breadcrumb,"cookies"]:void 0,eventBus:e.eventBus,
options:e.options,parameters:t.value.cookie},{
title:ig((()=>[...r[3]||(r[3]=[ey("Cookies",-1)])])),_:1
},8,["breadcrumb","eventBus","options","parameters"]),e.requestBody?(Ub(),
Hb(l6e,{key:0,breadcrumb:e.breadcrumb?[...e.breadcrumb,"body"]:void 0,
eventBus:e.eventBus,options:e.options,requestBody:e.requestBody},{
title:ig((()=>[...r[4]||(r[4]=[ey("Body",-1)])])),_:1
},8,["breadcrumb","eventBus","options","requestBody"])):ny("",!0)],64))}}),u6e={
key:0,class:"mt-6"},d6e={"aria-label":"Responses",
class:"mb-3 list-none p-0 text-sm"},p6e=Qg({__name:"OperationResponses",props:{
responses:{},breadcrumb:{},collapsableItems:{type:Boolean},eventBus:{},
options:{}},
setup:e=>(t,n)=>Object.keys(e.responses??{}).length?(Ub(),Qb("div",u6e,[n[0]||(n[0]=Gb("div",{
class:"text-c-1 mt-3 mb-3 leading-[1.45] font-medium"
},"Responses",-1)),Gb("ul",d6e,[(Ub(!0),Qb(Mb,null,wv(e.responses,((t,n)=>(Ub(),
Hb(G8e,{key:n,breadcrumb:e.breadcrumb,collapsableItems:e.collapsableItems,
eventBus:e.eventBus,name:n,options:e.options,parameter:xm(qke)(t)
},null,8,["breadcrumb","collapsableItems","eventBus","name","options","parameter"])))),128))])])):ny("",!0)
}),h6e={class:"group callback-list-item"},f6e={
class:"font-code bg-b-1 callback-sticky-offset callback-list-item-title sticky flex cursor-pointer flex-row items-start gap-2 border-t py-3 text-sm group-open:flex-wrap"
},m6e={
class:"text-c-1 min-w-0 flex-1 truncate leading-3 group-open:whitespace-normal"
},g6e={class:"text-c-2"},v6e={
class:"callback-operation-container flex flex-col gap-2"},b6e=$0e(Qg({
__name:"Callback",props:{callback:{},method:{},name:{},url:{},eventBus:{},
options:{}},
setup:e=>(t,n)=>(Ub(),Qb("details",h6e,[Gb("summary",f6e,[Yb(xm(Q_),{
class:"callback-list-item-icon text-c-3 group-hover:text-c-1 absolute top-3.5 -left-5 size-4 transition-transform duration-100 group-open:rotate-90"
}),Yb(xm(S8e),{as:"span",class:"request-method py-0.75",method:e.method
},null,8,["method"]),Gb("div",m6e,[ey(Uh(e.name)+" ",1),Gb("span",g6e,Uh(e.url),1)])]),Gb("div",v6e,[Yb(c6e,{
eventBus:e.eventBus,options:e.options,
parameters:e.callback.parameters?.map((e=>xm(qke)(e)))??[],
requestBody:xm(qke)(e.callback.requestBody)
},null,8,["eventBus","options","parameters","requestBody"]),Yb(p6e,{
collapsableItems:!1,eventBus:e.eventBus,options:e.options,
responses:e.callback.responses},null,8,["eventBus","options","responses"])])]))
}),[["__scopeId","data-v-102d2096"]]),y6e={"aria-label":"Callbacks",
class:"callbacks-list gap-3",role:"group"},O6e=Qg({__name:"Callbacks",props:{
path:{},callbacks:{},eventBus:{},options:{}},setup(e){const t=Sy((()=>{
const t=[];return Tje(e.callbacks).forEach((([e,n])=>{
Tje(qke(n)).forEach((([n,r])=>{"object"==typeof r&&r&&Tje(r).forEach((([r,o])=>{
IH(r)&&t.push({name:e,url:n,method:r,callback:o})}))}))})),t}))
;return(n,r)=>(Ub(),Qb("div",y6e,[r[0]||(r[0]=Gb("div",{
class:"callbacks-title text-c-1 my-3 text-lg font-medium"
}," Callbacks ",-1)),(Ub(!0),
Qb(Mb,null,wv(t.value,(({callback:t,method:n,name:r,url:o})=>(Ub(),Hb(b6e,{
key:`${r}-${o}-${n}`,callback:t,eventBus:e.eventBus,method:n,name:r,
options:e.options,path:e.path,url:o
},null,8,["callback","eventBus","method","name","options","path","url"])))),128))]))
}}),w6e=["method"],x6e=$0e(Qg({__name:"TestRequestButton",props:{id:{},
method:{},path:{},eventBus:{}},setup(e){
const t=()=>e.eventBus.emit("ui:open:client-modal",{id:e.id})
;return(n,r)=>(Ub(),Qb("button",{class:"show-api-client-button",method:e.method,
type:"button",onClick:BO(t,["stop"])},[Yb(xm(rC),{class:"size-3",weight:"fill"
}),r[0]||(r[0]=Gb("span",null,"Test Request",-1)),Yb($1e,null,{
default:ig((()=>[ey("("+Uh(e.method)+" "+Uh(e.path)+")",1)])),_:1})],8,w6e))}
}),[["__scopeId","data-v-e851edeb"]]),k6e=Qg({__name:"XBadges",props:{
position:{},badges:{}},setup(e){
const t=Sy((()=>Array.isArray(e.badges)?e.badges.filter((t=>t.position===e.position||"after"===e.position&&!t.position)):[]))
;return(e,n)=>t.value.length?(Ub(!0),Qb(Mb,{key:0
},wv(t.value,(e=>(Ub(),Hb(xm(o1e),{key:e.name,color:e.color},{
default:ig((()=>[ey(Uh(e.name),1)])),_:2},1032,["color"])))),128)):ny("",!0)}
}),S6e={class:"operation-title"},_6e={class:"operation-details"},T6e={
class:"endpoint-label"},E6e={class:"endpoint-label-path"},A6e={
class:"endpoint-label-name"},C6e={key:1,class:"font-code text-sm"},$6e={
class:"endpoint-content"},P6e={class:"operation-details-card"},D6e={key:0,
class:"operation-details-card-item"},I6e={class:"operation-details-card-item"
},M6e={class:"operation-details-card-item"},N6e={key:1,
class:"operation-details-card-item"},R6e=$0e(Qg({__name:"ClassicLayout",props:{
id:{},method:{},options:{},path:{},clientOptions:{},isCollapsed:{type:Boolean},
isWebhook:{type:Boolean},selectedClient:{},eventBus:{},operation:{},
selectedServer:{},selectedSecuritySchemes:{}},setup(e){
const t=Sy((()=>e.operation.summary||e.path||"")),n=Sy((()=>U1e(e.operation))),{copyToClipboard:r}=PG()
;return(o,a)=>(Ub(),Hb(xm(h1e),{id:e.id,"aria-label":t.value,
class:"reference-endpoint",modelValue:!e.isCollapsed,transparent:"",
"onUpdate:modelValue":a[2]||(a[2]=t=>e.eventBus?.emit("toggle:nav-item",{
id:e.id,open:t}))},xv({title:ig((()=>[Gb("div",S6e,[Gb("div",_6e,[Yb(xm(S8e),{
class:"endpoint-type",method:e.method,short:""},null,8,["method"]),Yb(xm(I1e),{
class:"endpoint-anchor",
onCopyAnchorUrl:a[0]||(a[0]=()=>e.eventBus?.emit("copy-url:nav-item",{id:e.id}))
},{default:ig((()=>[Gb("h3",T6e,[Gb("div",E6e,[Yb(M8e,{
deprecated:xm(MX)(e.operation),path:e.path
},null,8,["deprecated","path"])]),Gb("div",A6e,Uh(t.value),1),xm(NX)(e.operation)?(Ub(),
Hb(xm(o1e),{key:0,class:Ih(["capitalize",xm(RX)(e.operation)])},{
default:ig((()=>[ey(Uh(xm(NX)(e.operation)),1)])),_:1
},8,["class"])):ny("",!0),e.isWebhook?(Ub(),Hb(xm(o1e),{key:1,
class:"font-code text-green flex w-fit items-center justify-center gap-1"},{
default:ig((()=>[Yb(xm(T$),{weight:"bold"}),a[3]||(a[3]=ey("Webhook ",-1))])),
_:1})):ny("",!0),Yb(xm(k6e),{badges:e.operation["x-badges"],position:"before"
},null,8,["badges"])])])),_:1})])])])),actions:ig((({active:t})=>[Yb(xm(k6e),{
badges:e.operation["x-badges"],position:"after"
},null,8,["badges"]),e.options.hideTestRequestButton?ny("",!0):(Ub(),Qb(Mb,{
key:0},[t&&!e.isWebhook?(Ub(),Hb(xm(x6e),{key:0,id:e.id,eventBus:e.eventBus,
method:e.method,path:e.path
},null,8,["id","eventBus","method","path"])):(Ub(),Hb(xm(rC),{key:1,
class:"endpoint-try-hint size-4.5"
}))],64)),e.options.showOperationId&&e.operation.operationId?(Ub(),
Qb("span",C6e,Uh(e.operation.operationId),1)):ny("",!0),Yb(xm(ure),{
class:"endpoint-copy p-0.5",icon:xm(dT),label:"Copy endpoint URL",size:"xs",
variant:"ghost",onClick:a[1]||(a[1]=BO((t=>xm(r)(e.path)),["stop"]))
},null,8,["icon"])])),
default:ig((()=>[Gb("div",$6e,[Gb("div",P6e,[Object.keys(n.value).length>0?(Ub(),
Qb("div",D6e,[Yb(H1e,{value:n.value
},null,8,["value"])])):ny("",!0),Gb("div",I6e,[Yb(c6e,{eventBus:e.eventBus,
options:e.options,parameters:e.operation.parameters,
requestBody:xm(qke)(e.operation.requestBody)
},null,8,["eventBus","options","parameters","requestBody"])]),Gb("div",M6e,[Yb(p6e,{
eventBus:e.eventBus,options:e.options,responses:e.operation.responses
},null,8,["eventBus","options","responses"])]),e.operation?.callbacks?(Ub(),
Qb("div",N6e,[Yb(O6e,{callbacks:e.operation.callbacks,eventBus:e.eventBus,
options:e.options,path:e.path
},null,8,["callbacks","eventBus","options","path"])])):ny("",!0)]),e.operation.responses?(Ub(),
Hb(xm(Z8e),{key:0,class:"operation-example-card",responses:e.operation.responses
},null,8,["responses"])):ny("",!0),Gb("div",null,[e.operation.externalDocs?(Ub(),
Hb(xm(X1e),{key:0},{default:ig((()=>[Yb(xm(e2e),{value:e.operation.externalDocs
},null,8,["value"])])),_:1})):ny("",!0),Yb(xm(v2),null,{
default:ig((()=>[Yb(xm(Q0e),{class:"operation-example-card",
clientOptions:e.clientOptions,eventBus:e.eventBus,fallback:"",
isWebhook:e.isWebhook,method:e.method,operation:e.operation,path:e.path,
securitySchemes:e.selectedSecuritySchemes,selectedClient:e.selectedClient,
selectedServer:e.selectedServer
},null,8,["clientOptions","eventBus","isWebhook","method","operation","path","securitySchemes","selectedClient","selectedServer"])])),
_:1})])])])),_:2},[e.operation.description?{name:"description",
fn:ig((()=>[Yb(xm(mre),{anchorPrefix:e.id,"aria-label":"Operation Description",
role:"group",transformType:"heading",value:e.operation.description,
withAnchors:"",withImages:""},null,8,["anchorPrefix","value"])])),key:"0"
}:void 0]),1032,["id","aria-label","modelValue"]))}
}),[["__scopeId","data-v-8a5966f4"]]),L6e={
class:"flex flex-row justify-between gap-1"},B6e={class:"flex gap-1"},j6e={
class:"flex gap-1"},U6e={class:"operation-details"},z6e={class:"examples"
},F6e=$0e(Qg({__name:"ModernLayout",props:{id:{},method:{},options:{},path:{},
clientOptions:{},isWebhook:{type:Boolean},selectedClient:{},eventBus:{},
operation:{},selectedServer:{},selectedSecuritySchemes:{}},setup(e){
const t=Sy((()=>e.operation.summary||e.path||"")),n=Hg(),r=Sy((()=>U1e(e.operation)))
;return(o,a)=>(Ub(),Hb(xm(l1e),{id:e.id,"aria-labelledby":xm(n),label:t.value,
tabindex:"-1",
onIntersecting:a[1]||(a[1]=()=>e.eventBus?.emit("intersecting:nav-item",{id:e.id
}))},{default:ig((()=>[Yb(xm(_1e),null,{
default:ig((()=>[Gb("div",L6e,[Gb("div",B6e,[e.options?.showOperationId&&e.operation.operationId?(Ub(),
Hb(xm(o1e),{key:0},{default:ig((()=>[ey(Uh(e.operation.operationId),1)])),_:1
})):ny("",!0),xm(NX)(e.operation)?(Ub(),Hb(xm(o1e),{key:1,
class:Ih(["capitalize",xm(RX)(e.operation)])},{
default:ig((()=>[ey(Uh(xm(NX)(e.operation)),1)])),_:1
},8,["class"])):ny("",!0),e.isWebhook?(Ub(),Hb(xm(o1e),{key:2,
class:"font-code text-green flex w-fit items-center justify-center gap-1"},{
default:ig((()=>[Yb(xm(T$),{weight:"bold"}),a[2]||(a[2]=ey("Webhook ",-1))])),
_:1})):ny("",!0),Yb(xm(k6e),{badges:e.operation["x-badges"],position:"before"
},null,8,["badges"])]),Gb("div",j6e,[Yb(xm(k6e),{badges:e.operation["x-badges"],
position:"after"},null,8,["badges"])])]),Gb("div",{
class:Ih(xm(MX)(e.operation)?"deprecated":"")},[Yb(xm(E1e),null,{
default:ig((()=>[Yb(xm(I1e),{
onCopyAnchorUrl:a[0]||(a[0]=()=>e.eventBus?.emit("copy-url:nav-item",{id:e.id}))
},{default:ig((()=>[Yb(xm(A1e),{id:xm(n),level:3},{
default:ig((()=>[ey(Uh(t.value),1)])),_:1},8,["id"])])),_:1})])),_:1
})],2),Yb(xm(v1e),null,{default:ig((()=>[Yb(xm(m1e),null,{
default:ig((()=>[Gb("div",U6e,[Yb(H1e,{value:r.value
},null,8,["value"]),Yb(xm(mre),{anchorPrefix:e.id,
"aria-label":"Operation Description",role:"group",transformType:"heading",
value:e.operation.description,withAnchors:"",withImages:""
},null,8,["anchorPrefix","value"]),Yb(c6e,{breadcrumb:[e.id],
eventBus:e.eventBus,options:e.options,parameters:e.operation.parameters,
requestBody:xm(qke)(e.operation.requestBody)
},null,8,["breadcrumb","eventBus","options","parameters","requestBody"]),Yb(p6e,{
breadcrumb:[e.id],collapsableItems:!e.options.expandAllResponses,
eventBus:e.eventBus,options:e.options,responses:e.operation.responses
},null,8,["breadcrumb","collapsableItems","eventBus","options","responses"]),Yb(xm(v2),null,{
default:ig((()=>[e.operation.callbacks?(Ub(),Hb(O6e,{key:0,
callbacks:e.operation.callbacks,class:"mt-6",eventBus:e.eventBus,
options:e.options,path:e.path
},null,8,["callbacks","eventBus","options","path"])):ny("",!0)])),_:1})])])),_:1
}),Yb(xm(m1e),null,{
default:ig((()=>[Gb("div",z6e,[e.operation.externalDocs?(Ub(),Hb(xm(X1e),{key:0
},{default:ig((()=>[Yb(xm(e2e),{value:e.operation.externalDocs
},null,8,["value"])])),_:1})):ny("",!0),Yb(xm(v2),null,{
default:ig((()=>[Yb(xm(Q0e),{clientOptions:e.clientOptions,eventBus:e.eventBus,
fallback:"",isWebhook:e.isWebhook,method:e.method,operation:e.operation,
path:e.path,securitySchemes:e.selectedSecuritySchemes,
selectedClient:e.selectedClient,selectedServer:e.selectedServer},xv({
header:ig((()=>[Yb(M8e,{
class:"font-code text-c-2 [&_em]:text-c-1 [&_em]:not-italic",
deprecated:e.operation?.deprecated,path:e.path
},null,8,["deprecated","path"])])),_:2},[e.isWebhook?void 0:{name:"footer",
fn:ig((()=>[e.options.hideTestRequestButton?ny("",!0):(Ub(),Hb(xm(x6e),{key:0,
id:e.id,eventBus:e.eventBus,method:e.method,path:e.path
},null,8,["id","eventBus","method","path"]))])),key:"0"
}]),1032,["clientOptions","eventBus","isWebhook","method","operation","path","securitySchemes","selectedClient","selectedServer"])])),
_:1}),Yb(xm(v2),null,{default:ig((()=>[e.operation.responses?(Ub(),Hb(xm(Z8e),{
key:0,responses:e.operation.responses,style:{"margin-top":"12px"}
},null,8,["responses"])):ny("",!0)])),_:1})])])),_:1})])),_:1})])),_:1})])),_:1
},8,["id","aria-labelledby","label"]))}
}),[["__scopeId","data-v-a158242e"]]),Z6e=Qg({__name:"Operation",props:{id:{},
method:{},options:{},document:{},path:{},pathValue:{},server:{},
securitySchemes:{},clientOptions:{},isCollapsed:{type:Boolean},isWebhook:{
type:Boolean},selectedClient:{},eventBus:{}},setup(e){const t=Sy((()=>{
const t=qke(e.pathValue?.[e.method]);if(!t)return null
;const n=jQe(e.pathValue?.parameters,t.parameters);return{...t,parameters:n}
})),n=Sy((()=>((...e)=>{
for(const t of e)if(t)if(Array.isArray(t))for(const e of t){const t=qke(e)
;if(t?.url)return t}else{const e=qke(t);if(e?.url)return e}return null
})(t.value?.servers??null,e.pathValue?.servers??null,e.server))),r=Sy((()=>((e,t,n={})=>{
const r=t?.security??e.security??[],o=vXe(e?.["x-scalar-selected-security"],t?.["x-scalar-selected-security"]),a=new Set(r.map((e=>P8e(e)))),i=o.selectedSchemes[o.selectedIndex]
;if(i&&a.has(P8e(i)))return jHe(n,[i])
;for(const s of o.selectedSchemes)if(a.has(P8e(s)))return jHe(n,[s])
;return t?.security?.length&&!e?.["x-scalar-set-operation-security"]?jHe(n,r.slice(0,1)):[]
})(e.document,t.value,e.securitySchemes)));return(o,a)=>t.value?(Ub(),Qb(Mb,{
key:0},["classic"===e.options.layout?(Ub(),Hb(R6e,{key:0,id:e.id,
clientOptions:e.clientOptions,eventBus:e.eventBus,isCollapsed:e.isCollapsed,
isWebhook:e.isWebhook,method:e.method,operation:t.value,options:e.options,
path:e.path,selectedClient:e.selectedClient,selectedSecuritySchemes:r.value,
selectedServer:n.value
},null,8,["id","clientOptions","eventBus","isCollapsed","isWebhook","method","operation","options","path","selectedClient","selectedSecuritySchemes","selectedServer"])):(Ub(),
Hb(F6e,{key:1,id:e.id,clientOptions:e.clientOptions,eventBus:e.eventBus,
isWebhook:e.isWebhook,method:e.method,operation:t.value,options:e.options,
path:e.path,selectedClient:e.selectedClient,selectedSecuritySchemes:r.value,
selectedServer:n.value
},null,8,["id","clientOptions","eventBus","isWebhook","method","operation","options","path","selectedClient","selectedSecuritySchemes","selectedServer"]))],64)):ny("",!0)
}}),Q6e=Qg({__name:"TraversedEntry",props:{level:{default:0},entries:{},
document:{},clientOptions:{},options:{},selectedServer:{},securitySchemes:{},
selectedClient:{},expandedItems:{},eventBus:{}},setup(e){
const t=e=>"tag"===e.type&&!0===e.isGroup,n=e=>"tag"===e.type&&!t(e)&&"models"!==e.id,r=e=>"operation"===e.type,o=e=>"webhook"===e.type,a=e=>"models"===e.type,i=e=>"model"===e.type
;function s(t){
return o(t)?e.document.webhooks?.[t.name]:e.document.paths?.[t.path]}
return(l,c)=>{const u=gv("TraversedEntry",!0)
;return Ub(!0),Qb(Mb,null,wv(e.entries,(l=>(Ub(),Hb(y8e,{id:l.id,
key:`${l.id}-${e.options.layout}`},{
default:ig((()=>[r(l)||o(l)?(Ub(),Hb(xm(y1e),{key:0,omit:0!==e.level},{
default:ig((()=>[Yb(xm(Z6e),{id:l.id,clientOptions:e.clientOptions,
document:e.document,eventBus:e.eventBus,isCollapsed:!e.expandedItems[l.id],
isWebhook:o(l),method:l.method,options:e.options,path:o(l)?l.name:l.path,
pathValue:s(l),securitySchemes:e.securitySchemes,
selectedClient:e.selectedClient,server:e.selectedServer
},null,8,["id","clientOptions","document","eventBus","isCollapsed","isWebhook","method","options","path","pathValue","securitySchemes","selectedClient","server"])])),
_:2},1032,["omit"])):n(l)?(Ub(),Hb(xm($8e),{key:1,eventBus:e.eventBus,
isCollapsed:!e.expandedItems[l.id],isLoading:!1,layout:e.options.layout,
moreThanOneTag:e.entries.filter(n).length>1,tag:l},{
default:ig((()=>["children"in l&&l.children?.length?(Ub(),Hb(u,{key:0,
clientOptions:e.clientOptions,document:e.document,entries:l.children,
eventBus:e.eventBus,expandedItems:e.expandedItems,level:e.level+1,
options:e.options,securitySchemes:e.securitySchemes,
selectedClient:e.selectedClient,selectedServer:e.selectedServer
},null,8,["clientOptions","document","entries","eventBus","expandedItems","level","options","securitySchemes","selectedClient","selectedServer"])):ny("",!0)])),
_:2
},1032,["eventBus","isCollapsed","layout","moreThanOneTag","tag"])):t(l)?(Ub(),
Hb(u,{key:2,clientOptions:e.clientOptions,document:e.document,
entries:l.children||[],eventBus:e.eventBus,expandedItems:e.expandedItems,
level:e.level+1,options:e.options,securitySchemes:e.securitySchemes,
selectedClient:e.selectedClient,selectedServer:e.selectedServer
},null,8,["clientOptions","document","entries","eventBus","expandedItems","level","options","securitySchemes","selectedClient","selectedServer"])):a(l)&&e.document.components?.schemas?(Ub(),
Hb(x8e,{key:3,id:l.id,eventBus:e.eventBus,isCollapsed:!e.expandedItems[l.id],
layout:e.options.layout},{default:ig((()=>[Yb(u,{clientOptions:e.clientOptions,
document:e.document,entries:l.children||[],eventBus:e.eventBus,
expandedItems:e.expandedItems,level:e.level+1,options:e.options,
securitySchemes:e.securitySchemes,selectedClient:e.selectedClient,
selectedServer:e.selectedServer
},null,8,["clientOptions","document","entries","eventBus","expandedItems","level","options","securitySchemes","selectedClient","selectedServer"])])),
_:2
},1032,["id","eventBus","isCollapsed","layout"])):i(l)&&e.document.components?.schemas?.[l.name]?(Ub(),
Hb(t8e,{key:4,id:l.id,eventBus:e.eventBus,isCollapsed:!e.expandedItems[l.id],
name:l.name,options:e.options,
schema:xm(qke)(e.document.components.schemas[l.name])
},null,8,["id","eventBus","isCollapsed","name","options","schema"])):ny("",!0)])),
_:2},1032,["id"])))),128)}}}),H6e={key:0,class:"plugin-view"},V6e=Qg({
__name:"RenderPlugins",props:{viewName:{},options:{}},setup(e){
const{getViewComponents:t}=Z1e(),n=t(e.viewName)
;return(t,r)=>xm(n).length?(Ub(),
Qb("div",H6e,[(Ub(!0),Qb(Mb,null,wv(xm(n),((t,n)=>(Ub(),Hb(xm(v2),{key:n},{
default:ig((()=>[t.renderer?(Ub(),Hb(bv(t.renderer),iy({key:0,ref_for:!0},{
component:t.component,options:e.options,...t.props
}),null,16)):(Ub(),Hb(bv(t.component),iy({key:1,ref_for:!0},{options:e.options,
...t.props}),null,16))])),_:2},1024)))),128))])):ny("",!0)}}),q6e={
class:"section-flare"};const W6e=$0e({},[["render",function(e,t){
return Ub(),Qb("div",q6e,[...t[0]||(t[0]=[ty('<div class="section-flare-item" data-v-2a9c8c02></div><div class="section-flare-item" data-v-2a9c8c02></div><div class="section-flare-item" data-v-2a9c8c02></div><div class="section-flare-item" data-v-2a9c8c02></div><div class="section-flare-item" data-v-2a9c8c02></div><div class="section-flare-item" data-v-2a9c8c02></div><div class="section-flare-item" data-v-2a9c8c02></div><div class="section-flare-item" data-v-2a9c8c02></div>',8)])])
}],["__scopeId","data-v-2a9c8c02"]]),X6e={class:"narrow-references-container"
},G6e={key:1,class:"h-dvh"},Y6e=Qg({__name:"Content",props:{infoSectionId:{},
options:{},document:{},xScalarDefaultClient:{},items:{},expandedItems:{},
eventBus:{},environment:{},headingSlugGenerator:{type:Function}},setup(e){
const t=Sy((()=>fXe(BQe(e.options.hiddenClients)))),n=Sy((()=>U1e(e.document))),r=Sy((()=>U1e(e.document?.info))),o=Sy((()=>zQe(e.options?.servers??e.document?.servers,{
baseServerUrl:e.options?.baseServerURL,
documentUrl:e.document?.["x-scalar-original-source-url"]
}))),a=Sy((()=>UQe(e.document??null,o.value))),i=Sy((()=>qZe(e.document?.components?.securitySchemes,e.options.authentication?.securitySchemes)))
;return(s,l)=>(Ub(),
Qb(Mb,null,[Yb(xm(W6e)),Gb("div",X6e,[kv(s.$slots,"start"),Yb(y8e,{
id:e.infoSectionId},{"empty-state":ig((()=>[kv(s.$slots,"empty-state")])),
default:ig((()=>[Yb(xm(y2e),{id:e.infoSectionId,
documentDownloadType:e.options.documentDownloadType,documentExtensions:n.value,
eventBus:e.eventBus,externalDocs:e.document?.externalDocs,
headingSlugGenerator:e.headingSlugGenerator,info:e.document?.info,
infoExtensions:r.value,layout:e.options.layout,
oasVersion:e.document?.["x-original-oas-version"]},{
selectors:ig((()=>[Yb(xm(v2),null,{
default:ig((()=>[o.value?.length?(Ub(),Hb(xm(w2e),{key:0,
class:"scalar-reference-intro-server scalar-client introduction-card-item text-base leading-normal [--scalar-address-bar-height:0px]"
},{default:ig((()=>[Yb(xm(E2e),{eventBus:e.eventBus,selectedServer:a.value,
servers:o.value},null,8,["eventBus","selectedServer","servers"])])),_:1
})):ny("",!0)])),_:1}),Yb(xm(v2),null,{
default:ig((()=>[e.document?(Ub(),Hb(xm(w2e),{key:0,
class:"scalar-reference-intro-auth scalar-client introduction-card-item leading-normal"
},{default:ig((()=>[Yb(xm(P2e),{document:e.document,environment:e.environment,
eventBus:e.eventBus,options:e.options,securitySchemes:i.value,
selectedServer:a.value
},null,8,["document","environment","eventBus","options","securitySchemes","selectedServer"])])),
_:1})):ny("",!0)])),_:1}),Yb(xm(v2),null,{default:ig((()=>[t.value.length?(Ub(),
Hb(xm(w2e),{key:0,class:"introduction-card-item scalar-reference-intro-clients"
},{default:ig((()=>[Yb(xm(r1e),{
class:"introduction-card-item scalar-reference-intro-clients",
clientOptions:t.value,eventBus:e.eventBus,selectedClient:e.xScalarDefaultClient,
xScalarSdkInstallation:e.document?.info?.["x-scalar-sdk-installation"]
},null,8,["clientOptions","eventBus","selectedClient","xScalarSdkInstallation"])])),
_:1})):ny("",!0)])),_:1})])),_:1
},8,["id","documentDownloadType","documentExtensions","eventBus","externalDocs","headingSlugGenerator","info","infoExtensions","layout","oasVersion"])])),
_:3},8,["id"]),e.items.length&&e.document?(Ub(),Hb(Q6e,{key:0,
clientOptions:t.value,document:e.document,entries:e.items,eventBus:e.eventBus,
expandedItems:e.expandedItems,options:e.options,securitySchemes:i.value,
selectedClient:e.xScalarDefaultClient,selectedServer:a.value
},null,8,["clientOptions","document","entries","eventBus","expandedItems","options","securitySchemes","selectedClient","selectedServer"])):ny("",!0),Yb(xm(V6e),{
options:e.options,viewName:"content.end"
},null,8,["options"]),kv(s.$slots,"end"),xm(c8e)?ny("",!0):(Ub(),
Qb("div",G6e))])],64))}}),K6e={
class:"flex h-[var(--scalar-header-height)] w-full items-center border-b bg-inherit px-2"
},J6e={key:1,class:"flex-1 text-sm font-medium whitespace-nowrap"},e3e={
class:"flex h-6 items-center gap-1 pl-1"},t3e=Qg({__name:"MobileHeader",props:{
breadcrumb:{},isSidebarOpen:{type:Boolean},showSidebar:{type:Boolean}},
emits:["toggleSidebar"],setup(e,{emit:t}){
const n=t,{mediaQueries:r}=K_e(),o=jS({
base:"items-center bg-b-1 sticky top-0 z-1000",variants:{open:{
true:"max-h-dvh h-dvh custom-scrollbar flex flex-col"},lg:{
true:"hidden [grid-area:header]"}}})
;return(t,a)=>xm(r).lg.value?kv(t.$slots,"sidebar",Mh(iy({key:0},{
sidebarClasses:"sticky top-0 h-dvh [grid-area:navigation]"}))):(Ub(),Qb("div",{
key:1,class:Ih(["t-doc__header",xm(o)({open:e.isSidebarOpen,lg:xm(r).lg.value
})])},[Gb("header",K6e,[e.showSidebar?(Ub(),Hb(xm(ure),{key:0,
icon:e.isSidebarOpen?xm(I$):xm(CA),
label:e.isSidebarOpen?"Close Menu":"Open Menu",size:"md",
onClick:a[0]||(a[0]=e=>n("toggleSidebar"))
},null,8,["icon","label"])):ny("",!0),e.showSidebar?(Ub(),
Qb("span",J6e,Uh(e.breadcrumb),1)):kv(t.$slots,"search",{key:2
}),Gb("div",e3e,[kv(t.$slots,"actions")])]),e.isSidebarOpen?kv(t.$slots,"sidebar",Mh(iy({
key:0},{
sidebarClasses:"overflow-y-auto custom-scrollbar min-h-0 flex-1 w-full border-none"
}))):ny("",!0)],2))}}),n3e={key:0,class:"document-selector -mb-1 p-3 pb-0"
},r3e={
class:"group/dropdown-label hover:bg-b-2 text-c-2 flex h-8 w-full cursor-pointer items-center rounded border px-2 py-1.75",
type:"button"},o3e={class:"text-c-1 overflow-hidden text-base text-ellipsis"
},a3e=Qg({__name:"DocumentSelector",props:{options:{},modelValue:{}},
emits:["update:modelValue"],setup(e,{emit:t}){
const n=e,r=t,o=Sy((()=>n.options.map((e=>({id:e.id,label:e.label
}))))),a=Sy((()=>o.value.find((e=>e.id===n.modelValue))))
;return(t,n)=>e.options.length>1?(Ub(),Qb("div",n3e,[Yb(xm(hre),{
modelValue:a.value,options:o.value,resize:"",
"onUpdate:modelValue":n[0]||(n[0]=e=>r("update:modelValue",e.id))},{
default:ig((()=>[Gb("button",r3e,[Yb(xm(Y_),{class:"mr-1 size-4 text-current"
}),Gb("span",o3e,Uh(a.value?.label||"Select API"),1)])])),_:1
},8,["modelValue","options"])])):ny("",!0)}})
;const i3e=e=>"object"==typeof e&&null!==e&&!("$ref"in e&&"string"==typeof e.$ref)
;function s3e(e){const t=["Body"],n=qke(e?.schema),r=n?.properties
;return r&&Object.keys(r).forEach((o=>{if(!e.schema)return;t.push(function(e,t){
let n=e;const r=t.required?.includes(e);n+=r?" REQUIRED ":" optional "
;const o=qke(t.properties?.[e])
;return o&&(n+=o.type,o.description&&(n+=" "+o.description)),n}(o,n))
;const a=qke(r[o])
;"object"===a.type&&Boolean(a.properties)&&a.properties&&Object.keys(a.properties).forEach((e=>{
t.push(`${e} ${qke(a.properties?.[e])?.type}`)}))})),t}function l3e(e){
const t=[];return function n(r){r.forEach((r=>{!function(e,t,n){
if("operation"===e.type){
const r=qke(n?.paths?.[e.path]?.[e.method])??{},o=function(e){try{
const t=qke(e?.requestBody)?.content?.["application/json"]
;if(!t)throw new Error("Body not found");return s3e(t)}catch(t){return!1}
}(r)||function(e){const t={path:[],query:[],header:[],cookie:[],body:[],
formData:[]},n=e.parameters??[];return n&&n.forEach((e=>{
i3e(e)&&("object"==typeof e&&null!==e&&"$ref"in e||("path"===e.in?t.path.push(e):"query"===e.in?t.query.push(e):"header"===e.in?t.header.push(e):"cookie"===e.in?t.cookie.push(e):"body"===e.in?t.body.push(e):"formData"===e.in&&t.formData.push(e)))
})),t}(r),a="boolean"!=typeof o?o:null;return void t.push({type:"operation",
title:e.title,id:e.id,description:r.description||"",method:e.method,path:e.path,
body:a||"",operationId:r.operationId,entry:e})}if("webhook"===e.type){
const r=qke(n?.webhooks?.[e.name]?.[e.method])??{};return void t.push({id:e.id,
type:"webhook",title:e.title,description:"Webhook",method:e.method,
body:r.description||"",operationId:r.operationId,entry:e})}if("model"===e.type){
const r=qke(n?.components?.schemas?.[e.name]),o=r?.description??""
;return void t.push({type:"model",title:e.title,description:"Model",id:e.id,
body:o,entry:e})}if("models"===e.type)return void t.push({id:e.id,
type:"heading",title:"Models",description:"Heading",body:"",entry:e})
;if("tag"===e.type&&!0===e.isWebhooks)return void t.push({id:e.id,
type:"heading",title:"Webhooks",description:"Heading",body:"",entry:e})
;if("tag"===e.type&&!1===e.isGroup)return void t.push({id:e.id,title:e.title,
description:e.description||"",type:"tag",body:"",entry:e})
;if("tag"===e.type&&!0===e.isGroup)return void t.push({id:e.id,title:e.title,
description:"Tag Group",type:"tag",body:"",entry:e});if("text"===e.type)t.push({
id:e.id,type:"heading",title:e.title??"",description:"Heading",body:"",entry:e})
}(r,t,e),"children"in r&&r.children&&n(r.children)}))
}(e?.["x-scalar-navigation"]?.children??[]),t}function c3e(e){const t=Sy((()=>{
const t=new Qxe([],{keys:[{name:"title",weight:.7},{name:"description",weight:.3
},{name:"body",weight:.2},{name:"operationId",weight:.6},{name:"path",weight:.5
},{name:"tag",weight:.4},{name:"method",weight:.3}],threshold:.3,distance:100,
includeScore:!0,includeMatches:!0,ignoreLocation:!0,useExtendedSearch:!0,
findAllMatches:!0});return t.setCollection(l3e(km(e))),t})),n=bm("");return{
results:Sy((()=>{if(0!==n.value.length)return t.value.search(n.value,{limit:25})
;return t.value._docs.slice(0,25).map(((e,t)=>({item:e,refIndex:t})))})),query:n
}}const u3e={class:"sr-only"},d3e={class:"inline-flex items-center gap-1"},p3e={
class:"sr-only"},h3e=Qg({__name:"SearchResult",props:{id:{},isSelected:{
type:Boolean},result:{}},setup(e){const t={heading:HC,model:$_,operation:BC,
tag:PC,webhook:BC},n={heading:"Heading",operation:"Operation",tag:"Tag",
model:"Model",webhook:"Webhook"};return(r,o)=>(Ub(),Hb(xm(Vre),{id:e.id,
icon:t[e.result.item.type],selected:e.isSelected},xv({
default:ig((()=>[Gb("span",{class:Ih({
"text-decoration-line":"operation"===e.result.item.entry.type&&e.result.item.entry.isDeprecated
})
},[Gb("span",u3e,[ey(Uh(n[e.result.item.type])+":  ",1),"operation"===e.result.item.entry.type&&e.result.item.entry.isDeprecated?(Ub(),
Qb(Mb,{key:0
},[ey(" (Deprecated)  ")],64)):ny("",!0)]),ey(" "+Uh(e.result.item.title)+" ",1),o[0]||(o[0]=Gb("span",{
class:"sr-only"},",",-1))],2)])),_:2
},["webhook"!==e.result.item.type&&(e.result.item.method||e.result.item.path)&&e.result.item.path!==e.result.item.title?{
name:"description",
fn:ig((()=>[Gb("span",d3e,["operation"===e.result.item.type?(Ub(),Qb(Mb,{key:0
},[Yb(xm(iDe),{"aria-hidden":"true",method:e.result.item.method??"get"
},null,8,["method"]),Gb("span",p3e," HTTP Method: "+Uh(e.result.item.method??"get"),1)],64)):ny("",!0),o[1]||(o[1]=Gb("span",{
class:"sr-only"},"Path: ",-1)),ey(" "+Uh(e.result.item.path),1)])])),key:"0"
}:e.result.item.description?{name:"description",
fn:ig((()=>[o[2]||(o[2]=Gb("span",{class:"sr-only"
},"Description: ",-1)),ey(" "+Uh(e.result.item.description),1)])),key:"1"
}:void 0]),1032,["id","icon","selected"]))}}),f3e={class:"mb-0 flex flex-col",
role:"search"},m3e=$0e(Qg({__name:"SearchModal",props:{modalState:{},
document:{},eventBus:{}},setup(e){
const t=e,n=BX(),r=`${n}-search-result`,o=`${n}-search-instructions`,{query:a,results:i}=c3e((()=>t.document)),s=bm(void 0)
;mg((()=>t.modalState.open),(e=>{e&&(a.value="")}));const l=e=>{
const t="up"===e?-1:1,n=i.value.length
;"number"==typeof s.value?s.value=(s.value+t+n)%n:s.value=-1===t?n-1:0}
;function c(e){if("number"!=typeof e||!i.value[e])return;const n=i.value[e]
;t.modalState.hide(),t.eventBus.emit("scroll-to:nav-item",{id:n.item.id})}
const u=Sy((()=>{const e=i.value[s.value??-1]
;return e?`search-result-${e.item.id}`:void 0}));return(t,n)=>(Ub(),Hb(xm(eae),{
"aria-label":"Reference Search",state:e.modalState,variant:"search"},{
default:ig((()=>[Gb("div",f3e,[Yb(xm(Bre),{modelValue:xm(a),
"onUpdate:modelValue":n[0]||(n[0]=e=>vm(a)?a.value=e:null),
"aria-activedescendant":u.value,"aria-autocomplete":"list","aria-controls":r,
"aria-describedby":o,role:"combobox",onBlur:n[1]||(n[1]=e=>s.value=void 0),
onKeydown:[n[2]||(n[2]=UO(BO((e=>l("down")),["stop","prevent"]),["down"])),n[3]||(n[3]=UO(BO((()=>c(s.value)),["stop","prevent"]),["enter"])),n[4]||(n[4]=UO(BO((e=>l("up")),["stop","prevent"]),["up"]))]
},null,8,["modelValue","aria-activedescendant"])]),Yb(xm(qre),{id:r,
"aria-label":"Reference Search Results",class:"custom-scroll p-1 pt-0",
noResults:!xm(i).length},{query:ig((()=>[ey(Uh(xm(a)),1)])),
default:ig((()=>[(Ub(!0),Qb(Mb,null,wv(xm(i),((e,t)=>(Ub(),Hb(h3e,{
id:`search-result-${e.item.id}`,key:e.refIndex,isSelected:s.value===t,result:e,
onClick:BO((()=>c(t)),["prevent"])
},null,8,["id","isSelected","result","onClick"])))),128))])),_:1
},8,["noResults"]),Gb("div",{id:o,class:"ref-search-meta"
},[...n[5]||(n[5]=[Gb("span",{"aria-hidden":"true",class:"contents"
},[Gb("span",null,"↑↓ Navigate"),Gb("span",null,"⏎ Select")],-1),Gb("span",{
class:"sr-only"
}," Press up arrow / down arrow to navigate, enter to select, type to filter results ",-1)])])])),
_:1},8,["state"]))}}),[["__scopeId","data-v-c1c368f9"]]),g3e=Qg({
__name:"SearchButton",props:{forceIcon:{type:Boolean},searchHotKey:{default:"k"
},hideModels:{type:Boolean,default:!1},document:{},eventBus:{}},setup(e){
const t=bm(),n=Koe(),r=t=>{
(C2()?t.metaKey:t.ctrlKey)&&t.key===e.searchHotKey&&(t.preventDefault(),
t.stopPropagation(),n.open?n.hide():n.show())};function o(){n.show()}
return mg((()=>n.open),(async(e,n)=>{!e&&n&&(await Xm(),t.value?.$el.focus())
})),
iv((()=>window.addEventListener("keydown",r))),cv((()=>window.removeEventListener("keydown",r))),
(r,a)=>(Ub(),Qb(Mb,null,[e.forceIcon?(Ub(),Hb(xm(ure),{key:0,icon:xm(ZA),
label:"Search",onClick:o},null,8,["icon"])):(Ub(),Hb(xm(boe),{key:1,
ref_key:"button",ref:t,class:Ih(["w-full",r.$attrs.class]),onClick:o},{
shortcut:ig((()=>[xm(C2)()?(Ub(),Qb(Mb,{key:0},[a[0]||(a[0]=Gb("span",{
class:"sr-only"},"Command",-1)),a[1]||(a[1]=Gb("span",{"aria-hidden":"true"
},"⌘",-1))],64)):(Ub(),Qb(Mb,{key:1},[a[2]||(a[2]=Gb("span",{class:"sr-only"
},"CTRL",-1)),a[3]||(a[3]=Gb("span",{"aria-hidden":"true"
},"⌃",-1))],64)),ey(" "+Uh(e.searchHotKey),1)])),
default:ig((()=>[a[4]||(a[4]=Gb("span",{class:"sr-only"
},"Open Search",-1)),a[5]||(a[5]=Gb("span",{"aria-hidden":"true",
class:"sidebar-search-placeholder"}," Search ",-1))])),_:1
},8,["class"])),Yb(m3e,{document:e.document,eventBus:e.eventBus,
hideModels:e.hideModels,modalState:xm(n)
},null,8,["document","eventBus","hideModels","modalState"])],64))}}),v3e=Qg({
__name:"ApiReferenceToolbarConfigLayout",props:{modelValue:{},modelModifiers:{}
},emits:["update:modelValue"],setup(e){const t={label:"Modern",value:"modern"
},n={label:"Classic",value:"classic"},r=[t,n],o=Kv(e,"modelValue"),a=Sy({
get:()=>"modern"===o.value?t:n,set:e=>o.value=e.value})
;return(e,t)=>(Ub(),Hb(xm(z$),{modelValue:a.value,
"onUpdate:modelValue":t[0]||(t[0]=e=>a.value=e),options:r
},null,8,["modelValue"]))}}),b3e=Qg({
__name:"ApiReferenceToolbarConfigLayoutOptions",props:Nv({configuration:{}},{
modelValue:{default:{}},modelModifiers:{}}),emits:["update:modelValue"],
setup(e){const t=Kv(e,"modelValue");function n(n,r=!1){
return t.value[n]??e.configuration?.[n]??r}function r(e,n,r=!1){t.value=n!==r?{
...t.value,[e]:n
}:Object.fromEntries(Object.entries(t.value).filter((([t])=>e!==t)))}
return(e,t)=>(Ub(),Hb(xm(U$),null,{default:ig((()=>[Yb(xm(joe),{
modelValue:n("showSidebar",!0),
"onUpdate:modelValue":t[0]||(t[0]=e=>r("showSidebar",!!e,!0))},{
default:ig((()=>[...t[9]||(t[9]=[ey(" Show Sidebar ",-1)])])),_:1
},8,["modelValue"]),Yb(xm(joe),{modelValue:n("defaultOpenAllTags"),
"onUpdate:modelValue":t[1]||(t[1]=e=>r("defaultOpenAllTags",!!e))},{
default:ig((()=>[...t[10]||(t[10]=[ey(" Default Open All Tags ",-1)])])),_:1
},8,["modelValue"]),Yb(xm(joe),{modelValue:n("expandAllModelSections"),
"onUpdate:modelValue":t[2]||(t[2]=e=>r("expandAllModelSections",!!e))},{
default:ig((()=>[...t[11]||(t[11]=[ey(" Expand All Model Sections ",-1)])])),_:1
},8,["modelValue"]),Yb(xm(joe),{modelValue:n("expandAllResponses"),
"onUpdate:modelValue":t[3]||(t[3]=e=>r("expandAllResponses",!!e))},{
default:ig((()=>[...t[12]||(t[12]=[ey(" Expand All Responses ",-1)])])),_:1
},8,["modelValue"]),Yb(xm(joe),{modelValue:n("hideClientButton"),
"onUpdate:modelValue":t[4]||(t[4]=e=>r("hideClientButton",!!e))},{
default:ig((()=>[...t[13]||(t[13]=[ey(" Hide Client Button ",-1)])])),_:1
},8,["modelValue"]),Yb(xm(joe),{modelValue:n("hideDarkModeToggle"),
"onUpdate:modelValue":t[5]||(t[5]=e=>r("hideDarkModeToggle",!!e))},{
default:ig((()=>[...t[14]||(t[14]=[ey(" Hide Dark Mode Toggle ",-1)])])),_:1
},8,["modelValue"]),Yb(xm(joe),{modelValue:n("hideModels"),
"onUpdate:modelValue":t[6]||(t[6]=e=>r("hideModels",!!e))},{
default:ig((()=>[...t[15]||(t[15]=[ey(" Hide Models ",-1)])])),_:1
},8,["modelValue"]),Yb(xm(joe),{modelValue:n("hideSearch"),
"onUpdate:modelValue":t[7]||(t[7]=e=>r("hideSearch",!!e))},{
default:ig((()=>[...t[16]||(t[16]=[ey(" Hide Search ",-1)])])),_:1
},8,["modelValue"]),Yb(xm(joe),{modelValue:n("hideTestRequestButton"),
"onUpdate:modelValue":t[8]||(t[8]=e=>r("hideTestRequestButton",!!e))},{
default:ig((()=>[...t[17]||(t[17]=[ey(" Hide Test Request Button ",-1)])])),_:1
},8,["modelValue"])])),_:1}))}}),y3e={class:"min-w-0 flex-1 truncate text-left"
},O3e={class:"text-c-1 inline-block min-w-0 flex-1 truncate"},w3e=Qg({
__name:"ApiReferenceToolbarConfigTheme",props:{modelValue:{},modelModifiers:{}},
emits:["update:modelValue"],setup(e){
const t=Kv(e,"modelValue"),n=Sy((()=>M_e.filter((e=>"none"!==e)).map((e=>({id:e,
label:N_e[e],css:R_e[e].theme}))))),r=Sy({get:()=>{const e=t.value??"default"
;return n.value.find((t=>t.id===e))??n.value[0]},set:e=>t.value=e.id})
;return(e,t)=>(Ub(),Hb(xm(HK),{modelValue:r.value,
"onUpdate:modelValue":t[0]||(t[0]=e=>r.value=e),options:n.value,resize:""},{
default:ig((({open:e})=>[Yb(xm(R$),null,{
default:ig((()=>[Gb("div",y3e,Uh(r.value.label),1),Yb(xm(Moe),{class:"mr-2",
css:r.value.css},null,8,["css"]),Yb(xm(L_),{
class:Ih(["size-3.5 transition-transform",{"rotate-180":e}])
},null,8,["class"])])),_:2},1024)])),
option:ig((({selected:e,option:t})=>[Yb(xm(KG),{selected:e
},null,8,["selected"]),Gb("span",O3e,Uh(t.label),1),Yb(xm(Moe),{css:t.css
},null,8,["css"])])),_:1},8,["modelValue","options"]))}}),x3e={
class:"text-c-2 hover:text-c-1 hover:bg-b-2 flex items-center gap-1 rounded px-2 py-2.25 text-base leading-none",
type:"button"},k3e={
class:"custom-scroll bg-b-1 flex flex-col gap-7 rounded-lg p-7 pb-6"},S3e={
class:"text-c-2 flex items-center justify-center gap-1 p-2 text-sm"},_3e=Qg({
__name:"ApiReferenceToolbarPopover",setup:e=>(e,t)=>(Ub(),Hb(xm(Rre),{
class:"max-h-[inherit] max-w-[inherit] p-0 text-base",placement:"bottom-end",
teleport:""},{default:ig((({open:t})=>[kv(e.$slots,"button",{open:t
},(()=>[Gb("button",x3e,[kv(e.$slots,"label"),Yb(xm(L_),{
class:Ih(["transition-transform",{"rotate-180":t}])},null,8,["class"])])]))])),
popover:ig((n=>[Gb("div",k3e,[kv(e.$slots,"default",Mh(Kb(n)))]),Gb("div",S3e,[Yb(xm(mA),{
class:"size-3.5 shrink-0"
}),Gb("div",null,[kv(e.$slots,"info",{},(()=>[t[0]||(t[0]=ey(' "',-1)),kv(e.$slots,"label"),t[1]||(t[1]=ey('" will only appear when running on localhost. ',-1))]))])])])),
backdrop:ig((()=>[Yb(xm(ZK),{class:"bg-b-2 rounded-lg"})])),_:3}))}),T3e={
class:"flex flex-col gap-4"},E3e=Qg({__name:"ApiReferenceToolbarConfig",
props:Nv({configuration:{}},{overrides:{},overridesModifiers:{}}),
emits:["update:overrides"],setup(e){const t=Kv(e,"overrides"),n=Sy((()=>LX({
...t.value,...e.configuration,...t.value}))),r=Sy({
get:()=>t.value?.theme??e.configuration?.theme??"default",set:e=>t.value={
...t.value,theme:e}}),o=Sy({
get:()=>t.value?.layout??e.configuration?.layout??"modern",set:e=>t.value={
...t.value,layout:e}});return(a,i)=>(Ub(),Hb(_3e,{class:"w-120"},{
label:ig((()=>[...i[3]||(i[3]=[ey("Configure",-1)])])),
default:ig((()=>[Yb(xm(Xoe),null,{
label:ig((()=>[...i[4]||(i[4]=[ey("Scalar Configuration",-1)])])),
default:ig((()=>[Yb(xm(LG),{class:"bg-b-1.5 max-h-40 rounded border text-sm",
content:n.value,lang:"json"},null,8,["content"])])),_:1
}),Gb("div",T3e,[Yb(xm(E2),null,{
label:ig((()=>[...i[5]||(i[5]=[ey("Theme",-1)])])),default:ig((()=>[Yb(w3e,{
modelValue:r.value,"onUpdate:modelValue":i[0]||(i[0]=e=>r.value=e)
},null,8,["modelValue"])])),_:1}),Yb(xm(E2),null,{
label:ig((()=>[...i[6]||(i[6]=[ey("Layout",-1)])])),default:ig((()=>[Yb(v3e,{
modelValue:o.value,"onUpdate:modelValue":i[1]||(i[1]=e=>o.value=e)
},null,8,["modelValue"])])),_:1}),Yb(xm(E2),{is:"div"},{
label:ig((()=>[...i[7]||(i[7]=[ey("Layout Options",-1)])])),
default:ig((()=>[Yb(b3e,{modelValue:t.value,
"onUpdate:modelValue":i[2]||(i[2]=e=>t.value=e),configuration:e.configuration
},null,8,["modelValue","configuration"])])),_:1})])])),_:1}))}}),A3e={
class:"text-c-3 [&_code]:font-code [&_a:hover]:text-c-1 text-center leading-normal [&_a]:underline"
};const C3e=$0e({},[["render",function(e,t){
return Ub(),Qb("p",A3e,[kv(e.$slots,"default")])}]]);async function $3e(e){
const t=JSON.stringify({document:e
}),n=await fetch(VH("https://proxy.scalar.com","https://api.scalar.com/core/share/upload/apis"),{
method:"POST",headers:{"Content-Type":"application/json"},body:t})
;if(!n.ok)throw new Error(` Failed to generate temporary link, server responded with ${n.status}`)
;const r=await n.json();if(!function(e){
return!!e&&"object"==typeof e&&"url"in e&&"string"==typeof e.url
}(r))throw new Error("Failed to generate temporary link, invalid response from server")
;return r.url}const P3e=Qg({__name:"ApiReferenceToolbarRegisterButton",
props:Nv({workspace:{},sdks:{default:()=>[]}},{url:{},urlModifiers:{}}),
emits:["update:url"],setup(e){const t=Kv(e,"url"),{toast:n}=CG(),r=Goe()
;function o(t){const n=new URL("https://dashboard.scalar.com/register")
;n.searchParams.set("url",t),
e.sdks.forEach((e=>n.searchParams.append("sdk",e))),
window.open(n.toString(),"_blank")}async function a(){
if(r.isLoading||!e.workspace)return;if(t.value)return void o(t.value);r.start()
;const a=e.workspace.exportActiveDocument("json")
;if(!a)return n("Unable to export active document","error"),
void(await r.invalidate());try{
t.value=await $3e(a),await r.validate(),o(t.value),await Xm(),await r.clear()
}catch(i){const e=i instanceof Error?i.message:"An unknown error occurred"
;n(e,"error"),await r.invalidate()}}return(e,t)=>(Ub(),Hb(xm(WS),{
class:"h-auto p-2.5",loader:xm(r),onClick:a},{
default:ig((()=>[kv(e.$slots,"default",{},(()=>[t[0]||(t[0]=ey("Generate",-1))]))])),
_:3},8,["loader"]))}}),D3e={class:"inline-flex items-center gap-2"},I3e=Qg({
__name:"ApiReferenceToolbarSdks",props:{workspace:{}},setup(e){const t=[{
key:"typescript",label:"Typescript",icon:"programming-language-typescript"},{
key:"python",label:"Python",icon:"programming-language-python"},{key:"csharp",
label:"C#",icon:"programming-language-csharp"},{key:"java",label:"Java",
icon:"programming-language-java"},{key:"ruby",label:"Ruby",
icon:"programming-language-ruby"},{key:"php",label:"PHP",
icon:"programming-language-php"},{key:"go",label:"Go",
icon:"programming-language-go"}],n=bm([]);return(r,o)=>(Ub(),Hb(_3e,{
class:"w-110"},{label:ig((()=>[...o[0]||(o[0]=[ey("Generate SDKs",-1)])])),
default:ig((()=>[Yb(xm(Xoe),null,{
label:ig((()=>[...o[1]||(o[1]=[ey("Select Languages",-1)])])),
default:ig((()=>[Yb(xm(U$),null,{
default:ig((()=>[(Ub(),Qb(Mb,null,wv(t,(({key:e,label:t,icon:r})=>Yb(xm(joe),{
key:e,modelValue:n.value.includes(e),
"onUpdate:modelValue":t=>n.value=t?[...n.value,e]:n.value.filter((t=>t!==e))},{
default:ig((()=>[Gb("span",D3e,[Yb(xm(Gne),{icon:r,class:"text-c-2 size-3.5"
},null,8,["icon"]),ey(" "+Uh(t),1)])])),_:2
},1032,["modelValue","onUpdate:modelValue"]))),64))])),_:1}),Yb(P3e,{
sdks:n.value,workspace:e.workspace},null,8,["sdks","workspace"]),Yb(C3e,null,{
default:ig((()=>[...o[2]||(o[2]=[ey(" Generating SDKs is a paid feature starting at $100/mo, learn more in our ",-1),Gb("a",{
href:"https://scalar.com/products/sdks/getting-started",target:"_blank"
}," guides",-1),ey(". ",-1)])])),_:1})])),_:1})])),_:1}))}}),M3e={
class:"text-c-2 grid grid-cols-2 gap-2.5 font-medium"},N3e=Qg({
__name:"ApiReferenceToolbarShareRegister",props:{workspace:{}},setup(e){
const t=[{icon:WE,label:"Custom Domains"},{icon:EE,label:"GitHub Sync"},{
icon:JT,label:"Markdown/MDX"},{icon:RA,label:"Password Protection"},{icon:y$,
label:"Spectral Linting"},{icon:$_,label:"JSON Schema Support"}]
;return(n,r)=>(Ub(),Qb(Mb,null,[Gb("ul",M3e,[(Ub(),Qb(Mb,null,wv(t,(e=>Gb("li",{
key:e.label,class:"flex items-center gap-2"},[(Ub(),Hb(bv(e.icon),{
class:"text-c-3 size-3.5",weight:"bold"
})),ey(" "+Uh(e.label),1)]))),64))]),Yb(P3e,{workspace:e.workspace},{
default:ig((()=>[...r[0]||(r[0]=[ey(" Deploy on Scalar ",-1)])])),_:1
},8,["workspace"]),Yb(C3e,null,{
default:ig((()=>[...r[1]||(r[1]=[ey(" Uploading documents to the Scalar Registry is a Premium feature. See what else is included in our ",-1),Gb("a",{
href:"https://scalar.com/",target:"_blank"}," guides",-1),ey(". ",-1)])])),_:1
})],64))}}),R3e=Qg({__name:"ApiReferenceToolbarShareTemporary",props:Nv({
workspace:{}},{url:{},urlModifiers:{}}),emits:["update:url"],setup(e){
const{toast:t}=CG(),n=Goe(),r=Kv(e,"url");async function o(){
if(n.isLoading||!e.workspace||r.value)return;n.start()
;const o=e.workspace.exportActiveDocument("json")
;if(!o)return t("Unable to export active document","error"),
void(await n.invalidate());try{
r.value=await $3e(o),await a(r.value),await n.validate()}catch(i){
const e=i instanceof Error?i.message:"An unknown error occurred"
;t(e,"error"),await n.invalidate()}}const{copyToClipboard:a}=PG()
;return(e,t)=>(Ub(),Qb(Mb,null,[Yb(xm($oe),{modelValue:r.value,
placeholder:`${xm("https://registry.scalar.com/share")}/apis/...`,readonly:"",
onClick:t[1]||(t[1]=e=>r.value&&xm(a)(r.value))},xv({_:2},[r.value?{
name:"aside",fn:ig((()=>[Yb(xm(ure),{class:"-m-1.5 -ml-1",icon:xm(dT),
label:"Copy link to clipboard",size:"sm",onClick:t[0]||(t[0]=e=>xm(a)(r.value))
},null,8,["icon"])])),key:"0"
}:void 0]),1032,["modelValue","placeholder"]),Yb(xm(WS),{class:"h-auto p-2.5",
disabled:!!r.value,loader:xm(n),variant:"outlined",onClick:o},{
default:ig((()=>[...t[2]||(t[2]=[ey(" Generate ",-1)])])),_:1
},8,["disabled","loader"]),Yb(C3e,{class:"-mt-1"},{
default:ig((()=>[...t[3]||(t[3]=[ey(" Shared documents will automatically be deleted after 7 days. ",-1)])])),
_:1})],64))}}),L3e=Qg({__name:"ApiReferenceToolbarShare",props:{workspace:{}},
setup:e=>(t,n)=>(Ub(),Hb(_3e,{class:"w-120"},{
label:ig((()=>[...n[0]||(n[0]=[ey("Share",-1)])])),
default:ig((()=>[Yb(xm(Xoe),null,{
label:ig((()=>[...n[1]||(n[1]=[ey("Temporary Link",-1)])])),
default:ig((()=>[Yb(R3e,{workspace:e.workspace},null,8,["workspace"])])),_:1
}),Yb(xm(Xoe),null,{label:ig((()=>[...n[2]||(n[2]=[ey("Cloud Hosting",-1)])])),
default:ig((()=>[Yb(N3e,{workspace:e.workspace},null,8,["workspace"])])),_:1
})])),_:1}))}),B3e={
class:"text-c-2 hover:text-c-1 hover:bg-b-2 flex items-center gap-1 rounded px-2 py-2.25 text-base leading-none",
type:"button"},j3e={class:"-m-2 flex flex-col gap-2 leading-relaxed"},U3e={
class:"bg-b-2 inline-flex items-center gap-0.5 rounded border px-1 py-0.5 text-sm"
},z3e='showDeveloperTools: "never"',F3e=Qg({__name:"ApiReferenceToolbarTitle",
setup(e){const{copyToClipboard:t}=PG();return(e,n)=>(Ub(),Hb(_3e,{class:"w-120",
placement:"bottom-start"},{
button:ig((()=>[Gb("button",B3e,[n[1]||(n[1]=ey(" Developer Tools ",-1)),Yb(xm(mA))])])),
info:ig((()=>[...n[5]||(n[5]=[ey(" The developer tools will only appear when running on localhost. ",-1)])])),
default:ig((()=>[Gb("div",j3e,[n[4]||(n[4]=Gb("div",null," The developer tools allow you to customize the appearance and behavior of your documentation. You can also share your documentation using the Scalar Registry. ",-1)),Gb("div",null,[n[2]||(n[2]=ey(" To disable the toolbar, set ",-1)),Gb("div",U3e,[Gb("code",{
class:"font-code"},Uh(z3e)),Yb(xm(ure),{class:"-m-1 p-1.25",icon:xm(dT),
label:"Copy link to clipboard",size:"sm",onClick:n[0]||(n[0]=e=>xm(t)(z3e))
},null,8,["icon"])]),n[3]||(n[3]=ey(" in your configuration. ",-1))])])])),_:1
}))}}),Z3e={key:0,"aria-label":"Developer Tools",
class:"api-reference-toolbar h-header bg-b-1 sticky top-0 z-10 flex justify-center border-b px-15"
},Q3e={class:"-mx-2 flex max-w-(--refs-content-max-width) flex-1 items-center"
},H3e={class:"flex flex-1 items-center"},V3e=Qg({__name:"ApiReferenceToolbar",
props:Nv({workspace:{},configuration:{}},{overrides:{},overridesModifiers:{}}),
emits:["update:overrides"],setup(e){
const t=Kv(e,"overrides"),n=Sy((()=>"always"===e.configuration?.showDeveloperTools||"never"!==e.configuration?.showDeveloperTools&&("undefined"!=typeof window&&zH(window.location.href))))
;return(r,o)=>n.value?(Ub(),
Qb("header",Z3e,[Gb("div",Q3e,[Gb("div",H3e,[Yb(F3e)]),e.workspace?(Ub(),Qb(Mb,{
key:0},[Yb(L3e,{workspace:e.workspace},null,8,["workspace"]),Yb(I3e,{
workspace:e.workspace},null,8,["workspace"])],64)):ny("",!0),Yb(E3e,{
overrides:t.value,"onUpdate:overrides":o[0]||(o[0]=e=>t.value=e),
configuration:e.configuration
},null,8,["overrides","configuration"])])])):ny("",!0)}});function q3e(e,t,n){
const r="json"===n||!xH(n)&&EX(e),o=function(e,t){
return t&&!EX(e)?O_e(WSe(e)):!t&&EX(e)?w_e(WSe(e)):e
}(e,r),a=r?".json":".yaml",i=t?t+a:"openapi"+a,s=new Blob([o],{
type:r?"application/json":"application/x-yaml"
}),l=URL.createObjectURL(s),c=document.createElement("a");c.href=l,c.download=i,
c.dispatchEvent(function(){try{return new MouseEvent("click",{bubbles:!0,
cancelable:!0,view:window})}catch{return new MouseEvent("click",{bubbles:!0,
cancelable:!0})}}()),setTimeout((()=>{window.URL.revokeObjectURL(l),c.remove()
}),100)}
const W3e=e=>"object"==typeof e&&null!==e&&!Array.isArray(e),X3e="undefined"==typeof window?{
getItem:()=>null,setItem:()=>null,removeItem:()=>null}:localStorage,G3e=()=>{
const e=ake;return{get:()=>X3e.getItem(e),set:t=>{X3e.setItem(e,t)}}},Y3e=()=>{
const e=ike,t=ske,n=(n,r)=>{return`${r}-${o=n,"schemas"===o?e:t}`;var o};return{
getSchemas:e=>{const t=JSON.parse(X3e.getItem(n("schemas",e))??"{}")
;return OUe(UZe,t)},setSchemas:(e,t)=>{
X3e.setItem(n("schemas",e),JSON.stringify(t))},getSelectedSchemes:e=>{
const t=JSON.parse(X3e.getItem(n("selectedSchemes",e))??"{}");return OUe(FZe,t)
},setSelectedSchemes:(e,t)=>{
X3e.setItem(n("selectedSchemes",e),JSON.stringify(t))}}},K3e=(e,t,n=0)=>{
if(W3e(e)&&W3e(t))for(const[r,o]of Object.entries(t))0===n&&"type"===r||("string"==typeof o&&""!==o||"number"==typeof o||"boolean"==typeof o?e[r]=o:K3e(qke(e[r]),o,n+1))
},J3e=e=>{
const t=e.workspace["x-scalar-active-document"],n=e.workspace.activeDocument
;if(!n||!t)return void console.warn("Active document not found in workspace, skipping auth schemes loading")
;const r=Y3e().getSelectedSchemes(t);if((e=>{
const t=e.workspace["x-scalar-active-document"],n=e.workspace.activeDocument
;if(!n||!t)return void console.warn("Active document not found in workspace, skipping auth secrets loading")
;const r=n.components?.securitySchemes??{},o=Y3e().getSchemas(t)
;for(const[a,i]of Object.entries(o)){const e=qke(r[a]);W3e(e)&&K3e(e,i)}
})(e),void 0!==n["x-scalar-selected-security"])return
;const o=new Set(Object.keys(n.components?.securitySchemes??{})),a=r["x-scalar-selected-security"]?.selectedSchemes,i=a?.filter((e=>((e,t)=>Object.keys(e).every((e=>t.has(e))))(e,o)))
;if(i&&i.length>0){
const e=((e,t)=>e>=t?t-1:e)(r["x-scalar-selected-security"]?.selectedIndex??0,i.length)
;n["x-scalar-selected-security"]={selectedIndex:e,selectedSchemes:i}}},e5e=e=>{
const t={hooks:{}}
;return mg([()=>e.value.onBeforeRequest,()=>e.value.onRequestSent],(([e,n])=>{
t.hooks||(t.hooks={}),t.hooks.beforeRequest=e?async t=>{const n=await e(t)
;return void 0===n?t:n}:void 0,t.hooks.responseReceived=n?e=>{n(e.request.url)
}:void 0}),{immediate:!0}),[t]},t5e=({config:e,store:t,isDarkMode:n})=>{
mg((()=>km(e).defaultHttpClient),(e=>{if(e){
const{targetKey:n,clientKey:r}=e,o=`${n}/${r}`
;AGe(o)&&t.update("x-scalar-default-client",o)}}),{immediate:!0
}),mg((()=>km(e).darkMode),(e=>t.update("x-scalar-color-mode",e?"dark":"light"))),
mg((()=>n.value),(e=>t.update("x-scalar-color-mode",e?"dark":"light")),{
immediate:!0}),km(e).metaData&&function(e,t){
const{title:n,titleTemplate:r,...o}=e;ew({title:n,titleTemplate:r,_flatMeta:o},{
...t,transform(e){const t=Kd({...e._flatMeta});return delete e._flatMeta,{...e,
meta:t}}})
}(km(e).metaData),mg((()=>km(e).proxyUrl),(e=>t.update("x-scalar-active-proxy",e)),{
immediate:!0});l2(Sy((()=>km(e).favicon)))},n5e=e=>{const t=new rTe,n={}
;if(!e)return n;return(Array.isArray(e)?e:[e]).flatMap((e=>{
if(t=e,Boolean(!Array.isArray(t)&&t&&"sources"in t&&Array.isArray(t.sources))){
const{sources:t,...n}=e;return t?.map((e=>({...n,...e})))??[]}var t;return[e]
})).map((e=>{const t=$d.safeParse(e);return t.success?t.data:null
})).filter((e=>!(!e||!e.url&&!e.content))).map(((e,n)=>o5e(e,n,t))).forEach((e=>{
const{url:t,content:r,...o}=e;n[e.slug]={config:o,title:e.title,slug:e.slug,
default:!!e?.default,source:r?{content:r5e(r)??{}}:{url:t}}})),n
},r5e=e=>e?"function"==typeof e?r5e(e()):"string"==typeof e?(e=>{
if("string"!=typeof e)return e;const t=TX.parseSafe(e,null);if(t)return t
;if(e.length>0&&["{","["].includes(e[0]??""))throw Error("Invalid JSON or YAML")
;return _X.parseSafe(e,(e=>{throw Error(e)}))
})(e):e:null,o5e=(e,t=0,n)=>e.title?{...e,slug:e.slug||n.slug(e.title),
title:e.title}:e.slug?{...e,slug:n.slug(e.slug),title:e.slug}:{...e,
slug:`api-${t+1}`,title:`API #${t+1}`
},a5e=({debounceDelay:e=500,maxWait:t=1e4,prefix:n="",persistAuth:r=!1})=>{
const{execute:o}=TSe({delay:e,maxWait:t
}),a=Y3e(),i=G3e(),s=()=>"string"==typeof n?n:n();return{hooks:{
onWorkspaceStateChanges(e){if("meta"!==e.type){if("documents"===e.type){
if(!("function"==typeof r?r():r))return
;const{path:t,value:n}=e,{securitySchemes:i={}}=n.components??{}
;"components"===t[0]&&"securitySchemes"===t[1]&&o("x-scalar-security-schemes",(()=>a.setSchemas(s(),i)))
;const l=n["x-scalar-selected-security"]
;"x-scalar-selected-security"===t[0]&&l&&o("x-scalar-selected-security-schemes",(()=>a.setSelectedSchemes(s(),{
"x-scalar-selected-security":l})))}}else{
const t=e.value["x-scalar-default-client"]
;void 0!==t&&o("x-scalar-default-client",(()=>i.set(t)))}}}}},i5e={key:1,
class:"flex flex-col p-3 pt-1.5"},s5e={key:1},l5e=["aria-label"],c5e={
class:"w-64 *:!p-0 empty:hidden"},u5e={key:1,class:"references-footer"},d5e=Qg({
__name:"ApiReference",props:{configuration:{}},setup(e,{expose:t}){
const n=e,{mediaQueries:r}=K_e(),{copyToClipboard:o}=PG(),a=!1,i=Sy(I_e),s=H_e({
debug:a}),l=bm(!1);mg((()=>r?.lg?.value),((e,t)=>{t&&!e&&(l.value=!1)
})),function(e){cg(ow,e)}((()=>Hg()))
;const c=Sy((()=>n5e(n.configuration))),u=Sy((()=>Object.keys(c.value).length>1)),d=bm(Object.values(c.value).find((e=>e.default))?.slug??c.value[Object.keys(c.value)?.[0]??""]?.slug??"")
;if("undefined"!=typeof window){
const e=new URL(window.location.href),t=e.searchParams.get("api")
;if(t&&c.value[t]){d.value=t
;const n=r8e(e,c.value[t].config.pathRouting?.basePath,t),r=o8e(n,c.value[t].config.pathRouting?.basePath,u.value)
;r&&(r.searchParams.delete("api"),
window.history.replaceState({},"",r.toString()))}
const n=Object.values(c.value).map((e=>e.config.pathRouting?.basePath)),r=r8e(e,n.find((t=>t&&e.pathname.startsWith(t.startsWith("/")?t:`/${t}`))),u.value?void 0:d.value).split("/")[0]
;r&&c.value[r]&&(d.value=r)}const p=Sy((()=>Object.values(c.value).map((e=>({
label:e.title,id:e.slug}))))),h=bm({}),f=Sy((()=>({...Cd.parse({}),
...c.value[d.value]?.config,...h.value
}))),m=Sy((()=>f.value.pathRouting?.basePath)),g=Sy((()=>((e,t)=>{
const{fonts:n=!0,layer:r="scalar-theme"}=t??{},o=[R_e[e||"default"]?.theme??D_e,n?'/* Inter (--scalar-font) */\n/* cyrillic-ext */\n@font-face {\n  font-family: "Inter";\n  font-style: normal;\n  font-weight: 100 900;\n  font-display: swap;\n  src: url(https://fonts.scalar.com/inter-cyrillic-ext.woff2) format("woff2");\n  unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;\n}\n/* cyrillic */\n@font-face {\n  font-family: "Inter";\n  font-style: normal;\n  font-weight: 100 900;\n  font-display: swap;\n  src: url(https://fonts.scalar.com/inter-cyrillic.woff2) format("woff2");\n  unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;\n}\n/* greek-ext */\n@font-face {\n  font-family: "Inter";\n  font-style: normal;\n  font-weight: 100 900;\n  font-display: swap;\n  src: url(https://fonts.scalar.com/inter-greek-ext.woff2) format("woff2");\n  unicode-range: U+1F00-1FFF;\n}\n/* greek */\n@font-face {\n  font-family: "Inter";\n  font-style: normal;\n  font-weight: 100 900;\n  font-display: swap;\n  src: url(https://fonts.scalar.com/inter-greek.woff2) format("woff2");\n  unicode-range: U+0370-0377, U+037A-037F, U+0384-038A, U+038C, U+038E-03A1, U+03A3-03FF;\n}\n/* vietnamese */\n@font-face {\n  font-family: "Inter";\n  font-style: normal;\n  font-weight: 100 900;\n  font-display: swap;\n  src: url(https://fonts.scalar.com/inter-vietnamese.woff2) format("woff2");\n  unicode-range:\n    U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169,\n    U+01A0-01A1, U+01AF-01B0, U+0300-0301, U+0303-0304, U+0308-0309, U+0323,\n    U+0329, U+1EA0-1EF9, U+20AB;\n}\n/* latin-ext */\n@font-face {\n  font-family: "Inter";\n  font-style: normal;\n  font-weight: 100 900;\n  font-display: swap;\n  src: url(https://fonts.scalar.com/inter-latin-ext.woff2) format("woff2");\n  unicode-range:\n    U+0100-02AF, U+0304, U+0308, U+0329, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F,\n    U+A720-A7FF;\n}\n/* latin */\n@font-face {\n  font-family: "Inter";\n  font-style: normal;\n  font-weight: 100 900;\n  font-display: swap;\n  src: url(https://fonts.scalar.com/inter-latin.woff2) format("woff2");\n  unicode-range:\n    U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA,\n    U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+2074, U+20AC, U+2122, U+2191,\n    U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\n}\n/* keyboard symbols (←↑→↓↵⇧⇪⌘⌥) */\n@font-face {\n  font-family: "Inter";\n  font-style: normal;\n  font-weight: 100 900;\n  font-display: swap;\n  src: url(https://fonts.scalar.com/inter-symbols.woff2) format("woff2");\n  unicode-range: U+2190-2193, U+21B5, U+21E7, U+21EA, U+2318, U+2325;\n}\n/* JetBrains Mono (--scalar-font-code) */\n/* cyrillic-ext */\n@font-face {\n  font-family: "JetBrains Mono";\n  font-style: normal;\n  font-weight: 400;\n  src: url(https://fonts.scalar.com/mono-cyrillic-ext.woff2) format("woff2");\n  unicode-range: U+0460-052F, U+1C80-1C88, U+20B4, U+2DE0-2DFF, U+A640-A69F, U+FE2E-FE2F;\n}\n/* cyrillic */\n@font-face {\n  font-family: "JetBrains Mono";\n  font-style: normal;\n  font-weight: 400;\n  src: url(https://fonts.scalar.com/mono-cyrillic.woff2) format("woff2");\n  unicode-range: U+0301, U+0400-045F, U+0490-0491, U+04B0-04B1, U+2116;\n}\n/* greek */\n@font-face {\n  font-family: "JetBrains Mono";\n  font-style: normal;\n  font-weight: 400;\n  src: url(https://fonts.scalar.com/mono-greek.woff2) format("woff2");\n  unicode-range: U+0370-0377, U+037A-037F, U+0384-038A, U+038C, U+038E-03A1, U+03A3-03FF;\n}\n/* vietnamese */\n@font-face {\n  font-family: "JetBrains Mono";\n  font-style: normal;\n  font-weight: 400;\n  src: url(https://fonts.scalar.com/mono-vietnamese.woff2) format("woff2");\n  unicode-range:\n    U+0102-0103, U+0110-0111, U+0128-0129, U+0168-0169,\n    U+01A0-01A1, U+01AF-01B0, U+0300-0301, U+0303-0304, U+0308-0309, U+0323,\n    U+0329, U+1EA0-1EF9, U+20AB;\n}\n/* latin-ext */\n@font-face {\n  font-family: "JetBrains Mono";\n  font-style: normal;\n  font-weight: 400;\n  src: url(https://fonts.scalar.com/mono-latin-ext.woff2) format("woff2");\n  unicode-range:\n    U+0100-02AF, U+0304, U+0308, U+0329, U+1E00-1E9F, U+1EF2-1EFF, U+2020, U+20A0-20AB, U+20AD-20C0, U+2113, U+2C60-2C7F,\n    U+A720-A7FF;\n}\n/* latin */\n@font-face {\n  font-family: "JetBrains Mono";\n  font-style: normal;\n  font-weight: 400;\n  src: url(https://fonts.scalar.com/mono-latin.woff2) format("woff2");\n  unicode-range:\n    U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA,\n    U+02DC, U+0304, U+0308, U+0329, U+2000-206F, U+2074, U+20AC, U+2122, U+2191,\n    U+2193, U+2212, U+2215, U+FEFF, U+FFFD;\n}\n':""].join("")
;return r?`@layer ${r} {\n${o}}`:o})(f.value.theme,{
fonts:f.value.withDefaultFonts})));if(cg(F1e,z1e({
plugins:Object.values(c.value).flatMap((e=>e.config.plugins??[]))
})),f.value.redirect&&"undefined"!=typeof window){
const e=f.value.redirect((f.value.pathRouting?window.location.pathname:"")+window.location.hash)
;e&&window.history.replaceState({},"",e)}const v=E0e({plugins:[a5e({
prefix:()=>d.value,persistAuth:()=>f.value.persistAuth??!1})]
}),{toggleColorMode:b,isDarkMode:y}=UG({initialColorMode:{true:"dark",
false:"light",undefined:"system"}[String(f.value.darkMode)],
overrideColorMode:f.value.forceDarkModeState
}),O=Sy((()=>Object.entries(v.workspace.documents).map((([e,t])=>({id:e,
type:"document",description:t.info.description,name:t.info.title??e,
title:t.info.title??e,children:t?.["x-scalar-navigation"]?.children??[]
}))))),w=UBe(O,{hooks:{}}),x=e=>{e.forEach((e=>{
"tag"!==e.type&&"models"!==e.type||w.setExpanded(e.id,!0),
"children"in e&&e.children&&x(e.children)}))},k=Sy((()=>{const e=f.value
;if(!e)return[];const t=w.items.value.find((e=>e.id===d.value))?.children??[]
;if(e.defaultOpenAllTags&&x(t),e.expandAllModelSections){
const e=t.find((e=>"models"===e.type))
;e&&(w.setExpanded(e.id,!0),e.children?.forEach((e=>{w.setExpanded(e.id,!0)})))}
return t.filter((t=>!e.hideModels||"models"!==t.id))
})),S=Sy((()=>k.value.find((e=>"text"===e.type&&"Introduction"===e.title))?.id)),_=bm(""),T=Sy((()=>({
breadcrumb:_.value}))),E=e=>{const t=w.getEntryById(e)
;t&&"document"!==t.type?_.value=t.title:_.value=""},A=e=>{E(e),w.setSelected(e),
g8e(e,w.setExpanded,w.getEntryById)};t5e({config:()=>f.value,store:v,
isDarkMode:y});const C=Sy((()=>OJe(v,v.workspace.activeDocument??null)))
;"undefined"!=typeof window&&(window.dataDumpWorkspace=()=>v),t({eventBus:s,
workspaceStore:v});const $=async(e,t)=>{const n=c.value[e]
;if(!n)return void console.warn(`Document ${e} not found in configList`)
;const r={...n.config,...h.value},o=r.onDocumentSelect?.();!function(e,t,n){
const r=o8e(t||e,n.pathRouting?.basePath,u.value)
;r&&window.history.replaceState({},"",r.toString()),d.value=e
}(e,t,r),I.value?.route({documentSlug:e,method:"get",path:"/"})
;if(!v.workspace.documents[e]&&await v.addDocument(n.source.url?{name:e,
url:n.source.url,fetch:r.fetch}:{name:e,document:n.source.content??{}
},r),v.update("x-scalar-active-document",e),r.persistAuth&&J3e(v),(async()=>{
await o,r.onLoaded?.(e)})(),t&&t!==e)A(t);else{
const e=k.value.find((e=>"tag"===e.type));e&&w.setExpanded(e.id,!0)}}
;mg((()=>Object.values(c.value)),(async(e,t)=>{const n=async(e,t)=>{
v.workspace.documents[e.slug]&&(e.source.url&&e.source.url!==t?.source.url?await v.addDocument({
name:e.slug,url:e.source.url,fetch:e.config.fetch
},e.config):e.source.content&&C0e(e.source.content,t&&"content"in t.source?t.source.content??{}:{}).length&&await v.addDocument({
name:e.slug,document:e.source.content},e.config))};e.forEach(((e,r)=>n(e,t[r])))
;const r=e.map((e=>e.slug)),o=t.map((e=>e.slug))
;r.length===o.length&&r.every(((e,t)=>e===o[t]))||await $(r[0]??"")}),{deep:!0
}),dv((()=>$(d.value))),av((async()=>{(e=>{const t=G3e().get()
;AGe(t)&&!e.workspace["x-scalar-default-client"]&&e.update("x-scalar-default-client",t)
})(v),
await $(d.value,r8e(window.location.href,c.value[d.value]?.config.pathRouting?.basePath,u.value?void 0:d.value))
}));const P=Sy((()=>c.value[d.value]?.source?.url)),D=qg("modal"),I=bm(null)
;iv((()=>{D.value&&(I.value=o0e({el:D.value,eventBus:s,workspaceStore:v,
options:f,plugins:e5e(f)}))})),cv((()=>{I.value?.app.unmount()
})),s.on("server:update:selected",(({url:e})=>f.value.onServerChange?.(e))),
s.on("ui:download:document",(async({format:e})=>{if("direct"===e){
const e=c.value[d.value]?.source?.url
;if(!e)return void console.error("Direct download is not supported for documents without a URL source")
;const t=await fetch(VH(f.value.proxyUrl,e)).then((e=>e.text()))
;return void q3e(t,d.value??"openapi")}const t=v.exportActiveDocument(e)
;t?q3e(t,d.value??"openapi",e):console.error("No document found to download")}))
;const M=(e,t)=>{const n=w.getEntryById(e)
;if(("tag"===n?.type||"models"===n?.type)&&w.isExpanded(e)){const t=p8e()
;return w.setExpanded(e,!1),void t()}
"tag"!==n?.type&&"models"!==n?.type&&(l.value=!1),A(e)
;const r=o8e(e,m.value,u.value)
;r&&(window.history.pushState({},"",r),"sidebar"===t&&f.value.onSidebarClick?.(r.toString()))
}
;s.on("select:nav-item",(({id:e})=>M(e))),s.on("scroll-to:nav-item",(({id:e})=>M(e))),
s.on("intersecting:nav-item",(({id:e})=>{if(!h8e.value)return
;w.setSelected(e),E(e);const t=o8e(e,m.value,u.value)
;t&&v.workspace.activeDocument&&window.history.replaceState({},"",t.toString())
})),s.on("toggle:nav-item",(({id:e,open:t})=>{
t&&f.value.onShowMore?.(e),w.setExpanded(e,t??!w.isExpanded(e))
})),s.on("copy-url:nav-item",(({id:e})=>{
const t=o8e(e,m.value,u.value)?.toString();return t&&o(t)})),av((()=>{
window.history.scrollRestoration="manual",
oae(),window.addEventListener("popstate",(()=>{
const e=r8e(window.location.href,f.value.pathRouting?.basePath,u.value?void 0:d.value)
;e&&A(e)}))}));const N=qg("documentStartRef");s1e(N,(()=>{
s.emit("intersecting:nav-item",{id:d.value})}));const R=Sy((()=>{
const e=v.workspace["x-scalar-color-mode"]
;return"system"===e?"undefined"==typeof window||"function"!=typeof window?.matchMedia?"light":window.matchMedia("(prefers-color-scheme: dark)").matches?"dark":"light":e
}));return(e,t)=>(Ub(),Qb("div",null,[(Ub(),Hb(bv("style"),null,{
default:ig((()=>[ey(Uh(f.value.customCss)+" "+Uh(g.value),1)])),_:1
})),Gb("div",{ref:"documentEl",
class:Ih(["scalar-app scalar-api-reference references-layout",[{
"scalar-api-references-standalone-mobile":f.value.showSidebar,
"scalar-scrollbars-obtrusive":i.value,"references-editable":f.value.isEditable,
"references-sidebar":f.value.showSidebar,
"references-sidebar-mobile-open":l.value,
"references-classic":"classic"===f.value.layout},e.$attrs.class]])
},["modern"===f.value.layout?(Ub(),Hb(t3e,{key:0,breadcrumb:_.value,
isSidebarOpen:l.value,showSidebar:f.value.showSidebar,
onToggleSidebar:t[2]||(t[2]=()=>l.value=!l.value)},{
search:ig((()=>[f.value.hideSearch?ny("",!0):(Ub(),Hb(g3e,{key:0,class:"my-2",
document:xm(v).workspace.activeDocument,eventBus:xm(s),
hideModels:f.value.hideModels,searchHotKey:f.value.searchHotKey,
showSidebar:f.value.showSidebar
},null,8,["document","eventBus","hideModels","searchHotKey","showSidebar"]))])),
sidebar:ig((({sidebarClasses:n})=>[f.value.showSidebar&&"modern"===f.value.layout?(Ub(),
Hb(xm(BBe),{key:0,
"aria-label":`Sidebar for ${xm(v).workspace.activeDocument?.info?.title}`,
class:Ih(["t-doc__sidebar",n]),isExpanded:xm(w).isExpanded,
isSelected:xm(w).isSelected,items:k.value,layout:"reference",options:f.value,
role:"navigation",onSelectItem:t[1]||(t[1]=e=>M(e,"sidebar"))},{
header:ig((()=>[p.value.length>1?(Ub(),Hb(a3e,{key:0,modelValue:d.value,
options:p.value,"onUpdate:modelValue":$
},null,8,["modelValue","options"])):ny("",!0),f.value.hideSearch?ny("",!0):(Ub(),
Qb("div",i5e,[Yb(g3e,{document:xm(v).workspace.activeDocument,eventBus:xm(s),
hideModels:f.value.hideModels,searchHotKey:f.value.searchHotKey
},null,8,["document","eventBus","hideModels","searchHotKey"])])),kv(e.$slots,"sidebar-start",Mh(Kb(T.value)),void 0,!0)])),
footer:ig((()=>[kv(e.$slots,"sidebar-end",Mh(Kb(T.value)),(()=>[Yb(xm(noe),{
class:"darklight-reference"},{
toggle:ig((()=>[f.value.hideDarkModeToggle||f.value.forceDarkModeState?(Ub(),
Qb("span",s5e)):(Ub(),Hb(xm(QG),{key:0,modelValue:"dark"===R.value,
"onUpdate:modelValue":t[0]||(t[0]=()=>xm(b)())},null,8,["modelValue"]))])),
default:ig((()=>[f.value.hideClientButton?ny("",!0):(Ub(),Hb(xm(lae),{key:0,
buttonSource:"sidebar",integration:f.value._integration,isDevelopment:xm(a),
url:P.value},null,8,["integration","isDevelopment","url"]))])),_:1})]),!0)])),
_:3
},8,["aria-label","class","isExpanded","isSelected","items","options"])):ny("",!0)])),
_:3},8,["breadcrumb","isSidebarOpen","showSidebar"])):ny("",!0),Gb("main",{
"aria-label":`Open API Documentation for ${xm(v).workspace.activeDocument?.info?.title}`,
class:"references-rendered"},[Yb(Y6e,{document:xm(v).workspace.activeDocument,
environment:C.value,eventBus:xm(s),expandedItems:xm(w).expandedItems.value,
headingSlugGenerator:f.value.generateHeadingSlug??(e=>`${d.value}/description/${e.slug}`),
infoSectionId:S.value??"description/introduction",items:k.value,options:f.value,
xScalarDefaultClient:xm(v).workspace["x-scalar-default-client"]},xv({
start:ig((()=>[xm(v).workspace.activeDocument&&xm(r).lg.value?(Ub(),Hb(V3e,{
key:0,overrides:h.value,"onUpdate:overrides":t[3]||(t[3]=e=>h.value=e),
configuration:f.value,workspace:xm(v)
},null,8,["overrides","configuration","workspace"])):ny("",!0),Gb("div",{
ref_key:"documentStartRef",ref:N
},null,512),"classic"===f.value.layout?(Ub(),Hb(M0e,{key:1},{
"dark-mode-toggle":ig((()=>[f.value.hideDarkModeToggle||f.value.forceDarkModeState?ny("",!0):(Ub(),
Hb(xm(FG),{key:0,class:"text-c-2 hover:text-c-1",mode:R.value,style:{
transform:"scale(1.4)"},variant:"icon",onClick:t[4]||(t[4]=()=>xm(b)())
},null,8,["mode"]))])),
default:ig((()=>[Gb("div",c5e,[p.value.length>1?(Ub(),Hb(a3e,{key:0,
modelValue:d.value,options:p.value,"onUpdate:modelValue":$
},null,8,["modelValue","options"])):ny("",!0)]),f.value.hideSearch?ny("",!0):(Ub(),
Hb(g3e,{key:0,class:"t-doc__sidebar max-w-64",
document:xm(v).workspace.activeDocument,eventBus:xm(s),
hideModels:f.value.hideModels,searchHotKey:f.value.searchHotKey
},null,8,["document","eventBus","hideModels","searchHotKey"]))])),_:1
})):ny("",!0),kv(e.$slots,"content-start",Mh(Kb(T.value)),void 0,!0)])),
end:ig((()=>[kv(e.$slots,"content-end",Mh(Kb(T.value)),void 0,!0)])),_:2
},[f.value.isEditable?{name:"empty-state",
fn:ig((()=>[kv(e.$slots,"editor-placeholder",Mh(Kb(T.value)),void 0,!0)])),
key:"0"
}:void 0]),1032,["document","environment","eventBus","expandedItems","headingSlugGenerator","infoSectionId","items","options","xScalarDefaultClient"])],8,l5e),e.$slots.footer?(Ub(),
Qb("div",u5e,[kv(e.$slots,"footer",Mh(Kb(T.value)),void 0,!0)])):ny("",!0),Gb("div",{
ref_key:"modal",ref:D},null,512)],2),Yb(xm($G))]))}
}),p5e=$0e(d5e,[["__scopeId","data-v-097f69f2"]]),h5e=e=>e.getElementById("api-reference")
;const f5e=(e,t)=>{let n=null;const r=h5e(e);return r?(n=e.createElement("div"),
r?.parentNode?.insertBefore(n,r)):t&&(n=t),n},m5e=(e,t)=>{
const n="scalar-refs",r=am({configuration:t??e??{}});let o=HO((()=>_y(p5e,r)))
;if(o.use(GO()),o.config.idPrefix=n,t){
const t="string"==typeof e?document.querySelector(e):e
;t?o.mount(t):console.error("Could not find a mount point for API References:",e)
}document.addEventListener("scalar:reload-references",(()=>{
if(console.warn("scalar:reload-references event has been deprecated, please use the scalarInstance.app.mount method instead."),
!r.configuration)return;const t="string"==typeof e?document.querySelector(e):e
;t&&(t&&!document.body.contains(t)&&document.body.appendChild(t),
o.unmount(),o=HO((()=>_y(p5e,r))),o.use(GO()),o.config.idPrefix=n,o.mount(t))
}),!1);const a=()=>{r.configuration={},o.unmount()}
;document.addEventListener("scalar:destroy-references",(()=>{
console.warn("scalar:destroy-references event has been deprecated, please use scalarInstance.destroy instead."),
a()}),!1),document.addEventListener("scalar:update-references-config",(e=>{
console.warn("scalar:update-references-config event has been deprecated, please use scalarInstance.updateConfiguration instead."),
"detail"in e&&Object.assign(r,e.detail)}),!1);return{app:o,
getConfiguration:()=>r.configuration??{},updateConfiguration:e=>{
r.configuration=e},destroy:a}}
;console.info("@scalar/api-reference@1.43.15"),"object"==typeof window&&(window.Scalar={
createApiReference:m5e}),function(e,t){
const n=e.querySelector("[data-spec]"),r=e.querySelector("[data-spec-url]")
;t?.darkMode?e.body?.classList.add("dark-mode"):e.body?.classList.add("light-mode")
;const o=f5e(e,n||r);o&&m5e(o,t)}(document,function(e){
const t=e.querySelector("[data-spec]"),n=e.querySelector("[data-spec-url]"),r=e.querySelector("#api-reference[data-configuration]"),o=()=>{
if(r){const e=r.getAttribute("data-configuration");if(e)return{
_integration:"html",...JSON.parse(e.split("&quot;").join('"'))}}
return $d.parse({_integration:"html"})},a=()=>{if(o().url)return o().url
;if(o().spec?.url)return o().spec?.url;const t=h5e(e);if(t){
const e=t.getAttribute("data-url")?.trim();if(e)return e}if(n){
console.warn('[@scalar/api-reference] The [data-spec-url] HTML API is deprecated. Use the new <script id="api-reference" data-url="/scalar.json" /> API instead.')
;const e=n.getAttribute("data-spec-url");if(e)return e}},i=()=>{const n=h5e(e)
;if(n){const e=n.innerHTML?.trim();if(e)return e}if(t){
console.warn('[@scalar/api-reference] The [data-spec] HTML API is deprecated. Use the new <script id="api-reference" type="application/json">{"openapi":"3.1.0","info":{"title":"Example"},"paths":{}}<\/script> API instead.')
;const e=t.getAttribute("data-spec")?.trim();if(e)return e}},s=()=>{
const t=h5e(e);if(t){const e=t.getAttribute("data-proxy-url")
;if(e)return e.trim()}};if(n||t||h5e(e)){const e=i()?{content:i()}:{url:a()}
;return $d.parse({_integration:"html",proxyUrl:s(),...o(),...e})}
return $d.parse({_integration:"html"})}(document))}));
